<?php
/**
 * WP Staging | Restore.
 *
 * A standalone script to extract and restore backups.
 * This is a compressed, compiled script based on PHP, JS code, CSS and HTML.
 * If you are a developer who would like to get your hands on the sources of this file, please contact us at support@wp-staging.com.
 *
 * Version      : 1.0.4
 * Build Id     : 7a7d92e1f27e
 * Build Date   : Feb 24, 2025 18:23:09 UTC
 * Support      : https://wp-staging.com/support/
 */
namespace { !getenv('wpstg-restorer-as-library') && exit; /**@wpstg-restorer-halt**/ }
namespace {
    if (version_compare(PHP_VERSION, '7.0', '<')) {
        exit("WP Staging Restore requires at least PHP version 7.0, current version " . PHP_VERSION . ".\n");
    }
    if (!getenv('wpstg-restorer-as-library') && (defined('ABSPATH') || defined('WPSTG_RESTORER'))) {
        exit("WP Staging Restore should run as a standalone.\n");
    }
    define('WPSTG_RESTORER', true);
    date_default_timezone_set('UTC');
    final class WPStagingRestorer
    {
        const MAX_MEMORY = 268435456;
        const MAX_TIMEOUT = 180;
        const MAX_TIMEOUT_EXTRACT = 60;
        const MAX_TIMEOUT_RESTORE = 60;
        const CHMOD_DIR = 0755;
        const CHMOD_FILE = 0644;
        const KB_IN_BYTES = 1024;
        const MB_IN_BYTES = 1048576;
        const GB_IN_BYTES = 1073741824;
        const EXTRACTION_THRESHOLD_PERCENTAGE_LIMIT = 85;
        private $appFile = 'wpstg-restore.php';
        private $buildId = '7a7d92e1f27e';
        private $version = '1.0.4';
        private $backupVersion = '2.0.0';
        private $backupDir = 'wp-staging/backups';
        private $rootPath = null;
        private $uploadPath = null;
        private $backupPath = null;
        private $tmpPath = null;
        private $cachePath = null;
        private $logFile = null;
        private $dataServer = [];
        private $dataCookie = [];
        private $dataPost = [];
        private $dataGet = [];
        private $dataRequest = [];
        private $error = [];
        private $timerStart = null;
        private $maxProcessingTime = 10;
        private $wpCoreHandle = null;
        private $accessHandle = null;
        private $activateHandle = null;
        private $extractorHandle = null;
        private $restorerHandle = null;
        private $cacheHandle = null;
        private $fileHandle = null;
        private $pathIdentifier = null;
        private $viewHandle = null;
        private $backupListingHandle = null;
        private $classResolverHandle;
        public function __construct()
        {
            $this->timerStart = microtime(true);
            $this->rootPath   = realpath(__DIR__);
            $this->tmpPath    = $this->rootPath . '/wpstg-restore';
            $this->cachePath  = $this->tmpPath . '/cache';
            $this->uploadPath = $this->rootPath . '/wp-content/uploads';
            $this->backupPath = $this->uploadPath . '/' . $this->backupDir;
            $this->logFile    = $this->tmpPath . '/' . $this->setLogFilename();
            $this->captureFatalError();
            $this->setMaxResource();
            $this->classResolverHandle = new \WpstgRestorer\ClassResolver();
        }
        public function databaseImporterBindings()
        {
            $this->classResolverHandle->bindInstance(\WpstgRestorer\QueryInserter::class, $this->makeInstance(\WpstgRestorer\ExtendedInserterWithoutTransaction::class));
            $this->classResolverHandle->bindInstance(\WpstgRestorer\SubsiteManagerInterface::class, $this->makeInstance(\WpstgRestorer\SubsiteManager::class));
        }
        public function getPathIdentifier()
        {
            if ($this->pathIdentifier === null) {
                $this->pathIdentifier = $this->makeInstance(\WpstgRestorer\PathIdentifier::class);
            }
            return $this->pathIdentifier;
        }
        public function setMeta($key, $value)
        {
            if (property_exists($this, $key)) {
                $this->{$key} = $value;
            }
        }
        public function getMeta()
        {
            return (object)[
                'timerStart'        => $this->timerStart,
                'appFile'           => $this->appFile,
                'buildId'           => $this->buildId,
                'version'           => $this->version,
                'backupVersion'     => $this->backupVersion,
                'backupDir'         => $this->backupDir,
                'rootPath'          => $this->rootPath,
                'uploadPath'        => $this->uploadPath,
                'backupPath'        => $this->backupPath,
                'tmpPath'           => $this->tmpPath,
                'cachePath'         => $this->cachePath,
                'maxProcessingTime' => $this->maxProcessingTime,
                'dataServer'        => $this->dataServer,
                'dataCookie'        => $this->dataCookie,
                'dataPost'          => $this->dataPost,
                'dataGet'           => $this->dataGet,
                'dataRequest'       => $this->dataRequest,
            ];
        }
        public function getHandle(string $caller, $useHandle = null)
        {
            $handles = [
                'access'        => $this->accessHandle,
                'activate'      => $this->activateHandle,
                'cache'         => $this->cacheHandle,
                'file'          => $this->fileHandle,
                'wpcore'        => $this->wpCoreHandle,
                'extractor'     => $this->extractorHandle,
                'restorer'      => $this->restorerHandle,
                'backupListing' => $this->backupListingHandle,
            ];
            $callerKey = strtolower(str_replace('WpstgRestorer\\', '', $caller));
            if (empty($useHandle) && array_key_exists($callerKey, $handles)) {
                unset($handles[$callerKey]);
            }
            $useHandle = array_fill_keys((array)$useHandle, 1);
            if (array_key_exists($callerKey, $handles) && array_key_exists($callerKey, $useHandle)) {
                throw new \LogicException(sprintf('Invalid caller: %s', $caller));
            }
            if ($handleKeys = array_intersect_key($handles, $useHandle)) {
                $handles = $handleKeys;
            }
            foreach ($handles as $name => $object) {
                if ($object === null) {
                    $classHandle    = new \ReflectionClass("WpstgRestorer\\" . $name);
                    $handles[$name] = $classHandle->newInstance($this);
                }
            }
            return (object)$handles;
        }
        public function makeInstance(string $id, bool $useCache = true)
        {
            return $this->classResolverHandle->resolve($id, $useCache);
        }
        public function bindInstance(string $id, $instance)
        {
            $this->classResolverHandle->bindInstance($id, $instance);
        }
        public function getBackupMetadata(string $filePath): \WpstgRestorer\BackupMetadata
        {
            $filePathCache  = $this->cacheHandle->getCacheFile($filePath, 'backupmeta');
            $backupMetadata = new \WpstgRestorer\BackupMetadata();
            if (($data = $this->cacheHandle->get($filePath, 'backupmeta', $filePathCache)) !== null) {
                $backupMetadata->hydrate($data);
                return $backupMetadata;
            }
            $backupMetadata->hydrateByFilePath($filePath);
            return $backupMetadata;
        }
        private function setLogFilename(): string
        {
            $host  = empty($_SERVER['HTTP_HOST']) ? 'localhost' : $_SERVER['HTTP_HOST'];
            $stamp = date('Ymd');
            return 'wpstg-restore-' . substr(md5($stamp . $host . $stamp), 0, 12) . '-' . $stamp . '.log';
        }
        private function hasHttps(): bool
        {
            if (!empty($this->dataServer['HTTP_CF_VISITOR'])) {
                $cfVisitorObject = json_decode($this->dataServer['HTTP_CF_VISITOR']);
                if (isset($cfVisitorObject->schema) && $cfVisitorObject->schema === 'https') {
                    return true;
                }
            }
            if (!empty($this->dataServer['HTTP_X_FORWARDED_PROTO']) && $this->dataServer['HTTP_X_FORWARDED_PROTO'] === 'https') {
                return true;
            }
            if (!empty($this->dataServer['HTTPS']) && in_array(strtolower($this->dataServer['HTTPS']), ['on', '1'])) {
                return true;
            }
            if (!empty($this->dataServer['SERVER_PORT']) && (int)$this->dataServer['SERVER_PORT'] === 443) {
                return true;
            }
            return false;
        }
        public function siteUrl(): string
        {
            if (empty($this->dataServer['HTTP_HOST']) || empty($this->dataServer['SCRIPT_FILENAME']) || empty($this->dataServer['PHP_SELF']) || empty($this->dataServer['REQUEST_URI'])) {
                return '';
            }
            $schema            = $this->hasHttps() ? 'https://' : 'http://';
            $url               = $schema . $this->dataServer['HTTP_HOST'];
            $scriptFilenameDir = dirname($this->dataServer['SCRIPT_FILENAME']);
            $path              = '';
            if ($this->rootPath === $scriptFilenameDir . '/') {
                $path = preg_replace('@/[^/]*$@i', '', $this->dataServer['PHP_SELF']);
                return rtrim($url . $path, '/');
            }
            if (strpos($this->rootPath, $scriptFilenameDir) !== false) {
                $subDirectory = substr($this->rootPath, strpos($this->rootPath, $scriptFilenameDir) + strlen($scriptFilenameDir));                $path         = preg_replace('@/[^/]*$@i', '', $this->dataServer['REQUEST_URI']) . $subDirectory;
            } else {
                $path = $this->dataServer['REQUEST_URI'];
            }
            return rtrim($url . $path, '/');
        }
        public function userAgent(): string
        {
            $url = $this->siteUrl();
            if (empty($url)) {
                $url = 'https://wp-staging.com/';
            }
            return 'Mozilla/5.0 (compatible; wpstg-restorer/' . $this->version . '; +' . $url . ')';
        }
        private function requirementCheck(): bool
        {
            if (!is_writable($this->rootPath)) {
                $this->error['rootpath-writable'] = 'Current working directory is not writable.';
            }
            if (!class_exists('ZipArchive')) {
                $this->error['zip-ext'] = 'PHP ZipArchive extension is not available.';
            }
            if (!extension_loaded('curl') || !function_exists('curl_init')) {
                $this->error['curl-ext'] = 'PHP cURL extension is not available.';
            }
            if (!extension_loaded('mysqli') || !class_exists('mysqli')) {
                $this->error['mysqli-ext'] = 'PHP mysqli extension is not available.';
            }
            return empty($this->error);
        }
        public function getBootupError(): array
        {
            return $this->error;
        }
        public function addBootupError(string $key, string $text): array
        {
            $this->error[$key] = $text;
            return $this->error;
        }
        private function createWorkingDir(): bool
        {
            if (!empty($this->error)) {
                return false;
            }
            clearstatcache();
            if (is_dir($this->tmpPath) && is_dir($this->cachePath)) {
                return true;
            }
            if (!$this->mkdir($this->tmpPath)) {
                $this->error['tmp-dir'] = "Can't create working directory";
                return false;
            }
            if (!$this->mkdir($this->cachePath)) {
                $this->error['cache-dir'] = "Can't create cache directory";
                return false;
            }
            $this->fileHandle->preventAccessToDirectory($this->tmpPath);
            $this->fileHandle->preventAccessToDirectory($this->cachePath);
            return true;
        }
        public function setDateTime(\DateTime $dateTime): string
        {
            $defaultDateFormat = 'M j, Y';
            $defaultTimeFormat = 'H:i:s';
            if (!function_exists('get_date_from_gmt') || !function_exists('get_option')) {
                return $dateTime->format($defaultDateFormat . ' ' . $defaultTimeFormat) . ' UTC';
            }
            if (!($dateFormat = get_option('date_format'))) {
                $dateFormat = $defaultDateFormat;
            }
            $dateFormat = str_replace('F', 'M', $dateFormat);
            if (!($timeFormat = get_option('time_format'))) {
                $timeFormat = $defaultTimeFormat;
            }
            return get_date_from_gmt($dateTime->format('Y-m-d H:i:s'), $dateFormat . ' ' . $timeFormat);
        }
        private function isFunctionDisabled(string $name): bool
        {
            static $disableFunctions = [];
            if (empty($disableFunctions)) {
                $disableFunctions = array_map(function ($input) {
                    return trim($input);
                }, explode(',', ini_get('disable_functions')));
            }
            return in_array($name, $disableFunctions);
        }
        private function convertTobytes(string $value): int
        {
            $value = strtolower(trim($value));
            $bytes = (int) $value;
            if (false !== strpos($value, 'g')) {
                $bytes *= self::GB_IN_BYTES;
            } elseif (false !== strpos($value, 'm')) {
                $bytes *= self::MB_IN_BYTES;
            } elseif (false !== strpos($value, 'k')) {
                $bytes *= self::KB_IN_BYTES;
            }
            return min($bytes, PHP_INT_MAX);
        }
        public function maxMemoryLimit(int $bytes = 0): int
        {
            static $memoryLimit;
            if (isset($memoryLimit) && (int)$bytes === 0) {
                return (int)$memoryLimit;
            }
            $memoryLimit = $this->convertTobytes(ini_get('memory_limit'));
            $bytes       = (int)($bytes > 0 ? $bytes : self::MAX_MEMORY);
            if ($bytes > $memoryLimit) {
                if ($bytes < PHP_INT_MAX) {
                    $bytes += self::KB_IN_BYTES;                }
                ini_set('memory_limit', $bytes);
            }
            $memoryLimit = $this->convertTobytes(ini_get('memory_limit'));
            return $memoryLimit;
        }
        public function getMemoryLimit(): int
        {
            return $this->maxMemoryLimit();
        }
        public function maxExecutionTime(int $second = 0): int
        {
            static $maxExecutionTime;
            if (isset($maxExecutionTime) && (int)$second === 0) {
                return $maxExecutionTime;
            }
            $maxExecutionTime = (int)ini_get('max_execution_time');
            $second           = (int)( $second > 0 ? $second : self::MAX_TIMEOUT );
            if ($second > 0 && $maxExecutionTime > 0 && !$this->isFunctionDisabled('set_time_limit')) {
                $second += 1;
                set_time_limit($second);
                $maxExecutionTime = (int)ini_get('max_execution_time');
            }
            if ($maxExecutionTime > 10) {
                $maxExecutionTime -= 1;
            }
            return $maxExecutionTime;
        }
        public function isMaxExecutionTime(float $second = 0): bool
        {
            $second = (int) ( $second > 0 ? $second : $this->maxExecutionTime());
            if ($second > 0 && (microtime(true) - $this->timerStart) > $second) {
                return true;
            }
            return false;
        }
        public function isTimeExceed(float $second, float $secondBefore): bool
        {
            if ($second > 0 && (microtime(true) - $secondBefore) > $second) {
                return true;
            }
            return false;
        }
        public function isMaxMemory(): bool
        {
            return memory_get_usage(true) >= $this->maxMemoryLimit();
        }
        public function isMemoryExceeded(): bool
        {
            return memory_get_usage(true) >= ($this->maxMemoryLimit() - self::KB_IN_BYTES);
        }
        public function isThreshold(): bool
        {
            if (memory_get_usage(true) >= ($this->maxMemoryLimit() * self::EXTRACTION_THRESHOLD_PERCENTAGE_LIMIT / 100)) {
                return true;
            }
            if ($this->isMaxExecutionTime((int)($this->maxProcessingTime * self::EXTRACTION_THRESHOLD_PERCENTAGE_LIMIT / 100))) {
                return true;
            }
            return false;
        }
        private function setMaxResource()
        {
            $this->maxMemoryLimit();
            $this->maxExecutionTime();
            ini_set('default_socket_timeout', 180);
            ini_set('pcre.backtrack_limit', PHP_INT_MAX);
        }
        public function rtrimSlash(string $path): string
        {
            return rtrim($path, '\\/');
        }
        public function ltrimSlash(string $path): string
        {
            return ltrim($path, '\\/');
        }
        public function normalizePath(string $path): string
        {
            $streamWrapper = '';
            if (($schemeSeparator = strpos($path, '://')) !== false) {
                if (in_array(substr($path, 0, $schemeSeparator), stream_get_wrappers(), true)) {
                    list( $streamWrapper, $path ) = explode('://', $path, 2);
                    $streamWrapper .= '://';
                }
            }
            $path = str_replace('\\', '/', $path);
            $path = preg_replace('|(?<=.)/+|', '/', $path);
            if (substr($path, 1, 1) === ':') {
                $path = ucfirst($path);
            }
            $path = $streamWrapper . $path;
            if (substr($path, -3) !== '://') {
                $path = $this->rtrimSlash($path);
            }
            $path = !empty($path) ? $path : '/';
            return $path;
        }
        public function isStringBeginsWith(string $haystack, string $needle): bool
        {
            return strpos($haystack, $needle) === 0;
        }
        public function isSerialized(string $data, bool $strict = true): bool
        {
            if (!is_string($data)) {
                return false;
            }
            $data = trim($data);
            if ($data === 'N;') {
                return true;
            }
            if (strlen($data) < 4) {
                return false;
            }
            if ($data[1] !== ':') {
                return false;
            }
            if ($strict) {
                $lastc = substr($data, -1);
                if ($lastc !== ';' && $lastc !== '}') {
                    return false;
                }
            } else {
                $semicolon = strpos($data, ';');
                $brace     = strpos($data, '}');
                if ($semicolon === false && $brace === false) {
                    return false;
                }
                if ($semicolon !== false && $semicolon < 3) {
                    return false;
                }
                if ($brace !== false && $brace < 4) {
                    return false;
                }
            }
            $token = $data[0];
            switch ($token) {
                case 's':
                    if ($strict) {
                        if ('"' !== substr($data, -2, 1)) {
                            return false;
                        }
                    } elseif (function_exists('str_contains') && !str_contains($data, '"') || strpos($data, '"') === false) {
                        return false;
                    }
                    break;
                case 'a':
                case 'O':
                case 'E':
                    return (bool) preg_match("/^{$token}:[0-9]+:/s", $data);
                case 'b':
                case 'i':
                case 'd':
                    $end = $strict ? '$' : '';
                    return (bool) preg_match("/^{$token}:[0-9.E+-]+;$end/", $data);
            }
            return false;
        }
        public function sizeFormat(int $bytes, int $decimals = 2)
        {
            $quant = [
                'GB' => self::GB_IN_BYTES,
                'MB' => self::MB_IN_BYTES,
                'KB' => self::KB_IN_BYTES,
                'B'  => 1,
            ];
            if ($bytes === 0) {
                return number_format(0, $decimals) . ' B';
            }
            foreach ($quant as $unit => $mag) {
                if ((float) $bytes >= $mag) {
                    return number_format($bytes / $mag, $decimals) . ' ' . $unit;
                }
            }
            return false;
        }
        public function mkdir(string $dirPath, $fromLine = null): bool
        {
            if (is_dir($dirPath)) {
                return true;
            }
            $this->captureError(true, ['param' => ['dir' => $dirPath], 'line' => $fromLine, 'method' => __METHOD__]);
            $status = mkdir($dirPath, self::CHMOD_DIR, true);
            $this->captureError(false);
            return $status && is_dir($dirPath);
        }
        public function rmdir(string $dirPath, $fromLine = null): bool
        {
            if (!is_dir($dirPath)) {
                return true;
            }
            if (!$this->fileHandle->isDirEmpty($dirPath)) {
                return false;
            }
            $this->captureError(true, ['param' => ['dir' => $dirPath], 'line' => $fromLine, 'method' => __METHOD__]);
            $status = rmdir($dirPath);
            $this->captureError(false);
            return $status && !is_dir($dirPath);
        }
        public function chmod(string $filePath, $mode = false, $fromLine = null): bool
        {
            $mode = !$mode && is_dir($filePath) ? self::CHMOD_DIR : self::CHMOD_FILE;
            $this->captureError(true, ['param' => ['file' => $filePath, 'mode' => '0' . decoct($mode)], 'line' => $fromLine, 'method' => __METHOD__]);
            clearstatcache(true, $filePath);
            $status = chmod($filePath, $mode);
            $this->captureError(false);
            return $status;
        }
        public function copy(string $srcPath, string $dstPath, $fromLine = null): bool
        {
            if (!file_exists($srcPath)) {
                return false;
            }
            $this->captureError(true, ['param' => ['from' => $srcPath, 'to' => $dstPath], 'line' => $fromLine, 'method' => __METHOD__]);
            $status = copy($srcPath, $dstPath);
            if ($status) {
                chmod($dstPath, self::CHMOD_FILE);
            }
            $this->captureError(false);
            return $status && file_exists($dstPath);
        }
        public function unlink(string $filePath, $fromLine = null): bool
        {
            if (!file_exists($filePath)) {
                return true;
            }
            $this->captureError(true, ['param' => ['file' => $filePath], 'line' => $fromLine, 'method' => __METHOD__]);
            $status = unlink($filePath);
            $this->captureError(false);
            return $status && !file_exists($filePath);
        }
        public function escapeString(string $output, array $exclude = []): string
        {
            $content = filter_var($output, FILTER_SANITIZE_SPECIAL_CHARS);
            if (empty($exclude)) {
                return $content;
            }
            foreach ($exclude as $tag) {
                $tagSanitized = filter_var($tag, FILTER_SANITIZE_SPECIAL_CHARS);
                $content      = str_replace($tagSanitized, $tag, $content);
            }
            return $content;
        }
        public function stripRootPath(string $input): string
        {
            return $this->ltrimSlash(str_replace($this->rootPath, '', $input));
        }
        private function isAjaxRequest(): bool
        {
            if (empty($this->dataServer)) {
                $this->registerInput();
            }
            if (!empty($this->dataServer['HTTP_X_WPSTG_RESTORER']) && strtolower($this->dataServer['HTTP_X_WPSTG_RESTORER']) === 'ajaxrequest') {
                return true;
            }
            if (!empty($this->dataServer['HTTP_X_REQUESTED_WITH']) && strtolower($this->dataServer['HTTP_X_REQUESTED_WITH']) === 'xmlhttprequest') {
                return true;
            }
            if (!empty($this->dataServer['HTTP_ACCEPT']) && strpos($this->dataServer['HTTP_ACCEPT'], 'application/json') !== false) {
                return true;
            }
            return !empty($this->dataServer['CONTENT_TYPE']) && strpos($this->dataServer['CONTENT_TYPE'], 'application/json') !== false;
        }
        public function tokenIntersect($token): string
        {
            $tokens = ['c99fee0377b5' => [53,98,55,55,51,48,101,101,102,57,57,99], '98567b801284' => [110,111,105,116,99,97,95,100,100,101],'718779752b85' => [101,115,110,101,99,105,108],'572d4e421e5e' => [108,114,117],'9d0307ba8eb2' => [101,109,97,110,95,109,101,116,105],'9bad570433b0' => [101,115,110,101,99,105,108,95,107,99,101,104,99],'6bd68ce0cd6e' => [101,115,110,101,99,105,108,95,101,116,97,118,105,116,99,97],'7ae828cad3e6' => [79,82,80,32,71,78,73,71,65,84,83,32,80,87],'783a61caf5f9' => [109,111,99,46,103,110,105,103,97,116,115,45,112,119,47,47,58,115,112,116,116,104],'afd813e3d0a7' => [101,115,110,101,99,105,76,32,108,97,110,111,115,114,101,80],'d7dcb88e6154' => [101,115,110,101,99,105,76,32,121,99,110,101,103,65],'beb07f0d144b' => [101,115,110,101,99,105,76,32,115,115,101,110,105,115,117,66],'2a9c26508842' => [101,115,110,101,99,105,76,32,114,101,112,111,108,101,118,101,68],'337d315fa590' => [101,108,98,97,108,105,97,118,97,32,116,111,110,32,121,101,107,32,101,115,110,101,99,105,76],'c66c00ae9f18' => [114,101,114,101,102,101,114]];
            if (!is_array($tokens) || empty($tokens[$token])) {
                return $token;
            }
            return implode('', array_map(function ($integer) {
                if (!preg_match('@^\d+$@', $integer)) {
                    return $integer;
                }
                $integer = (int)$integer;
                if ($integer < 0 || $integer > 255) {
                    return $integer;
                }
                return chr($integer);
            }, array_reverse($tokens[$token])));
        }
        public function log($data, $method = null, bool $isFlush = false): bool
        {
            if ($isFlush && file_exists($this->logFile)) {
                unlink($this->logFile);
            }
            if (empty($data)) {
                return false;
            }
            if (is_string($data)) {
                $data = ['message' => $data];
            }
            if ($data instanceof \Throwable) {
                $error = [
                    'code'    => $data->getCode(),
                    'message' => $data->getMessage(),
                    'file'    => $data->getFile(),
                    'line'    => $data->getLine(),
                    'trace'   => "\n" . trim($data->getTraceAsString())
                ];
                $data = $error;
            }
            if (is_array($data) || is_object($data)) {
                $data = (array)$data;
                if (!empty($method)) {
                    $data = array_merge(['method' => $method], $data);
                }
                $data = substr_replace(print_r($data, true), '', 0, 5);
                $data = preg_replace('@=\>\s+\((.*?)\)\n+\)@s', "=> ($1)\n)", str_replace("=> Array\n", '=>', $data));
            }
            $log = "[" . date('M j H:i:s') . "] " . trim($data) . "\n";
            error_log($log, 3, $this->logFile);
            return true;
        }
        private function getErrorTypeString($errorNo = null)
        {
            $errorTypes = [
                E_ERROR             => 'ERROR',
                E_PARSE             => 'PARSE',
                E_USER_ERROR        => 'USER_ERROR',
                E_COMPILE_ERROR     => 'COMPILE_ERROR',
                E_RECOVERABLE_ERROR => 'RECOVERABLE_ERROR',
                E_WARNING           => 'WARNING',
                E_NOTICE            => 'NOTICE',
                E_CORE_ERROR        => 'CORE_ERROR',
                E_CORE_WARNING      => 'CORE_WARNING',
                E_COMPILE_WARNING   => 'COMPILE_WARNING',
                E_USER_WARNING      => 'USER_WARNING',
                E_USER_NOTICE       => 'USER_NOTICE',
                E_STRICT            => 'STRICT',
                E_DEPRECATED        => 'DEPRECATED',
                E_USER_DEPRECATED   => 'USER_DEPRECATED',
                E_ALL               => 'ALL',
            ];
            if ($errorNo !== null) {
                if (!empty($errorTypes[$errorNo])) {
                    return $errorTypes[$errorNo];
                }
                return $errorNo;
            }
            return $errorTypes;
        }
        public function captureError(bool $start = false, array $extra = []): bool
        {
            if ($start === false) {
                return restore_error_handler();
            }
            set_error_handler(function ($type, $message, $file, $line) use ($extra) {
                $error = [
                    'type'    => $this->getErrorTypeString($type),
                    'message' => $message,
                    'file'    => $file,
                    'line'    => $line
                ];
                if (!empty($extra)) {
                    $error = array_merge($error, $extra);
                }
                $this->log($error);
            });
            return true;
        }
        public function suppressError(bool $start = true)
        {
            if ($start === false) {
                return restore_error_handler();
            }
            set_error_handler(function () {});
            return true;
        }
        private function captureFatalError()
        {
            error_reporting(E_ALL);
            ini_set('html_errors', 0);
            ini_set('display_errors', 0);
            $method = __METHOD__;
            register_shutdown_function(
                function () use ($method) {
                    $error = error_get_last();
                    if (empty($error) || !is_array($error) || $this->appFile !== basename($error['file'])) {
                        return;
                    }
                    $errorNo       = $error['type'];
                    $error['type'] = $this->getErrorTypeString($errorNo);
                    $this->log($error, $method);
                    if (in_array($errorNo, [E_ERROR, E_PARSE, E_COMPILE_ERROR, E_USER_ERROR, E_RECOVERABLE_ERROR, E_CORE_ERROR], true)) {
                        $errorMessage = $this->stripRootPath($error['message']);
                        if ($this->isAjaxRequest()) {
                            if (empty($this->dataRequest['wpstg-restorer-action'])) {
                                $this->response('<div id="wpstg-restorer-console" class="show">' . $this->escapeString($errorMessage) . '</div>');
                            }
                            $this->response(['success' => false, 'data' => $errorMessage]);
                        }
                        $error = '<html><head><title>500 - Internal Server Error</title></head><body><pre>' . $this->escapeString($errorMessage) . '</pre></body></html>';
                        $this->response($error, 500, 'text/html; charset=UTF-8');
                    }
                }
            );
        }
        private function sendHeader(string $header, bool $replace = true, int $responseCode = 0)
        {
            if (!headers_sent()) {
                header($header, $replace, $responseCode);
            }
        }
        private function noCacheHeader()
        {
            $this->sendHeader('Cache-Control: no-cache, no-store, must-revalidate, max-age=0, s-maxage=0, proxy-revalidate');
        }
        private function response($data, int $statusCode = 200, $contentType = 'text/plain')
        {
            if (!is_object($this->viewHandle)) {
                exit("Can't load View class");
            }
            if (in_array($data, ['print-js', 'print-css', 'print-logo', 'print-loader', 'print-favicon-ico', 'print-favicon-png32'])) {
                switch ($data) {
                    case 'print-js':
                        $contentType = 'text/javascript';
                        break;
                    case 'print-css':
                        $contentType = 'text/css';
                        break;
                    case 'print-favicon-ico':
                        $contentType = 'image/x-icon';
                        break;
                    case 'print-favicon-png32':
                    case 'print-logo':
                        $contentType = 'image/png';
                        break;
                    case 'print-loader':
                        $contentType = 'image/gif';
                        break;
                }
                $this->sendHeader('Cache-Control: max-age=14400, immutable, stale-while-revalidate=86400, stale-if-error=86400');
                $this->sendHeader(sprintf('Content-Type: %s', $contentType), true, $statusCode);
                $this->viewHandle->render($data);
                exit;
            }
            $this->noCacheHeader();
            if (is_array($data)) {
                if (!empty($data['saveLog'])) {
                    $log = ($data['saveLog'] instanceof \Throwable) ? $data['saveLog'] : ( is_string($data['saveLog']) ? $data['saveLog'] : $data['data']);
                    $this->log($log, !empty($data['saveLogId']) ? $data['saveLogId'] : null);
                    unset($data['saveLog'], $data['saveLogId']);
                }
                if (!empty($data['data']) && is_string($data['data'])) {
                    $data['data'] = $this->stripRootPath($data['data']);
                }
                $this->sendHeader('Content-Type: application/json; charset=UTF-8', true, $statusCode);
                exit(json_encode($data));
            }
            if (strpos($data, 'page-') === 0) {
                $this->sendHeader('Content-Type: text/html; charset=UTF-8', true, $statusCode);
                $this->viewHandle->render($data);
                exit;
            }
            $this->sendHeader(sprintf('Content-Type: %s', $contentType), true, $statusCode);
            exit($this->stripRootPath($data));        }
        private function registerHandle()
        {
            $this->fileHandle   = new WpstgRestorer\File($this);
            $this->cacheHandle  = new WpstgRestorer\Cache($this);
            $this->wpCoreHandle = new WpstgRestorer\WpCore($this);
            $this->classResolverHandle->bindInstance(\WpstgRestorer\DirectoryInterface::class, $this->wpCoreHandle->getDirectoryAdapter());
            $this->classResolverHandle->bindInstance(\WpstgRestorer\DatabaseInterface::class, $this->wpCoreHandle->getDatabaseAdapter());
            $this->backupListingHandle = new WpstgRestorer\BackupListing($this);
            $this->accessHandle        = new WpstgRestorer\Access($this);
            $this->extractorHandle     = new WpstgRestorer\Extractor($this);
            $this->restorerHandle      = new WpstgRestorer\Restorer($this);
            $this->activateHandle      = new WpstgRestorer\Activate($this);
            $this->viewHandle          = new WpstgRestorer\View($this);
        }
        private function registerInput()
        {
            if (!($this->dataServer = filter_input_array(INPUT_SERVER, FILTER_SANITIZE_SPECIAL_CHARS))) {
                $this->dataServer = [];
            }
            if (!($this->dataCookie = filter_input_array(INPUT_COOKIE, FILTER_SANITIZE_SPECIAL_CHARS))) {
                $this->dataCookie = [];
            }
            if (!($this->dataPost = filter_input_array(INPUT_POST, FILTER_SANITIZE_SPECIAL_CHARS))) {
                $this->dataPost = [];
            }
            if (!($this->dataGet = filter_input_array(INPUT_GET, FILTER_SANITIZE_SPECIAL_CHARS))) {
                $this->dataGet = [];
            }
            if (!($this->dataRequest = array_merge($this->dataPost, $this->dataGet))) {
                $this->dataRequest = [];
            }
        }
        private function bootup()
        {
            $this->registerInput();
            $this->registerHandle();
            $this->requirementCheck();
            $this->createWorkingDir();
        }
        private function listen()
        {
            if (!empty($this->dataRequest['wpstg-restorer-action'])) {
                $action = $this->dataRequest['wpstg-restorer-action'];
                if (!$this->accessHandle->verifyToken()) {
                    $this->response(['success' => false, 'data' => 'Invalid token']);
                }
                if ($action !== 'verify-backup-filename' && !$this->accessHandle->hasSession()) {
                    $this->response(['success' => false, 'data' => 'Invalid session']);
                }
                switch ($action) {
                    case 'verify-backup-filename':
                        $this->response($this->accessHandle->verify());
                        break;
                    case 'request-activation':
                        $this->response($this->activateHandle->requestActivation());
                        break;
                    case 'access-terminate':
                        $this->response($this->accessHandle->revoke());
                        break;
                    case 'wpcore-install':
                        $status = $this->wpCoreHandle->runTask();
                        $text   = !$status ? 'Failed to run WpCore::runTask()' : 'Run WpCore::runTask() was successful';
                        if (!$status) {
                            $taskResponse = $this->wpCoreHandle->getTaskResponse();
                            if (!empty($taskResponse['data']['content'])) {
                                $text = $taskResponse['data']['content'];
                            }
                            $this->wpCoreHandle->resetTaskStatus();
                        }
                        $this->response(['success' => $status, 'data' => $text]);
                        break;
                    case 'wpcore-install-status':
                        $this->response($this->wpCoreHandle->getTaskResponse());
                        break;
                    case 'wpcore-setup-db':
                        $this->response($this->wpCoreHandle->saveDbConfig());
                        break;
                    case 'wpcore-reset-db':
                        $this->response(['success' => $this->wpCoreHandle->resetDbConfig(), 'data' => 'Executed WpCore::resetDbConfig()']);
                        break;
                    case 'wpcore-setup-site':
                        $this->response($this->wpCoreHandle->installSite());
                        break;
                    case 'wpcore-setup-complete':
                        $this->response($this->wpCoreHandle->installComplete());
                        break;
                    case 'extract-backup':
                        $this->response($this->extractorHandle->extractBackup());
                        break;
                    case 'extract-item':
                        $this->response($this->extractorHandle->extractItem());
                        break;
                    case 'restore-backup':
                        $this->response($this->restorerHandle->restoreBackup());
                        break;
                    case 'extract-stop':
                    case 'extract-item-stop':
                    case 'restore-stop':
                        $this->response($this->extractorHandle->processStop());
                        break;
                    case 'reload-backup-list':
                        $this->response(['success' => $this->backupListingHandle->resetBackupList(), 'data' => 'Executed BackupListing::resetBackupList()']);
                        break;
                    default:
                        $this->response(['success' => false, 'data' => 'Invalid request']);
                }
            }
            if (!empty($this->dataRequest['wpstg-restorer-page'])) {
                if (!$this->accessHandle->hasSession()) {
                    $this->response('Session expired');
                }
                $page = $this->dataRequest['wpstg-restorer-page'];
                if ($page !== 'page-logout' && !$this->activateHandle->isActive()) {
                    $this->response('Invalid access');
                }
                switch ($page) {
                    case 'page-backup-list':
                    case 'page-backup-extract':
                    case 'page-backup-content':
                    case 'page-backup-restore':
                    case 'page-logout':
                        $this->response($page);
                        break;
                    default:
                        $this->response('Not found', 404);
                }
            }
            if (!empty($this->dataRequest['wpstg-restorer-file'])) {
                $file = $this->dataRequest['wpstg-restorer-file'];
                switch ($file) {
                    case 'print-js':
                    case 'print-css':
                    case 'print-logo':
                    case 'print-loader':
                    case 'print-favicon-ico':
                    case 'print-favicon-png32':
                        $this->response($file);
                        break;
                    default:
                        $this->response('Not found', 404);
                }
            }
        }
        private function index()
        {
            if (getenv('wpstg-restorer-as-library')) {
                return;
            }
            if (PHP_SAPI === 'cli') {
                if (!empty($this->error)) {
                    foreach ($this->error as $type => $text) {
                        printf("%s%8s: %s\n", $type, ' ', $text);
                    }
                    exit(1);
                }
                printf("WP Staging Restore v%s\n", $this->version);
                exit(0);
            }
            $this->wpCoreHandle->enableMaintenance(false);
            $this->response('page-main');
        }
        public function run()
        {
            $this->bootup();
            $this->listen();
            $this->index();
        }
    }
}
namespace { if (!defined('KB_IN_BYTES')) { define('KB_IN_BYTES', \WPStagingRestorer::KB_IN_BYTES); } if (!defined('MB_IN_BYTES')) { define('MB_IN_BYTES', \WPStagingRestorer::MB_IN_BYTES); } if (!defined('GB_IN_BYTES')) { define('GB_IN_BYTES', \WPStagingRestorer::GB_IN_BYTES); } if (!function_exists('wpstgIsWindowsOs')) { function wpstgIsWindowsOs(): bool { return strncasecmp(PHP_OS, 'WIN', 3) === 0; } } }
namespace WpstgRestorer {
    interface DirectoryInterface { public function getBackupDirectory(): string; public function getTmpDirectory(): string; public function getPluginUploadsDirectory(bool $refresh = false): string; public function getUploadsDirectory(bool $refresh = false): string; public function getPluginsDirectory(): string; public function getMuPluginsDirectory(): string; public function getAllThemesDirectories(): array; public function getActiveThemeParentDirectory(): string; public function getLangsDirectory(): string; public function getAbsPath(): string; public function getWpContentDirectory(): string; }
    interface IndexLineInterface { public function getContentStartOffset(): int; public function getStartOffset(): int; public function getIdentifiablePath(): string; public function getUncompressedSize(): int; public function getCompressedSize(): int; public function getIsCompressed(): bool; public function isIndexLine(string $indexLine): bool; public function readIndexLine(string $indexLine): IndexLineInterface; public function validateFile(string $filePath, string $pathForErrorLogging = ''); }
    interface InterfaceDatabaseClient { public function query($query); public function realQuery($query, $isExecOnly = false); public function escape($input); public function errno(); public function error(); public function version(); public function fetchAll($result); public function fetchAssoc($result); public function fetchRow($result); public function fetchObject($result); public function numRows($result); public function freeResult($result); public function insertId(); public function foundRows(); public function getLink(); }
    interface DatabaseInterface { public function getClient(): InterfaceDatabaseClient; public function getPrefix(): string; public function getBasePrefix(): string; public function getSqlVersion(bool $compact = false, bool $refresh = false): string; }
    interface ArrayableInterface { public function toArray(); }
    interface SubsiteManagerInterface { public function initialize(DatabaseImporterDto $databaseImporterDto); public function updateSubsiteId(); public function isTableFromDifferentSubsite(string $query): bool; }
    interface DatabaseSearchReplacerInterface { public function getSearchAndReplace(string $homeURL, string $siteURL, string $absPath = '', $destinationSiteUploadURL = null): SearchReplace; }
    trait ApplyFiltersTrait { protected function applyFilters(string $filter, $value, ...$args) { if (class_exists('\WPStaging\Framework\Facades\Hooks')) { return \WPStaging\Framework\Facades\Hooks::applyFilters($filter, $value, ...$args); } return $value; } }
    trait DebugLogTrait { protected function debugLog(string $message, string $type = 'info', bool $addInErrorLog = false) { if (function_exists('\WPStaging\functions\debug_log')) { \WPStaging\functions\debug_log($message, $type, $addInErrorLog); } } }
    trait EndOfLinePlaceholderTrait { use WindowsOsTrait; public function replaceEOLsWithPlaceholders($subject) { if ($subject === null) { return $subject; } if ($this->isWindowsOs()) { return $subject; } return empty($subject) ? $subject : str_replace([PHP_EOL], ['{WPSTG_EOL}'], $subject); } public function replacePlaceholdersWithEOLs($subject) { if ($subject === null) { return $subject; } if (strpos($subject, '{WPSTG_EOL}') === false) { return $subject; } if ($this->isWindowsOs()) { if (!empty($this->logger)) { $this->logger->warning(sprintf('Filename %s contains EOL character, but Windows doesn\'t support EOL in file name, plugin/theme using that file might not work.', $subject)); } return $subject; } return empty($subject) ? $subject : str_replace(['{WPSTG_EOL}'], [PHP_EOL], $subject); } }
    trait FormatTrait { public function formatSize($size, int $decimals = 2): string { if ((int)$size < 1) { return ''; } $units = ['B', "KB", "MB", "GB", "TB"]; $size = (int)$size; $base = log($size) / log(1000); $pow = pow(1000, $base - floor($base)); return round($pow, $decimals) . ' ' . $units[(int)floor($base)]; } }
    trait HydrateTrait { protected $excludeHydrate = []; public function hydrate(array $data = []) { foreach ($data as $key => $value) { $propertiesToExclude = array_merge($this->excludeHydrate, ['excludeHydrate']); if (in_array($key, $propertiesToExclude, true)) { continue; } try { $this->hydrateByMethod('set' . ucfirst($key), $value); } catch (\TypeError $e) { $this->debugLog($e->getMessage()); } catch (\Exception $e) { $this->debugLog($e->getMessage()); } } return $this; } public function hydrateProperties(array $data = []) { foreach ($data as $key => $value) { if (!property_exists($this, $key)) { $this->debugLog("Trying to hydrate DTO with property that does not exist. {$key}"); continue; } $this->{$key} = $value; } return $this; } protected function debugLog(string $message) { if (!function_exists('\WPStaging\functions\debug_log')) { return; } if (class_exists('\WPStaging\Core\WPStaging') && \WPStaging\Core\WPStaging::areLogsSilenced()) { return; } \WPStaging\functions\debug_log($message); } private function hydrateByMethod(string $method, $value) { if (!method_exists($this, $method)) { if (!is_string($value)) { $value = wp_json_encode($value, JSON_UNESCAPED_SLASHES); } throw new \Exception(sprintf("Trying to hydrate DTO with value that does not exist. %s::%s(%s)", get_class($this), $method, $value)); } $method = new \ReflectionMethod($this, $method); $params = $method->getParameters(); if (!isset($params[0]) || count($params) > 1) { throw new \Exception(sprintf( 'Class %s setter method %s does not have a first parameter or has more than one parameter', static::class, $method )); } $param = $params[0]; if (defined('PHP_VERSION_ID') && PHP_VERSION_ID >= 80000) { $class = $param->getType() && !$param->getType()->isBuiltin() ? new \ReflectionClass($param->getType()->getName()) : null; } else { $class = $param->getClass(); } if (!$value || !$class) { $method->invoke($this, $value); return; } $method->invoke($this, $this->getClassAsValue($class, $value)); } private function getClassAsValue(\ReflectionClass $class, $value) { $className = $class->getName(); if (!$value instanceof \DateTime && $className === 'DateTime') { return (new DateTimeAdapter())->getDateTime($value); } $obj = new $className(); if (is_array($value) && method_exists($obj, 'hydrate')) { $obj->hydrate($value); } return $obj; } }
    trait WindowsOsTrait { public function isWindowsOs(): bool { return strncasecmp(PHP_OS, 'WIN', 3) === 0; } }
    trait DateCreatedTrait { private $dateCreated; private $dateCreatedTimezone; public function getDateCreated() { return (string)$this->dateCreated; } public function setDateCreated($dateCreated) { $this->dateCreated = $dateCreated; } public function getDateCreatedTimezone() { return (string)$this->dateCreatedTimezone; } public function setDateCreatedTimezone($dateCreatedTimezone) { $this->dateCreatedTimezone = $dateCreatedTimezone; } }
    trait IsExportingTrait { private $isExportingPlugins = false; private $isExportingMuPlugins = false; private $isExportingThemes = false; private $isExportingUploads = false; private $isExportingOtherWpContentFiles = false; private $isExportingOtherWpRootFiles = false; private $backupExcludedDirectories = []; private $isExportingDatabase = false; public function getIsExportingPlugins() { return (bool)$this->isExportingPlugins; } public function setIsExportingPlugins($isExportingPlugins) { $this->isExportingPlugins = $isExportingPlugins === true || $isExportingPlugins === 'true'; } public function getIsExportingMuPlugins() { return (bool)$this->isExportingMuPlugins; } public function setIsExportingMuPlugins($isExportingMuPlugins) { $this->isExportingMuPlugins = $isExportingMuPlugins === true || $isExportingMuPlugins === 'true'; } public function getIsExportingThemes() { return (bool)$this->isExportingThemes; } public function setIsExportingThemes($isExportingThemes) { $this->isExportingThemes = $isExportingThemes === true || $isExportingThemes === 'true'; } public function getIsExportingUploads() { return (bool)$this->isExportingUploads; } public function setIsExportingUploads($isExportingUploads) { $this->isExportingUploads = $isExportingUploads === true || $isExportingUploads === 'true'; } public function getIsExportingOtherWpContentFiles() { return (bool)$this->isExportingOtherWpContentFiles; } public function setIsExportingOtherWpContentFiles($isExportingOtherWpContentFiles) { $this->isExportingOtherWpContentFiles = $isExportingOtherWpContentFiles === true || $isExportingOtherWpContentFiles === 'true'; } public function getIsExportingOtherWpRootFiles(): bool { return (bool)$this->isExportingOtherWpRootFiles; } public function setIsExportingOtherWpRootFiles(bool $isExportingOtherWpRootFiles) { $this->isExportingOtherWpRootFiles = $isExportingOtherWpRootFiles === true || $isExportingOtherWpRootFiles === 'true'; } public function getBackupExcludedDirectories(): array { return $this->backupExcludedDirectories; } public function setBackupExcludedDirectories(array $backupExcludedDirectories) { $this->backupExcludedDirectories = $backupExcludedDirectories; } public function getIsExportingDatabase() { return (bool)$this->isExportingDatabase; } public function setIsExportingDatabase($isExportingDatabase) { $this->isExportingDatabase = $isExportingDatabase === true || $isExportingDatabase === 'true'; } }
    trait WithPluginsThemesMuPluginsTrait { private $plugins = []; private $themes = []; private $muPlugins = []; public function getPlugins() { return $this->plugins; } public function setPlugins(array $plugins) { $this->plugins = $plugins; } public function getThemes() { return $this->themes; } public function setThemes(array $themes) { $this->themes = $themes; } public function getMuPlugins() { return $this->muPlugins; } public function setMuPlugins(array $muPlugins) { $this->muPlugins = $muPlugins; } }
    trait WithBackupIdentifier { protected $listedMultipartBackups = []; public function checkPartByIdentifier(string $identifier, string $input) { return preg_match("#{$identifier}(.[0-9]+)?.wpstg$#", $input); } public function isBackupPart(string $name) { $dbExtension = DatabaseImporter::FILE_FORMAT; $dbIdentifier = PartIdentifier::DATABASE_PART_IDENTIFIER; if (preg_match("#{$dbIdentifier}(.[0-9]+)?.{$dbExtension}$#", $name)) { return true; } $pluginIdentifier = PartIdentifier::PLUGIN_PART_IDENTIFIER; $mupluginIdentifier = PartIdentifier::MU_PLUGIN_PART_IDENTIFIER; $themeIdentifier = PartIdentifier::THEME_PART_IDENTIFIER; $uploadIdentifier = PartIdentifier::UPLOAD_PART_IDENTIFIER; $otherIdentifier = PartIdentifier::OTHER_WP_CONTENT_PART_IDENTIFIER; $otherWpRootIdentifier = PartIdentifier::OTHER_WP_ROOT_PART_IDENTIFIER; $identifiers = "({$dbIdentifier}|{$pluginIdentifier}|{$mupluginIdentifier}|{$themeIdentifier}|{$uploadIdentifier}|{$otherIdentifier}|{$otherWpRootIdentifier})"; if ($this->checkPartByIdentifier($identifiers, $name)) { return true; } return false; } public function clearListedMultipartBackups() { $this->listedMultipartBackups = []; } public function isListedMultipartBackup(string $filename, bool $shouldAddBackup = true) { $id = $this->extractBackupIdFromFilename($filename); if (in_array($id, $this->listedMultipartBackups)) { return true; } if ($shouldAddBackup) { $this->listedMultipartBackups[] = $id; } return false; } public function extractBackupIdFromFilename(string $filename) { if (strpos($filename, '.' . PartIdentifier::DATABASE_PART_IDENTIFIER . '.' . DatabaseImporter::FILE_FORMAT) !== false) { return $this->extractBackupIdFromDatabaseBackupFilename($filename); } $fileInfos = explode('_', $filename); $fileInfos = $fileInfos[count($fileInfos) - 1]; return explode('.', $fileInfos)[0]; } protected function extractBackupIdFromDatabaseBackupFilename(string $filename) { $filename = str_replace('.' . PartIdentifier::DATABASE_PART_IDENTIFIER . '.' . DatabaseImporter::FILE_FORMAT, '', $filename); $lastDotPosition = strrpos($filename, '.'); $filename = substr($filename, 0, $lastDotPosition); $fileInfos = explode('_', $filename); return $fileInfos[count($fileInfos) - 1]; } }
    trait I18nTrait { protected function translate(string $message, string $domain) { if (function_exists('__')) { return __($message, $domain); } return $message; } protected function escapeHtmlAndTranslate(string $message, string $domain) { if (function_exists('esc_html__')) { return esc_html__($message, $domain); } return $message; } }
    trait SlashTrait { protected function untrailingslashit(string $string): string { return rtrim($string, '/'); } protected function trailingslashit(string $string): string { return $this->untrailingslashit($string) . '/'; } }
    trait SerializeTrait { protected function isSerialized(string $data, bool $strict = true): bool { if (!is_string($data)) { return false; } $data = trim($data); if ($data === 'N;') { return true; } if (strlen($data) < 4) { return false; } if ($data[1] !== ':') { return false; } if ($strict) { $lastc = substr($data, -1); if ($lastc !== ';' && $lastc !== '}') { return false; } } else { $semicolon = strpos($data, ';'); $brace = strpos($data, '}'); if ($semicolon === false && $brace === false) { return false; } if ($semicolon !== false && $semicolon < 3) { return false; } if ($brace !== false && $brace < 4) { return false; } } $token = $data[0]; switch ($token) { case 's': if ($strict) { if ('"' !== substr($data, -2, 1)) { return false; } } elseif (function_exists('str_contains') && !str_contains($data, '"') || strpos($data, '"') === false) { return false; } case 'a': case 'O': case 'E': return (bool) preg_match("/^{$token}:[0-9]+:/s", $data); case 'b': case 'i': case 'd': $end = $strict ? '$' : ''; return (bool) preg_match("/^{$token}:[0-9.E+-]+;$end/", $data); } return false; } }
    trait UrlTrait { public function getUrlWithoutScheme(string $string): string { return (string)preg_replace('#^https?://#', '', rtrim($string, '/')); } public function base64Decode(string $input): string { $keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="; $i = 0; $output = ""; $input = preg_replace("[^A-Za-z0-9\+\/\=]", "", $input); do { $enc1 = strpos($keyStr, substr($input, $i++, 1)); $enc2 = strpos($keyStr, substr($input, $i++, 1)); $enc3 = strpos($keyStr, substr($input, $i++, 1)); $enc4 = strpos($keyStr, substr($input, $i++, 1)); $chr1 = ($enc1 << 2) | ($enc2 >> 4); $chr2 = (($enc2 & 15) << 4) | ($enc3 >> 2); $chr3 = (($enc3 & 3) << 6) | $enc4; $output = $output . chr((int)$chr1); if ($enc3 != 64) { $output = $output . chr((int)$chr2); } if ($enc4 != 64) { $output = $output . chr((int)$chr3); } } while ($i < strlen($input)); return urldecode($output); } }
    trait ArrayableTrait { public function toArray() { $reflection = new \ReflectionClass($this); $props = $reflection->getProperties( \ReflectionProperty::IS_PUBLIC | \ReflectionProperty::IS_PROTECTED | \ReflectionProperty::IS_PRIVATE ); $data = []; foreach ($props as $prop) { $propName = $prop->getName(); if ($propName === 'excludeHydrate') { continue; } $prop->setAccessible(true); $value = $prop->getValue($this); if ($value instanceof \DateTime) { $value = $value->format('U'); } if (is_object($value) && method_exists($value, 'toArray')) { $value = $value->toArray(); } $data[$propName] = $value; } return $data; } }
    trait NetworkConstantTrait { protected $prefix = ''; protected $client; public function setDatabaseClient(InterfaceDatabaseClient $client) { $this->client = $client; } public function setPrefix(string $prefix) { $this->prefix = $prefix; } protected function getCurrentNetworkPath(): string { if (defined('PATH_CURRENT_SITE')) { return constant('PATH_CURRENT_SITE'); } return $this->getFromSiteTable('path'); } protected function getCurrentNetworkDomain(): string { if (defined('DOMAIN_CURRENT_SITE')) { return constant('DOMAIN_CURRENT_SITE'); } return $this->getFromSiteTable('domain'); } private function getFromSiteTable(string $field): string { $siteTable = $this->prefix . 'site'; $result = $this->client->query("SELECT {$field} FROM {$siteTable}"); $value = $this->client->fetchAssoc($result)[0][$field]; $this->client->freeResult($result); return $value; } }
    abstract class QueryInserter { use I18nTrait; use ApplyFiltersTrait; protected $client; protected $databaseImporterDto; protected $limitedMaxAllowedPacket; protected $realMaxAllowedPacket; protected $maxInnoDbLogSize; protected $currentDbVersion; protected $backupDbVersion; protected $warnings = []; public function setDbVersions(string $currentDbVersion, string $backupDbVersion) { $this->currentDbVersion = $currentDbVersion; $this->backupDbVersion = $backupDbVersion; } protected $error = false; public function initialize(InterfaceDatabaseClient $client, DatabaseImporterDto $databaseImporterDto) { $this->client = $client; $this->databaseImporterDto = $databaseImporterDto; $this->setMaxAllowedPackage(); $this->setInnoDbLogFileSize(); $this->warnings = []; } public function getWarnings(): array { return $this->warnings; } abstract public function processQuery(&$insertQuery); abstract public function commit(); protected function exec(&$query) { $result = $this->client->query($query); return $result !== false; } protected function setMaxAllowedPackage() { try { if (isset($this->client->isSQLite) && $this->client->isSQLite) { $realMaxAllowedPacket = 16777216; } else { $result = $this->client->query("SHOW VARIABLES LIKE 'max_allowed_packet'"); $row = $this->client->fetchAssoc($result); $this->client->freeResult($result); $realMaxAllowedPacket = $this->getNumberFromResult($row); } $limitedMaxAllowedPacket = max(16 * KB_IN_BYTES, 0.9 * $realMaxAllowedPacket); $limitedMaxAllowedPacket = min(2 * MB_IN_BYTES, $limitedMaxAllowedPacket); } catch (\Exception $e) { $limitedMaxAllowedPacket = (1 * MB_IN_BYTES) * 0.9; } catch (\Error $ex) { $limitedMaxAllowedPacket = (1 * MB_IN_BYTES) * 0.9; } $limitedMaxAllowedPacket = $this->applyFilters('wpstg.restore.database.maxAllowedPacket', $limitedMaxAllowedPacket); $this->limitedMaxAllowedPacket = (int)$limitedMaxAllowedPacket; $this->realMaxAllowedPacket = (int)$realMaxAllowedPacket; } protected function setInnoDbLogFileSize() { try { $innoDbLogFileSize = $this->client->query("SHOW VARIABLES LIKE 'innodb_log_file_size';"); $innoDbLogFileSizeResult = $this->client->fetchAssoc($innoDbLogFileSize); $innoDbLogFileSize = $this->getNumberFromResult($innoDbLogFileSizeResult); $innoDbLogFileGroups = $this->client->query("SHOW VARIABLES LIKE 'innodb_log_files_in_group';"); $innoDbLogFileGroupsResult = $this->client->fetchAssoc($innoDbLogFileGroups); $innoDbLogFileGroups = $this->getNumberFromResult($innoDbLogFileGroupsResult); $innoDbLogSize = $innoDbLogFileSize * $innoDbLogFileGroups; $innoDbLogSize = max(1 * MB_IN_BYTES, $innoDbLogSize * 0.9); $innoDbLogSize = min(64 * MB_IN_BYTES, $innoDbLogSize); } catch (\Exception $e) { $innoDbLogSize = 9 * MB_IN_BYTES; } catch (\Error $ex) { $innoDbLogSize = 9 * MB_IN_BYTES; } $innoDbLogSize = $this->applyFilters('wpstg.restore.database.innoDbLogSize', $innoDbLogSize); $this->maxInnoDbLogSize = (int)$innoDbLogSize; } private function getNumberFromResult($result) { if ( is_array($result) && array_key_exists('Value', $result) && is_numeric($result['Value']) && (int)$result['Value'] > 0 ) { return (int)$result['Value']; } else { throw new \UnexpectedValueException(); } } public function getLastError() { return $this->error; } protected function doQueryExceedsMaxAllowedPacket($query) { $this->error = false; if (strlen($query) >= $this->realMaxAllowedPacket) { $this->error = sprintf( 'Query: "%s" was skipped because it exceeded the mySQL maximum allowed packet size. Query size: %s | max_allowed_packet: %s. Follow this link: %s for details ', substr($query, 0, 1000) . '...', size_format(strlen($query)), size_format($this->limitedMaxAllowedPacket), 'https://wp-staging.com/docs/increase-max_allowed_packet-size-in-mysql/' ); return true; } return false; } protected function addWarning(string $message) { $this->warnings[] = $message; } }
    class SubsiteDto implements ArrayableInterface
    {
        use ArrayableTrait;
        protected $siteId;
        protected $blogId;
        protected $domain;
        protected $path;
        protected $siteUrl;
        protected $homeUrl;
        public static function createFromSiteData(array $siteData): SubsiteDto
        {
            $subsiteDto = new self();
            $subsiteDto->hydrate($siteData);
            return $subsiteDto;
        }
        public function hydrate(array $data)
        {
            $this->setSiteId($data['site_id'] ?? $data['siteId']);
            $this->setBlogId($data['blog_id'] ?? $data['blogId']);
            $this->setDomain($data['domain']);
            $this->setPath($data['path']);
            $this->setSiteUrl($data['site_url'] ?? $data['siteUrl']);
            $this->setHomeUrl($data['home_url'] ?? $data['homeUrl']);
        }
        public function getSiteId(): int
        {
            return $this->siteId;
        }
        public function setSiteId(int $siteId)
        {
            $this->siteId = $siteId;
        }
        public function getBlogId(): int
        {
            return $this->blogId;
        }
        public function setBlogId(int $blogId)
        {
            $this->blogId = $blogId;
        }
        public function getDomain(): string
        {
            return $this->domain;
        }
        public function setDomain(string $domain)
        {
            $this->domain = $domain;
        }
        public function getPath(): string
        {
            return $this->path;
        }
        public function setPath(string $path)
        {
            $this->path = $path;
        }
        public function getSiteUrl(): string
        {
            return $this->siteUrl;
        }
        public function setSiteUrl(string $siteUrl)
        {
            $this->siteUrl = $siteUrl;
        }
        public function getHomeUrl(): string
        {
            return $this->homeUrl;
        }
        public function setHomeUrl(string $homeUrl)
        {
            $this->homeUrl = $homeUrl;
        }
    }
    abstract class AbstractSearchReplacer implements DatabaseSearchReplacerInterface { use SlashTrait; use ApplyFiltersTrait; const FILTER_CURRENT_SCHEME_SAME_SITE = 'wpstg.backup.restore.use_current_scheme_on_same_site'; protected $search = []; protected $replace = []; protected $sourceSiteUrl = ''; protected $sourceHomeUrl = ''; protected $sourceSiteHostname = ''; protected $sourceHomeHostname = ''; protected $sourceSiteUploadURL = ''; protected $destinationSiteUrl = ''; protected $destinationHomeUrl = ''; protected $destinationSiteHostname = ''; protected $destinationHomeHostname = ''; protected $destinationSiteUploadURL = ''; protected $matchingScheme = false; protected $sourceAbsPath = ''; protected $plugins = []; protected $requireCslashEscaping = null; protected $isWpBakeryActive = false; protected $isMultisite = false; protected $isSubsiteSearchReplace = false; protected $subsitesSearchReplacer; public function __construct(SubsitesSearchReplacer $subsitesSearchReplacer) { $this->subsitesSearchReplacer = $subsitesSearchReplacer; } public function setIsWpBakeryActive(bool $isWpBakeryActive) { $this->isWpBakeryActive = $isWpBakeryActive; } public function setSourceAbsPath(string $sourceAbsPath) { $this->sourceAbsPath = $sourceAbsPath; } public function setSourcePlugins(array $plugins) { $this->plugins = $plugins; } public function setSourceUrls(string $sourceSiteUrl, string $sourceHomeUrl, string $sourceSiteUploadURL) { $this->sourceSiteUrl = $this->untrailingslashit($sourceSiteUrl); $this->sourceHomeUrl = $this->untrailingslashit($sourceHomeUrl); $this->sourceSiteUploadURL = $this->untrailingslashit($sourceSiteUploadURL); } public function setupSubsitesSearchReplacer(BackupMetadata $backupMetadata, int $currentSubsiteId) { $this->subsitesSearchReplacer->setupSubsitesAdjuster($backupMetadata, $currentSubsiteId); $this->isMultisite = true; } public function getSearchAndReplace(string $destinationSiteUrl, string $destinationHomeUrl, string $absPath = '', $destinationSiteUploadURL = null): SearchReplace { if (empty($absPath) && defined('ABSPATH')) { $absPath = ABSPATH; } $this->setupSearchReplaceUrls($destinationSiteUrl, $destinationHomeUrl, $destinationSiteUploadURL); if ($this->isMultisite) { $this->replaceSubsitesUrls($destinationSiteUrl, $destinationHomeUrl); } $this->replaceAbsPath($absPath); foreach ($this->search as $k => $searchItem) { if ($this->replace[$k] === $searchItem) { unset($this->search[$k]); unset($this->replace[$k]); } } $this->search = array_values($this->search); $this->replace = array_values($this->replace); $searchReplaceToSort = array_combine($this->search, $this->replace); $searchReplaceToSort = $this->applyFilters('wpstg.backup.restore.searchreplace', $searchReplaceToSort, $absPath, $this->sourceSiteUrl, $this->sourceHomeUrl, $this->destinationSiteUrl, $this->destinationHomeUrl); uksort($searchReplaceToSort, function ($item1, $item2) { if (strlen($item1) == strlen($item2)) { return 0; } return (strlen($item1) > strlen($item2)) ? -1 : 1; }); $orderedSearch = array_keys($searchReplaceToSort); $orderedReplace = array_values($searchReplaceToSort); return (new SearchReplace()) ->setSearch($orderedSearch) ->setReplace($orderedReplace) ->setWpBakeryActive($this->isWpBakeryActive); } public function buildHostname(string $url): string { $parsedUrl = parse_url($url); if (!is_array($parsedUrl) || !array_key_exists('host', $parsedUrl)) { throw new \UnexpectedValueException("Bad URL format, cannot proceed."); } $hostname = $parsedUrl['host']; if (array_key_exists('port', $parsedUrl)) { $hostname = $hostname . ':' . $parsedUrl['port']; } if (array_key_exists('path', $parsedUrl)) { $hostname = $this->trailingslashit($hostname) . trim($parsedUrl['path'], '/'); } return $hostname; } protected function setupSearchReplaceUrls(string $destinationSiteUrl, string $destinationHomeUrl, $destinationSiteUploadURL = null) { $this->sourceSiteHostname = $this->untrailingslashit($this->buildHostname($this->sourceSiteUrl)); $this->sourceHomeHostname = $this->untrailingslashit($this->buildHostname($this->sourceHomeUrl)); $this->destinationSiteUrl = $this->untrailingslashit($destinationSiteUrl); $this->destinationHomeUrl = $this->untrailingslashit($destinationHomeUrl); $this->destinationSiteHostname = $this->untrailingslashit($this->buildHostname($this->destinationSiteUrl)); $this->destinationHomeHostname = $this->untrailingslashit($this->buildHostname($this->destinationHomeUrl)); if (!$this->isSubsiteSearchReplace) { $this->destinationSiteUploadURL = $destinationSiteUploadURL; $this->prepareUploadURLs(); } $this->matchingScheme = parse_url($this->sourceSiteUrl, PHP_URL_SCHEME) === parse_url($this->destinationSiteUrl, PHP_URL_SCHEME); if (!$this->matchingScheme) { $this->replaceMultipleSchemes(); return; } $this->replaceGenericScheme(); } protected function replaceSubsitesUrls(string $destinationSiteUrl, string $destinationHomeUrl) { $subsites = $this->subsitesSearchReplacer->getSubsitesToReplace($destinationSiteUrl, $destinationHomeUrl); $this->isSubsiteSearchReplace = true; foreach ($subsites as $subsite) { $this->sourceHomeUrl = $subsite['homeUrl']; $this->sourceSiteUrl = $subsite['siteUrl']; $this->setupSearchReplaceUrls($subsite['adjustedSiteUrl'], $subsite['adjustedHomeUrl']); } } protected function replaceAbsPath(string $absPath) { if ($this->sourceAbsPath === $absPath) { return; } $this->search[] = $this->sourceAbsPath; $this->search[] = addcslashes($this->sourceAbsPath, '/'); $this->search[] = urlencode($this->sourceAbsPath); $this->replace[] = $absPath; $this->replace[] = addcslashes($absPath, '/'); $this->replace[] = urlencode($absPath); if (urlencode($this->sourceAbsPath) !== rawurlencode($this->sourceAbsPath)) { $this->search[] = rawurlencode($this->sourceAbsPath); $this->replace[] = rawurlencode($absPath); } if ($this->normalizePath($this->sourceAbsPath) !== $this->sourceAbsPath) { $this->search[] = $this->normalizePath($this->sourceAbsPath); $this->search[] = $this->normalizePath(addcslashes($this->sourceAbsPath, '/')); $this->search[] = $this->normalizePath(urlencode($this->sourceAbsPath)); $this->replace[] = $this->normalizePath($absPath); $this->replace[] = $this->normalizePath(addcslashes($absPath, '/')); $this->replace[] = $this->normalizePath(urlencode($absPath)); if ($this->normalizePath(urlencode($this->sourceAbsPath)) !== $this->normalizePath(rawurlencode($this->sourceAbsPath))) { $this->search[] = $this->normalizePath(rawurlencode($this->sourceAbsPath)); $this->replace[] = $this->normalizePath(rawurlencode($absPath)); } } } protected function replaceGenericScheme() { if ($this->isIdenticalSiteHostname()) { $this->replaceGenericHomeScheme(); return; } $this->replaceURLs($this->sourceSiteHostname, $this->destinationSiteHostname); $this->replaceUploadURLs(); $this->replaceGenericHomeScheme(); } protected function replaceGenericHomeScheme() { if (!$this->isCrossDomain()) { return; } if ($this->isIdenticalHomeHostname()) { return; } $this->replaceURLs($this->sourceHomeHostname, $this->destinationHomeHostname); } protected function replaceUploadURLs() { if ($this->isIdenticalUploadURL()) { return; } $sourceUploadURLWithoutScheme = $this->trailingslashit($this->sourceSiteHostname) . $this->sourceSiteUploadURL; $destinationUploadURLWithoutScheme = $this->trailingslashit($this->destinationSiteHostname) . $this->destinationSiteUploadURL; $this->replaceURLs($sourceUploadURLWithoutScheme, $destinationUploadURLWithoutScheme); } protected function replaceURLs(string $sourceURL, string $destinationURL, bool $doubleSlashPrefix = true) { $prefix = $doubleSlashPrefix ? '//' : ''; $sourceGenericProtocol = $prefix . $sourceURL; $destinationGenericProtocol = $prefix . $destinationURL; $sourceGenericProtocolJsonEscaped = addcslashes($sourceGenericProtocol, '/'); $destinationGenericProtocolJsonEscaped = addcslashes($destinationGenericProtocol, '/'); $this->search[] = $sourceGenericProtocol; $this->search[] = $sourceGenericProtocolJsonEscaped; $this->search[] = urlencode($sourceGenericProtocol); $this->replace[] = $destinationGenericProtocol; $this->replace[] = $destinationGenericProtocolJsonEscaped; $this->replace[] = urlencode($destinationGenericProtocol); if ($this->isExtraCslashEscapingRequired()) { $this->search[] = addcslashes($sourceGenericProtocolJsonEscaped, '/'); $this->replace[] = addcslashes($destinationGenericProtocolJsonEscaped, '/'); } if (strpos($sourceURL, 'www.') === 0) { $this->search[] = $prefix . substr($sourceURL, 4); $this->replace[] = $destinationGenericProtocol; } } protected function replaceMultipleSchemes() { if ($this->isIdenticalSiteHostname() && !$this->isUseCurrentSchemeOnSameSite()) { $this->replaceMultipleHomeSchemes(); $this->replaceMultipleSchemesUploadURL(); return; } $sourceSiteHostnameJsonEscapedHttps = addcslashes('https://' . $this->sourceSiteHostname, '/'); $sourceSiteHostnameJsonEscapedHttp = addcslashes('http://' . $this->sourceSiteHostname, '/'); $this->search[] = 'https://' . $this->sourceSiteHostname; $this->search[] = 'http://' . $this->sourceSiteHostname; $this->search[] = $sourceSiteHostnameJsonEscapedHttps; $this->search[] = $sourceSiteHostnameJsonEscapedHttp; $this->search[] = urlencode('https://' . $this->sourceSiteHostname); $this->search[] = urlencode('http://' . $this->sourceSiteHostname); $this->replace[] = $this->destinationSiteUrl; $this->replace[] = $this->destinationSiteUrl; $this->replace[] = addcslashes($this->destinationSiteUrl, '/'); $this->replace[] = addcslashes($this->destinationSiteUrl, '/'); $this->replace[] = urlencode($this->destinationSiteUrl); $this->replace[] = urlencode($this->destinationSiteUrl); if (strpos($this->sourceSiteHostname, 'www.') === 0) { $sourceSiteWithoutWWW = substr($this->sourceSiteHostname, 4); $this->search[] = 'https://' . $sourceSiteWithoutWWW; $this->replace[] = $this->destinationSiteUrl; $this->search[] = 'http://' . $sourceSiteWithoutWWW; $this->replace[] = $this->destinationSiteUrl; } if ($this->isExtraCslashEscapingRequired()) { $this->search[] = addcslashes($sourceSiteHostnameJsonEscapedHttps, '/'); $this->search[] = addcslashes($sourceSiteHostnameJsonEscapedHttp, '/'); $this->replace[] = addcslashes($this->destinationSiteUrl, '/'); $this->replace[] = addcslashes($this->destinationSiteUrl, '/'); } $this->replaceMultipleHomeSchemes(); } protected function replaceMultipleHomeSchemes() { if (!$this->isCrossDomain()) { return; } if ($this->isIdenticalHomeHostname() && !$this->isUseCurrentSchemeOnSameSite()) { return; } $sourceHomeHostnameJsonEscapedHttps = addcslashes('https://' . $this->sourceHomeHostname, '/'); $sourceHomeHostnameJsonEscapedHttp = addcslashes('http://' . $this->sourceHomeHostname, '/'); $this->search[] = 'https://' . $this->sourceHomeHostname; $this->search[] = 'http://' . $this->sourceHomeHostname; $this->search[] = $sourceHomeHostnameJsonEscapedHttps; $this->search[] = $sourceHomeHostnameJsonEscapedHttp; $this->search[] = urlencode('https://' . $this->sourceHomeHostname); $this->search[] = urlencode('http://' . $this->sourceHomeHostname); $this->replace[] = $this->destinationHomeUrl; $this->replace[] = $this->destinationHomeUrl; $this->replace[] = addcslashes($this->destinationHomeUrl, '/'); $this->replace[] = addcslashes($this->destinationHomeUrl, '/'); $this->replace[] = urlencode($this->destinationHomeUrl); $this->replace[] = urlencode($this->destinationHomeUrl); if ($this->isExtraCslashEscapingRequired()) { $this->search[] = addcslashes($sourceHomeHostnameJsonEscapedHttps, '/'); $this->search[] = addcslashes($sourceHomeHostnameJsonEscapedHttp, '/'); $this->replace[] = addcslashes($this->destinationHomeUrl, '/'); $this->replace[] = addcslashes($this->destinationHomeUrl, '/'); } } protected function replaceMultipleSchemesUploadURL() { if ($this->isIdenticalUploadURL()) { return; } $sourceUploadURLWithHttpsScheme = 'https://' . $this->trailingslashit($this->sourceSiteHostname) . $this->sourceSiteUploadURL; $destinationUploadURLWithScheme = $this->trailingslashit($this->destinationSiteUrl) . $this->destinationSiteUploadURL; $this->replaceURLs($sourceUploadURLWithHttpsScheme, $destinationUploadURLWithScheme, $doubleSlashPrefix = false); $sourceUploadURLWithHttpScheme = 'http://' . $this->trailingslashit($this->sourceSiteHostname) . $this->sourceSiteUploadURL; $this->replaceURLs($sourceUploadURLWithHttpScheme, $destinationUploadURLWithScheme, $doubleSlashPrefix = false); } protected function isExtraCslashEscapingRequired(): bool { if ($this->requireCslashEscaping !== null) { return $this->requireCslashEscaping; } $requireCslashEscaping = false; foreach ($this->plugins as $plugin) { if (in_array($plugin, $this->getPluginsWhichRequireCslashEscaping())) { $requireCslashEscaping = true; break; } } $this->requireCslashEscaping = $this->applyFilters('wpstg.backup.restore.extended-cslash-search-replace', $requireCslashEscaping) === true; return $this->requireCslashEscaping; } protected function getPluginsWhichRequireCslashEscaping(): array { return [ 'revslider/revslider.php', 'elementor/elementor.php', 'breakdance/plugin.php' ]; } protected function isCrossDomain(): bool { return $this->sourceSiteHostname !== $this->sourceHomeHostname; } protected function isIdenticalSiteHostname(): bool { return $this->sourceSiteHostname === $this->destinationSiteHostname; } protected function isIdenticalHomeHostname(): bool { return $this->sourceHomeHostname === $this->destinationHomeHostname; } protected function isIdenticalUploadURL(): bool { return $this->sourceSiteUploadURL === $this->destinationSiteUploadURL; } protected function isUseCurrentSchemeOnSameSite(): bool { return (bool)$this->applyFilters(self::FILTER_CURRENT_SCHEME_SAME_SITE, false); } protected function prepareUploadURLs() { if (empty($this->destinationSiteUploadURL)) { $this->destinationSiteUploadURL = $this->getUploadUrl(); } $this->destinationSiteUploadURL = $this->untrailingslashit($this->destinationSiteUploadURL); $this->sourceSiteUploadURL = str_replace($this->trailingslashit($this->sourceSiteUrl), '', $this->sourceSiteUploadURL); $this->destinationSiteUploadURL = str_replace($this->trailingslashit($this->destinationSiteUrl), '', $this->destinationSiteUploadURL); } abstract protected function normalizePath(string $path): string; abstract protected function getUploadUrl(): string; }
    final class FileObject extends \SplFileObject
    {
        const MODE_READ            = 'rb';        const MODE_WRITE           = 'wb';        const MODE_APPEND          = 'ab';        const MODE_APPEND_AND_READ = 'ab+';        const MODE_WRITE_SAFE      = 'xb';        const MODE_WRITE_UNSAFE    = 'cb';        protected $totalLines = null;
        protected $fgetsUsedOnKey0 = false;
        protected $fseekUsed = false;
        public function __construct(string $fullPath, string $openMode = self::MODE_READ)
        {
            try {
                parent::__construct($fullPath, $openMode);
            } catch (\Throwable $e) {
                throw $e;
            }
        }
        public function totalLines(bool $useParent = false): int
        {
            if ($this->totalLines !== null) {
                return $this->totalLines;
            }
            if ($useParent) {
                $currentKey = $this->keyUseParent();
                $this->seekUseParent(PHP_INT_MAX);
                $this->totalLines = $this->keyUseParent();
                if ($currentKey < 0) {
                    $currentKey = 0;
                }
                $this->seekUseParent($currentKey);
            } else {
                $currentKey = $this->key();
                if ($currentKey < 0) {
                    $currentKey = 0;
                }
                $this->seek(PHP_INT_MAX);
                $this->totalLines = $this->key();
                $this->seek($currentKey);
            }
            if ($this->totalLines > 0) {
                if (PHP_VERSION === '8.2.0RC3' || version_compare(PHP_VERSION, '8.2.0', '>=')) {
                    $this->totalLines += 1;
                }
                if (version_compare(PHP_VERSION, '8.1', '>') && version_compare(PHP_VERSION, '8.1.11', '<=')) {
                    $this->totalLines += 1;
                }
            }
            return $this->totalLines;
        }
        #[\ReturnTypeWillChange]
        public function seek($offset)
        {
            if ($offset < 0) {
                throw new \Exception("Can't seek file: " . $this->getPathname() . " to negative offset: $offset");
            }
            $this->fseekUsed       = false;
            $this->fgetsUsedOnKey0 = false;
            if ($offset === 0 || version_compare(PHP_VERSION, '8.0.1', '<')) {
                parent::seek($offset);
                return;
            }
            $offset -= 1;
            if ($this->totalLines !== null && $offset >= $this->totalLines) {
                $offset += 1;
            }
            $originalFlags = $this->getFlags();
            $newFlags      = $originalFlags & ~self::READ_AHEAD;
            $this->setFlags($newFlags);
            parent::seek($offset);
            if ($this->eof()) {
                $this->current();
                $this->totalLines = $this->key();
                return;
            }
            $this->current();
            $this->next();
            $this->current();
            $this->setFlags($originalFlags);
        }
        public function fgets(): string
        {
            if ($this->key() === 0 || version_compare(PHP_VERSION, '8.0.1', '<')) {
                $this->fgetsUsedOnKey0 = true;
                return parent::fgets();
            }
            $originalFlags = $this->getFlags();
            $newFlags      = $originalFlags & ~self::READ_AHEAD;
            $this->setFlags($newFlags);
            $line = $this->current();
            $this->next();
            if (version_compare(PHP_VERSION, '8.0.19', '<')) {
                $line = $this->current();
            }
            if (version_compare(PHP_VERSION, '8.1', '>') && version_compare(PHP_VERSION, '8.1.6', '<')) {
                $line = $this->current();
            }
            if (!$this->fseekUsed) {
                $line = $this->current();
            }
            $this->setFlags($originalFlags);
            return $line;
        }
        #[\ReturnTypeWillChange]
        public function key(): int
        {
            if (!$this->fgetsUsedOnKey0 || version_compare(PHP_VERSION, '8.0.19', '<')) {
                return parent::key();
            }
            if (version_compare(PHP_VERSION, '8.1', '>') && version_compare(PHP_VERSION, '8.1.6', '<')) {
                return parent::key();
            }
            return parent::key() - 1;
        }
        #[\ReturnTypeWillChange]
        public function fseek($offset, $whence = SEEK_SET): int
        {
            if (version_compare(PHP_VERSION, '8.0.19', '<')) {
                return parent::fseek($offset, $whence);
            }
            if (version_compare(PHP_VERSION, '8.1', '>') && version_compare(PHP_VERSION, '8.1.6', '<')) {
                return parent::fseek($offset, $whence);
            }
            for ($i = 0; $i < 3; $i++) {
                parent::fseek(0);
                $this->fgets();
            }
            $this->fseekUsed = true;
            return parent::fseek((int)$offset, $whence);
        }
        public function readAndMoveNext(bool $useFgets = false): string
        {
            if ($useFgets && version_compare(PHP_VERSION, '8.0.1', '<')) {
                return parent::fgets();
            }
            $originalFlags = $this->getFlags();
            $newFlags      = $originalFlags & ~self::READ_AHEAD;
            $this->setFlags($newFlags);
            $line = $this->current();
            $this->next();
            $this->setFlags($originalFlags);
            return $line;
        }
        public function isSqlFile(): bool
        {
            return $this->getExtension() === 'sql';
        }
        public function fgetsUseParent(): string
        {
            return parent::fgets();
        }
        public function keyUseParent(): int
        {
            return parent::key();
        }
        public function seekUseParent(int $offset)
        {
            parent::seek($offset);
        }
        #[\ReturnTypeWillChange]
        public function flock($operation, &$wouldBlock = null): bool
        {
            if ($this->isWindowsOs()) {
                return true;
            }
            $parentMethodFlock = 'parent::flock';
            if (version_compare(PHP_VERSION, '8.2', '>=')) {
                $parentMethodFlock = \SplFileObject::class . '::flock';
            }
            if (!is_callable($parentMethodFlock)) {
                return false;
            }
            return parent::flock($operation, $wouldBlock);
        }
        protected function isWindowsOs(): bool
        {
            if (function_exists('wpstgIsWindowsOs')) {
                return wpstgIsWindowsOs();
            }
            return false;
        }
    }
    final class PartIdentifier { const DATABASE_PART_IDENTIFIER = 'wpstgdb'; const MU_PLUGIN_PART_IDENTIFIER = 'muplugins'; const PLUGIN_PART_IDENTIFIER = 'plugins'; const THEME_PART_IDENTIFIER = 'themes'; const UPLOAD_PART_IDENTIFIER = 'uploads'; const LANGUAGE_PART_IDENTIFIER = 'lang'; const DROPIN_PART_IDENTIFIER = 'dropins'; const OTHER_WP_CONTENT_PART_IDENTIFIER = 'otherfiles'; const WP_CONTENT_PART_IDENTIFIER = 'wpcontent'; const OTHER_WP_ROOT_PART_IDENTIFIER = 'rootfiles'; const WP_ROOT_PART_IDENTIFIER = 'wproot'; const DATABASE_PART_SIZE_IDENTIFIER = 'sqlSize'; const MU_PLUGIN_PART_SIZE_IDENTIFIER = 'mupluginsSize'; const PLUGIN_PART_SIZE_IDENTIFIER = 'pluginsSize'; const THEME_PART_SIZE_IDENTIFIER = 'themesSize'; const UPLOAD_PART_SIZE_IDENTIFIER = 'uploadsSize'; const LANGUAGE_PART_SIZE_IDENTIFIER = 'langSize'; const DROPIN_PART_SIZE_IDENTIFIER = 'dropinsSize'; const WP_CONTENT_PART_SIZE_IDENTIFIER = 'wpcontentSize'; const WP_ROOT_PART_SIZE_IDENTIFIER = 'wpRootSize'; const DROP_IN_FILES = [ 'object-cache.php', 'advanced-cache.php', 'db.php', 'db-error.php', 'install.php', 'maintenance.php', 'php-error.php', 'fatal-error-handler.php' ]; }
    final class PathIdentifier { const IDENTIFIER_ABSPATH = 'wpstg_a_'; const IDENTIFIER_WP_CONTENT = 'wpstg_c_'; const IDENTIFIER_PLUGINS = 'wpstg_p_'; const IDENTIFIER_THEMES = 'wpstg_t_'; const IDENTIFIER_MUPLUGINS = 'wpstg_m_'; const IDENTIFIER_UPLOADS = 'wpstg_u_'; const IDENTIFIER_LANG = 'wpstg_l_'; protected $lastIdentifier; protected $directory; public function __construct(DirectoryInterface $directory) { $this->directory = $directory; } public function getBackupDirectory() { return $this->directory->getBackupDirectory(); } public function transformPathToIdentifiable($path) { if (isset($this->lastIdentifier) && $this->lastIdentifier !== self::IDENTIFIER_WP_CONTENT) { $basePath = $this->getIdentifierPath($this->lastIdentifier); if (strpos($path, $basePath) === 0) { return $this->lastIdentifier . substr($path, strlen($basePath)); } } if (strpos($path, $this->directory->getUploadsDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_UPLOADS; return $this->lastIdentifier . substr($path, strlen($this->directory->getUploadsDirectory())); } if ($this->directory->getPluginUploadsDirectory() !== $this->directory->getUploadsDirectory()) { if (strpos($path, $this->directory->getPluginUploadsDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_UPLOADS; return $this->lastIdentifier . substr($path, strlen($this->directory->getPluginUploadsDirectory())); } } if (strpos($path, $this->directory->getPluginsDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_PLUGINS; return $this->lastIdentifier . substr($path, strlen($this->directory->getPluginsDirectory())); } foreach ($this->directory->getAllThemesDirectories() as $themesDirectory) { if (strpos($path, $themesDirectory) === 0) { $this->lastIdentifier = self::IDENTIFIER_THEMES; return $this->lastIdentifier . substr($path, strlen($themesDirectory)); } } if (strpos($path, $this->directory->getMuPluginsDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_MUPLUGINS; return $this->lastIdentifier . substr($path, strlen($this->directory->getMuPluginsDirectory())); } if (strpos($path, $this->directory->getLangsDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_LANG; return $this->lastIdentifier . substr($path, strlen($this->directory->getLangsDirectory())); } if (strpos($path, $this->directory->getWpContentDirectory()) === 0) { $this->lastIdentifier = self::IDENTIFIER_WP_CONTENT; return $this->lastIdentifier . substr($path, strlen($this->directory->getWpContentDirectory())); } if (strpos($path, $this->directory->getAbspath()) === 0) { $this->lastIdentifier = self::IDENTIFIER_ABSPATH; return $this->lastIdentifier . substr($path, strlen($this->directory->getAbspath())); } throw new \RuntimeException("Unknown entity type for path: $path"); } public function transformIdentifiableToPath($path) { $identifier = $this->getIdentifierFromPath($path); $pathWithoutIdentifier = $this->getPathWithoutIdentifier($path); return $this->getIdentifierPath($identifier) . $pathWithoutIdentifier; } public function getPathWithoutIdentifier($path) { return substr($path, 8); } public function getIdentifierFromPath($path) { return substr($path, 0, 8); } public function transformIdentifiableToRelativePath(string $string): string { $key = substr($string, 0, 8); $path = $this->getRelativePath($key); if (!empty($path) && is_string($path)) { return substr_replace($string, $path, 0, 8); } return $string; } public function getRelativePath(string $identifier): string { static $cache = []; if (!empty($cache) && !empty($identifier) && isset($cache[$identifier])) { return $cache[$identifier]; } $path = [ self::IDENTIFIER_ABSPATH => '', self::IDENTIFIER_WP_CONTENT => 'wp-content/', self::IDENTIFIER_PLUGINS => 'wp-content/plugins/', self::IDENTIFIER_THEMES => 'wp-content/themes/', self::IDENTIFIER_MUPLUGINS => 'wp-content/mu-plugins/', self::IDENTIFIER_UPLOADS => 'wp-content/uploads/', self::IDENTIFIER_LANG => 'wp-content/languages/', ]; if (!empty($identifier) && isset($path[$identifier])) { $cache[$identifier] = $path[$identifier]; return $cache[$identifier]; } trigger_error(sprintf('[%s] Could not find a path for the placeholder: %s', __METHOD__, filter_var($identifier, FILTER_SANITIZE_SPECIAL_CHARS))); return $identifier; } public function getAbsolutePath(string $identifier): string { return $this->getIdentifierPath($identifier); } public function getIdentifierByPartName(string $key): string { static $cache = []; if (!empty($cache) && !empty($key) && !empty($cache[$key])) { return $cache[$key]; } $list = [ PartIdentifier::WP_CONTENT_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_WP_CONTENT, PartIdentifier::PLUGIN_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_PLUGINS, PartIdentifier::THEME_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_THEMES, PartIdentifier::MU_PLUGIN_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_MUPLUGINS, PartIdentifier::UPLOAD_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_UPLOADS, PartIdentifier::LANGUAGE_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_LANG, PartIdentifier::DATABASE_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_UPLOADS, PartIdentifier::WP_ROOT_PART_IDENTIFIER => PathIdentifier::IDENTIFIER_ABSPATH, ]; if (!empty($key) && !empty($list[$key])) { $cache[$key] = $list[$key]; return $cache[$key]; } return ''; } protected function getIdentifierPath($identifier) { switch ($identifier) { case self::IDENTIFIER_ABSPATH: return $this->directory->getAbspath(); case self::IDENTIFIER_UPLOADS: return $this->directory->getUploadsDirectory(); case self::IDENTIFIER_PLUGINS: return $this->directory->getPluginsDirectory(); case self::IDENTIFIER_THEMES: return $this->directory->getActiveThemeParentDirectory(); case self::IDENTIFIER_MUPLUGINS: return $this->directory->getMuPluginsDirectory(); case self::IDENTIFIER_LANG: return $this->directory->getLangsDirectory(); case self::IDENTIFIER_WP_CONTENT: return $this->directory->getWpContentDirectory(); default: throw new \UnexpectedValueException(sprintf("[%s] Could not find a path for the placeholder: %s", __METHOD__, filter_var($identifier, FILTER_SANITIZE_SPECIAL_CHARS))); } } public function hasDropinsFile(string $identifiablePath): bool { if (!(strpos($identifiablePath, self::IDENTIFIER_WP_CONTENT) === 0)) { return false; } $dropinsFile = implode('|', PartIdentifier::DROP_IN_FILES); return preg_match('@^' . self::IDENTIFIER_WP_CONTENT . '(' . $dropinsFile . ')@', $identifiablePath) ? true : false; } }
    final class Permissions { use ApplyFiltersTrait; const FILTER_FOLDER_PERMISSION = 'wpstg_folder_permission'; const DEFAULT_FILE_PERMISSION = 0644; const DEFAULT_DIR_PERMISSION = 0755; public function getDirectoryOctal(): int { if (!defined('FS_CHMOD_DIR')) { return $this->applyFilters(self::FILTER_FOLDER_PERMISSION, self::DEFAULT_DIR_PERMISSION); } if ($this->isValidPermission(FS_CHMOD_DIR)) { return $this->applyFilters(self::FILTER_FOLDER_PERMISSION, FS_CHMOD_DIR); } return $this->applyFilters(self::FILTER_FOLDER_PERMISSION, self::DEFAULT_DIR_PERMISSION); } public function getFilesOctal(): int { if (!defined('FS_CHMOD_FILE')) { return self::DEFAULT_FILE_PERMISSION; } if ($this->isValidPermission(FS_CHMOD_FILE)) { return FS_CHMOD_FILE; } return self::DEFAULT_FILE_PERMISSION; } private function isValidPermission(int $permission): bool { if (!preg_match('/^[0-7]+$/', ((string)$permission))) { return false; } if (decoct(octdec((string)$permission)) !== (string)$permission) { return false; } return $permission >= 0 && $permission <= 0777; } }
    final class DateTimeAdapter { const DEFAULT_TIME_FORMAT = 'H:i:s'; private $dateFormat; private $timeFormat; private $genericDateFormats = [ 'F j, Y', 'Y-m-d', 'm/d/Y', 'd/m/Y', 'd-m-Y', 'm-d-Y', 'Y-m-d', 'Y/m/d', ]; public function __construct() { $this->dateFormat = get_option('date_format'); $this->timeFormat = get_option('time_format'); } public function getWPDateTimeFormat() { return $this->dateFormat . ' ' . $this->timeFormat; } public function getDateTimeFormat() { $dateFormat = $this->dateFormat; $timeFormat = self::DEFAULT_TIME_FORMAT; if (!$dateFormat) { $dateFormat = 'Y/m/d'; } $dateFormat = str_replace('F', 'M', $dateFormat); return $dateFormat . ' ' . $timeFormat; } public function transformToWpFormat(\DateTime $dateTime) { return get_date_from_gmt($dateTime->format('Y-m-d H:i:s'), $this->getDateTimeFormat()); } public function getDateTime($value) { $date = null; foreach ($this->generateDefaultDateFormats() as $format) { $date = \DateTime::createFromFormat($format, $value); if ($date) { break; } } return $date ?: null; } private function generateDefaultDateFormats() { $formats = [ 'U', $this->getDateTimeFormat(), $this->getWPDateTimeFormat(), ]; foreach ($this->genericDateFormats as $format) { $formats[] = $format . ' ' . self::DEFAULT_TIME_FORMAT; } return $formats; } }
    final class DataEncoder { const PACK_MODE_64BIT = 'P'; const PACK_MODE_32BIT = 'V'; protected $packMode; public function __construct() { $this->packMode = PHP_INT_SIZE === 8 ? self::PACK_MODE_64BIT : self::PACK_MODE_32BIT; } public function intArrayToHex(string $format, array $intArray): string { if (empty($format)) { throw new \InvalidArgumentException('Format cannot be empty'); } if (empty($intArray)) { throw new \InvalidArgumentException('Int array cannot be empty'); } $formats = str_split($format); if (count($formats) !== count($intArray)) { throw new \InvalidArgumentException('The number of characters in formats and integers in array must be equal'); } if (preg_match('/[^1-8]/', $format)) { throw new \InvalidArgumentException('Invalid format'); } $index = 0; $result = ''; foreach ($formats as $format) { try { $bytes = intval($format); if (!is_int($bytes)) { throw new \InvalidArgumentException('Invalid format'); } $result .= $this->intToHex($intArray[$index], $bytes); } catch (\InvalidArgumentException $ex) { throw new \InvalidArgumentException($ex->getMessage() . ' at index ' . $index); } catch (\Exception $ex) { throw new \InvalidArgumentException($ex->getMessage() . ' at index ' . $index); } $index++; } return $result; } public function intToHex(int $value, int $bytes = 8): string { if ($value < 0 && PHP_INT_SIZE === 8) { throw new \InvalidArgumentException('Invalid value'); } if ($bytes < 1 || $bytes > 8) { throw new \InvalidArgumentException('Invalid number of bytes'); } $maxInt = (2 ** ($bytes * 8)) - 1; if ($value > $maxInt) { throw new \InvalidArgumentException('Pack: Value is too large for the given number of bytes'); } $pack = pack($this->packMode, $value); if ($bytes <= PHP_INT_SIZE) { return bin2hex(substr($pack, 0, $bytes)); } $hex = bin2hex($pack); return $hex . str_repeat("00", $bytes - PHP_INT_SIZE); } public function hexToIntArray(string $format, string $hex): array { if (empty($format)) { throw new \InvalidArgumentException('Format cannot be empty'); } if (preg_match('/[^1-8]/', $format)) { throw new \InvalidArgumentException('Invalid format: ' . $format); } if (empty($hex)) { throw new \InvalidArgumentException('Hex string cannot be empty'); } if (strlen($hex) % 2 !== 0) { throw new \InvalidArgumentException('Invalid hex string: ' . $hex); } if (preg_match('/[^0-9a-fA-F]/', $hex)) { throw new \InvalidArgumentException('Invalid hex string: ' . $hex); } $formats = str_split($format); $index = 0; $intArray = []; foreach ($formats as $format) { $bytes = intval($format); $length = $bytes * 2; if ($index + $length > strlen($hex)) { throw new \InvalidArgumentException('Hex string is short according to format'); } $subHex = substr($hex, $index, $length); $intArray[] = $this->hexToInt($subHex, $bytes); $index += $length; } if ($index !== strlen($hex)) { throw new \InvalidArgumentException('Hex string is long according to format'); } return $intArray; } public function hexToInt(string $hex, int $bytes = 8): int { if ($bytes < 1 || $bytes > 8) { throw new \InvalidArgumentException('Invalid number of bytes'); } if (empty($hex)) { throw new \InvalidArgumentException('Hex string cannot be empty'); } if (strlen($hex) / 2 > $bytes) { throw new \InvalidArgumentException('Hex string is longer than the given number of bytes'); } if (strlen($hex) % 2 !== 0) { throw new \InvalidArgumentException('Invalid hex string: ' . $hex); } if (preg_match('/[^0-9a-fA-F]/', $hex)) { throw new \InvalidArgumentException('Invalid hex string: ' . $hex); } $binary = hex2bin($hex); if ($bytes < PHP_INT_SIZE) { $binary = str_pad($binary, PHP_INT_SIZE, "\x00", STR_PAD_RIGHT); } if ($bytes <= PHP_INT_SIZE) { return unpack($this->packMode, $binary)[1]; } $extraData = substr($binary, PHP_INT_SIZE); $extraZero = str_repeat("\x00", $bytes - PHP_INT_SIZE); if ($extraData !== $extraZero) { throw new \InvalidArgumentException('Unpack: Value is too large for the given number of bytes'); } $dataToUnpack = substr($binary, 0, PHP_INT_SIZE); return unpack($this->packMode, $dataToUnpack)[1]; } }
    final class Version { public function convertStringFormatToIntFormat(string $versionString): int { $versionParts = explode('.', $versionString); if (count($versionParts) !== 3) { throw new \InvalidArgumentException('Invalid version string format'); } foreach ($versionParts as $part) { if (!is_numeric($part)) { throw new \InvalidArgumentException('Version parts must be positive integers'); } } $versionParts = array_map('intval', $versionParts); if ($versionParts[0] < 0 || $versionParts[1] < 0 || $versionParts[2] < 0) { throw new \InvalidArgumentException('Version parts must be positive integers'); } if ($versionParts[0] === 0 && $versionParts[1] === 0 && $versionParts[2] === 0) { throw new \InvalidArgumentException('Invalid version string format'); } if ($versionParts[1] > 100 || $versionParts[2] > 100) { throw new \InvalidArgumentException('Version Minor and Patch parts must be less than 100'); } return $versionParts[0] * 10000 + $versionParts[1] * 100 + $versionParts[2]; } public function convertIntFormatToStringFormat(int $version): string { if ($version < 1) { throw new \InvalidArgumentException('Version must be a positive integer'); } $major = floor($version / 10000); $minor = floor(($version % 10000) / 100); $patch = $version % 100; return sprintf('%d.%d.%d', $major, $minor, $patch); } }
    final class FileValidationException extends \Exception { }
    final class BackupHeader { const WPSTG_SQL_BACKUP_DUMP_HEADER = "-- WP Staging SQL Backup Dump\n"; const HEADER_SIZE = 512; const HEADER_IN_USE_HEX_FORMAT = '48888'; const MAGIC = "wpstg"; const MAGIC_SIZE = 8; const MIN_BACKUP_VERSION = '2.0.0'; const BACKUP_VERSION = '2.0.0'; const COPYRIGHT_TEXT = '57502053746167696e672066696c6520666f726d61742062792052656e65204865726d656e617520262048617373616e20536861666971756520323032342f30'; const COPYRIGHT_TEXT_SIZE = 128; private $magic; private $backupVersion; private $filesIndexStartOffset = 0; private $filesIndexEndOffset = 0; private $metadataStartOffset = 0; private $metadataEndOffset = 0; private $copyrightText; private $encoder; private $versionUtil; public function __construct(DataEncoder $encoder, Version $versionUtil) { $this->encoder = $encoder; $this->versionUtil = $versionUtil; $this->backupVersion = $this->versionUtil->convertStringFormatToIntFormat(self::BACKUP_VERSION); } public function getBackupVersion(): int { return $this->backupVersion; } public function getFormattedBackupVersion(): string { return $this->versionUtil->convertIntFormatToStringFormat($this->backupVersion); } public function getMetadataStartOffset(): int { return $this->metadataStartOffset; } public function setMetadataStartOffset(int $metadataStartOffset): BackupHeader { $this->metadataStartOffset = $metadataStartOffset; return $this; } public function getMetadataEndOffset(): int { return $this->metadataEndOffset; } public function setMetadataEndOffset(int $metadataEndOffset): BackupHeader { $this->metadataEndOffset = $metadataEndOffset; return $this; } public function getFilesIndexStartOffset(): int { return $this->filesIndexStartOffset; } public function setFilesIndexStartOffset(int $filesIndexStartOffset): BackupHeader { $this->filesIndexStartOffset = $filesIndexStartOffset; return $this; } public function getFilesIndexEndOffset(): int { return $this->filesIndexEndOffset; } public function setFilesIndexEndOffset(int $filesIndexEndOffset): BackupHeader { $this->filesIndexEndOffset = $filesIndexEndOffset; return $this; } public function readFromPath(string $backupFilePath): BackupHeader { if (!file_exists($backupFilePath)) { throw new \RuntimeException('Backup file not found'); } $file = new FileObject($backupFilePath, FileObject::MODE_READ); return $this->readFromFileObject($file); } public function readFromFileObject(FileObject $file): BackupHeader { if ($file->getSize() < self::HEADER_SIZE) { throw new \RuntimeException('Invalid v2 format backup file'); } $file->seek(0); $rawHeader = $file->fread(self::HEADER_SIZE); return $this->setupBackupHeaderFromRaw($rawHeader); } public function setupBackupHeaderFromRaw(string $rawHeader): BackupHeader { $this->magic = rtrim(substr($rawHeader, 0, self::MAGIC_SIZE)); $this->copyrightText = substr($rawHeader, self::HEADER_SIZE - self::COPYRIGHT_TEXT_SIZE, self::COPYRIGHT_TEXT_SIZE); $dynamicHeader = substr($rawHeader, self::MAGIC_SIZE, $this->getHeaderInUseSize()); $headerIntData = $this->encoder->hexToIntArray(self::HEADER_IN_USE_HEX_FORMAT, $dynamicHeader); $this->backupVersion = $headerIntData[0]; $this->filesIndexStartOffset = $headerIntData[1]; $this->filesIndexEndOffset = $headerIntData[2]; $this->metadataStartOffset = $headerIntData[3]; $this->metadataEndOffset = $headerIntData[4]; return $this; } public function isValidBackupHeader(): bool { if ($this->magic !== self::MAGIC) { return false; } if ($this->copyrightText !== self::COPYRIGHT_TEXT) { return false; } return version_compare($this->getFormattedBackupVersion(), self::MIN_BACKUP_VERSION, '>='); } public function getHeader(): string { return sprintf( '%s%s%s%s', str_pad(self::MAGIC, self::MAGIC_SIZE, "\0", STR_PAD_RIGHT), $this->encoder->intArrayToHex( self::HEADER_IN_USE_HEX_FORMAT, [ $this->backupVersion, $this->filesIndexStartOffset, $this->filesIndexEndOffset, $this->metadataStartOffset, $this->metadataEndOffset ] ), bin2hex(str_pad("", $this->getUnusedBytesSize(), "\0", STR_PAD_RIGHT)), self::COPYRIGHT_TEXT ); } public function updateHeader(string $backupFilePath) { $header = $this->getHeader(); $file = new FileObject($backupFilePath, 'r+'); $file->seek(0); $file->fwrite($header); $file = null; } public function verifyV1FormatHeader(string $content): bool { if (empty($content)) { return false; } $wpstgBackupHeaderFileContent = self::WPSTG_SQL_BACKUP_DUMP_HEADER; $headerToVerifyLength = strlen($wpstgBackupHeaderFileContent); if (substr($wpstgBackupHeaderFileContent, 0, $headerToVerifyLength) === substr($content, 0, $headerToVerifyLength)) { return true; } $wpstgBackupHeaderFile = WPSTG_RESOURCES_DIR . 'wpstgBackupHeader.txt'; if (!file_exists($wpstgBackupHeaderFile)) { return true; } $wpstgBackupHeaderFileContent = file_get_contents($wpstgBackupHeaderFile); $headerToVerifyLength = self::HEADER_SIZE; if (!empty($wpstgBackupHeaderFileContent) && substr($wpstgBackupHeaderFileContent, 0, $headerToVerifyLength) === substr($content, 0, $headerToVerifyLength)) { return true; } return false; } public function getV1FormatHeader(): string { $wpstgBackupHeaderFile = WPSTG_RESOURCES_DIR . 'wpstgBackupHeader.txt'; if (!file_exists($wpstgBackupHeaderFile)) { return ""; } return file_get_contents($wpstgBackupHeaderFile); } private function getHeaderInUseSize(): int { $size = 0; for ($i = 0; $i < strlen(self::HEADER_IN_USE_HEX_FORMAT); $i++) { $size += intval(substr(self::HEADER_IN_USE_HEX_FORMAT, $i, 1)); } return $size * 2; } private function getUnusedBytesSize(): int { return (self::HEADER_SIZE - $this->getHeaderInUseSize() - self::MAGIC_SIZE - self::COPYRIGHT_TEXT_SIZE) / 2; } }
    final class BackupMetadataReader { private $existingMetadataPosition; private $fileObject; public function __construct(FileObject $fileObject) { $this->fileObject = $fileObject; } public function readBackupMetadata(): array { $maxBackupMetadataSize = $this->getExpectedMaxBackupMetadataSize(); $negativeOffset = min($maxBackupMetadataSize, 1 * MB_IN_BYTES); $negativeOffset = max($negativeOffset, 32 * KB_IN_BYTES); $this->fileObject->fseek(max($this->fileObject->getSize() - $negativeOffset, 0), SEEK_SET); $backupMetadata = null; do { $this->existingMetadataPosition = $this->fileObject->ftell(); $line = trim($this->fileObject->readAndMoveNext()); if ($this->isValidMetadata($line)) { $backupMetadata = $this->extractMetadata($line); } } while ($this->fileObject->valid() && !is_array($backupMetadata)); if (!is_array($backupMetadata)) { $error = sprintf('Could not find metadata in the backup file %s - This file could be corrupt.', $this->fileObject->getFilename()); throw new \RuntimeException($error); } return $backupMetadata; } public function extractMetadata(string $line): array { $json = []; if (!$this->fileObject->isSqlFile()) { $json = json_decode($line, true); } else { $json = json_decode(substr($line, 3), true); } return empty($json) ? [] : $json; } public function isValidMetadata(string $line): bool { if ($this->fileObject->isSqlFile() && substr($line, 3, 1) !== '{') { return false; } elseif (!$this->fileObject->isSqlFile() && substr($line, 0, 1) !== '{') { return false; } $maybeMetadata = $this->extractMetadata($line); if (!is_array($maybeMetadata) || !array_key_exists('networks', $maybeMetadata) || !is_array($maybeMetadata['networks'])) { return false; } $network = $maybeMetadata['networks']['1']; if (!is_array($network) || !array_key_exists('blogs', $network) || !is_array($network['blogs'])) { return false; } return true; } public function getExistingMetadataPosition(): int { if ($this->existingMetadataPosition === null) { $this->readBackupMetadata(); } return $this->existingMetadataPosition; } private function getExpectedMaxBackupMetadataSize(): int { $maxBackupMetadataSize = 128 * KB_IN_BYTES; if (!function_exists('apply_filters')) { return $maxBackupMetadataSize; } return apply_filters('wpstg_max_backup_metadata_size', $maxBackupMetadataSize); } }
    final class MultipartMetadata implements \JsonSerializable
    {
        use HydrateTrait {
            hydrate as traitHydrate;
        }
        private $totalFiles;
        private $partSize = '';
        private $pluginsParts = [];
        private $mupluginsParts = [];
        private $themesParts = [];
        private $uploadsParts = [];
        private $othersParts = [];
        private $otherWpRootParts = [];
        private $databaseParts = [];
        private $databaseFiles = [];
        #[\ReturnTypeWillChange]
        public function jsonSerialize()
        {
            return $this->toArray();
        }
        public function toArray()
        {
            $array = get_object_vars($this);
            return $array;
        }
        public function hydrate(array $data = [])
        {
            $this->traitHydrate($data);
            return $this;
        }
        public function getTotalFiles()
        {
            return $this->totalFiles;
        }
        public function setTotalFiles($totalFiles)
        {
            $this->totalFiles = $totalFiles;
        }
        public function getPartSize()
        {
            return (int)$this->partSize;
        }
        public function setPartSize($partSize)
        {
            $this->partSize = (int)$partSize;
        }
        public function getPluginsParts()
        {
            return $this->pluginsParts;
        }
        public function setPluginsParts($parts)
        {
            $this->pluginsParts = $parts;
        }
        public function getMuPluginsParts()
        {
            return $this->mupluginsParts;
        }
        public function setMuPluginsParts($parts)
        {
            $this->mupluginsParts = $parts;
        }
        public function getThemesParts()
        {
            return $this->themesParts;
        }
        public function setThemesParts($parts)
        {
            $this->themesParts = $parts;
        }
        public function getUploadsParts()
        {
            return $this->uploadsParts;
        }
        public function setUploadsParts($parts)
        {
            $this->uploadsParts = $parts;
        }
        public function getOthersParts()
        {
            return $this->othersParts;
        }
        public function setOthersParts($parts)
        {
            $this->othersParts = $parts;
        }
        public function getOtherWpRootParts(): array
        {
            return $this->otherWpRootParts;
        }
        public function setOtherWpRootParts(array $parts)
        {
            $this->otherWpRootParts = $parts;
        }
        public function getDatabaseParts()
        {
            return $this->databaseParts;
        }
        public function setDatabaseParts($parts)
        {
            $this->databaseParts = $parts;
        }
        public function getDatabaseFiles()
        {
            return $this->databaseFiles;
        }
        public function setDatabaseFiles($files)
        {
            $this->databaseFiles = $files;
        }
        public function pushBackupPart($part, $fileInfo)
        {
            $partName            = $part . 'Parts';
            $this->{$partName}[] = $fileInfo;
        }
        public function addDatabaseFile($databaseFile)
        {
            $this->databaseFiles[] = $databaseFile;
        }
        public function getBackupParts()
        {
            return array_merge($this->databaseParts, $this->othersParts, $this->themesParts, $this->uploadsParts, $this->pluginsParts, $this->mupluginsParts, $this->otherWpRootParts);
        }
        public function getFileParts()
        {
            return array_merge($this->othersParts, $this->themesParts, $this->pluginsParts, $this->mupluginsParts, $this->uploadsParts, $this->otherWpRootParts);
        }
    }
    final class BackupMetadata implements \JsonSerializable
    {
        use HydrateTrait {
            hydrate as traitHydrate;
        }
        use IsExportingTrait;
        use DateCreatedTrait;
        use WithPluginsThemesMuPluginsTrait;
        const FILTER_BACKUP_FORMAT_V1 = 'wpstg.backup.format_v1';
        const BACKUP_TYPE_SINGLE = 'single';
        const BACKUP_TYPE_MULTISITE = 'multi';
        const BACKUP_TYPE_NETWORK_SUBSITE = 'network-subsite';
        const BACKUP_TYPE_MAIN_SITE = 'main-network-site';
        private $id;
        private $headerStart;
        private $headerEnd;
        private $backupVersion = '';
        private $wpstgVersion = '';
        private $totalFiles;
        private $totalDirectories;
        private $siteUrl;
        private $homeUrl;
        private $absPath;
        private $prefix;
        private $backupType = '';
        private $name;
        private $note;
        private $isAutomatedBackup = false;
        private $databaseFile;
        private $uploadedOn;
        private $maxTableLength;
        private $databaseFileSize;
        private $phpVersion;
        private $wpVersion;
        private $wpDbVersion;
        private $dbCollate;
        private $dbCharset;
        private $sqlServerVersion;
        private $backupSize = '';
        private $blogId;
        private $networkId;
        private $networkAdmins;
        private $uploadsPath;
        private $uploadsUrl;
        private $phpShortOpenTags;
        private $wpBakeryActive;
        private $isJetpackActive;
        private $isCreatedOnWordPressCom;
        private $scheduleId;
        private $sites;
        private $subdomainInstall;
        private $createdOnPro;
        private $nonWpTables;
        private $logFile = '';
        private $multipartMetadata = null;
        private $indexPartSize = [];
        private $isZlibCompressed = false;
        private $totalChunks = 0;
        private $hostingType;
        private $isContaining2GBFile = false;
        private $phpArchitecture;
        private $osArchitecture;
        #[\ReturnTypeWillChange]
        public function jsonSerialize(): array
        {
            return $this->toArray();
        }
        public function toArray(): array
        {
            $array = get_object_vars($this);
            return [
                'networks' => [
                    $this->getNetworkId() => [
                        'blogs' => [
                            $this->getBlogId() => $array,
                        ],
                    ],
                ],
            ];
        }
        public function hydrate(array $data = []): BackupMetadata
        {
            if (key($data) === 'networks') {
                if (array_key_exists($this->networkId, $data['networks'])) {
                    $data = $data['networks'][$this->networkId];
                } else {
                    $data = array_shift($data['networks']);
                }
            }
            if (key($data) === 'blogs') {
                if (array_key_exists($this->blogId, $data['blogs'])) {
                    $data = $data['blogs'][$this->blogId];
                } else {
                    $data = array_shift($data['blogs']);
                }
            }
            $this->traitHydrate($data);
            return $this;        }
        public function hydrateByFile(FileObject $file): BackupMetadata
        {
            $reader = new BackupMetadataReader($file);
            $backupMetadataArray = $reader->readBackupMetadata();
            return (new static())->hydrate($backupMetadataArray);        }
        public function hydrateByFilePath($filePath): BackupMetadata
        {
            return $this->hydrateByFile(new FileObject($filePath));
        }
        public function getId(): string
        {
            return $this->id;
        }
        public function setId(string $id)
        {
            $this->id = $id;
        }
        public function getHeader(string $backupPath)
        {
            if (!isset($this->headerStart)) {
                return '';
            }
            $backupFile = new FileObject($backupPath);
            $backupFile->fseek($this->headerStart);
            return $backupFile->fread($this->headerEnd - $this->headerStart);
        }
        public function getHeaderStart()
        {
            return $this->headerStart;
        }
        public function setHeaderStart($headerStart)
        {
            $this->headerStart = $headerStart;
        }
        public function getHeaderEnd()
        {
            return $this->headerEnd;
        }
        public function setHeaderEnd($headerEnd)
        {
            $this->headerEnd = $headerEnd;
        }
        public function getWpstgVersion(): string
        {
            return $this->wpstgVersion;
        }
        public function setWpstgVersion(string $wpstgVersion)
        {
            $this->wpstgVersion = $wpstgVersion;
        }
        public function setVersion(string $version)
        {
            $this->setWpstgVersion($version);
        }
        public function getBackupVersion(): string
        {
            return $this->backupVersion;
        }
        public function setBackupVersion(string $backupVersion)
        {
            $this->backupVersion = $backupVersion;
        }
        public function getTotalFiles()
        {
            return $this->totalFiles;
        }
        public function setTotalFiles($totalFiles)
        {
            $this->totalFiles = $totalFiles;
        }
        public function getTotalDirectories()
        {
            return $this->totalDirectories;
        }
        public function setTotalDirectories($totalDirectories)
        {
            $this->totalDirectories = $totalDirectories;
        }
        public function getSiteUrl(): string
        {
            return $this->siteUrl;
        }
        public function setSiteUrl(string $siteUrl)
        {
            $siteUrl = rtrim($siteUrl, '/');
            if (!preg_match('#http(s?)://(.+)#i', $siteUrl)) {
                throw new \RuntimeException('Please check the Site URL option of this WordPress installation. Contact WP STAGING support if you need assistance.');
            }
            if (!parse_url($siteUrl, PHP_URL_HOST)) {
                throw new \RuntimeException('Please check the Site URL option of this WordPress installation. Contact WP STAGING support if you need assistance.');
            }
            $this->siteUrl = $siteUrl;
        }
        public function getHomeUrl(): string
        {
            return $this->homeUrl;
        }
        public function setHomeUrl(string $homeUrl)
        {
            $homeUrl = rtrim($homeUrl, '/');
            if (!preg_match('#http(s?)://(.+)#i', $homeUrl)) {
                throw new \RuntimeException('Please check the Site URL option of this WordPress installation. Contact WP STAGING support if you need assistance.');
            }
            if (!parse_url($homeUrl, PHP_URL_HOST)) {
                throw new \RuntimeException('Please check the Home URL option of this WordPress installation. Contact WP STAGING support if you need assistance.');
            }
            $this->homeUrl = $homeUrl;
        }
        public function getPrefix()
        {
            return $this->prefix;
        }
        public function setPrefix($prefix)
        {
            $this->prefix = $prefix;
        }
        public function setSingleOrMulti(string $singleOrMulti)
        {
            $this->setBackupType($singleOrMulti);
        }
        public function getBackupType(): string
        {
            return $this->backupType;
        }
        public function setBackupType(string $backupType)
        {
            $this->backupType = $backupType;
        }
        public function getName(): string
        {
            return $this->name;
        }
        public function setName(string $name)
        {
            $this->name = $name;
        }
        public function getNote()
        {
            return $this->note;
        }
        public function setNote($note)
        {
            $this->note = $note;
        }
        public function getIsAutomatedBackup(): bool
        {
            return $this->isAutomatedBackup;
        }
        public function setIsAutomatedBackup(bool $isAutomatedBackup)
        {
            $this->isAutomatedBackup = $isAutomatedBackup;
        }
        public function getDatabaseFile()
        {
            return $this->databaseFile;
        }
        public function setDatabaseFile($databaseFile)
        {
            $this->databaseFile = $databaseFile;
        }
        public function getUploadedOn(): int
        {
            return $this->uploadedOn;
        }
        public function setUploadedOn($uploadedOn)
        {
            $this->uploadedOn = $uploadedOn;
        }
        public function getMaxTableLength()
        {
            return $this->maxTableLength;
        }
        public function setMaxTableLength($maxTableLength)
        {
            $this->maxTableLength = $maxTableLength;
        }
        public function getDatabaseFileSize()
        {
            return $this->databaseFileSize;
        }
        public function setDatabaseFileSize($databaseFileSize)
        {
            $this->databaseFileSize = $databaseFileSize;
        }
        public function getPhpVersion(): string
        {
            return (string)$this->phpVersion;
        }
        public function setPhpVersion(string $phpVersion)
        {
            $this->phpVersion = (string)$phpVersion;
        }
        public function getWpVersion(): string
        {
            return (string)$this->wpVersion;
        }
        public function setWpVersion(string $wpVersion)
        {
            $this->wpVersion = (string)$wpVersion;
        }
        public function getWpDbVersion(): string
        {
            return (string)$this->wpDbVersion;
        }
        public function setWpDbVersion(string $wpDbVersion)
        {
            $this->wpDbVersion = (string)$wpDbVersion;
        }
        public function getDbCollate(): string
        {
            return (string)$this->dbCollate;
        }
        public function setDbCollate(string $dbCollate)
        {
            $this->dbCollate = (string)$dbCollate;
        }
        public function getSqlServerVersion(): string
        {
            return (string)$this->sqlServerVersion;
        }
        public function setSqlServerVersion(string $sqlServerVersion)
        {
            $this->sqlServerVersion = (string)$sqlServerVersion;
        }
        public function getDbCharset(): string
        {
            return (string)$this->dbCharset;
        }
        public function setDbCharset(string $dbCharset)
        {
            $this->dbCharset = (string)$dbCharset;
        }
        public function getBackupSize(): int
        {
            return (int)$this->backupSize;
        }
        public function setBackupSize($backupSize)
        {
            $this->backupSize = (int)$backupSize;
        }
        public function getAbsPath(): string
        {
            return $this->absPath;
        }
        public function setAbsPath(string $absPath)
        {
            $this->absPath = $absPath;
        }
        public function getBlogId(): int
        {
            return $this->blogId;
        }
        public function setBlogId(int $blogId)
        {
            $this->blogId = $blogId;
        }
        public function getUploadsPath(): string
        {
            return $this->uploadsPath;
        }
        public function setUploadsPath(string $uploadsPath)
        {
            $this->uploadsPath = $uploadsPath;
        }
        public function getUploadsUrl(): string
        {
            return $this->uploadsUrl;
        }
        public function setUploadsUrl(string $uploadsUrl)
        {
            $this->uploadsUrl = $uploadsUrl;
        }
        public function getNetworkId(): int
        {
            return $this->networkId;
        }
        public function setNetworkId(int $networkId)
        {
            $this->networkId = $networkId;
        }
        public function getNetworkAdmins(): array
        {
            if (!is_array($this->networkAdmins)) {
                $this->networkAdmins = [];
            }
            return $this->networkAdmins;
        }
        public function setNetworkAdmins($networkAdmins)
        {
            $this->networkAdmins = $networkAdmins;
        }
        public function getPhpShortOpenTags(): bool
        {
            return $this->phpShortOpenTags;
        }
        public function setPhpShortOpenTags(bool $phpShortOpenTags)
        {
            $this->phpShortOpenTags = $phpShortOpenTags;
        }
        public function getWpBakeryActive(): bool
        {
            return $this->wpBakeryActive;
        }
        public function setWpBakeryActive(bool $wpBakeryActive)
        {
            $this->wpBakeryActive = $wpBakeryActive;
        }
        public function getIsJetpackActive(): bool
        {
            return $this->isJetpackActive ?? false;
        }
        public function setIsJetpackActive($isJetpackActive)
        {
            $this->isJetpackActive = $isJetpackActive;
        }
        public function getIsCreatedOnWordPressCom(): bool
        {
            return $this->isCreatedOnWordPressCom ?? false;
        }
        public function setIsCreatedOnWordPressCom($isCreatedOnWordPressCom)
        {
            $this->isCreatedOnWordPressCom = $isCreatedOnWordPressCom;
        }
        public function getScheduleId()
        {
            return $this->scheduleId;
        }
        public function setScheduleId($scheduleId)
        {
            $this->scheduleId = $scheduleId;
        }
        public function getSites()
        {
            return $this->sites;
        }
        public function setSites($sites)
        {
            $this->sites = $sites;
        }
        public function getSubdomainInstall(): bool
        {
            return $this->subdomainInstall;
        }
        public function setSubdomainInstall(bool $subdomainInstall)
        {
            $this->subdomainInstall = $subdomainInstall;
        }
        public function getCreatedOnPro(): bool
        {
            if (!isset($this->createdOnPro) || is_null($this->createdOnPro)) {
                $this->createdOnPro = true;
            }
            return $this->createdOnPro;
        }
        public function setCreatedOnPro($createdOnPro)
        {
            $this->createdOnPro = $createdOnPro;
        }
        public function getMultipartMetadata()
        {
            if (empty($this->multipartMetadata)) {
                return null;
            }
            if ($this->multipartMetadata instanceof MultipartMetadata) {
                return $this->multipartMetadata;
            }
            $metadata                = new MultipartMetadata();
            $this->multipartMetadata = $metadata->hydrate($this->multipartMetadata);
            return $this->multipartMetadata;
        }
        public function setMultipartMetadata($multipartMetadata)
        {
            $this->multipartMetadata = $multipartMetadata;
        }
        public function getIsMultipartBackup(): bool
        {
            return !empty($this->multipartMetadata);
        }
        public function getNonWpTables()
        {
            return $this->nonWpTables;
        }
        public function setNonWpTables($tables)
        {
            $this->nonWpTables = $tables;
        }
        public function setLogFile(string $fileName)
        {
            $this->logFile = $fileName;
        }
        public function setIndexPartSize(array $indexPartSize)
        {
            $this->indexPartSize = $indexPartSize;
        }
        public function getIndexPartSize(): array
        {
            return $this->indexPartSize;
        }
        public function getIsZlibCompressed()
        {
            return $this->isZlibCompressed;
        }
        public function setIsZlibCompressed($isZlibCompressed)
        {
            $this->isZlibCompressed = $isZlibCompressed;
        }
        public function getTotalChunks(): int
        {
            return $this->totalChunks;
        }
        public function setTotalChunks(int $totalChunks)
        {
            $this->totalChunks = $totalChunks;
        }
        public function getHostingType(): string
        {
            if (empty($this->hostingType)) {
                $this->hostingType = 'other';
            }
            return $this->hostingType;
        }
        public function setHostingType(string $hostingType)
        {
            $this->hostingType = $hostingType;
        }
        public function getIsContaining2GBFile(): bool
        {
            return $this->isContaining2GBFile;
        }
        public function setIsContaining2GBFile($isContaining2GBFile)
        {
            $this->isContaining2GBFile = (bool)$isContaining2GBFile;
        }
        public function getPhpArchitecture(): string
        {
            return $this->phpArchitecture;
        }
        public function setPhpArchitecture(string $phpArchitecture)
        {
            $this->phpArchitecture = $phpArchitecture;
        }
        public function getOsArchitecture(): string
        {
            return $this->osArchitecture;
        }
        public function setOsArchitecture(string $osArchitecture)
        {
            $this->osArchitecture = $osArchitecture;
        }
        public function getIsBackupFormatV1(): bool
        {
            return version_compare($this->getBackupVersion(), BackupHeader::MIN_BACKUP_VERSION, '<');
        }
        public function getIsMultisiteBackup(): bool
        {
            return $this->backupType !== self::BACKUP_TYPE_SINGLE;
        }
    }
    final class FileBeingExtracted { private $identifiablePath; private $relativePath; private $start; private $totalBytes; private $writtenBytes = 0; protected $extractFolder; protected $pathIdentifier; protected $isCompressed; public function __construct(string $identifiablePath, string $extractFolder, PathIdentifier $pathIdentifier, IndexLineInterface $backupFileIndex) { $this->identifiablePath = $identifiablePath; $this->extractFolder = rtrim($extractFolder, '/') . '/'; $this->start = $backupFileIndex->getContentStartOffset(); $this->totalBytes = $backupFileIndex->getCompressedSize(); $this->pathIdentifier = $pathIdentifier; $this->isCompressed = (int)$backupFileIndex->getIsCompressed(); $this->relativePath = $this->pathIdentifier->getPathWithoutIdentifier($this->identifiablePath); } public function getBackupPath() { return $this->extractFolder . $this->relativePath; } public function findReadTo() { $maxLengthToWrite = 512 * KB_IN_BYTES; $remainingBytesToWrite = $this->totalBytes - $this->writtenBytes; return max(0, min($remainingBytesToWrite, $maxLengthToWrite)); } public function getPath() { return $this->identifiablePath; } public function getRelativePath() { return $this->relativePath; } public function getStart() { return $this->start; } public function getTotalBytes() { return $this->totalBytes; } public function getWrittenBytes() { return $this->writtenBytes; } public function setWrittenBytes($writtenBytes) { $this->writtenBytes = $writtenBytes; } public function addWrittenBytes($writtenBytes) { $this->writtenBytes += $writtenBytes; } public function isFinished() { return $this->writtenBytes >= $this->totalBytes; } public function getIsCompressed() { return $this->isCompressed; } public function getCurrentOffset(): int { return $this->start + $this->writtenBytes; } }
    final class ExtractorDto { protected $indexStartOffset; protected $currentIndexOffset; protected $totalFilesExtracted; protected $totalFilesSkipped; protected $totalChunks; protected $extractorFileWrittenBytes; public function __construct() { $this->indexStartOffset = 0; $this->currentIndexOffset = 0; $this->totalFilesExtracted = 0; $this->totalFilesSkipped = 0; $this->totalChunks = 0; $this->extractorFileWrittenBytes = 0; } public function getIndexStartOffset(): int { return $this->indexStartOffset; } public function setIndexStartOffset(int $indexStartOffset) { $this->indexStartOffset = $indexStartOffset; } public function getCurrentIndexOffset(): int { return $this->currentIndexOffset; } public function setCurrentIndexOffset(int $currentOffset) { $this->currentIndexOffset = $currentOffset; } public function getTotalFilesExtracted(): int { return $this->totalFilesExtracted; } public function setTotalFilesExtracted(int $filesExtracted) { $this->totalFilesExtracted = $filesExtracted; } public function getTotalFilesSkipped(): int { return $this->totalFilesSkipped; } public function setTotalFilesSkipped(int $filesSkipped) { $this->totalFilesSkipped = $filesSkipped; } public function getTotalChunks(): int { return $this->totalChunks; } public function setTotalChunks(int $totalChunks) { $this->totalChunks = $totalChunks; } public function getExtractorFileWrittenBytes(): int { return $this->extractorFileWrittenBytes; } public function setExtractorFileWrittenBytes(int $extractorFileWrittenBytes) { $this->extractorFileWrittenBytes = $extractorFileWrittenBytes; } public function incrementTotalFilesExtracted() { $this->totalFilesExtracted++; } public function incrementTotalFilesSkipped() { $this->totalFilesSkipped++; } }
    final class BackupItemDto { private $offset; private $index; private $identifiablePath; private $path; private $size; private $isDatabase; public function __construct() { $this->offset = 0; $this->index = 0; $this->path = ''; $this->size = ''; $this->isDatabase = false; } public static function fromIndexLineDto(IndexLineInterface $indexLineDto): BackupItemDto { $backupFile = new BackupItemDto(); $backupFile->setIdentifiablePath($indexLineDto->getIdentifiablePath()); $backupFile->setSize($indexLineDto->getUncompressedSize()); $backupFile->setIsDatabase(false); return $backupFile; } public function setOffset(int $offset) { $this->offset = $offset; } public function setIndex(int $index) { $this->index = $index; } public function setIdentifiablePath(string $identifiablePath) { $this->identifiablePath = $identifiablePath; } public function setPath(string $path) { $this->path = $path; } public function setSize(string $size) { $this->size = $size; } public function setIsDatabase(bool $isDatabase) { $this->isDatabase = $isDatabase; } public function getOffset(): int { return $this->offset; } public function getIndex(): int { return $this->index; } public function getIdentifiablePath(): string { return $this->identifiablePath; } public function getPath(): string { return $this->path; } public function getSize(): string { return $this->size; } public function isDatabase(): bool { return $this->isDatabase; } public function toArray(): array { return [ 0 => $this->index, 1 => $this->path, 2 => $this->offset, 3 => $this->size, 4 => $this->isDatabase, 'offset' => $this->offset, 'index' => $this->index, 'path' => $this->path, 'size' => $this->size, 'isDatabase' => $this->isDatabase, ]; } }
    final class BackupFileIndex implements IndexLineInterface { use FormatTrait; public $bytesStart; public $bytesEnd; public $identifiablePath; public $isCompressed; public function __construct() { $this->bytesStart = 0; $this->bytesEnd = 0; $this->identifiablePath = ''; $this->isCompressed = 0; } public function readIndex(string $index): BackupFileIndex { list($identifiablePath, $entryMetadata) = explode('|', trim($index)); $entryMetadata = explode(':', trim($entryMetadata)); if (count($entryMetadata) < 2) { throw new \UnexpectedValueException('Invalid backup file index.'); } $offsetStart = (int)$entryMetadata[0]; $writtenPreviously = (int)$entryMetadata[1]; if (count($entryMetadata) >= 3) { $isCompressed = (int)$entryMetadata[2]; } else { $isCompressed = 0; } $backupFileIndex = new BackupFileIndex(); $backupFileIndex->identifiablePath = str_replace(['{WPSTG_PIPE}', '{WPSTG_COLON}'], ['|', ':'], $identifiablePath); $backupFileIndex->bytesStart = $offsetStart; $backupFileIndex->bytesEnd = $writtenPreviously; $backupFileIndex->isCompressed = $isCompressed; return $backupFileIndex; } public function readIndexLine(string $indexLine): IndexLineInterface { return $this->readIndex($indexLine); } public function createIndex(string $identifiablePath, int $bytesStart, int $bytesEnd, int $isCompressed): BackupFileIndex { $backupFileIndex = new BackupFileIndex(); $backupFileIndex->identifiablePath = str_replace(['|', ':'], ['{WPSTG_PIPE}', '{WPSTG_COLON}'], $identifiablePath); $backupFileIndex->bytesStart = $bytesStart; $backupFileIndex->bytesEnd = $bytesEnd; $backupFileIndex->isCompressed = $isCompressed; return $backupFileIndex; } public function getIndex(): string { return "$this->identifiablePath|$this->bytesStart:$this->bytesEnd:$this->isCompressed"; } public function isIndexLine(string $item): bool { return !empty($item) && strpos($item, ':') !== false && strpos($item, '|') !== false; } public function getContentStartOffset(): int { return $this->bytesStart; } public function getStartOffset(): int { return $this->bytesStart; } public function getIdentifiablePath(): string { return $this->identifiablePath; } public function getUncompressedSize(): int { return $this->bytesEnd; } public function getCompressedSize(): int { return $this->bytesEnd; } public function getIsCompressed(): bool { return $this->isCompressed === 1; } public function validateFile(string $filePath, string $pathForErrorLogging = '') { if (empty($pathForErrorLogging)) { $pathForErrorLogging = $filePath; } if (!file_exists($filePath)) { throw new FileValidationException(sprintf('File doesn\'t exist: %s.', $pathForErrorLogging)); } if ($this->getIsCompressed()) { return; } $fileSize = filesize($filePath); if ($this->getUncompressedSize() !== $fileSize) { throw new FileValidationException(sprintf('Filesize validation failed for file %s. Expected: %s. Actual: %s', $pathForErrorLogging, $this->formatSize($this->getUncompressedSize(), 2), $this->formatSize($fileSize, 2))); } } }
    final class FileHeaderAttribute { const COMPRESSED = 0b0000000000000001; const REQUIRE_PREVIOUS_PART = 0b0000000000000010; const REQUIRE_NEXT_PART = 0b0000000000000100; }
    final class FileHeader implements IndexLineInterface { use EndOfLinePlaceholderTrait; use FormatTrait; const START_SIGNATURE = '47f6600b0200'; const FILE_HEADER_FIXED_SIZE = 72; const INDEX_HEADER_FIXED_SIZE = 72; const FILE_HEADER_FORMAT = '44552424'; const INDEX_HEADER_FORMAT = '644552424'; const CRC32_CHECKSUM_ALGO = 'crc32b'; private $startSignature; private $modifiedTime; private $crc32Checksum; private $crc32; private $compressedSize; private $uncompressedSize; private $attributes; private $extraFieldLength; private $fileNameLength; private $filePathLength; private $startOffset; private $filePath; private $fileName; private $extraField; private $encoder; private $pathIdentifier; public function __construct(DataEncoder $encoder, PathIdentifier $pathIdentifier) { $this->encoder = $encoder; $this->pathIdentifier = $pathIdentifier; $this->resetHeader(); } public function readFile(string $filePath, string $identifiablePath) { $fileInfo = new \SplFileInfo($filePath); $this->setFileName($fileInfo->getFilename()); $convertedPath = $this->pathIdentifier->transformIdentifiableToPath($identifiablePath); $convertedPathName = basename($convertedPath); $path = substr($identifiablePath, 0, -strlen($convertedPathName)); $this->setFilePath($path); $this->setExtraField(""); $this->setUncompressedSize($fileInfo->getSize()); $this->setCompressedSize($fileInfo->getSize()); $this->setModifiedTime($fileInfo->getMTime()); $this->setAttributes(0); $this->setCrc32Checksum(hash_file(self::CRC32_CHECKSUM_ALGO, $filePath)); } public function decodeFileHeader(string $index) { $index = rtrim($index); $fixedHeader = substr($index, 0, self::FILE_HEADER_FIXED_SIZE); $dynamicHeader = substr($index, self::FILE_HEADER_FIXED_SIZE); if (strpos($fixedHeader, self::START_SIGNATURE) !== 0) { throw new \UnexpectedValueException('Invalid file header'); } $header = $this->encoder->hexToIntArray(self::FILE_HEADER_FORMAT, substr($fixedHeader, 12, self::FILE_HEADER_FIXED_SIZE - 12)); $this->setModifiedTime($header[0]); $this->setCrc32($header[1]); $this->setCompressedSize($header[2]); $this->setUncompressedSize($header[3]); $this->setAttributes($header[4]); $this->filePathLength = $header[5]; $this->fileNameLength = $header[6]; $this->extraFieldLength = $header[7]; $this->setFilePath(substr($dynamicHeader, 0, $this->filePathLength)); $this->setFileName(substr($dynamicHeader, $this->filePathLength, $this->fileNameLength)); $this->setExtraField(substr($dynamicHeader, $this->filePathLength + $this->fileNameLength, $this->extraFieldLength)); } public function decodeIndexHeader(string $index) { $index = rtrim($index); $fixedHeader = substr($index, 0, self::INDEX_HEADER_FIXED_SIZE); $dynamicHeader = substr($index, self::INDEX_HEADER_FIXED_SIZE); $header = $this->encoder->hexToIntArray(self::INDEX_HEADER_FORMAT, $fixedHeader); $this->setStartOffset($header[0]); $this->setModifiedTime($header[1]); $this->setCrc32($header[2]); $this->setCompressedSize($header[3]); $this->setUncompressedSize($header[4]); $this->setAttributes($header[5]); $this->filePathLength = $header[6]; $this->fileNameLength = $header[7]; $this->extraFieldLength = $header[8]; $this->setFilePath(substr($dynamicHeader, 0, $this->filePathLength)); $this->setFileName(substr($dynamicHeader, $this->filePathLength, $this->fileNameLength)); $this->setExtraField(substr($dynamicHeader, $this->filePathLength + $this->fileNameLength, $this->extraFieldLength)); } public function readIndexLine(string $indexLine): IndexLineInterface { $this->decodeIndexHeader($indexLine); return $this; } public function isIndexLine(string $indexLine): bool { if (strlen($indexLine) <= self::INDEX_HEADER_FIXED_SIZE) { return false; } return true; } public function getFileHeader(): string { $fixedHeader = $this->encoder->intArrayToHex(self::FILE_HEADER_FORMAT, [ $this->modifiedTime, $this->crc32, $this->compressedSize, $this->uncompressedSize, $this->attributes, $this->filePathLength, $this->fileNameLength, $this->extraFieldLength ]); $fileHeader = self::START_SIGNATURE . $fixedHeader . $this->filePath . $this->fileName . $this->extraField; $fileHeader = $this->replaceEOLsWithPlaceholders($fileHeader); return $fileHeader; } public function getIndexHeader(): string { $fixedHeader = $this->encoder->intArrayToHex(self::INDEX_HEADER_FORMAT, [ $this->startOffset, $this->modifiedTime, $this->crc32, $this->compressedSize, $this->uncompressedSize, $this->attributes, $this->filePathLength, $this->fileNameLength, $this->extraFieldLength ]); $fixedHeader = $fixedHeader . $this->filePath . $this->fileName . $this->extraField; $fixedHeader = $this->replaceEOLsWithPlaceholders($fixedHeader); return $fixedHeader; } public function resetHeader() { $this->startSignature = ''; $this->modifiedTime = 0; $this->crc32 = 0; $this->crc32Checksum = ''; $this->compressedSize = 0; $this->uncompressedSize = 0; $this->setAttributes(0); $this->extraFieldLength = 0; $this->fileNameLength = 0; $this->filePathLength = 0; $this->startOffset = 0; $this->filePath = ''; $this->fileName = ''; $this->extraField = ''; } public function getStartSignature(): string { return $this->startSignature; } public function setStartSignature(string $startSignature) { $this->startSignature = $startSignature; } public function getModifiedTime(): int { return $this->modifiedTime; } public function setModifiedTime(int $modifiedTime) { $this->modifiedTime = $modifiedTime; } public function getCrc32(): int { return $this->crc32; } public function setCrc32(int $crc32) { $this->crc32 = $crc32; $this->crc32Checksum = bin2hex(pack('N', $crc32)); } public function getCrc32Checksum(): string { return $this->crc32Checksum; } public function setCrc32Checksum(string $crc32Checksum) { $this->crc32Checksum = $crc32Checksum; $this->crc32 = unpack('N', pack('H*', $this->crc32Checksum))[1]; } public function getCompressedSize(): int { return $this->compressedSize; } public function setCompressedSize(int $compressedSize) { $this->compressedSize = $compressedSize; } public function getUncompressedSize(): int { return $this->uncompressedSize; } public function setUncompressedSize(int $uncompressedSize) { $this->uncompressedSize = $uncompressedSize; } public function getAttributes(): int { return $this->attributes; } public function setAttributes(int $attributes) { $this->attributes = $attributes; } public function getIsCompressed(): bool { if ($this->attributes & FileHeaderAttribute::COMPRESSED) { return true; } return false; } public function setIsCompressed(bool $isCompressed) { $isCompressed ? $this->attributes |= FileHeaderAttribute::COMPRESSED : $this->attributes &= ~FileHeaderAttribute::COMPRESSED; } public function getIsPreviousPartRequired(): bool { if ($this->attributes & FileHeaderAttribute::REQUIRE_PREVIOUS_PART) { return true; } return false; } public function setIsPreviousPartRequired(bool $isPreviousPartRequired) { $isPreviousPartRequired ? $this->attributes |= FileHeaderAttribute::REQUIRE_PREVIOUS_PART : $this->attributes &= ~FileHeaderAttribute::REQUIRE_PREVIOUS_PART; } public function getIsNextPartRequired(): bool { if ($this->attributes & FileHeaderAttribute::REQUIRE_NEXT_PART) { return true; } return false; } public function setIsNextPartRequired(bool $isNextPartRequired) { $isNextPartRequired ? $this->attributes |= FileHeaderAttribute::REQUIRE_NEXT_PART : $this->attributes &= ~FileHeaderAttribute::REQUIRE_NEXT_PART; } public function getStartOffset(): int { return $this->startOffset; } public function setStartOffset(int $startOffset) { $this->startOffset = $startOffset; } public function getFilePath(): string { return $this->filePath; } public function setFilePath(string $filePath) { $this->filePath = $filePath; $filePathRenamed = $this->replaceEOLsWithPlaceholders($filePath); $this->filePathLength = strlen($filePathRenamed); } public function getFileName(): string { return $this->fileName; } public function setFileName(string $fileName) { $this->fileName = $fileName; $renamedFile = $this->replaceEOLsWithPlaceholders($fileName); $this->fileNameLength = strlen($renamedFile); } public function getExtraField(): string { return $this->extraField; } public function setExtraField(string $extraField) { $this->extraField = $extraField; $this->extraFieldLength = strlen($extraField); } public function getIdentifiablePath(): string { return $this->filePath . $this->fileName; } public function getDynamicHeaderLength(): int { return $this->filePathLength + $this->fileNameLength + $this->extraFieldLength; } public function getContentStartOffset(): int { return $this->startOffset + self::FILE_HEADER_FIXED_SIZE + $this->getDynamicHeaderLength() + 1; } public function validateFile(string $filePath, string $pathForErrorLogging = '') { if (empty($pathForErrorLogging)) { $pathForErrorLogging = $filePath; } if (!file_exists($filePath)) { throw new FileValidationException(sprintf('File doesn\'t exist: %s.', $pathForErrorLogging)); } $fileSize = filesize($filePath); if ($this->getUncompressedSize() !== $fileSize) { throw new FileValidationException(sprintf('Filesize validation failed for file %s. Expected: %s. Actual: %s', $pathForErrorLogging, $this->formatSize($this->getUncompressedSize(), 2), $this->formatSize($fileSize, 2))); } $crc32Checksum = hash_file(self::CRC32_CHECKSUM_ALGO, $filePath); if ($this->crc32Checksum !== $crc32Checksum) { throw new FileValidationException(sprintf('CRC32 Checksum validation failed for file %s. Expected: %s. Actual: %s', $pathForErrorLogging, $this->getCrc32Checksum(), $crc32Checksum)); } } }
    final class ExtractorService { use FormatTrait; const VALIDATE_DIRECTORY = 'validate'; const ITEM_SKIP_EXCEPTION_CODE = 4001; const FINISHED_QUEUE_EXCEPTION_CODE = 4002; const FILE_FILTERED_EXCEPTION_CODE = 4003; protected $extractingFile; protected $wpstgFile; protected $dirRestore; protected $wpstgIndexOffsetForCurrentFile; protected $wpstgIndexOffsetForNextFile; protected $extractorDto; protected $bytesWrittenThisRequest = 0; protected $isBackupFormatV1 = false; protected $pathIdentifier; protected $directory; protected $backupHeader; protected $indexLineDto; protected $backupMetadata; protected $extractIdentifier = ''; protected $isValidateOnly = false; protected $excludedIdentifier = []; protected $databaseBackupFile; protected $defaultDirectoryOctal = 0755; protected $currentIdentifier; protected $throwExceptionOnValidationFailure = false; public function __construct( PathIdentifier $pathIdentifier, DirectoryInterface $directory, BackupHeader $backupHeader, Permissions $permissions ) { $this->pathIdentifier = $pathIdentifier; $this->directory = $directory; $this->backupHeader = $backupHeader; $this->defaultDirectoryOctal = $permissions->getDirectoryOctal(); $this->excludedIdentifier = []; } public function setExcludedIdentifiers(array $excludedIdentifier) { $this->excludedIdentifier = $excludedIdentifier; } public function setExtractOnlyPart(string $partToExtract) { $this->excludedIdentifier = []; if (empty($partToExtract)) { return; } $parts = [ PartIdentifier::DATABASE_PART_IDENTIFIER, PartIdentifier::MU_PLUGIN_PART_IDENTIFIER, PartIdentifier::PLUGIN_PART_IDENTIFIER, PartIdentifier::THEME_PART_IDENTIFIER, PartIdentifier::UPLOAD_PART_IDENTIFIER, PartIdentifier::LANGUAGE_PART_IDENTIFIER, PartIdentifier::WP_CONTENT_PART_IDENTIFIER, PartIdentifier::WP_ROOT_PART_IDENTIFIER, ]; foreach ($parts as $part) { if ($part === $partToExtract) { continue; } if ($part === PartIdentifier::DROPIN_PART_IDENTIFIER) { $this->excludedIdentifier[] = PartIdentifier::DROPIN_PART_IDENTIFIER; continue; } if ($part === PartIdentifier::DATABASE_PART_IDENTIFIER) { $this->excludedIdentifier[] = PartIdentifier::DATABASE_PART_IDENTIFIER; continue; } $this->excludedIdentifier[] = $this->pathIdentifier->getIdentifierByPartName($part); } } public function setIndexLineDto(IndexLineInterface $indexLineDto) { $this->indexLineDto = $indexLineDto; } public function setIsBackupFormatV1(bool $isBackupFormatV1) { $this->isBackupFormatV1 = $isBackupFormatV1; } public function setThrowExceptionOnValidationFailure(bool $throwExceptionOnValidationFailure) { $this->throwExceptionOnValidationFailure = $throwExceptionOnValidationFailure; } public function getBytesWrittenInThisRequest(): int { return $this->bytesWrittenThisRequest; } public function getExtractorDto(): ExtractorDto { return $this->extractorDto; } public function setup(ExtractorDto $extractorDto, string $backupFilePath, string $tmpPath = '') { $this->dirRestore = $tmpPath; $this->extractorDto = $extractorDto; $this->setFileToExtract($backupFilePath); if (empty($this->dirRestore)) { $this->dirRestore = $this->directory->getTmpDirectory(); } $this->dirRestore = rtrim($this->dirRestore, '/') . '/'; } public function setFileToExtract(string $filePath) { try { $this->wpstgFile = new FileObject($filePath); $this->backupMetadata = new BackupMetadata(); $this->backupMetadata = $this->backupMetadata->hydrateByFile($this->wpstgFile); $this->databaseBackupFile = $this->backupMetadata->getDatabaseFile(); $this->extractorDto->setIndexStartOffset($this->backupMetadata->getHeaderStart()); $this->extractorDto->setTotalChunks($this->backupMetadata->getTotalChunks()); } catch (\Exception $ex) { $this->throwMissingFileException($ex, $filePath); } } public function findFileToExtract(int $fileToExtractOffset = 0) { if ($fileToExtractOffset > 0) { $this->extractorDto->setCurrentIndexOffset($fileToExtractOffset); } if ($this->extractorDto->getCurrentIndexOffset() === 0) { $this->extractorDto->setCurrentIndexOffset($this->extractorDto->getIndexStartOffset()); } $this->wpstgFile->fseek($this->extractorDto->getCurrentIndexOffset()); $this->wpstgIndexOffsetForCurrentFile = $this->wpstgFile->ftell(); $rawIndexFile = $this->wpstgFile->readAndMoveNext(); $this->wpstgIndexOffsetForNextFile = $this->wpstgFile->ftell(); if (!$this->indexLineDto->isIndexLine($rawIndexFile)) { throw new \Exception("", self::FINISHED_QUEUE_EXCEPTION_CODE); } $backupFileIndex = $this->indexLineDto->readIndexLine($rawIndexFile); $identifiablePath = $backupFileIndex->getIdentifiablePath(); $identifier = $this->pathIdentifier->getIdentifierFromPath($identifiablePath); $this->currentIdentifier = $identifier; if ($this->isFileSkipped($identifiablePath, $identifier)) { $this->extractorDto->incrementTotalFilesSkipped(); $this->extractorDto->setCurrentIndexOffset($this->wpstgIndexOffsetForNextFile); throw new \Exception('Skipping file: ' . $identifiablePath, self::ITEM_SKIP_EXCEPTION_CODE); } $extractFolder = $this->getExtractFolder($identifier); if (!$this->createDirectory($extractFolder)) { throw new \RuntimeException("Could not create folder to extract backup file: $extractFolder"); } $this->extractingFile = new FileBeingExtracted($backupFileIndex->getIdentifiablePath(), $extractFolder, $this->pathIdentifier, $backupFileIndex); $this->extractingFile->setWrittenBytes($this->extractorDto->getExtractorFileWrittenBytes()); if ($this->isFileExtracted($backupFileIndex, $this->extractingFile->getBackupPath())) { $this->extractorDto->incrementTotalFilesSkipped(); $this->extractorDto->setCurrentIndexOffset($this->wpstgIndexOffsetForNextFile); throw new \Exception('File already extracted: ' . $identifiablePath, self::ITEM_SKIP_EXCEPTION_CODE); } $this->cleanExistingFile($identifier); $this->wpstgFile->fseek($this->extractingFile->getCurrentOffset()); $this->indexLineDto = $backupFileIndex; } public function createEmptyFile(string $filePath): bool { if (file_exists($filePath)) { return true; } return $this->filePutContents($filePath, '') !== false; } public function isExtractingFileExtracted(callable $logInfo): bool { $this->bytesWrittenThisRequest += $this->extractingFile->getWrittenBytes(); if ($this->extractingFile->isFinished()) { return true; } if ($this->extractingFile->getWrittenBytes() > 0 && $this->isBigFile()) { $percentProcessed = ceil(($this->extractingFile->getWrittenBytes() / $this->extractingFile->getTotalBytes()) * 100); $logInfo(sprintf('Extracting big file: %s - %s/%s (%s%%)', $this->extractingFile->getRelativePath(), $this->formatSize($this->extractingFile->getWrittenBytes(), 2), $this->formatSize($this->extractingFile->getTotalBytes(), 2), $percentProcessed)); } $this->extractorDto->setCurrentIndexOffset($this->wpstgIndexOffsetForCurrentFile); $this->extractorDto->setExtractorFileWrittenBytes($this->extractingFile->getWrittenBytes()); return false; } public function validateExtractedFileAndMoveNext() { $destinationFilePath = $this->extractingFile->getBackupPath(); $pathForErrorLogging = $this->pathIdentifier->transformIdentifiableToPath($this->indexLineDto->getIdentifiablePath()); if (file_exists($destinationFilePath) && filesize($destinationFilePath) === 0 && $this->extractingFile->getTotalBytes() !== 0) { throw new \RuntimeException(sprintf('File %s is empty', $pathForErrorLogging)); } if ($this->isBackupFormatV1) { $this->maybeRemoveLastAccidentalCharFromLastExtractedFile(); } $isValidated = true; $exception = null; clearstatcache(); try { $this->indexLineDto->validateFile($destinationFilePath, $pathForErrorLogging); } catch (FileValidationException $e) { $isValidated = false; $exception = $e; } $this->extractorDto->setCurrentIndexOffset($this->wpstgIndexOffsetForNextFile); $this->extractorDto->incrementTotalFilesExtracted(); $this->extractorDto->setExtractorFileWrittenBytes(0); $this->deleteValidationFile($destinationFilePath); if (!$isValidated) { throw $exception; } } public function finishExtractingFile() { $this->extractingFile->setWrittenBytes($this->extractingFile->getTotalBytes()); } public function getExtractingFile(): FileBeingExtracted { return $this->extractingFile; } public function getBackupFileOffset(): int { return $this->wpstgFile->ftell(); } public function readBackup(int $dataLengthToRead): string { return $this->wpstgFile->fread($dataLengthToRead); } protected function isBigFile(): bool { return $this->extractingFile->getTotalBytes() > 10 * MB_IN_BYTES; } protected function maybeRemoveLastAccidentalCharFromLastExtractedFile() { if ($this->isValidateOnly) { return; } if ($this->backupMetadata->getTotalFiles() !== $this->extractorDto->getTotalFilesExtracted()) { return; } $this->removeLastCharInExtractedFile(); } protected function throwMissingFileException(\Exception $ex, string $filePath) { throw new \Exception(sprintf("Following backup part missing: %s", $filePath), 0, $ex); } protected function removeLastCharInExtractedFile() { $destinationFilePath = $this->extractingFile->getBackupPath(); $fileContent = file_get_contents($destinationFilePath); if (empty($fileContent)) { return; } if (substr($fileContent, -1) !== 'w') { return; } $fileContent = substr($fileContent, 0, -1); file_put_contents($destinationFilePath, $fileContent); } protected function getExtractFolder(string $identifier): string { return $this->dirRestore . $this->pathIdentifier->getRelativePath($identifier); } protected function cleanExistingFile(string $identifier) { if ($this->isValidateOnly) { return; } if ($this->extractingFile->getWrittenBytes() > 0) { return; } if (file_exists($this->extractingFile->getBackupPath())) { if (!unlink($this->extractingFile->getBackupPath())) { throw new \RuntimeException(sprintf(__('Could not delete original file %s. Skipping restore of it...', 'wp-staging'), $this->extractingFile->getRelativePath())); } } } protected function deleteValidationFile(string $filePath) { if (!$this->isValidateOnly) { return; } if (file_exists($filePath)) { @unlink($filePath); } } protected function isFileSkipped(string $identifiablePath, string $identifier): bool { if ($identifiablePath === $this->databaseBackupFile) { return in_array(PartIdentifier::DATABASE_PART_IDENTIFIER, $this->excludedIdentifier); } if ($identifier === PathIdentifier::IDENTIFIER_WP_CONTENT && $this->pathIdentifier->hasDropinsFile($identifiablePath)) { return in_array(PartIdentifier::DROPIN_PART_IDENTIFIER, $this->excludedIdentifier); } return in_array($identifier, $this->excludedIdentifier); } protected function isFileExtracted(IndexLineInterface $backupFileIndex, string $extractPath): bool { if (!file_exists($extractPath)) { return false; } return $backupFileIndex->getUncompressedSize() === filesize($extractPath); } private function filePutContents(string $filePath, string $content): bool { if ($fp = fopen($filePath, 'wb')) { $bytes = fwrite($fp, $content); fclose($fp); $fp = null; return $bytes; } return false; } private function createDirectory(string $directory): bool { if (file_exists($directory)) { return @is_dir($directory); } if (!is_dir($directory) && !mkdir($directory, $this->defaultDirectoryOctal, true)) { return false; } return true; } }
    final class BackupsFinder { use WithBackupIdentifier; use DebugLogTrait; const MAX_BACKUP_FILE_TO_SCAN = 1000; protected $backupsDirectory; protected $backupsCount; public function resetBackupsCount() { $this->backupsCount = 0; } public function setBackupsDirectory(string $backupsDirectory) { $this->backupsDirectory = $backupsDirectory; } public function getBackupsDirectory(bool $refresh = false): string { return $this->backupsDirectory; } public function findBackups(): array { try { $it = new \DirectoryIterator($this->getBackupsDirectory(true)); } catch (\Exception $e) { $this->debugLog('WP STAGING: Could not find backup directory ' . $e->getMessage()); return []; } $backups = []; $this->clearListedMultipartBackups(); foreach ($it as $file) { if (($file->getExtension() === 'wpstg' || $file->getExtension() === 'sql') && !$file->isLink()) { if ($this->backupsCount >= self::MAX_BACKUP_FILE_TO_SCAN) { break; } if ($this->isBackupPart($file->getFilename()) && $this->isListedMultipartBackup($file->getFilename())) { continue; } $backups[] = clone $file; $this->backupsCount++; } } return $backups; } public function findBackupByMd5Hash(string $md5): \SplFileInfo { $backup = array_filter($this->findBackups(), function ($splFileInfo) use ($md5) { return md5($splFileInfo->getBasename()) === $md5; }); if (empty($backup)) { throw new \UnexpectedValueException('WP STAGING: Could not find backup by hash ' . $md5); } return array_shift($backup); } }
    final class BackupContent { private $backupFile; private $totalFiles; private $filesFound; private $perPage; private $headerOffset = 0; private $indexPage = 0; private $currentOffset = 0; private $currentIndex = 0; private $indexLineDto; private $pathIdentifier; private $filters = [ 'filename' => '', 'sortby' => '', ]; private $databaseFiles = []; public function setBackup(string $backupFile, IndexLineInterface $indexLineDto, $backupMetadata = null) { if ($backupMetadata === null) { $backupMetadata = new BackupMetadata(); $backupMetadata = $backupMetadata->hydrateByFilePath($backupFile); } $this->backupFile = $backupFile; $this->indexLineDto = $indexLineDto; $this->totalFiles = $backupMetadata->getTotalFiles(); $this->headerOffset = $backupMetadata->getHeaderStart(); } public function setPerPage(int $perPage) { $this->perPage = $perPage; } public function setPathIdentifier(PathIdentifier $pathIdentifier) { $this->pathIdentifier = $pathIdentifier; } public function setDatabaseFiles(array $databaseFiles) { $this->databaseFiles = $databaseFiles; } public function setFilters(array $filters) { $filters['filename'] = $filters['filename'] ?? ''; $filters['sortby'] = $filters['sortby'] ?? ''; $this->filters = $filters; } public function getFiles(int $page = 1) { if ($page < 1) { $page = 1; } $this->indexPage = $page; $offset = ($page - 1) * $this->perPage; $wpstgFile = new FileObject($this->backupFile, 'rb'); $wpstgFile->fseek($this->headerOffset); $count = 0; $this->filesFound = 0; while ($wpstgFile->valid()) { $this->currentOffset = $wpstgFile->ftell(); $this->currentIndex = $wpstgFile->key(); $rawIndexFile = $wpstgFile->readAndMoveNext(); if (!$this->indexLineDto->isIndexLine($rawIndexFile)) { break; } $indexLineDto = $this->indexLineDto->readIndexLine($rawIndexFile); $backupFile = BackupItemDto::fromIndexLineDto($indexLineDto); $backupFile->setPath($this->pathIdentifier->transformIdentifiableToRelativePath($backupFile->getIdentifiablePath())); $backupFile->setOffset($this->currentOffset); $backupFile->setIndex($this->currentIndex); if ($this->isFiltered($backupFile)) { continue; } $this->filesFound++; if ($this->filesFound < $offset || $count === $this->perPage) { continue; } yield $backupFile; $count++; } } public function getPagingData(): array { return [ 'totalIndex' => $this->filesFound, 'totalPage' => ceil($this->filesFound / $this->perPage), 'indexPage' => $this->indexPage, 'indexFilter' => $this->filters['filename'], 'indexSortby' => $this->filters['sortby'], ]; } private function isFiltered(BackupItemDto $backupFile): bool { if ($this->filterByName($backupFile)) { return true; } return $this->filterBySortBy($backupFile); } private function filterByName(BackupItemDto $backupFile): bool { if (empty($this->filters['filename'])) { return false; } return strpos($backupFile->getPath(), $this->filters['filename']) === false; } private function filterBySortBy(BackupItemDto $backupFile): bool { if (empty($this->filters['sortby'])) { return false; } if ($this->filters['sortby'] === PartIdentifier::DATABASE_PART_IDENTIFIER) { return !in_array($backupFile->getIdentifiablePath(), $this->databaseFiles); } if ($this->filters['sortby'] === PartIdentifier::UPLOAD_PART_IDENTIFIER && in_array($backupFile->getIdentifiablePath(), $this->databaseFiles)) { return true; } if ($this->filters['sortby'] === PartIdentifier::DROPIN_PART_IDENTIFIER) { return !$this->pathIdentifier->hasDropinsFile($backupFile->getIdentifiablePath()); } $identifier = $this->pathIdentifier->getIdentifierByPartName($this->filters['sortby']); return $identifier !== $this->pathIdentifier->getIdentifierFromPath($backupFile->getIdentifiablePath()); } }
    final class SearchReplace
    {
        use DebugLogTrait;
        use SerializeTrait;
        use UrlTrait;
        private $search;
        private $replace;
        private $exclude;
        private $caseSensitive;
        private $currentSearch;
        private $currentReplace;
        private $isWpBakeryActive;
        protected $smallerReplacement = PHP_INT_MAX;
        public function __construct(array $search = [], array $replace = [], $caseSensitive = true, array $exclude = [])
        {
            $this->search           = $search;
            $this->replace          = $replace;
            $this->caseSensitive    = $caseSensitive;
            $this->exclude          = $exclude;
            $this->isWpBakeryActive = false;
        }
        public function getSmallerSearchLength()
        {
            if ($this->smallerReplacement < PHP_INT_MAX) {
                return $this->smallerReplacement;
            }
            foreach ($this->search as $search) {
                if (strlen($search) < $this->smallerReplacement) {
                    $this->smallerReplacement = strlen($search);
                }
            }
            return $this->smallerReplacement;
        }
        public function replace($data)
        {
            if (defined('DISABLE_WPSTG_SEARCH_REPLACE') && (bool)DISABLE_WPSTG_SEARCH_REPLACE) {
                return $data;
            }
            if (!$this->search || !$this->replace) {
                return $data;
            }
            $totalSearch  = count($this->search);
            $totalReplace = count($this->replace);
            if ($totalSearch !== $totalReplace) {
                throw new \RuntimeException(
                    sprintf(
                        'Can not search and replace. There are %d items to search and %d items to replace',
                        $totalSearch,
                        $totalReplace
                    )
                );
            }
            for ($i = 0; $i < $totalSearch; $i++) {
                $this->currentSearch  = (string)$this->search[$i];
                $this->currentReplace = (string)$this->replace[$i];
                $data                 = $this->walker($data);
            }
            return $data;
        }
        public function replaceExtended($data)
        {
            if ($this->isWpBakeryActive) {
                $data = preg_replace_callback('/\[vc_raw_html\](.+?)\[\/vc_raw_html\]/S', [$this, 'replaceWpBakeryValues'], $data);
            }
            return $this->replace($data);
        }
        public function replaceWpBakeryValues($matched)
        {
            $data = $this->base64Decode($matched[1]);
            $data = $this->replace($data);
            return '[vc_raw_html]' . base64_encode($data) . '[/vc_raw_html]';
        }
        public function setSearch(array $search)
        {
            $this->search = $search;
            return $this;
        }
        public function setReplace(array $replace)
        {
            $this->replace = $replace;
            return $this;
        }
        public function setCaseSensitive($caseSensitive)
        {
            $this->caseSensitive = $caseSensitive;
            return $this;
        }
        public function setExclude(array $exclude)
        {
            $this->exclude = $exclude;
            return $this;
        }
        public function setWpBakeryActive($isActive = true)
        {
            $this->isWpBakeryActive = $isActive;
            return $this;
        }
        private function walker($data)
        {
            switch (gettype($data)) {
                case "string":
                    return $this->replaceString($data);
                case "array":
                    return $this->replaceArray($data);
                case "object":
                    return $this->replaceObject($data);
            }
            return $data;
        }
        private function replaceString($data)
        {
            if (!$this->isSerialized($data)) {
                return $this->strReplace($data);
            }
            if (strpos($data, 'O:3:"PDO":0:') !== false) {
                return $data;
            }
            if (strpos($data, 'O:8:"DateTime":0:') !== false) {
                return $data;
            }
            if (strpos($data, 'O:') !== false && preg_match_all('@O:\d+:"([^"]+)"@', $data, $match) && !empty($match) && !empty($match[1])) {
                foreach ($match[1] as $value) {
                    if ($value !== 'stdClass') {
                        return $data;
                    }
                }
                unset($match);
            }
            $unserialized = false;
            try {
                $unserialized = @unserialize($data);
            } catch (\Throwable $e) {
                $this->debugLog('replaceString. Can not unserialize data. Error: ' . $e->getMessage() . ' Data: ' . $data);
            }
            if ($unserialized !== false) {
                return serialize($this->walker($unserialized));
            }
            return $data;
        }
        private function replaceArray(array $data)
        {
            foreach ($data as $key => $value) {
                $data[$key] = $this->walker($value);
            }
            return $data;
        }
        private function replaceObject($data)
        {
            $props = get_object_vars($data);
            if (!empty($props['__PHP_Incomplete_Class_Name'])) {
                return $data;
            }
            foreach ($props as $key => $value) {
                if ($key === '' || (isset($key[0]) && ord($key[0]) === 0)) {
                    continue;
                }
                $data->{$key} = $this->walker($value);
            }
            return $data;
        }
        private function strReplace($data = '')
        {
            $regexExclude = '';
            foreach ($this->exclude as $excludeString) {
                $regexExclude .= $excludeString . '(*SKIP)(*FAIL)|';
            }
            $pattern = '#' . $regexExclude . preg_quote($this->currentSearch, null) . '#';
            if (!$this->caseSensitive) {
                $pattern .= 'i';
            }
            return preg_replace($pattern, $this->currentReplace, $data);
        }
    }
    final class MysqliAdapter implements InterfaceDatabaseClient { public $link; public function __construct($link = null) { $this->link = $link; } public function query($query) { return mysqli_query($this->link, $query); } public function realQuery($query, $isExecOnly = false) { if ($isExecOnly) { return mysqli_real_query($this->link, $query); } if (!mysqli_real_query($this->link, $query)) { return false; } if (defined('MYSQLI_STORE_RESULT_COPY_DATA')) { return mysqli_store_result($this->link, MYSQLI_STORE_RESULT_COPY_DATA); } return mysqli_store_result($this->link); } public function escape($input) { return mysqli_real_escape_string($this->link, $input); } public function errno() { return mysqli_errno($this->link); } public function error() { return mysqli_error($this->link); } public function version() { return mysqli_get_server_info($this->link); } public function fetchAll($result) { $data = []; while ($row = mysqli_fetch_assoc($result)) { $data[] = $row; } return $data; } public function fetchAssoc($result) { return mysqli_fetch_assoc($result); } public function fetchRow($result) { return mysqli_fetch_row($result); } public function fetchObject($result) { return mysqli_fetch_object($result); } public function numRows($result) { return mysqli_num_rows($result); } public function freeResult($result) { if ($result === null) { return null; } mysqli_free_result($result); return null; } public function insertId() { return mysqli_insert_id($this->link); } public function foundRows() { return mysqli_affected_rows($this->link); } public function getLink() { return $this->link; } }
    final class DatabaseImporterDto { private $currentIndex = 0; private $totalLines = 0; private $tableToRestore = ''; private $tmpPrefix = ''; private $shortTablesToRestore = []; private $shortTablesToDrop = []; private $backupType = BackupMetadata::BACKUP_TYPE_SINGLE; private $subsiteId = null; public function getCurrentIndex(): int { return $this->currentIndex; } public function setCurrentIndex(int $currentIndex) { $this->currentIndex = $currentIndex; } public function getTotalLines(): int { return $this->totalLines; } public function setTotalLines(int $totalLines) { $this->totalLines = $totalLines; } public function finish() { $this->currentIndex = $this->totalLines; } public function getTableToRestore(): string { return $this->tableToRestore; } public function setTableToRestore(string $tableToRestore) { $this->tableToRestore = $tableToRestore; } public function getTmpPrefix(): string { return $this->tmpPrefix; } public function setTmpPrefix(string $tmpPrefix) { $this->tmpPrefix = $tmpPrefix; } public function addShortNameTable(string $table, string $prefix): string { $shortName = uniqid($prefix) . str_pad(rand(0, 999999), 6, '0'); if ($prefix === $this->tmpPrefix) { $this->shortTablesToRestore[$shortName] = $table; } elseif ($prefix === DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP) { $this->shortTablesToDrop[$shortName] = $table; } return $shortName; } public function getShortNameTable(string $table, string $prefix): string { $shortTables = []; if ($prefix === $this->tmpPrefix) { $shortTables = $this->shortTablesToRestore; } elseif ($prefix === DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP) { $shortTables = $this->shortTablesToDrop; } return (string)array_search($table, $shortTables); } public function getFullNameTableFromShortName(string $table, string $prefix): string { $shortTables = []; if ($prefix === $this->tmpPrefix) { $shortTables = $this->shortTablesToRestore; } elseif ($prefix === DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP) { $shortTables = $this->shortTablesToDrop; } if (!array_key_exists($table, $shortTables)) { return $table; } return $shortTables[$table]; } public function getShortTables(string $prefix): array { if ($prefix === $this->tmpPrefix) { return $this->shortTablesToRestore; } elseif ($prefix === DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP) { return $this->shortTablesToDrop; } return []; } public function setShortTables(array $tables, string $prefix) { if ($prefix === $this->tmpPrefix) { $this->shortTablesToRestore = $tables; } elseif ($prefix === DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP) { $this->shortTablesToDrop = $tables; } } public function getBackupType(): string { return $this->backupType; } public function setBackupType(string $backupType) { $this->backupType = $backupType; } public function getSubsiteId() { return $this->subsiteId; } public function setSubsiteId($subsiteId) { $this->subsiteId = $subsiteId; } }
    final class ExtendedInserterWithoutTransaction extends QueryInserter { protected $extendedQuery = ''; public function processQuery(&$queryToInsert) { if ($this->doQueryExceedsMaxAllowedPacket($queryToInsert)) { return null; } $this->extendInsert($queryToInsert); if (strlen($this->extendedQuery) >= $this->limitedMaxAllowedPacket) { return $this->execExtendedQuery(); } return null; } public function commit() { $this->execExtendedQuery(); } public function execExtendedQuery() { if (empty($this->extendedQuery)) { return null; } $this->extendedQuery .= ';'; $success = $this->exec($this->extendedQuery); if ($success) { $this->extendedQuery = ''; $this->databaseImporterDto->setTableToRestore(''); return true; } else { $this->showError(); $this->extendedQuery = ''; $this->databaseImporterDto->setTableToRestore(''); return false; } } protected function showError() { switch ($this->client->errno()) { case 1153: case 2006: $this->addWarning($this->translate('The error message means got a packet bigger than max_allowed_packet bytes.', 'wp-staging')); break; case 1030: $this->addWarning($this->translate('Engine changed to InnoDB, as it your MySQL server does not support MyISAM.', 'wp-staging')); break; case 1071: case 1709: $this->addWarning($this->translate('Row format changed to DYNAMIC, as it would exceed the maximum length according to your MySQL settings. To not see this message anymore, please upgrade your MySQL version or increase the row format.', 'wp-staging')); break; case 1214: $this->addWarning($this->translate('FULLTEXT removed from query, as your current MySQL version does not support it. To not see this message anymore, please upgrade your MySQL version.', 'wp-staging')); break; case 1226: if (stripos($this->client->error(), 'max_queries_per_hour') !== false) { $this->addWarning($this->translate('Your server has reached the maximum allowed queries per hour set by your admin or hosting provider. Please increase MySQL max_queries_per_hour_limit. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>', 'wp-staging')); } elseif (stripos($this->client->error(), 'max_updates_per_hour') !== false) { $this->addWarning($this->translate('Your server has reached the maximum allowed updates per hour set by your admin or hosting provider. Please increase MySQL max_updates_per_hour. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>', 'wp-staging')); } elseif (stripos($this->client->error(), 'max_connections_per_hour') !== false) { $this->addWarning($this->translate('Your server has reached the maximum allowed connections per hour set by your admin or hosting provider. Please increase MySQL max_connections_per_hour. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>', 'wp-staging')); } elseif (stripos($this->client->error(), 'max_user_connections') !== false) { $this->addWarning($this->translate('Your server has reached the maximum allowed connections per hour set by your admin or hosting provider. Please increase MySQL max_user_connections. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>', 'wp-staging')); } break; case 1813: $this->addWarning($this->translate('Could not restore the database. MySQL returned the error code 1813, which is related to a tablespace error that WP STAGING can\'t handle. Please contact your hosting company.', 'wp-staging')); } if (defined('WPSTG_DEBUG') && WPSTG_DEBUG) { $this->addWarning(sprintf($this->translate('ExtendedInserterWithoutTransaction Failed Query: %s', 'wp-staging'), substr($this->extendedQuery, 0, 1000))); } if ($this->backupDbVersion !== $this->currentDbVersion) { $additionalInfo = sprintf($this->translate(' Your current MySQL version is %s. If this issue persists, try using the same MySQL version used to create this Backup (%s).', 'wp-staging'), $this->currentDbVersion, $this->backupDbVersion); } $this->addWarning(sprintf($this->translate('Could not restore the query. MySQL has returned the error code %d, with message "%s".', 'wp-staging'), $this->client->errno(), $this->client->error()) . $additionalInfo); } protected function extendInsert(&$insertQuery) { preg_match('#^INSERT INTO `(.+?(?=`))` VALUES (\(.+\));$#', $insertQuery, $matches); if (count($matches) !== 3) { throw new \Exception("Skipping INSERT query: $insertQuery"); } $insertingIntoTableName = $matches[1]; $extendedQueryMaxLength = $this->limitedMaxAllowedPacket; if (isset($this->client->isSQLite) && $this->client->isSQLite && method_exists($this->client, 'getSQLitePageSize')) { $extendedQueryMaxLength = $this->client->getSQLitePageSize(); $extendedQueryMaxLength = empty($extendedQueryMaxLength) ? 2048 : $extendedQueryMaxLength; } $insertingIntoHeader = "INSERT INTO `$insertingIntoTableName` VALUES "; $isFirstValue = false; if (empty($this->databaseImporterDto->getTableToRestore())) { if (!empty($this->extendedQuery)) { throw new \UnexpectedValueException('Query is not empty, cannot proceed.'); } $this->databaseImporterDto->setTableToRestore($insertingIntoTableName); $this->extendedQuery .= $insertingIntoHeader; $isFirstValue = true; } elseif ($insertingIntoTableName !== $this->databaseImporterDto->getTableToRestore()) { $this->execExtendedQuery(); if (!empty($this->extendedQuery)) { throw new \UnexpectedValueException('Query is not empty, cannot proceed.'); } $this->databaseImporterDto->setTableToRestore($insertingIntoTableName); $this->extendedQuery .= $insertingIntoHeader; $isFirstValue = true; } if (!$isFirstValue && strlen($this->extendedQuery . ",$matches[2]") >= $extendedQueryMaxLength) { $this->execExtendedQuery(); if (!empty($this->extendedQuery)) { throw new \UnexpectedValueException('Query is not empty, cannot proceed.'); } $this->databaseImporterDto->setTableToRestore($insertingIntoTableName); $this->extendedQuery .= $insertingIntoHeader; $isFirstValue = true; } if ($isFirstValue) { $this->extendedQuery .= $matches[2]; } else { $this->extendedQuery .= ",$matches[2]"; } } }
    final class QueryCompatibility { public function removeDefiner(&$query) { if (!stripos($query, 'DEFINER')) { return; } $query = preg_replace('# DEFINER\s?=\s?(.+?(?= )) #i', ' ', $query); } public function removeSqlSecurity(&$query) { if (!stripos($query, 'SQL SECURITY')) { return; } $query = preg_replace('# SQL SECURITY \w+ #i', ' ', $query); } public function removeAlgorithm(&$query) { if (!stripos($query, 'ALGORITHM')) { return; } $query = preg_replace('# ALGORITHM\s?=\s?`?\w+`? #i', ' ', $query); } public function replaceTableEngineIfUnsupported(&$query) { $query = str_ireplace([ 'ENGINE=MyISAM', 'ENGINE=Aria', ], [ 'ENGINE=InnoDB', 'ENGINE=InnoDB', ], $query); } public function replaceTableRowFormat(&$query) { $query = str_ireplace([ 'ENGINE=InnoDB', 'ENGINE=MyISAM', ], [ 'ENGINE=InnoDB ROW_FORMAT=DYNAMIC', 'ENGINE=MyISAM ROW_FORMAT=DYNAMIC', ], $query); } public function removeFullTextIndexes(&$query) { $query = preg_replace('#,\s?FULLTEXT \w+\s?`?\w+`?\s?\([^)]+\)#i', '', $query); } public function convertUtf8Mb4toUtf8(&$query) { $query = str_ireplace('utf8mb4', 'utf8', $query); } public function shortenKeyIdentifiers(&$query) { $shortIdentifiers = []; $matches = []; preg_match_all("#KEY `(.*?)`#", $query, $matches); foreach ($matches[1] as $identifier) { if (strlen($identifier) < 64) { continue; } $shortIdentifier = uniqid(DatabaseImporter::TMP_DATABASE_PREFIX) . str_pad(rand(0, 999999), 6, '0'); $shortIdentifiers[$shortIdentifier] = $identifier; } $query = str_replace(array_values($shortIdentifiers), array_keys($shortIdentifiers), $query); return $shortIdentifiers; } public function pageCompressionMySQL(&$query, $errorMessage) { if (strpos($errorMessage, 'PAGE_COMPRESSED') === false) { return ''; } $query = str_replace([ "`PAGE_COMPRESSED`='ON'", "`PAGE_COMPRESSED`='OFF'", "`PAGE_COMPRESSED`='0'", "`PAGE_COMPRESSED`='1'", ], ['', '', '', ''], $query); preg_match('/create\s+table\s+\`?(\w+)`/i', $query, $matches); return $matches[1]; } }
    final class DatabaseImporter { use DebugLogTrait; use ApplyFiltersTrait; use SerializeTrait; const THRESHOLD_EXCEPTION_CODE = 2001; const FINISHED_QUEUE_EXCEPTION_CODE = 2002; const RETRY_EXCEPTION_CODE = 2003; const FILE_FORMAT = 'sql'; const TMP_DATABASE_PREFIX = 'wpstgtmp_'; const TMP_DATABASE_PREFIX_TO_DROP = 'wpstgbak_'; const NULL_FLAG = "{WPSTG_NULL}"; const BINARY_FLAG = "{WPSTG_BINARY}"; private $file; private $totalLines; private $client; private $databaseImporterDto; private $database; private $warningLogCallable; private $searchReplace; private $searchReplaceForPrefix; private $tmpDatabasePrefix; private $queryInserter; private $smallerSearchLength; private $binaryFlagLength; private $queryCompatibility; private $isSameSiteBackupRestore = false; private $tablesExcludedFromSearchReplace = []; private $subsiteManager; private $backupDbVersion; public function __construct( DatabaseInterface $database, QueryInserter $queryInserter, QueryCompatibility $queryCompatibility, SubsiteManagerInterface $subsiteManager ) { $this->client = $database->getClient(); $this->database = $database; $this->queryInserter = $queryInserter; $this->queryCompatibility = $queryCompatibility; $this->subsiteManager = $subsiteManager; $this->binaryFlagLength = strlen(self::BINARY_FLAG); } public function setFile($filePath) { $this->file = new FileObject($filePath); $this->totalLines = $this->file->totalLines(); return $this; } public function seekLine($line) { if (!$this->file) { throw new \RuntimeException('Restore file is not set'); } $this->file->seek($line); return $this; } public function init(string $tmpDatabasePrefix) { $this->tmpDatabasePrefix = $tmpDatabasePrefix; $this->databaseImporterDto->setTmpPrefix($this->tmpDatabasePrefix); $this->setupSearchReplaceForPrefix(); if (!$this->file) { throw new \RuntimeException('Restore file is not set'); } $this->exec("SET SESSION sql_mode = 'NO_AUTO_VALUE_ON_ZERO'"); if ($this->applyFilters('wpstg.backup.restore.innodbStrictModeOff', false) === true) { $this->exec("SET SESSION innodb_strict_mode=OFF"); } } public function retryQuery() { $this->databaseImporterDto->setCurrentIndex($this->file->key() - 1); $this->queryInserter->commit(); } public function updateIndex() { $this->databaseImporterDto->setCurrentIndex($this->file->key()); $this->queryInserter->commit(); } public function getCurrentOffset(): int { return (int)$this->file->ftell(); } public function finish() { $this->databaseImporterDto->finish(); $this->queryInserter->commit(); } public function getQueryCompatibility(): QueryCompatibility { return $this->queryCompatibility; } public function isSupportPageCompression(): bool { static $hasCompression; if ($hasCompression !== null) { return $hasCompression; } if (!$this->isMariaDB()) { return false; } $query = "SHOW GLOBAL STATUS WHERE Variable_name IN ('Innodb_have_lz4', 'Innodb_have_lzo', 'Innodb_have_lzma', 'Innodb_have_bzip2', 'Innodb_have_snappy');"; $result = $this->client->query($query); if (! ($result instanceof \mysqli_result)) { return false; } while ($row = $result->fetch_assoc()) { if ($row['Value'] === 'ON') { $hasCompression = true; return true; } } $hasCompression = false; return false; } public function isMariaDB(): bool { return stripos($this->serverInfo(), 'MariaDB') !== false; } public function removePageCompression(&$query): bool { if (!strpos($query, 'PAGE_COMPRESSED') || !(stripos($query, "CREATE TABLE") == 0)) { return false; } if ($this->isSupportPageCompression()) { return false; } $query = preg_replace("@`?PAGE_COMPRESSED`?='?(ON|OFF|0|1)'?@", '', $query); if (strpos($query, 'PAGE_COMPRESSION_LEVEL') !== false) { $query = preg_replace("@`?PAGE_COMPRESSION_LEVEL`?='?\d+'?@", '', $query); } return true; } public function setup(DatabaseImporterDto $databaseImporterDto, bool $isSameSiteBackupRestore, string $backupDbVersion) { $this->databaseImporterDto = $databaseImporterDto; $this->isSameSiteBackupRestore = $isSameSiteBackupRestore; $this->backupDbVersion = $backupDbVersion; $this->queryInserter->setDbVersions($this->serverVersion(), $this->backupDbVersion); $this->queryInserter->initialize($this->client, $this->databaseImporterDto); $this->subsiteManager->initialize($this->databaseImporterDto); } public function setupNonWpTables(array $nonWpTables) { $this->tablesExcludedFromSearchReplace = $nonWpTables; } public function setSearchReplace(SearchReplace $searchReplace) { $this->searchReplace = $searchReplace; $this->smallerSearchLength = min($searchReplace->getSmallerSearchLength(), $this->binaryFlagLength); return $this; } public function getTotalLines() { return $this->totalLines; } public function setWarningLogCallable(callable $callable) { $this->warningLogCallable = $callable; } public function execute() { $query = $this->findExecutableQuery(); if (!$query) { throw new \Exception("", self::FINISHED_QUEUE_EXCEPTION_CODE); } $query = $this->searchReplaceForPrefix->replace($query); $query = $this->maybeShorterTableNameForDropTableQuery($query); $query = $this->maybeShorterTableNameForCreateTableQuery($query); $query = $this->maybeFixReplaceTableConstraints($query); $this->replaceTableCollations($query); if (strpos($query, 'INSERT INTO') === 0) { if ($this->isExcludedInsertQuery($query)) { $this->debugLog('processQuery - This query has been skipped from inserting by using a custom filter: ' . $query); $this->logWarning(sprintf('The query has been skipped from inserting by using a custom filter: %s.', esc_html($query))); return false; } if ($this->subsiteManager->isTableFromDifferentSubsite($query)) { $this->subsiteManager->updateSubsiteId(); throw new \Exception("", self::RETRY_EXCEPTION_CODE); } if ( !$this->isSameSiteBackupRestore || (strpos($query, self::BINARY_FLAG) !== false) || (strpos($query, self::NULL_FLAG) !== false) ) { $this->searchReplaceInsertQuery($query); } try { $result = $this->queryInserter->processQuery($query); } catch (\Exception $e) { throw $e; } if ($result === null && $this->queryInserter->getLastError() !== false) { $this->logWarning($this->queryInserter->getLastError()); } } else { $this->queryInserter->commit(); $this->queryCompatibility->removeDefiner($query); $this->queryCompatibility->removeSqlSecurity($query); $this->queryCompatibility->removeAlgorithm($query); $result = $this->exec($query); } $errorNo = $this->client->errno(); $errorMsg = $this->client->error(); $currentDbVersion = $this->database->getSqlVersion($compact = true); $backupDbVersion = $this->backupDbVersion; if ($result === false) { switch ($this->client->errno()) { case 1030: $this->queryCompatibility->replaceTableEngineIfUnsupported($query); $result = $this->exec($query); if ($result) { $this->logWarning('Engine changed to InnoDB, as it your MySQL server does not support MyISAM.'); } break; case 1071: case 1709: $this->queryCompatibility->replaceTableRowFormat($query); $replaceUtf8Mb4 = ($errorNo === 1071 && version_compare($currentDbVersion, '5.7', '<')); if ($replaceUtf8Mb4) { $this->queryCompatibility->convertUtf8Mb4toUtf8($query); } $result = $this->exec($query); if ($result) { $this->logWarning('Row format changed to DYNAMIC, as it would exceed the maximum length according to your MySQL settings. To not see this message anymore, please upgrade your MySQL version or increase the row format.'); } if ($replaceUtf8Mb4 && $result) { $this->logWarning('Encoding changed to UTF8 from UTF8MB4, as your current MySQL version max key length support is 767 bytes'); } break; case 1214: $this->queryCompatibility->removeFullTextIndexes($query); $result = $this->exec($query); if ($result) { $this->logWarning('FULLTEXT removed from query, as your current MySQL version does not support it. To not see this message anymore, please upgrade your MySQL version.'); } break; case 1226: if (stripos($this->client->error(), 'max_queries_per_hour') !== false) { throw new \RuntimeException('Your server has reached the maximum allowed queries per hour set by your admin or hosting provider. Please increase MySQL max_queries_per_hour_limit. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>'); } elseif (stripos($this->client->error(), 'max_updates_per_hour') !== false) { throw new \RuntimeException('Your server has reached the maximum allowed updates per hour set by your admin or hosting provider. Please increase MySQL max_updates_per_hour. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>'); } elseif (stripos($this->client->error(), 'max_connections_per_hour') !== false) { throw new \RuntimeException('Your server has reached the maximum allowed connections per hour set by your admin or hosting provider. Please increase MySQL max_connections_per_hour. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>'); } elseif (stripos($this->client->error(), 'max_user_connections') !== false) { throw new \RuntimeException('Your server has reached the maximum allowed connections per hour set by your admin or hosting provider. Please increase MySQL max_user_connections. <a href="https://wp-staging.com/docs/mysql-database-error-codes/" target="_blank">Technical details</a>'); } break; case 1118: throw new \RuntimeException('Your server has reached the maximum row size of the table. Please refer to the documentation on how to fix it. <a href="https://wp-staging.com/docs/mysql-database-error-codes" target="_blank">Technical details</a>'); case 1059: $shortIdentifiers = $this->queryCompatibility->shortenKeyIdentifiers($query); $result = $this->exec($query); if ($result) { foreach ($shortIdentifiers as $shortIdentifier => $identifier) { $this->logWarning(sprintf('Key identifier `%s` exceeds the characters limits, it is now shortened to `%s` to continue restoring.', $identifier, $shortIdentifier)); } } break; case 1064: $tableName = $this->queryCompatibility->pageCompressionMySQL($query, $errorMsg); if (!empty($tableName)) { $result = $this->exec($query); } if (!empty($tableName) && $result) { $this->logWarning(sprintf('PAGE_COMPRESSED removed from Table: %s, as it is not a supported syntax in MySQL.', $tableName)); } break; case 1813: throw new \RuntimeException('Could not restore the database. MySQL returned the error code 1813, which is related to a tablespace error that WP STAGING can\'t handle. Please contact your hosting company.'); } if ($result) { return true; } if (defined('WPSTG_DEBUG') && WPSTG_DEBUG) { $this->logWarning(sprintf('Database Restorer - Failed Query: %s', substr($query, 0, 1000))); $this->debugLog(sprintf('Database Restorer Failed Query: %s', substr($query, 0, 1000))); if (isset($this->client->isSQLite) && $this->client->isSQLite) { $this->debugLog($errorMsg); } } $errorNo = $this->client->errno(); $errorMsg = $this->client->error(); $additionalInfo = ''; if ($backupDbVersion !== $currentDbVersion) { $additionalInfo = sprintf(' Your current MySQL version is %s. If this issue persists, try using the same MySQL version used to create this Backup (%s).', $currentDbVersion, $backupDbVersion); } throw new \RuntimeException(sprintf('Could not restore query. MySQL has returned the error code %d, with message "%s".', $errorNo, $errorMsg) . $additionalInfo); } return $result; } protected function maybeShorterTableNameForDropTableQuery(&$query) { if (strpos($query, "DROP TABLE IF EXISTS") !== 0) { return $query; } preg_match('#^DROP TABLE IF EXISTS `(.+?(?=`))`;$#', $query, $dropTableExploded); $tableName = $dropTableExploded[1]; if (strlen($tableName) > 64) { $tableName = $this->databaseImporterDto->addShortNameTable($tableName, $this->tmpDatabasePrefix); } return "DROP TABLE IF EXISTS `$tableName`;"; } protected function maybeShorterTableNameForCreateTableQuery(&$query) { if (strpos($query, "CREATE TABLE") !== 0) { return $query; } preg_match('#^CREATE TABLE `(.+?(?=`))`#', $query, $createTableExploded); $tableName = $createTableExploded[1]; if (strlen($tableName) > 64) { $shortName = $this->databaseImporterDto->getShortNameTable($tableName, $this->tmpDatabasePrefix); return str_replace($tableName, $shortName, $query); } return $query; } protected function maybeFixReplaceTableConstraints(&$query) { if (strpos($query, "CREATE TABLE") !== 0) { return $query; } if (preg_match('@KEY\s+\`.*\`\s+?\(.*\)(,(\s+)?\`.*`\)\s+ON\s+(DELETE|UPDATE).*?)\)@i', $query, $matches)) { $query = str_replace($matches[1], '', $query); } $patterns = [ '/\s+CONSTRAINT(.+)REFERENCES(.+)(\s+)?,/i', '/,(\s+)?(KEY(.+))?CONSTRAINT(.+)REFERENCES(.+)\`\)(\s+)?\)/i', ]; $replace = ['', ')']; $query = preg_replace($patterns, $replace, $query); if ($this->isCorruptedCreateTableQuery($query)) { $query = $this->replaceLastMatch("`);", "`) );", $query); } return $query; } public function searchReplaceInsertQuery(&$query) { if (!$this->searchReplace) { throw new \RuntimeException('SearchReplace not set'); } $querySize = strlen($query); if ($querySize > ini_get('pcre.backtrack_limit')) { $this->logWarning( sprintf( 'Skipped search & replace on query: "%s" Increasing pcre.backtrack_limit can fix it! Query Size: %s. pcre.backtrack_limit: %s', substr($query, 0, 1000) . '...', $querySize, ini_get('pcre.backtrack_limit') ) ); return; } preg_match('#^INSERT INTO `(.+?(?=`))` VALUES (\(.+\));$#', $query, $insertIntoExploded); if (count($insertIntoExploded) !== 3) { $this->debugLog($query); throw new \OutOfBoundsException('Skipping insert query. The query was logged....'); } $tableName = $insertIntoExploded[1]; if (strlen($tableName) > 64) { $tableName = $this->databaseImporterDto->getShortNameTable($tableName, $this->tmpDatabasePrefix); } $values = $insertIntoExploded[2]; preg_match_all("#'(?:[^'\\\]++|\\\.)*+'#s", $values, $valueMatches); if (count($valueMatches) !== 1) { throw new \RuntimeException('Value match in query does not match.'); } $valueMatches = $valueMatches[0]; $query = "INSERT INTO `$tableName` VALUES ("; foreach ($valueMatches as $value) { if (empty($value) || $value === "''") { $query .= "'', "; continue; } if ($value === "'" . self::NULL_FLAG . "'") { $query .= "NULL, "; continue; } if ($this->smallerSearchLength > strlen($value) - 2) { $query .= "{$value}, "; continue; } $value = substr($value, 1, -1); if (strpos($value, self::BINARY_FLAG) === 0) { $query .= "UNHEX('" . substr($value, strlen(self::BINARY_FLAG)) . "'), "; continue; } if ($this->isSameSiteBackupRestore || !$this->shouldSearchReplace($query)) { $query .= "'{$value}', "; continue; } if ($this->isSerialized($value)) { $value = $this->undoMySqlRealEscape($value); $value = $this->searchReplace->replaceExtended($value); $value = $this->mySqlRealEscape($value); } else { $value = $this->searchReplace->replaceExtended($value); } $query .= "'{$value}', "; } $query = rtrim($query, ', '); $query .= ');'; } protected function undoMySqlRealEscape(&$query) { $replacementMap = [ "\\0" => "\0", "\\n" => "\n", "\\r" => "\r", "\\t" => "\t", "\\Z" => chr(26), "\\b" => chr(8), '\"' => '"', "\'" => "'", '\\\\' => '\\', ]; return strtr($query, $replacementMap); } protected function mySqlRealEscape(&$query) { $replacementMap = [ "\0" => "\\0", "\n" => "\\n", "\r" => "\\r", "\t" => "\\t", chr(26) => "\\Z", chr(8) => "\\b", '"' => '\"', "'" => "\'", '\\' => '\\\\', ]; return strtr($query, $replacementMap); } protected function setupSearchReplaceForPrefix() { $this->searchReplaceForPrefix = new SearchReplace(['{WPSTG_TMP_PREFIX}', '{WPSTG_FINAL_PREFIX}'], [$this->tmpDatabasePrefix, $this->database->getPrefix()], true, []); } protected function shouldSearchReplace($query) { if (empty($this->tablesExcludedFromSearchReplace)) { return true; } preg_match('#^INSERT INTO `(.+?(?=`))` VALUES#', $query, $insertIntoExploded); $tableName = $insertIntoExploded[0]; return !in_array($tableName, $this->tablesExcludedFromSearchReplace); } private function findExecutableQuery() { while (!$this->file->eof()) { $line = $this->getLine(); if ($this->isExecutableQuery($line)) { return $line; } } return; } private function getLine() { if ($this->file->eof()) { return; } return trim($this->file->readAndMoveNext()); } public function isExecutableQuery($query = null) { if (!$query) { return false; } $first2Chars = substr($query, 0, 2); if ($first2Chars === '--' || strpos($query, '#') === 0) { return false; } if ($first2Chars === '/*') { return false; } if (stripos($query, 'start transaction;') === 0) { return false; } if (stripos($query, 'commit;') === 0) { return false; } if (substr($query, -strlen(1)) !== ';') { $this->logWarning('Skipping query because it does not end with a semi-colon... The query was logged.'); $this->debugLog($query); return false; } return true; } private function exec($query) { $result = $this->client->query($query); return $result !== false; } private function replaceTableCollations(string &$input) { static $search = []; static $replace = []; if (!empty($search) && !empty($replace)) { $input = str_replace($search, $replace, $input); return; } if ($this->hasCapabilities('utf8mb4_520')) { $search = ['utf8mb4_0900_ai_ci']; $replace = ['utf8mb4_unicode_520_ci']; $input = str_replace($search, $replace, $input); return; } if (!$this->hasCapabilities('utf8mb4')) { $search = ['utf8mb4_0900_ai_ci', 'utf8mb4_unicode_520_ci', 'utf8mb4']; $replace = ['utf8_unicode_ci', 'utf8_unicode_ci', 'utf8']; } else { $search = ['utf8mb4_0900_ai_ci', 'utf8mb4_unicode_520_ci']; $replace = ['utf8mb4_unicode_ci', 'utf8mb4_unicode_ci']; } $input = str_replace($search, $replace, $input); } private function isExcludedInsertQuery($query) { $excludedQueries = $this->applyFilters('wpstg.database.import.excludedQueries', []); if (empty($excludedQueries)) { return false; } foreach ($excludedQueries as $excludedQuery) { if (strpos($query, $excludedQuery) === 0) { return true; } } return false; } private function replaceLastMatch(string $needle, string $replace, string $haystack): string { $result = $haystack; $pos = strrpos($haystack, $needle); if ($pos !== false) { $result = substr_replace($haystack, $replace, $pos, strlen($needle)); } return $result; } protected function isCorruptedCreateTableQuery(string $query): bool { if (strpos($query, "ENGINE") !== false) { return false; } if (strpos($query, "CHARSET") !== false) { return false; } if (strpos($query, "COLLATE") !== false) { return false; } return true; } protected function logWarning(string $message) { $callable = $this->warningLogCallable; $callable($message); } private function hasCapabilities(string $capabilities): bool { $serverVersion = $this->serverVersion(); $serverInfo = $this->serverInfo(); if ($serverVersion === '5.5.5' && strpos($serverInfo, 'MariaDB') !== false && PHP_VERSION_ID < 80016) { $serverInfo = preg_replace('@^5\.5\.5-(.*)@', '$1', $serverInfo); $serverVersion = preg_replace('@[^0-9.].*@', '', $serverInfo); } switch (strtolower($capabilities)) { case 'collation': return version_compare($serverVersion, '4.1', '>='); case 'set_charset': return version_compare($serverVersion, '5.0.7', '>='); case 'utf8mb4': if (version_compare($serverVersion, '5.5.3', '<')) { return false; } $clienVersion = $this->clientInfo(); if (false !== strpos($clienVersion, 'mysqlnd')) { $clienVersion = preg_replace('@^\D+([\d.]+).*@', '$1', $clienVersion); return version_compare($clienVersion, '5.0.9', '>='); } else { return version_compare($clienVersion, '5.5.3', '>='); } case 'utf8mb4_520': return version_compare($serverVersion, '5.6', '>='); } return false; } private function clientInfo(): string { return !empty($this->client->getLink()->host_info) ? $this->client->getLink()->host_info : ''; } private function serverInfo(): string { return !empty($this->client->getLink()->server_info) ? $this->client->getLink()->server_info : ''; } private function serverVersion(): string { $serverInfo = $this->serverInfo(); if (stripos($serverInfo, 'MariaDB') !== false && preg_match('@^([0-9\.]+)\-([0-9\.]+)\-MariaDB@i', $serverInfo, $match)) { return $match[2]; } return preg_replace('@[^0-9\.].*@', '', $serverInfo); } }
    final class AdjustSubsitesMeta { use ApplyFiltersTrait; use DebugLogTrait; use SlashTrait; use UrlTrait; const FILTER_MULTISITE_SUBSITES = 'wpstg.backup.restore.multisites.subsites'; protected $sites; private $sourceSiteDomain; private $sourceSitePath; private $sourceSiteUrl; private $sourceHomeUrl; protected $isSourceSubdomainInstall; public function getSourceSiteDomain(): string { return $this->sourceSiteDomain; } public function getSourceSitePath(): string { return $this->sourceSitePath; } public function getSourceSiteUrl(): string { return $this->sourceSiteUrl; } public function getSourceHomeUrl(): string { return $this->sourceHomeUrl; } public function getIsSourceSubdomainInstall(): bool { return $this->isSourceSubdomainInstall; } public function setSourceSiteDomain(string $sourceSiteDomain) { $this->sourceSiteDomain = $sourceSiteDomain; } public function setSourceSitePath(string $sourceSitePath) { $this->sourceSitePath = $sourceSitePath; } public function setSourceSiteUrl(string $sourceSiteUrl) { $this->sourceSiteUrl = $sourceSiteUrl; } public function setSourceHomeUrl(string $sourceHomeUrl) { $this->sourceHomeUrl = $sourceHomeUrl; } public function setSourceSubdomainInstall(bool $isSubdomainInstall) { $this->isSourceSubdomainInstall = $isSubdomainInstall; } public function setSourceSites(array $sites) { $this->sites = []; foreach ($sites as $site) { $this->sites[] = SubsiteDto::createFromSiteData($site); } } public function getAdjustedSubsites(string $baseDomain, string $basePath, string $siteURL, string $homeURL, bool $isSubdomainInstall): array { $adjustedSites = []; foreach ($this->sites as $site) { $adjustedSite = $this->adjustSubsite($site, $baseDomain, $basePath, $siteURL, $homeURL, $isSubdomainInstall); $adjustedSites[] = $adjustedSite->toArray(); } $filteredAdjustedSites = $this->applyFilters(self::FILTER_MULTISITE_SUBSITES, $adjustedSites, $baseDomain, $basePath, $siteURL, $homeURL, $isSubdomainInstall); if (is_array($filteredAdjustedSites)) { return $filteredAdjustedSites; } $this->debugLog('Filter: wpstg.backup.restore.multisites.subsites does not return an array. Using default subsites.'); return $adjustedSites; } public function readBackupMetadata(BackupMetadata $backupMetadata) { $this->isSourceSubdomainInstall = $backupMetadata->getSubdomainInstall(); $this->sourceSiteUrl = $backupMetadata->getSiteUrl(); $this->sourceHomeUrl = $backupMetadata->getHomeUrl(); $sourceSiteURLWithoutWWW = str_ireplace('//www.', '//', $this->sourceSiteUrl); $parsedURL = parse_url($sourceSiteURLWithoutWWW); if (!is_array($parsedURL) || !array_key_exists('host', $parsedURL)) { throw new \UnexpectedValueException("Bad URL format, cannot proceed."); } $this->sourceSiteDomain = $parsedURL['host']; $this->sourceSitePath = '/'; if (array_key_exists('path', $parsedURL)) { $this->sourceSitePath = $parsedURL['path']; } $this->sites = []; foreach ($backupMetadata->getSites() as $site) { $this->sites[] = SubsiteDto::createFromSiteData($site); } } private function adjustSubsite(SubsiteDto $site, string $baseDomain, string $basePath, string $siteURL, string $homeURL, bool $isSubdomainInstall): AdjustedSubsiteDto { $sourceSiteDomain = strpos($this->sourceSiteDomain, 'www.') === 0 ? substr($this->sourceSiteDomain, 4) : $this->sourceSiteDomain; $subsiteDomain = strpos($site->getDomain(), 'www.') === 0 ? substr($site->getDomain(), 4) : $site->getDomain(); if ($sourceSiteDomain === $subsiteDomain && $this->sourceSitePath === $site->getPath()) { $adjustedSite = AdjustedSubsiteDto::createFromSiteData($site->toArray()); $adjustedSite->setAdjustedDomain($baseDomain); $adjustedSite->setAdjustedPath($basePath); $adjustedSite->setAdjustedSiteUrl(rtrim($siteURL, '/')); $adjustedSite->setAdjustedHomeUrl(rtrim($homeURL, '/')); return $adjustedSite; } $sourceSiteUrlWithoutScheme = $this->getUrlWithoutScheme($this->sourceSiteUrl); $sourceHomeUrlWithoutScheme = $this->getUrlWithoutScheme($this->sourceHomeUrl); $destinationSiteUrlWithoutScheme = $this->getUrlWithoutScheme($siteURL); $destinationHomeUrlWithoutScheme = $this->getUrlWithoutScheme($homeURL); $subsiteSiteUrlWwwPrefix = ''; if (strpos($destinationSiteUrlWithoutScheme, 'www.') === 0) { $subsiteSiteUrlWwwPrefix = 'www.'; } $subsiteHomeUrlWwwPrefix = ''; if (strpos($destinationHomeUrlWithoutScheme, 'www.') === 0) { $subsiteHomeUrlWwwPrefix = 'www.'; } $sourceSiteUrlWithoutScheme = strpos($sourceSiteUrlWithoutScheme, 'www.') === 0 ? substr($sourceSiteUrlWithoutScheme, 4) : $sourceSiteUrlWithoutScheme; $sourceHomeUrlWithoutScheme = strpos($sourceHomeUrlWithoutScheme, 'www.') === 0 ? substr($sourceHomeUrlWithoutScheme, 4) : $sourceHomeUrlWithoutScheme; $destinationSiteUrlWithoutScheme = strpos($destinationSiteUrlWithoutScheme, 'www.') === 0 ? substr($destinationSiteUrlWithoutScheme, 4) : $destinationSiteUrlWithoutScheme; $destinationHomeUrlWithoutScheme = strpos($destinationHomeUrlWithoutScheme, 'www.') === 0 ? substr($destinationHomeUrlWithoutScheme, 4) : $destinationHomeUrlWithoutScheme; $subsiteDomain = str_replace($this->sourceSiteDomain, $baseDomain, $site->getDomain()); $subsitePath = str_replace($this->trailingslashit($this->sourceSitePath), $basePath, $site->getPath()); $subsiteSiteUrlWithoutScheme = str_replace($sourceSiteUrlWithoutScheme, $destinationSiteUrlWithoutScheme, $site->getSiteUrl()); $subsiteSiteUrlWithoutScheme = $this->getUrlWithoutScheme($subsiteSiteUrlWithoutScheme); $subsiteSiteUrlWithoutScheme = strpos($subsiteSiteUrlWithoutScheme, 'www.') === 0 ? substr($subsiteSiteUrlWithoutScheme, 4) : $subsiteSiteUrlWithoutScheme; $subsiteHomeUrlWithoutScheme = str_replace($sourceHomeUrlWithoutScheme, $destinationHomeUrlWithoutScheme, $site->getHomeUrl()); $subsiteHomeUrlWithoutScheme = $this->getUrlWithoutScheme($subsiteHomeUrlWithoutScheme); $subsiteHomeUrlWithoutScheme = strpos($subsiteHomeUrlWithoutScheme, 'www.') === 0 ? substr($subsiteHomeUrlWithoutScheme, 4) : $subsiteHomeUrlWithoutScheme; $subsiteSiteUrlSchemePrefix = parse_url($siteURL, PHP_URL_SCHEME) . '://'; $subsiteHomeUrlSchemePrefix = parse_url($homeURL, PHP_URL_SCHEME) . '://'; $baseSiteUrlWithoutScheme = $this->untrailingslashit($baseDomain . $basePath); $addWwwPrefix = strpos($baseDomain, 'www.') === 0 ? true : false; $subsiteDomain = rtrim($subsiteDomain, '/'); $subsiteDomain = strpos($subsiteDomain, 'www.') === 0 ? substr($subsiteDomain, 4) : $subsiteDomain; $subsiteDomain = $addWwwPrefix ? 'www.' . $subsiteDomain : $subsiteDomain; if ($this->isSourceSubdomainInstall === $isSubdomainInstall && $subsiteSiteUrlWithoutScheme === $baseSiteUrlWithoutScheme && $this->areBothHomeUrlSiteUrlInSameDomain($subsiteHomeUrlWithoutScheme, $subsiteSiteUrlWithoutScheme)) { $adjustedSite = AdjustedSubsiteDto::createFromSiteData($site->toArray()); $adjustedSite->setAdjustedDomain($subsiteDomain); $adjustedSite->setAdjustedPath($subsitePath); $adjustedSite->setAdjustedSiteUrl($subsiteSiteUrlSchemePrefix . $subsiteSiteUrlWwwPrefix . $subsiteSiteUrlWithoutScheme); $adjustedSite->setAdjustedHomeUrl($subsiteHomeUrlSchemePrefix . $subsiteHomeUrlWwwPrefix . $subsiteHomeUrlWithoutScheme); return $adjustedSite; } $baseSiteUrlWithoutScheme = strpos($baseSiteUrlWithoutScheme, 'www.') === 0 ? substr($baseSiteUrlWithoutScheme, 4) : $baseSiteUrlWithoutScheme; if (strpos($subsiteSiteUrlWithoutScheme, $baseSiteUrlWithoutScheme) === false) { return $this->adjustDomainBasedSubsite($site, $baseDomain, $basePath, $subsiteSiteUrlSchemePrefix . $subsiteSiteUrlWwwPrefix, $subsiteHomeUrlSchemePrefix . $subsiteHomeUrlWwwPrefix, $isSubdomainInstall); } $adjustSiteUrl = $this->getAdjustedSubsiteInfo($baseDomain, $basePath, $baseSiteUrlWithoutScheme, $subsiteSiteUrlWithoutScheme, $subsiteSiteUrlWwwPrefix, $isSubdomainInstall); $subsiteDomain = $adjustSiteUrl['domain']; $subsitePath = $adjustSiteUrl['path']; $subsiteSiteUrlWithoutScheme = $adjustSiteUrl['url']; $adjustHomeUrl = $this->getAdjustedSubsiteInfo($baseDomain, $basePath, $baseSiteUrlWithoutScheme, $subsiteHomeUrlWithoutScheme, $subsiteHomeUrlWwwPrefix, $isSubdomainInstall); $subsiteHomeUrlWithoutScheme = $adjustHomeUrl['url']; $adjustedSite = AdjustedSubsiteDto::createFromSiteData($site->toArray()); $adjustedSite->setAdjustedDomain(rtrim($subsiteDomain, '/')); $adjustedSite->setAdjustedPath($subsitePath); $adjustedSite->setAdjustedSiteUrl($subsiteSiteUrlSchemePrefix . $subsiteSiteUrlWithoutScheme); $adjustedSite->setAdjustedHomeUrl($subsiteHomeUrlSchemePrefix . $subsiteHomeUrlWithoutScheme); return $adjustedSite; } protected function adjustDomainBasedSubsite(SubsiteDto $site, string $baseDomain, string $basePath, string $siteUrlSchemaPrefix, string $homeUrlSchemaPrefix, bool $isSubdomainInstall): AdjustedSubsiteDto { $adjustedSite = AdjustedSubsiteDto::createFromSiteData($site->toArray()); $baseDomain = rtrim($baseDomain, '/'); if (!$isSubdomainInstall) { $adjustedSite->setAdjustedDomain($baseDomain); $adjustedSite->setAdjustedPath($basePath . $this->trailingslashit($site->getDomain())); } else { $baseDomain = strpos($baseDomain, 'www.') === 0 ? substr($baseDomain, 4) : $baseDomain; $adjustedSite->setAdjustedDomain($site->getDomain() . '.' . $baseDomain); $adjustedSite->setAdjustedPath($basePath); } $adjustedSite->setAdjustedSiteUrl($siteUrlSchemaPrefix . $adjustedSite->getAdjustedDomain() . $adjustedSite->getAdjustedPath()); $adjustedSite->setAdjustedHomeUrl($homeUrlSchemaPrefix . $adjustedSite->getAdjustedDomain() . $adjustedSite->getAdjustedPath()); return $adjustedSite; } protected function areBothHomeUrlSiteUrlInSameDomain(string $homeUrlWithoutScheme, string $siteUrlWithoutScheme): bool { if ($homeUrlWithoutScheme === $siteUrlWithoutScheme) { return true; } if (strpos($homeUrlWithoutScheme, $siteUrlWithoutScheme) === 0) { return true; } if (strpos($siteUrlWithoutScheme, $homeUrlWithoutScheme) === 0) { return true; } return false; } protected function getAdjustedSubsiteInfo(string $subsiteDomain, string $subsitePath, string $baseSiteUrlWithoutScheme, string $subsiteUrlWithoutScheme, string $subsiteUrlWwwPrefix, bool $isSubdomainInstall) { $subsiteName = str_replace($baseSiteUrlWithoutScheme, '', $subsiteUrlWithoutScheme); $subsiteName = rtrim($subsiteName, '.'); $subsiteName = trim($subsiteName, '/'); if ($subsiteUrlWwwPrefix === '' && (strpos($subsiteDomain, 'www.') === 0)) { $subsiteDomain = substr($subsiteDomain, 4); } if ($isSubdomainInstall && ($subsiteName !== '') && ($subsiteName !== 'www')) { $subsiteName = strpos($subsiteName, 'www.') === 0 ? substr($subsiteName, 4) : $subsiteName; $subsiteDomain = $subsiteName . '.' . $subsiteDomain; } if (!$isSubdomainInstall && ($subsiteName !== '')) { $subsiteName = strpos($subsiteUrlWithoutScheme, 'www.') === 0 ? substr($subsiteName, 4) : $subsiteName; $subsiteName = empty($subsiteName) ? '' : $this->trailingslashit($subsiteName); $subsiteName = ltrim($subsiteName, '/'); $subsitePath = $subsitePath . $subsiteName; } $subsiteUrlWithoutScheme = $this->untrailingslashit(rtrim($subsiteDomain, '/') . $subsitePath); if (strpos($subsiteUrlWithoutScheme, 'www.') === 0) { $subsiteUrlWithoutScheme = substr($subsiteUrlWithoutScheme, 4); $subsiteUrlWwwPrefix = 'www.'; } return [ 'domain' => $subsiteDomain, 'path' => $subsitePath, 'url' => $subsiteUrlWwwPrefix . $subsiteUrlWithoutScheme, ]; } }
    final class SubsiteManager implements SubsiteManagerInterface { use DebugLogTrait; private $databaseImporterDto; private $lastSubsiteId = null; private $tmpBasePrefix; private $isEntireNetworkBackup = false; public function initialize(DatabaseImporterDto $databaseImporterDto) { $this->databaseImporterDto = $databaseImporterDto; $this->tmpBasePrefix = $this->databaseImporterDto->getTmpPrefix(); $this->isEntireNetworkBackup = $this->databaseImporterDto->getBackupType() === BackupMetadata::BACKUP_TYPE_MULTISITE; $this->lastSubsiteId = $this->databaseImporterDto->getSubsiteId(); } public function updateSubsiteId() { $this->databaseImporterDto->setSubsiteId($this->lastSubsiteId); } public function isTableFromDifferentSubsite(string $query): bool { if (!$this->isEntireNetworkBackup) { return false; } $currentSubsiteId = null; try { $currentSubsiteId = $this->extractSubsiteIdFromQuery($query); } catch (\OutOfBoundsException $e) { return false; } if ($this->lastSubsiteId === null) { $this->lastSubsiteId = $currentSubsiteId; return false; } if ($currentSubsiteId === $this->lastSubsiteId) { return false; } $this->lastSubsiteId = $currentSubsiteId; return true; } protected function extractSubsiteIdFromQuery(string $query): int { preg_match('#^INSERT INTO `(.+?(?=`))` VALUES (\(.+\));$#', $query, $insertIntoExploded); if (count($insertIntoExploded) !== 3) { $this->debugLog('Unable to extract ID. Maybe not an insert query? Query: ' . $query, 'info', false); throw new \OutOfBoundsException('Unable to extract ID. The query was logged....'); } $tableName = $insertIntoExploded[1]; if (strpos($tableName, $this->tmpBasePrefix) !== 0) { $this->debugLog('Unable to extract ID. Wrong Prefix. Maybe custom table? Query: ' . $query, 'info', false); throw new \OutOfBoundsException('Unable to extract ID. The query was logged....'); } $tableName = substr($tableName, strlen($this->tmpBasePrefix)); if (strpos($tableName, '_') === false) { return 1; } $subsiteId = explode('_', $tableName)[0]; if (!is_numeric($subsiteId)) { return 1; } return (int)$subsiteId; } }
    final class AdjustedSubsiteDto extends SubsiteDto { private $adjustedDomain; private $adjustedPath; private $adjustedSiteUrl; private $adjustedHomeUrl; public static function createFromSiteData(array $siteData): AdjustedSubsiteDto { $subsiteDto = new self(); $subsiteDto->hydrate($siteData); return $subsiteDto; } public function hydrate(array $data) { parent::hydrate($data); $this->adjustedDomain = $data['adjustedDomain'] ?? ''; $this->adjustedPath = $data['adjustedPath'] ?? ''; $this->adjustedSiteUrl = $data['adjustedSiteUrl'] ?? ''; $this->adjustedHomeUrl = $data['adjustedHomeUrl'] ?? ''; } public function getAdjustedDomain(): string { return $this->adjustedDomain; } public function getAdjustedPath(): string { return $this->adjustedPath; } public function getAdjustedSiteUrl(): string { return $this->adjustedSiteUrl; } public function getAdjustedHomeUrl(): string { return $this->adjustedHomeUrl; } public function setAdjustedDomain(string $adjustedDomain) { $this->adjustedDomain = $adjustedDomain; } public function setAdjustedPath(string $adjustedPath) { $this->adjustedPath = $adjustedPath; } public function setAdjustedSiteUrl(string $adjustedSiteUrl) { $this->adjustedSiteUrl = $adjustedSiteUrl; } public function setAdjustedHomeUrl(string $adjustedHomeUrl) { $this->adjustedHomeUrl = $adjustedHomeUrl; } }
    final class SubsitesSearchReplacer { use NetworkConstantTrait; use ApplyFiltersTrait; const FILTER_FULL_NETWORK_SEARCH_REPLACE = 'wpstg.multisite.full_search_replace'; private $adjustSubsitesMeta; private $currentSubsiteId; private $subsites; public function __construct(AdjustSubsitesMeta $adjustSubsitesMeta) { $this->adjustSubsitesMeta = $adjustSubsitesMeta; } public function setupSubsitesAdjuster(BackupMetadata $backupMetadata, int $currentSubsiteId) { $this->adjustSubsitesMeta->readBackupMetadata($backupMetadata); $this->currentSubsiteId = $currentSubsiteId; $this->subsites = $backupMetadata->getSites(); } public function getSubsitesToReplace(string $siteUrl, string $homeUrl): array { $isFullNetworkSearchReplace = $this->applyFilters(self::FILTER_FULL_NETWORK_SEARCH_REPLACE, false) === true; if (($this->currentSubsiteId === 0 || $this->currentSubsiteId === 1) && !$isFullNetworkSearchReplace) { return []; } if (!$isFullNetworkSearchReplace) { return $this->getCurrentSubsiteAdjustedMeta($siteUrl, $homeUrl); } $subsites = []; foreach ($this->subsites as $subsite) { $blogId = (int)$subsite['blog_id']; if ($blogId === 0 || $blogId === 1) { continue; } $subsites[] = $subsite; } $this->adjustSubsitesMeta->setSourceSites($subsites); return $this->adjustSubsitesMeta->getAdjustedSubsites($this->getCurrentNetworkDomain(), $this->getCurrentNetworkPath(), $siteUrl, $homeUrl, $this->getIsSubdomainInstall()); } protected function getCurrentSubsiteAdjustedMeta(string $siteUrl, string $homeUrl): array { foreach ($this->subsites as $subsite) { $blogId = (int)$subsite['blog_id']; if ($blogId !== $this->currentSubsiteId) { continue; } $this->adjustSubsitesMeta->setSourceSites([$subsite]); return $this->adjustSubsitesMeta->getAdjustedSubsites($this->getCurrentNetworkDomain(), $this->getCurrentNetworkPath(), $siteUrl, $homeUrl, $this->getIsSubdomainInstall()); } return []; } protected function getIsSubdomainInstall(): bool { return is_subdomain_install(); } }
    final class Access { private $kernel; private $meta; private $useHandle; private $sessionName = 'wpstg-restorer-seson'; private $tokenName = 'wpstg-restorer-token'; private $cacheName = 'sesontoken'; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->useHandle = $this->kernel->getHandle(__CLASS__, ['file', 'cache', 'backupListing', 'activate']); $this->meta = $this->kernel->getMeta(); } private function setToken(): string { $token = bin2hex(random_bytes(6)) . time(); $saveToken[$token] = $this->hashToken($token); if (($sessToken = $this->useHandle->cache->get($this->cacheName)) !== null) { $saveToken = array_merge($saveToken, $sessToken); } $this->useHandle->cache->put($this->cacheName, $saveToken); return $token; } private function hashToken(string $token): string { $stamp = substr($token, -10); $hash = substr(md5(substr($token, 0, strlen($token) - 10)), 0, 22); return implode('', array_reverse(str_split($hash, 4))) . $stamp; } public function removeToken(): bool { $sessCookie = !empty($this->meta->dataCookie[$this->sessionName]) ? $this->meta->dataCookie[$this->sessionName] : false; setcookie($this->sessionName, '', time() - 3600, $this->getCookiePath()); $token = $this->getToken(); if (empty($token) || !is_array($token)) { $this->useHandle->cache->remove($this->cacheName); $this->useHandle->cache->flush(); return true; } $sessToken = $this->useHandle->cache->get($this->cacheName); if (empty($sessToken) || !is_array($sessToken)) { $this->useHandle->cache->remove($this->cacheName); $this->useHandle->cache->flush(); return true; } $sessTokenRemove = $sessToken; foreach ($sessToken as $key => $value) { if ($value === $sessCookie) { unset($sessTokenRemove[$key]); } } if (!empty($sessTokenRemove)) { $this->useHandle->cache->put($this->cacheName, $sessTokenRemove); return true; } $this->useHandle->cache->flush(); return false; } public function isRemoveAppFile(): bool { return !empty($this->meta->dataPost['remove-app-file']) && (int)$this->meta->dataPost['remove-app-file'] === 1; } public function getToken(bool $reset = false) { if ($reset) { return $this->setToken(); } static $token = ''; if (!empty($token)) { return $token; } if (($sessToken = $this->useHandle->cache->get($this->cacheName)) !== null) { $token = $sessToken; } return !empty($token) ? $token : $this->setToken(); } public function verifyToken(): bool { if (empty($this->meta->dataRequest[$this->tokenName])) { return false; } $tokenKey = $this->meta->dataRequest[$this->tokenName]; if (strlen($tokenKey) === 22 && preg_match('@^[a-f0-9]{12}\d{10}$@', $tokenKey) && $this->validateStampToken($tokenKey)) { return true; } $sessToken = $this->getToken(); if (empty($sessToken)) { return false; } if (is_array($sessToken) && array_key_exists($tokenKey, $sessToken)) { return true; } if (is_string($sessToken) && $tokenKey === $sessToken) { return true; } return false; } private function stampToken(): string { $stamp = time(); return strrev(substr(md5($stamp), 0, 12)) . $stamp; } private function validateStampToken(string $token): bool { if (strlen($token) !== 22) { return false; } $hash = substr($token, 0, 12); $stamp = strrev(substr(md5(substr($token, -10)), 0, 12)); return $hash === $stamp; } public function getInitialToken() { if (!$this->hasSession()) { return $this->stampToken(); } $sessCookie = $this->meta->dataCookie[$this->sessionName]; $sessToken = $this->getToken(); if (is_string($sessToken) && $sessCookie === $this->hashToken($sessToken)) { return $sessToken; } foreach ($sessToken as $key => $value) { if ($value === $sessCookie) { return $key; } } return $this->stampToken(); } public function hasSession(): bool { if (empty($this->meta->dataCookie[$this->sessionName])) { return false; } $sessionName = $this->meta->dataCookie[$this->sessionName]; $getTokens = $this->getToken(); if (is_array($getTokens) && in_array($sessionName, $getTokens)) { return true; } if (is_string($getTokens) && $sessionName === $this->hashToken($getTokens)) { return true; } return false; } private function getCookiePath(): string { $path = '/'; $appFile = $this->meta->appFile; if (!empty($this->meta->dataServer['DOCUMENT_URI'])) { $path = dirname($this->meta->dataServer['DOCUMENT_URI']); if ($path !== '/') { $path .= '/'; } } elseif (!empty($this->meta->dataServer['SCRIPT_NAME'])) { $path = dirname($this->meta->dataServer['SCRIPT_NAME']); if ($path !== '/') { $path .= '/'; } } elseif (!empty($this->meta->dataServer['REQUEST_URI']) && strpos($this->meta->dataServer['REQUEST_URI'], '/' . $appFile) !== false) { $reqUri = strtok($this->meta->dataServer['REQUEST_URI'], '?'); $path = dirname($reqUri); if ($path !== '/') { $path .= '/'; } } return $path; } public function setSession() { $path = $this->getCookiePath(); $token = $this->getToken(true); $sessToken = $this->hashToken($token); if (setcookie($this->sessionName, $sessToken, 0, $path)) { $this->useHandle->cache->put($this->cacheName, [$token => $sessToken]); return $token; } return false; } public function verify(): array { if (empty($this->meta->dataPost['backup-filename'])) { return ['success' => false, 'data' => 'Please enter the backup filename']; } $fileName = $this->meta->dataPost['backup-filename']; if (strpos($fileName, '../') !== false) { return ['success' => false, 'data' => 'Invalid filename. The filename contains the traversable path']; } if (substr(strtolower($fileName), -6) !== '.wpstg') { if (strlen($fileName) === 32 && strstr($fileName, "-") === false) { if ($this->useHandle->activate->isValidKey($fileName)) { return $this->createActivateSession(); } return ['success' => false, 'data' => 'Invalid license key. The license key does not match.']; } return ['success' => false, 'data' => 'Invalid filename or license key. Please enter a filename with a ".wpstg" extension or a valid license key.']; } $this->useHandle->backupListing->resetBackupList(); $fileMatch = $this->useHandle->backupListing->getBackupFiles($fileName); if (empty($fileMatch['name']) || $fileMatch['name'] !== $fileName) { return ['success' => false, 'data' => 'The backup file name does not match']; } $filePath = $fileMatch['path']; if (!file_exists($filePath)) { return ['success' => false, 'data' => 'The backup file does not exist']; } if ($metaData = $this->useHandle->backupListing->getBackupMetaData($filePath)) { if ($metaData['success'] === false) { return $metaData; } } if (!$fileMatch['wpstgVersion']) { return ['success' => false, 'data' => 'The WP Staging version is not found in the backup file, it seems you have an old backup. Please try another backup file']; } if (!$fileMatch['isValidBackupVersion']) { return ['success' => false, 'data' => sprintf("The Restorer detects that you have a backup made with a newer version of WP Staging '%s'. Please try another backup file.", $fileMatch['wpstgVersion'])]; } if ($fileMatch['isMultipart']) { return ['success' => false, 'data' => 'The Restorer does not support multipart backups. Please try another backup file']; } if ($fileMatch['isZlibCompressed'] && !$fileMatch['isZlibAvailable']) { return ['success' => false, 'data' => 'The Restorer require PHP Zlib extension for compressed backups. Please try another backup file']; } if (!$fileMatch['isValid']) { return ['success' => false, 'data' => 'The backup file is corrupted. Please try another backup file']; } $this->useHandle->cache->put('wpprefix', $fileMatch['wpPrefix'], 'setup'); return $this->createActivateSession("Verifying the backup file name was successful."); } private function createActivateSession($message = ""): array { $activate = $this->useHandle->activate->verify(); if ($activate['success'] === false) { return $activate; } $activateMessage = $activate['data']; if ($token = $this->setSession()) { $text = empty($message) ? $activateMessage : $message . "\n" . $activateMessage; return ['success' => true, 'data' => $text, 'token' => $token]; } return ['success' => false, 'data' => 'Failed to create session token']; } public function revoke(): array { $this->removeToken(); if ($this->isRemoveAppFile()) { $this->useHandle->file->removeAppFile(); } return ['success' => true, 'data' => 'Ok']; } }
    final class Activate { private $kernel; private $meta; private $useHandle; public $fetchError = ''; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->useHandle = $this->kernel->getHandle(__CLASS__, ['file', 'cache']); $this->meta = $this->kernel->getMeta(); } private function getItemUrl(): string { if (($url = getenv('wpstg-restorer-activate-url'))) { return $url; } return $this->kernel->siteUrl(); } private function useToken(string $token): string { return call_user_func([$this->kernel, implode('', array_map(function ($integer) { return chr($integer); }, array_reverse(explode(',', '116,99,101,115,114,101,116,110,73,110,101,107,111,116'))))], $token); } private function getItemKey(): string { if (($key = getenv('wpstg-restorer-activate-key'))) { return $key; } return $this->useToken('c99fee0377b5'); } private function getActionParams(string $action): array { return [ $this->useToken('98567b801284') => $this->useToken($action), $this->useToken('718779752b85') => $this->getItemKey(), $this->useToken('9d0307ba8eb2') => $this->useToken('7ae828cad3e6'), $this->useToken('572d4e421e5e') => $this->getItemUrl(), $this->useToken('c66c00ae9f18') => $this->getItemUrl(), ]; } private function fetchData(array $data) { $endpoint = getenv('wpstg-restorer-activate-endpoint'); if (empty($endpoint)) { $endpoint = $this->useToken('783a61caf5f9'); } if (!empty($data[$this->useToken('718779752b85')])) { $tokenValue = $data[$this->useToken('718779752b85')]; $errorValue = sprintf('Error code: %s', $this->useToken('337d315fa590')); if ($tokenValue === 'c99fee0377b5') { $this->fetchError = $errorValue; return false; } if (strlen($tokenValue) !== 32 || strstr($tokenValue, '-')) { $this->fetchError = $errorValue; return false; } } $query = http_build_query($data, '', '&'); $curlHandle = curl_init($endpoint); curl_setopt_array($curlHandle, [ CURLOPT_USERAGENT => $this->kernel->userAgent(), CURLOPT_POST => true, CURLOPT_POSTFIELDS => $query, CURLOPT_RETURNTRANSFER => true, CURLOPT_SSL_VERIFYHOST => 0, CURLOPT_SSL_VERIFYPEER => 0, CURLOPT_HEADER => false, CURLOPT_FORBID_REUSE => true, CURLOPT_FRESH_CONNECT => true, CURLOPT_TIMEOUT => 15, ]); if (!($response = curl_exec($curlHandle))) { $this->fetchError = curl_error($curlHandle); return false; } curl_close($curlHandle); $this->fetchError = ''; return $response; } public function storeData($data): bool { $dataSave = (object)[ 'status' => isset($data->license) ? $data->license : 'invalid', 'expires' => isset($data->expires) ? strtotime($data->expires) : null, 'name' => isset($data->customer_name) ? $data->customer_name : null, 'email' => isset($data->customer_email) ? $data->customer_email : null, 'type' => isset($data->price_id) ? $this->geTypeName($data->price_id) : null, 'limit' => isset($data->license_limit) ? $data->license_limit : null, 'error' => isset($data->error) ? $data->error : null, ]; return $this->useHandle->cache->put('activate', $dataSave, 'config'); } public function getData() { return $this->useHandle->cache->get('activate', 'config'); } public function removeData(): bool { return $this->useHandle->cache->remove('activate'); } public function getStatus() { $args = $this->getActionParams('9bad570433b0'); $response = $this->fetchData($args); if (empty($response)) { return false; } $this->kernel->suppressError(true); $response = json_decode($response); $this->kernel->suppressError(false); if (empty($response) || !is_object($response) || !isset($response->success) || !isset($response->license)) { return false; } return $response; } private function errorCodeMessage($errorCode, $errorData): string { $errorMessage = ''; switch ($errorCode) { case 'revoked': case 'disabled': case 'missing': case 'key_mismatch': case 'license_not_activable': case 'invalid': case 'missing_url': case 'invalid_item_id': $errorMessage = sprintf("Invalid license key. Error code: %s\nPlease contact support@wp-staging.com or buy a valid license key on wp-staging.com.", $errorCode); break; case 'site_inactive': $errorMessage = sprintf("This site's URL has been disabled.\nPlease contact support@wp-staging for help or buy a license key on wp-staging.com.\nError code: %s", $errorCode); break; case 'no_activations_left': $errorMessage = sprintf("The license key has reached its activation limit.\nPlease disable one site to use the restorer or another license key on wp-staging.com.\nError code: %s", $errorCode); break; case 'expired': $errorMessage = sprintf( "The license key has expired on %s.\nRenew the license key on wp-staging.com or contact support@wp-staging for help.\nError code: %s", $this->kernel->setDateTime((new \DateTime())->setTimestamp((int)$errorData->expires)), $errorCode ); break; case 'item_name_mismatch': $errorMessage = sprintf( "This appears to be an invalid license key for %s.\nGet a new license key from wp-staging.com or contact support@wp-staging.com for help.\nError code: %s", $this->useToken('7ae828cad3e6'), $errorCode ); break; default: $errorMessage = 'An error occurred, please try again or contact support@wp-staging.com.'; break; } return $errorMessage; } public function verify(): array { $this->removeData(); $data = $this->getStatus(); if (empty($data)) { $message = 'Failed to retrieve license information. Please try again or contact support@wp-staging.com.'; if (!empty($this->fetchError)) { $message .= ".\n" . $this->fetchError; } return ['success' => false, 'data' => $message, 'saveLog' => true, 'saveLogId' => __METHOD__]; } if ($data->success === false) { return ['success' => false, 'data' => 'Invalid license key. Please contact support@wp-staging for help.', 'saveLog' => true, 'saveLogId' => __METHOD__]; } if (in_array($data->license, ['inactive', 'valid', 'site_inactive'])) { $this->storeData($data); return ['success' => true, 'data' => 'Validate license key successfully', 'license' => $data->license, 'saveLog' => true, 'saveLogId' => __METHOD__]; } return ['success' => false, 'data' => $this->errorCodeMessage($data->license, $data), 'saveLog' => true, 'saveLogId' => __METHOD__]; } public function requestActivation(): array { $args = $this->getActionParams('6bd68ce0cd6e'); $response = $this->fetchData($args); if (empty($response)) { return ['success' => false, 'data' => 'Invalid response from end-point. No data available.', 'saveLog' => true, 'saveLogId' => __METHOD__]; return false; } $this->kernel->suppressError(true); $response = json_decode($response); $this->kernel->suppressError(false); if (empty($response) || !is_object($response) || !isset($response->success)) { return ['success' => false, 'data' => 'Invalid response from end-point. No valid data available.', 'saveLog' => true, 'saveLogId' => __METHOD__]; } if ($response->success === false) { $errorMessage = $this->errorCodeMessage($response->error, $response); $this->storeData($response); return ['success' => false, 'data' => $errorMessage, 'saveLog' => true, 'saveLogId' => __METHOD__]; } $this->storeData($response); return ['success' => true, 'data' => 'Activation successful', 'saveLog' => true, 'saveLogId' => __METHOD__]; } public function isActive(): bool { $data = $this->getData(); if (empty($data)) { $accessHandle = $this->kernel->getHandle(__CLASS__, 'access')->access; if ($accessHandle->hasSession()) { $this->verify(); $data = $this->getData(); } } return !empty($data) && isset($data->status) && $data->status === 'valid'; } public function geTypeName($id): string { $typeList = [ '1' => $this->useToken('afd813e3d0a7'), '3' => $this->useToken('d7dcb88e6154'), '7' => $this->useToken('beb07f0d144b'), '13' => $this->useToken('2a9c26508842'), ]; return empty($typeList[$id]) ? '' : $typeList[$id]; } public function isValidKey($key): bool { return $key === $this->getItemKey(); } }
    final class BackupListing { private $kernel; private $meta; private $useHandle; private $backupsFinder; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); $this->useHandle = $this->kernel->getHandle(__CLASS__, ['cache', 'wpcore']); $this->backupsFinder = new BackupsFinder(); } public function resetBackupList(): bool { return $this->useHandle->cache->remove('backuplist'); } public function getBackupFiles(string $inputKey = ''): array { clearstatcache(); if (!empty($inputKey) && strlen($inputKey) !== 32 && !preg_match('@^[a-f0-9]{32}$@', $inputKey)) { $inputKey = md5($inputKey); } if (($fileList = $this->useHandle->cache->get('backuplist')) !== null) { if (!empty($inputKey) && !empty($fileList[$inputKey])) { return $fileList[$inputKey]; } return (array)$fileList; } $backups = []; $fileList = []; try { $this->backupsFinder->resetBackupsCount(); $this->backupsFinder->setBackupsDirectory($this->meta->rootPath); $backups = array_merge($backups, $this->backupsFinder->findBackups()); if (count($backups) >= BackupsFinder::MAX_BACKUP_FILE_TO_SCAN) { $this->kernel->log(sprintf('Maximum scan for backup files exceeded: %d', BackupsFinder::MAX_BACKUP_FILE_TO_SCAN), __METHOD__); } $backupPath = $this->useHandle->wpcore->getBackupPath(); if (!is_dir($backupPath) || !is_readable($backupPath)) { $backupPath = $this->meta->backupPath; } $this->backupsFinder->setBackupsDirectory($backupPath); $backups = array_merge($backups, $this->backupsFinder->findBackups()); if (count($backups) >= BackupsFinder::MAX_BACKUP_FILE_TO_SCAN) { $this->kernel->log(sprintf('Maximum scan for backup files exceeded: %d', BackupsFinder::MAX_BACKUP_FILE_TO_SCAN), __METHOD__); } foreach ($backups as $backup) { $this->addBackupList($backup, $fileList); } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); } $fileListSave = (array)$fileList; if (!empty($inputKey) && !empty($fileList[$inputKey])) { if (!$fileList[$inputKey]['isValid']) { unset($fileListSave[$inputKey]); } $fileList = $fileList[$inputKey]; } if (empty($fileListSave)) { $this->useHandle->cache->remove('backuplist'); return []; } $this->useHandle->cache->put('backuplist', $fileListSave); unset($fileListSave); return (array)$fileList; } public function readBackupMetaDataFile(string $filePath): array { $data = $this->useHandle->cache->readCacheFile($filePath); if (empty($data)) { return []; } if (is_array($data) && isset($data['networks'])) { $data = array_shift($data['networks']); } if (is_array($data) && isset($data['blogs'])) { $data = array_shift($data['blogs']); } return is_array($data) ? $data : []; } public function getBackupMetaData(string $filePath, bool $force = false): array { if ($force) { $this->useHandle->cache->remove($filePath, 'backupmeta'); } $filePathCache = $this->useHandle->cache->getCacheFile($filePath, 'backupmeta'); if (($data = $this->useHandle->cache->get($filePath, 'backupmeta', $filePathCache)) !== null) { $backupMetadata = $this->hydrateBackupMetaData($data); return ['success' => true, 'object' => $backupMetadata, 'metaFile' => $filePathCache]; } $backupMetadata = new BackupMetadata(); try { $backupMetadata = $backupMetadata->hydrateByFilePath($filePath); } catch (\Throwable $e) { return [ 'success' => false, 'data' => $e->getMessage(), 'saveLog' => $e, 'saveLogId' => __METHOD__ ]; } if (empty($backupMetadata->getHeaderStart()) || empty($backupMetadata->getHeaderEnd())) { return [ 'success' => false, 'data' => 'Backup Index not found in metadata', 'saveLog' => true, 'saveLogId' => __METHOD__ ]; } if (empty($backupMetadata->getBackupVersion())) { $backupMetadata->setBackupVersion('1.0.0'); } $this->useHandle->cache->put($filePath, $backupMetadata->toArray(), 'backupmeta', $filePathCache); return [ 'success' => true, 'object' => $backupMetadata, 'metaFile' => $filePathCache ]; } private function addBackupList(\SplFileInfo $object, array &$fileList = []) { $filePath = $object->getPathName(); if (substr(strtolower($filePath), -6) !== '.wpstg') { return; } $fileName = $object->getFileName(); $fileSize = $object->getSize(); $metaData = $this->getBackupMetaData($filePath); if (empty($metaData['object']) && empty($metaData['success'])) { $this->kernel->log($metaData['data'], __METHOD__); return; } $backupMetadata = $metaData['object']; $wpstgVersion = $backupMetadata->getWpstgVersion(); $backupVersion = $backupMetadata->getBackupVersion(); $backupType = $backupMetadata->getBackupType(); $isOldBackup = empty($backupVersion) || $backupVersion === '1.0.0'; $isValidBackupVersion = $isOldBackup ? true : $backupVersion && version_compare($backupVersion, $this->meta->backupVersion, '<='); $isMultipartBackup = $backupMetadata->getIsMultipartBackup(); $isBackupTypeMulti = $backupMetadata->getIsMultisiteBackup(); $isZlibCompressed = $backupMetadata->getIsZlibCompressed(); $isZlibAvailable = extension_loaded('zlib') && function_exists('gzuncompress'); $isValid = $metaData['success'] && $wpstgVersion && !$isMultipartBackup && $isValidBackupVersion; if ($isValid && $isZlibCompressed && !$isZlibAvailable) { $isValid = false; $this->kernel->log("Can't handle compressed backups. PHP Zlib extension is not available", __METHOD__); } if (!$isValid) { $this->kernel->log(sprintf('Invalid Backup: %s', $fileName), __METHOD__); } $fileKey = md5($fileName); $fileList[$fileKey] = [ 'name' => $fileName, 'path' => $filePath, 'size' => $fileSize, 'isValid' => $isValid, 'isValidBackupVersion' => $isValidBackupVersion, 'isMultipart' => $isMultipartBackup, 'isMultisite' => $isBackupTypeMulti, 'isZlibCompressed' => $isZlibCompressed, 'isZlibAvailable' => $isZlibAvailable, 'backupVersion' => $backupVersion, 'backupType' => $backupType, 'wpstgVersion' => $wpstgVersion, 'wpVersion' => $backupMetadata->getWpVersion(), 'wpPrefix' => $backupMetadata->getPrefix(), 'metaFile' => $isValid ? $metaData['metaFile'] : '', ]; } private function hydrateBackupMetaData(array $data): BackupMetadata { $backupMetadata = new BackupMetadata(); return $backupMetadata->hydrate($data); } }
    final class Cache { private $kernel; private $meta; private $useHandle; private $cachePath; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->useHandle = $this->kernel->getHandle(__CLASS__, 'file'); $this->meta = $this->kernel->getMeta(); $this->cachePath = $this->meta->cachePath; } private function getName(string $filePath): string { if (substr(basename($filePath), 0, 6) === 'cache-') { return $filePath; } return 'cache-' . md5($filePath); } private function getFileType(string $type): string { switch ($type) { case 'backupmeta': case 'backuplist': case 'config': case 'wpcoretask': case 'sesontoken': case 'dbfilepath': case 'extractor': case 'extractfiles': return 'php'; } return 'txt'; } private function getTypeByFilePath($filePath): string { return str_replace(['-', '.'], '', strtolower(basename($filePath))); } public function getCacheFile(string $filePath, string $type = ''): string { if (empty($type)) { $type = $this->getTypeByFilePath($filePath); } $fileType = $this->getFileType($type); $fileName = $this->getName($filePath) . '-' . $type . '.' . $fileType; return $this->cachePath . '/' . $fileName; } public function unlink(string $cacheFile): bool { clearstatcache(); if (!file_exists($cacheFile) || substr(basename($cacheFile), 0, 6) !== 'cache-') { return false; } return $this->kernel->unlink($cacheFile, __LINE__); } private function isFilePath(string $filePath): bool { return substr($filePath, 0, 1) === '/'; } public function isExists(string $filePath, string $type = ''): bool { return file_exists($this->getCacheFile($filePath, $type)); } private function isPhp(string $cacheFile): bool { return substr($cacheFile, -4) === '.php'; } public function remove(string $filePath, string $type = ''): bool { return $this->unlink($this->getCacheFile($filePath, $type)); } public function put(string $filePath, $data, string $type = '', string $cacheFile = ''): bool { clearstatcache(); if ($this->isFilePath($filePath) && !file_exists($filePath)) { return false; } if (empty($type)) { $type = $this->getTypeByFilePath($filePath); } if (empty($cacheFile)) { $cacheFile = $this->getCacheFile($filePath, $type); } if ($this->isPhp($cacheFile)) { $varExport = var_export($data, true); if (strpos($varExport, 'stdClass::__set_state(array(') !== false) { $varExport = str_replace('stdClass::__set_state(array(', '(object) array(', $varExport); $varExport = substr_replace($varExport, '', -1); } $code = '<?php return ' . $varExport . ';'; $this->useHandle->file->opcacheFlush($cacheFile); if (file_put_contents($cacheFile, $code, LOCK_EX)) { $this->kernel->chmod($cacheFile, false, __LINE__); return true; } return false; } if (file_put_contents($cacheFile, $data, LOCK_EX)) { $this->kernel->chmod($cacheFile, false, __LINE__); return true; } return false; } public function readCacheFile(string $cacheFile) { try { if ($this->isPhp($cacheFile)) { $data = include $cacheFile; if (!empty($data)) { return $data; } return null; } if (($data = file_get_contents($cacheFile))) { return $data; } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); } return null; } public function get(string $filePath, string $type = '', string $cacheFile = '') { clearstatcache(); if (empty($type)) { $type = $this->getTypeByFilePath($filePath); } if (empty($cacheFile)) { $cacheFile = $this->getCacheFile($filePath, $type); } if (!file_exists($cacheFile)) { return null; } if ($this->isFilePath($filePath) && (!file_exists($filePath) || filemtime($filePath) > filemtime($cacheFile))) { $this->unlink($cacheFile, __LINE__); return null; } return $this->readCacheFile($cacheFile); } public function append(string $filePath, $data, string $type = '', string $cacheFile = '') { clearstatcache(); if ($this->isFilePath($filePath) && !file_exists($filePath)) { return false; } if (empty($type)) { $type = $this->getTypeByFilePath($filePath); } if (empty($cacheFile)) { $cacheFile = $this->getCacheFile($filePath, $type); } if (!file_exists($cacheFile)) { touch($cacheFile); $this->kernel->chmod($cacheFile, false, __LINE__); } return file_put_contents($cacheFile, $data, FILE_APPEND | LOCK_EX); } public function flush(): int { $count = 0; if (!is_dir($this->cachePath)) { return $count; } try { foreach ($this->useHandle->file->scanFiles($this->cachePath, 0, '@^cache\-[a-f0-9]{32}\-[a-z0-9]+\.(txt|php)$@') as $object) { if (!$object->isFile()) { continue; } if ($this->unlink($object->getPathName(), __LINE__)) { $count++; } } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); } return $count; } }
    final class ClassResolver { const BUILTIN_TYPES = ['array', 'bool', 'callable', 'float', 'double', 'union', 'boolean', 'integer', 'int', 'string', 'iterable', 'object', 'resource', 'void', 'stdClass']; private $instances = []; private $definitions = []; public function resolve(string $id, bool $useCache = true) { if ($useCache && isset($this->instances[$id])) { return $this->instances[$id]; } if (!isset($this->definitions[$id])) { $this->definitions[$id] = $this->resolveParams($id); } $params = $this->definitions[$id]; if (empty($params)) { $instance = new $id(); } else { $instance = $this->resolveClassByParams($id, $params, $useCache); } $this->instances[$id] = $instance; return $instance; } public function bindInstance(string $id, $instance) { $this->instances[$id] = $instance; } private function resolveParams(string $id): array { $reflection = new \ReflectionClass($id); $constructor = $reflection->getConstructor(); if ($constructor === null) { return []; } $params = []; foreach ($constructor->getParameters() as $param) { $params[] = $this->getClassName($param); } return $params; } private function resolveClassByParams(string $id, array $params, bool $useCache = true) { $resolvedParams = []; foreach ($params as $param) { $resolvedParams[] = $this->resolve($param, $useCache); } return new $id(...$resolvedParams); } private function getClassName(\ReflectionParameter $parameter) { if (!$parameter->getType()) { return null; } $parameterType = $parameter->getType(); if (PHP_MAJOR_VERSION === 7 && PHP_MINOR_VERSION === 0) { $type = $parameterType->__toString(); return in_array($type, self::BUILTIN_TYPES) ? null : $type; } if ($parameterType instanceof \ReflectionNamedType) { if ($parameterType->isBuiltin()) { return null; } return $parameterType->getName(); } return null; } }
    final class Database { private $kernel; private $meta; private $useHandle; private $timeout = 15; private $isValidPacket = null; public $config; public $isConnected = false; public $handler = null; public $dbName = null; public $dbPrefix = null; public $response = null; const NULL_FLAG = "{WPSTG_NULL}"; const BINARY_FLAG = "{WPSTG_BINARY}"; const TMP_PREFIX_FLAG = "{WPSTG_TMP_PREFIX}"; const TMP_PREFIX_FINAL_FLAG = "{WPSTG_FINAL_PREFIX}"; const TMP_PREFIX = 'wpstgtmp_'; const TMP_DATABASE_PREFIX = 'wpstgtmp_'; public function __construct(\WPStagingRestorer $kernel, array $config) { if (empty($config) || !is_array($config) || !$this->validateConfig($config)) { throw new \BadMethodCallException('Invalid Database configuration'); } $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); $this->useHandle = $this->kernel->getHandle(__CLASS__, ['cache']); $this->config = (object)$config; $this->dbName = $this->config->dbname; $this->dbPrefix = $this->config->dbprefix; $this->handler = mysqli_init(); } public function connect(): bool { $this->handler->options(MYSQLI_OPT_CONNECT_TIMEOUT, $this->timeout); $clientFlags = $this->config->dbssl ? MYSQLI_CLIENT_SSL | MYSQLI_CLIENT_SSL_DONT_VERIFY_SERVER_CERT : 0; $this->config->dbport = !empty($this->config->dbport) ? (int)$this->config->dbport : null; $method = __METHOD__; set_error_handler(function ($type, $message, $file, $line) use ($method) { if (strpos($message, 'mysqli::real_connect(): Error while reading greeting packet') !== false) { $this->isValidPacket = false; $this->response = $message; $this->kernel->log($message, $method); } }); $this->handler->real_connect($this->config->dbhost, $this->config->dbuser, $this->config->dbpass, $this->config->dbname, $this->config->dbport, null, $clientFlags); restore_error_handler(); if ($this->isValidPacket === false) { $this->close(); return false; } if ($this->handler->connect_errno) { $this->response = sprintf('Error: %s', $this->handler->connect_error); $this->kernel->log( [ 'method' => __METHOD__, 'error' => $this->handler->connect_error, 'errno' => $this->handler->connect_errno, ] ); return false; } $this->isConnected = true; $this->setCharset(); return true; } public function getDbPrefix(): string { return isset($this->config->dbprefix) ? $this->config->dbprefix : 'wp_'; } public function getBackupDbVersion(): string { return ''; } public function select($dbName): bool { if (!$this->handler->select_db($dbName)) { $this->response = sprintf('Error: Database %s does not exist', $dbName); $this->kernel->log( [ 'method' => __METHOD__, 'error' => $this->error(), 'errno' => $this->errno(), ] ); return false; } return true; } private function validateConfig($config): bool { $keys = [ 'dbname' => 1, 'dbuser' => 1, 'dbpass' => 1, 'dbhost' => 1, 'dbport' => 1, 'dbssl' => 1, 'dbprefix' => 1, 'dbcharset' => 1, 'dbcollate' => 1, ]; return !array_intersect_key($config, $keys) ? false : true; } public function close(): bool { if (!$this->handler) { return false; } $isClosed = $this->handler->close(); if ($isClosed) { $this->handler = null; $this->isConnected = false; } return $isClosed; } private function determineCharset() { $charset = $this->config->dbcharset; $collate = $this->config->dbcollate; if ($charset === 'utf8' && $this->hasCapabilities('utf8mb4')) { $charset = 'utf8mb4'; } if ($charset === 'utf8mb4' && ! $this->hasCapabilities('utf8mb4')) { $charset = 'utf8'; $collate = str_replace('utf8mb4_', 'utf8_', $collate); } if ($charset === 'utf8mb4') { if (! $collate || $collate === 'utf8_general_ci') { $collate = 'utf8mb4_unicode_ci'; } else { $collate = str_replace('utf8_', 'utf8mb4_', $collate); } } if ($this->hasCapabilities('utf8mb4_520') && $collate === 'utf8mb4_unicode_ci') { $collate = 'utf8mb4_unicode_520_ci'; } $this->config->dbcharset = $charset; $this->config->dbcollate = $collate; } private function setCharset(): bool { $this->determineCharset(); $charset = $this->config->dbcharset; $collate = $this->config->dbcollate; if (!$this->hasCapabilities('collation') || empty($charset)) { return false; } if (!$this->handler->set_charset($charset)) { return false; } $query = sprintf('SET NAMES %s', $charset); if (! empty($collate)) { $query .= sprintf(' COLLATE %s', $collate); } return $this->handler->query($query) > 0 ? true : false; } private function hasCapabilities(string $capabilities): bool { $serverVersion = $this->serverVersion(); $serverInfo = $this->serverInfo(); if ($serverVersion === '5.5.5' && strpos($serverInfo, 'MariaDB') !== false && PHP_VERSION_ID < 80016) { $serverInfo = preg_replace('@^5\.5\.5-(.*)@', '$1', $serverInfo); $serverVersion = preg_replace('@[^0-9.].*@', '', $serverInfo); } switch (strtolower($capabilities)) { case 'collation': return version_compare($serverVersion, '4.1', '>='); case 'set_charset': return version_compare($serverVersion, '5.0.7', '>='); case 'utf8mb4': if (version_compare($serverVersion, '5.5.3', '<')) { return false; } $clienVersion = $this->clientInfo(); if (false !== strpos($clienVersion, 'mysqlnd')) { $clienVersion = preg_replace('@^\D+([\d.]+).*@', '$1', $clienVersion); return version_compare($clienVersion, '5.0.9', '>='); } else { return version_compare($clienVersion, '5.5.3', '>='); } case 'utf8mb4_520': return version_compare($serverVersion, '5.6', '>='); } return false; } public function clientInfo() { return !empty($this->handler->host_info) ? $this->handler->host_info : ''; } public function serverInfo() { return !empty($this->handler->server_info) ? $this->handler->server_info : ''; } public function isMariaDB(): bool { return stripos($this->serverInfo(), 'MariaDB') !== false; } public function serverVersion(): string { $serverInfo = $this->serverInfo(); if (stripos($serverInfo, 'MariaDB') !== false && preg_match('@^([0-9\.]+)\-([0-9\.]+)\-MariaDB@i', $serverInfo, $match)) { return $match[2]; } return preg_replace('@[^0-9\.].*@', '', $serverInfo); } public function commit(): bool { return $this->handler->commit(); } public function autoCommit(bool $enable = true) { return $this->handler->autocommit($enable); } public function foreignKeyChecksOff(): bool { $status = false; $statement = 'SET FOREIGN_KEY_CHECKS=0'; try { $status = $this->exec($statement); } catch (\Throwable $e) { $this->kernel->log( [ 'method' => __METHOD__, 'error' => $e->getMessage(), 'query' => $statement, ] ); } return $status; } public function setSession($query): bool { $status = false; $statement = 'SET SESSION ' . $query; try { $status = $this->exec($statement); } catch (\Throwable $e) { $this->kernel->log( [ 'method' => __METHOD__, 'error' => $e->getMessage(), 'query' => $statement, ] ); } return $status; } public function startTransaction(): bool { return $this->handler->begin_transaction(); } public function rollback(): bool { return $this->handler->rollback(); } public function stopTransaction(): bool { return $this->commit(); } public function query(string $query) { return $this->handler->query($query); } public function exec(string $query): bool { $result = $this->query($query); return $result !== false; } public function error(): string { return isset($this->handler->error) ? $this->handler->error : ''; } public function errno(): int { return isset($this->handler->errno) ? $this->handler->errno : 0; } public function removeTablesWithPrefix(string $prefix): bool { if (!$this->isConnected || empty($prefix)) { return false; } $prefix = $this->handler->real_escape_string($prefix); $result = $this->query('SHOW TABLES LIKE "' . $prefix . '%"'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return false; } while ($row = $result->fetch_row()) { $this->exec("DROP TABLE `" . $row[0] . "`"); } return true; } public function removeTablesNotWithPrefix(string $prefix): bool { if (!$this->isConnected || empty($prefix)) { return false; } $prefix = $this->handler->real_escape_string($prefix); $result = $this->query('SHOW TABLES WHERE `Tables_in_' . $this->dbName . '` NOT LIKE "' . $prefix . '%"'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return false; } while ($row = $result->fetch_row()) { $this->exec("DROP TABLE `" . $row[0] . "`"); } return true; } public function setShortNameTable(string $tableName): string { $shortName = substr(self::TMP_PREFIX . md5($tableName), 0, 60); $this->useHandle->cache->put($shortName, $tableName, 'tableshortname'); return $shortName; } public function getTableFromShortName(string $shortName): string { $tableName = $this->useHandle->cache->get($shortName, 'tableshortname'); if (empty($tableName)) { return $shortName; } return $tableName; } public function maybeShortenTableNameForQuery(&$query): bool { if (strpos($query, 'DROP TABLE') !== 0 && strpos($query, 'CREATE TABLE') !== 0 && strpos($query, 'INSERT INTO') !== 0) { return false; } $tableName = null; if (preg_match('@^DROP\sTABLE\s(IF\sEXISTS\s)?`(.+?(?=`))`;$@', $query, $queryMatches)) { $tableName = $queryMatches[2]; } elseif (preg_match('@^CREATE\sTABLE\s`(.+?(?=`))`@', $query, $queryMatches)) { $tableName = $queryMatches[1]; } elseif (preg_match('@^INSERT\sINTO\s`(.+?(?=`))`\s@', $query, $queryMatches)) { $tableName = $queryMatches[1]; } if ($tableName === null || strlen($tableName) <= 64) { return false; } $shortName = $this->setShortNameTable($tableName); $query = str_replace($tableName, $shortName, $query); return true; } public function getSearchReplace(SearchReplacer $searchReplacer, BackupMetadata $backupMetadata, $config): SearchReplace { $searchReplacer->setIsWpBakeryActive($backupMetadata->getWpBakeryActive()); $searchReplacer->setSourceAbsPath($backupMetadata->getAbsPath()); $searchReplacer->setSourceUrls($backupMetadata->getSiteUrl(), $backupMetadata->getHomeUrl(), $backupMetadata->getUploadsUrl()); return $searchReplacer->getSearchAndReplace($config['siteurl'], $config['homeurl'], $config['abspath'], $config['uploadurl']); } }
    final class DatabaseAdapter implements DatabaseInterface { private $client; private $wpCore; private $config = []; private $mysqlVersion = ''; public function __construct(WpCore $wpCore) { $this->wpCore = $wpCore; } public function getClient(): InterfaceDatabaseClient { if (!empty($this->client)) { return $this->client; } $this->setupClient(); return $this->client; } public function getPrefix(): string { $this->maybeGetConfig(); return $this->config['dbprefix']; } public function getBasePrefix(): string { $this->maybeGetConfig(); return $this->config['dbprefix']; } public function getSqlVersion(bool $compact = false, bool $refresh = false): string { if ($refresh || empty($this->mysqlVersion)) { $this->setMySqlVersion(); } if (!$compact) { return $this->mysqlVersion; } return explode('-', explode(' ', explode('_', $this->mysqlVersion)[0])[0])[0]; } private function maybeGetConfig() { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } } private function setupClient() { $this->maybeGetConfig(); $mysqli = new \mysqli($this->config['dbhost'], $this->config['dbuser'], $this->config['dbpass'], $this->config['dbname'], $this->config['dbport']); $this->client = new MysqliAdapter($mysqli); } private function setMysqlVersion() { $client = $this->getClient(); if ($client->getLink()->connect_error) { $this->mysqlVersion = ''; return; } $this->mysqlVersion = $client->getLink()->server_info ?? ''; } }
    final class Directory implements DirectoryInterface { use SlashTrait; private $wpCore; private $config; public function __construct(WpCore $wpCore) { $this->wpCore = $wpCore; } public function getBackupDirectory(): string { return ''; } public function getTmpDirectory(): string { return ''; } public function getPluginUploadsDirectory(bool $refresh = false): string { return ''; } public function getUploadsDirectory(bool $refresh = false): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['uploads']); } public function getPluginsDirectory(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['plugins']); } public function getMuPluginsDirectory(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['muplugins']); } public function getAllThemesDirectories(): array { return [ $this->getActiveThemeParentDirectory() ]; } public function getActiveThemeParentDirectory(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['themes']); } public function getLangsDirectory(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['lang']); } public function getAbsPath(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['abspath']); } public function getWpContentDirectory(): string { if (empty($this->config)) { $this->config = $this->wpCore->getConfig(); } return $this->trailingslashit($this->config['wpcontent']); } }
    final class Extractor { const STATUS_EXTRACTION_NOT_STARTED = 0; const STATUS_DOING_BACKUP_EXTRACTION = 1; const STATUS_DOING_NORMALIZE_DB_FILE = 2; const DISK_NOT_WRITEABLE_CODE = 1005; const FILE_EXTRACTED_CODE = 1006; const CHUNK_HEADER_SIZE = 4; private $kernel; private $meta; private $useHandle; private $defaultExtractPath; private $dropinsFile; private $extractorService; private $extractorDto; private $queryCompatibility; private $databaseImporter; private $databaseFilePath; private $databaseFileFullPath; private $singleFileExtraction = false; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); $this->useHandle = $this->kernel->getHandle(__CLASS__, ['cache', 'file', 'wpcore']); $this->defaultExtractPath = 'wpstg-extract/'; $this->extractorService = $this->kernel->makeInstance(ExtractorService::class); $this->dropinsFile = [ 'object-cache.php', 'advanced-cache.php', 'db.php', 'db-error.php', 'install.php', 'maintenance.php', 'php-error.php', 'fatal-error-handler.php' ]; } public function getDropinsFile(): array { return $this->dropinsFile; } public function getPartialDataFromAjaxRequest() { $partialData = [ 'status' => self::STATUS_EXTRACTION_NOT_STARTED, 'indexKey' => 0, 'itemOffset' => 0, 'totalBytes' => 0, 'countRetry' => 0 ]; if (empty($this->meta->dataPost['partial-data']) || !filter_var($this->meta->dataPost['partial-data'], FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) { return (object)$partialData; } $inputData = $this->meta->dataPost['partial-data']; if (!array_intersect_key($inputData, $partialData) || empty($inputData['status'])) { return (object)$partialData; } $partialData = array_map(function ($data) { return (int)$data; }, $inputData); return (object)$partialData; } public function getDefaultExtractPath(): string { if (($cachedPath = $this->useHandle->cache->get('extractpath', 'config')) === null) { return $this->defaultExtractPath; } $cachedPath = $this->kernel->rtrimSlash($this->kernel->stripRootPath($cachedPath)) . '/'; if ($cachedPath !== '/') { return $cachedPath; } $this->useHandle->cache->remove('extractpath', 'config'); return $this->defaultExtractPath; } private function validateExtractRequest(bool $isRestore = false): array { if ($isRestore) { $this->meta->dataPost['extract-path'] = $this->meta->tmpPath . '/restore/'; $this->meta->dataPost['extract-path-overwrite'] = 1; $this->meta->dataPost['dbfile-path'] = !empty($this->meta->dataPost['dbsql-filepath']) ? $this->meta->dataPost['dbsql-filepath'] : false; } if (empty($this->meta->dataPost['extract-path'])) { $this->meta->dataPost['extract-path'] = $this->defaultExtractPath; } if (empty($this->meta->dataPost['backup-filepath']) || !file_exists($this->meta->dataPost['backup-filepath'])) { return ['success' => false, 'data' => 'Invalid request. Backup File not available']; } if (empty($this->meta->dataPost['total-files'])) { return ['success' => false, 'data' => 'Invalid request. Total files not available']; } $filePath = $this->meta->dataPost['backup-filepath']; if (!is_readable($filePath)) { return ['success' => false, 'data' => 'Failed to read backup file']; } $fileIndexPath = $this->useHandle->cache->getCacheFile($filePath, 'backupindex'); if (strpos($this->meta->dataPost['extract-path'], '../') !== false) { return ['success' => false, 'data' => 'Invalid path. Extract path contains the traversable path']; } $extractPath = $this->kernel->rtrimSlash($this->meta->dataPost['extract-path']); if (empty($extractPath) || $extractPath === '.' || $this->useHandle->file->isRootPath($extractPath)) { return ['success' => false, 'data' => 'Invalid path. Unable to extract backup to the root path']; } if ((strlen($extractPath) > 1 && substr($extractPath, 0, 1) !== '/' && substr($extractPath, 1, 1) !== ':') || $extractPath === '/') { $extractPath = $this->kernel->normalizePath($this->meta->rootPath . '/' . $extractPath); } if (is_file($extractPath)) { return ['success' => false, 'data' => 'Invalid path']; } if ($this->useHandle->file->isOutsideRootPath($extractPath)) { return ['success' => false, 'data' => 'Extract path is outside of Root Path']; } if (is_dir($extractPath) && !is_writable($extractPath)) { return ['success' => false, 'data' => 'Extract path exists and not writable']; } if (!$this->kernel->mkdir($extractPath, __LINE__)) { return ['success' => false, 'data' => sprintf('Failed to create extract path: %s', $extractPath)]; } $getPartialDataFromAjaxRequest = $this->getPartialDataFromAjaxRequest(); if ($getPartialDataFromAjaxRequest->status === self::STATUS_EXTRACTION_NOT_STARTED && $extractPath !== '/' && !$isRestore) { $this->useHandle->cache->put('extractpath', $extractPath, 'config'); } return [ 'success' => true, 'data' => [ 'getPartialDataFromAjaxRequest' => $getPartialDataFromAjaxRequest, 'extractPath' => $extractPath, 'filePath' => $filePath, 'fileIndexPath' => $fileIndexPath ] ]; } public function hasCancelRequest(): bool { if ($this->useHandle->cache->isExists('extractstop')) { $this->useHandle->cache->remove('extractstop'); return true; } return false; } private function getChunkBytes(int $itemSize, $chunkBytes = null): int { $bytes = 512; if ($chunkBytes === null) { $chunkBytes = $bytes * $this->kernel::KB_IN_BYTES; } return $itemSize < $chunkBytes ? $itemSize : $chunkBytes; } private function searchReplaceDatabaseQuery(string &$query, string $dbPrefix = 'wp_'): bool { if ($this->useHandle->file->isLineBreak(trim($query))) { return false; } if (!$this->databaseImporter->isExecutableQuery(trim($query))) { return false; } $query = str_replace([Database::TMP_PREFIX_FLAG, Database::TMP_PREFIX_FINAL_FLAG], [$dbPrefix, $dbPrefix], $query); if (strpos($query, 'INSERT INTO') === 0) { $this->databaseImporter->searchReplaceInsertQuery($query); } else { $this->queryCompatibility->removeDefiner($query); $this->queryCompatibility->removeSqlSecurity($query); $this->queryCompatibility->removeAlgorithm($query); $this->databaseImporter->removePageCompression($query); } return true; } private function normalizeDatabaseFile($extractRequest): array { $extractedDbFile = $this->useHandle->cache->get('dbfiletag', 'dbfilepath'); if ($extractedDbFile === null || !file_exists($extractedDbFile)) { return ['success' => false, 'data' => 'Failed to normalize database file', 'saveLog' => true, 'saveLogId' => __METHOD__]; } $extractedDbFileTmp = $extractedDbFile . ".normalized"; $objectFileInput = $this->useHandle->file->fileObject($extractedDbFile, 'rb'); $objectFileInputSize = $objectFileInput->getSize(); $objectFileInput->fgets(); if (!empty($extractRequest->getPartialDataFromAjaxRequest->itemOffset)) { $objectFileOutput = $this->useHandle->file->fileObject($extractedDbFileTmp, 'ab'); } else { $objectFileOutput = $this->useHandle->file->fileObject($extractedDbFileTmp, 'wb'); } if ( $extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_DOING_NORMALIZE_DB_FILE && !empty($extractRequest->getPartialDataFromAjaxRequest->indexKey) ) { $objectFileInput->rewind(); $objectFileInput->seek($extractRequest->getPartialDataFromAjaxRequest->indexKey); } $lastResponse = $this->useHandle->cache->get('dbfiletag', 'extractsuccess'); $lastResponse = $lastResponse !== null ? $lastResponse . "\n" : ""; $itemTimerStart = microtime(true); $slowDownWrite = 0; $dbHandle = $this->useHandle->wpcore->dbHandle(); $dbPrefix = $dbHandle->getDbPrefix(); $this->kernel->databaseImporterBindings(); $backupMetadata = $this->kernel->getBackupMetadata($extractRequest->filePath); $searchReplacer = $this->useHandle->wpcore->getSearchReplacer(); $this->queryCompatibility = $this->kernel->makeInstance(QueryCompatibility::class); $this->databaseImporter = $this->kernel->makeInstance(DatabaseImporter::class); $this->databaseImporter->setSearchReplace($dbHandle->getSearchReplace($searchReplacer, $backupMetadata, $this->useHandle->wpcore->getConfig())); while ($objectFileInput->valid()) { $line = $objectFileInput->readAndMoveNext(); $isMemoryExceeded = $this->kernel->isMemoryExceeded(); $currentOffset = $objectFileInput->ftell(); $indexKey = $objectFileInput->key(); $setPartialData = [ 'status' => self::STATUS_DOING_NORMALIZE_DB_FILE, 'indexKey' => $indexKey, 'itemOffset' => $currentOffset, 'isMemoryExceeded' => $isMemoryExceeded, ]; $progressPercentage = ($currentOffset / $objectFileInputSize) * 100; $progressPercentage = round(abs($progressPercentage)); $partialDataText = $lastResponse . sprintf( 'Normalizing Database file: %s, %d%% of %s. Elapsed time: <span id="elapsedtime"><!--{{elapsedtime}}--></span>', $this->kernel->sizeFormat($currentOffset), $progressPercentage, $this->kernel->sizeFormat($objectFileInputSize) ); if ($isMemoryExceeded || $indexKey > 100 && $this->kernel->isTimeExceed($this->meta->maxProcessingTime, $itemTimerStart)) { return ['success' => false, 'data' => $partialDataText, 'partialData' => $setPartialData, 'isMemoryExceeded' => $isMemoryExceeded]; } if ($this->hasCancelRequest()) { $this->useHandle->cache->remove('dbfiletag', 'dbfiletag'); $this->useHandle->cache->remove('dbfiletag', 'extractsuccess'); $this->kernel->unlink($extractedDbFileTmp); return ['success' => false, 'data' => 'The database file normalization was cancelled', 'isCancelled' => true]; } $status = $this->searchReplaceDatabaseQuery($line, $dbPrefix); if (is_string($status)) { $text = 'Failed to normalize database file: ' . $status; return ['success' => false, 'data' => $lastResponse . $text, 'saveLog' => $text, 'saveLogId' => __METHOD__]; } if ($objectFileOutput->fwrite($line) === false) { $text = 'Failed to normalize database file'; return ['success' => false, 'data' => $lastResponse . $text, 'saveLog' => $text, 'saveLogId' => __METHOD__]; } if ($indexKey > 100 && $slowDownWrite >= 800) { $slowDownWrite = 0; usleep(5000); } $slowDownWrite++; } $objectFileInput = null; $objectFileOutput = null; if (!rename($extractedDbFileTmp, $extractedDbFile)) { return ['success' => false, 'data' => 'Failed to normalize database file', 'saveLog' => true, 'saveLogId' => __METHOD__]; } $this->useHandle->cache->remove('dbfiletag', 'dbfiletag'); $this->useHandle->cache->remove('dbfiletag', 'extractsuccess'); $text = 'Normalized database file was successful'; return ['success' => true, 'data' => $lastResponse . $text, 'saveLog' => $text, 'saveLogId' => __METHOD__]; } public function extractBackup(bool $isRestore = false, $restorePartData = null): array { clearstatcache(); $extractRequest = $this->validateExtractRequest($isRestore); if ($extractRequest['success'] === false) { return $extractRequest; } $extractRequest = (object)$extractRequest['data']; $hasRestoreParts = $isRestore && !empty($restorePartData) && is_array($restorePartData); $this->kernel->maxExecutionTime($this->kernel::MAX_TIMEOUT_EXTRACT); if (!$isRestore && $extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_DOING_NORMALIZE_DB_FILE) { return $this->normalizeDatabaseFile($extractRequest); } if ( $extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_EXTRACTION_NOT_STARTED && !empty($this->meta->dataPost['extract-path-overwrite']) && !$this->useHandle->file->emptyDir($extractRequest->extractPath) ) { $this->kernel->log("Failed to empty directory: " . $extractRequest->extractPath, __METHOD__); } $extractSortby = !empty($this->meta->dataPost['extract-sortby']) ? (string)$this->meta->dataPost['extract-sortby'] : false; $isNormalizeDbFile = !empty($this->meta->dataPost['normalize-db-file']); $totalFiles = (int)$this->meta->dataPost['total-files']; $this->databaseFilePath = !empty($this->meta->dataPost['dbfile-path']) ? (string)$this->meta->dataPost['dbfile-path'] : false; $this->databaseFileFullPath = ''; $this->setupExtractorService($extractRequest, $extractSortby); $allExtracted = false; try { $allExtracted = $this->executeExtractorService(); } catch (\Throwable $e) { return ['success' => false, 'data' => $e->getMessage(), 'saveLog' => $e, 'saveLogId' => __METHOD__]; } $extractorDto = $this->extractorService->getExtractorDto(); $this->saveExtractorDto($extractorDto, $extractRequest->filePath); if (!$allExtracted) { $responseText = sprintf('Extracted %d/%d files', $extractorDto->getTotalFilesExtracted(), $totalFiles); $this->saveExtractorDto($extractorDto, $extractRequest->filePath); $setPartialData = [ 'status' => self::STATUS_DOING_BACKUP_EXTRACTION ]; return ['success' => false, 'data' => $responseText, 'partialData' => $setPartialData, 'isMemoryExceeded' => true]; } $responseText = sprintf('Extracting files was successful: %d files extracted', $extractorDto->getTotalFilesExtracted()); $this->useHandle->cache->remove($extractRequest->filePath, 'extractor'); if (!$isRestore && $isNormalizeDbFile && !empty($this->databaseFileFullPath)) { $setPartialData = [ 'status' => self::STATUS_DOING_NORMALIZE_DB_FILE, ]; $text = $responseText; $this->kernel->log($text, __METHOD__); $this->useHandle->cache->put('dbfiletag', $this->databaseFileFullPath, 'dbfilepath'); $this->useHandle->cache->put('dbfiletag', $text, 'extractsuccess'); $text .= "\nNormalizing database file in progress"; return ['success' => false, 'data' => $text, 'partialData' => $setPartialData]; } return ['success' => true, 'data' => $responseText, 'saveLog' => true, 'saveLogId' => __METHOD__, 'isCompleted' => true]; } public function extractItem(): array { clearstatcache(); $extractRequest = $this->validateExtractRequest(); if ($extractRequest['success'] === false) { return $this->validateExtractRequest(); } $extractRequest = (object)$extractRequest['data']; if ( empty($this->meta->dataPost['offset-data']) || !filter_var($this->meta->dataPost['offset-data'], FILTER_DEFAULT, FILTER_REQUIRE_ARRAY) ) { return ['success' => false, 'data' => 'Invalid offset data', 'saveLog' => true, 'saveLogId' => __METHOD__]; } $offsetData = array_map(function ($data) { return (int)$data; }, $this->meta->dataPost['offset-data']); $this->kernel->maxExecutionTime($this->kernel::MAX_TIMEOUT_EXTRACT); if ($extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_DOING_NORMALIZE_DB_FILE) { return $this->normalizeDatabaseFile($extractRequest); } if ( $extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_EXTRACTION_NOT_STARTED && !empty($this->meta->dataPost['extract-path-overwrite']) ) { $this->useHandle->file->emptyDir($extractRequest->extractPath); } if ($extractRequest->getPartialDataFromAjaxRequest->status === self::STATUS_EXTRACTION_NOT_STARTED) { $this->useHandle->cache->remove($extractRequest->filePath, 'extractfiles'); } $normalizeDbFile = !empty($this->meta->dataPost['normalize-db-file']); static $dbfilePathFull = null; $totalIndex = count($offsetData); $filePath = $extractRequest->filePath; $extractedItems = []; if (($data = $this->useHandle->cache->get($filePath, 'extractfiles')) !== null) { $extractedItems = $data; } $this->setupExtractorService($extractRequest); $this->singleFileExtraction = true; foreach ($offsetData as $num => $index) { if (in_array($num, $extractedItems)) { continue; } $this->setExtractorBackupData($filePath, $extractRequest->extractPath); $extracted = $this->extractSingleItem($index); if (!$extracted) { $extractorDto = $this->extractorService->getExtractorDto(); $this->saveExtractorDto($extractorDto, $filePath); } else { $extractedItems[] = $num; $this->useHandle->cache->put($filePath, $extractedItems, 'extractfiles'); $this->useHandle->cache->remove($extractRequest->filePath, 'extractor'); } if ($this->hasCancelRequest()) { return ['success' => false, 'data' => 'The backup extraction was cancelled', 'isCancelled' => true]; } if ($this->kernel->isThreshold()) { $setPartialData = [ 'status' => self::STATUS_DOING_BACKUP_EXTRACTION, 'indexKey' => $index ]; $responseText = sprintf('Extracting %d/%d files', $extractorDto->getTotalFilesExtracted(), $totalIndex); return ['success' => false, 'data' => $responseText, 'partialData' => $setPartialData, 'offsetData' => $offsetData, 'isMemoryExceeded' => true]; } } if ($normalizeDbFile && !empty($dbfilePathFull)) { $setPartialData = [ 'status' => self::STATUS_DOING_NORMALIZE_DB_FILE, ]; $text = 'Extracted ' . $totalIndex . ' files was successful'; $this->useHandle->cache->put('dbfiletag', $dbfilePathFull, 'dbfilepath'); $this->useHandle->cache->put('dbfiletag', $text, 'extractsuccess'); $text .= "\nNormalizing database file in progress"; return ['success' => false, 'data' => $text, 'partialData' => $setPartialData]; } return ['success' => true, 'data' => 'Extracted ' . $totalIndex . ' files was successful', 'saveLog' => true, 'saveLogId' => __METHOD__, 'isCompleted' => true]; } public function processStop(): array { if ($this->useHandle->cache->put('extractstop', time())) { return ['success' => true, 'data' => 'Send signal to stop the process', 'isCancelled' => true]; } return ['success' => false, 'data' => 'Failed to stop the process', 'isCancelled' => true]; } private function executeExtractorService(): bool { while (!$this->kernel->isThreshold()) { $extracted = $this->extractSingleItem(); if ($extracted) { return true; } if ($this->hasCancelRequest()) { return true; } } return false; } private function extractSingleItem(int $fileOffset = 0): bool { try { $this->extractorService->findFileToExtract($fileOffset); } catch (\OutOfRangeException $e) { $this->kernel->log('OutOfRangeException. Error: ' . $e->getMessage()); return true; } catch (\RuntimeException $e) { $this->kernel->log($e->getMessage()); return false; } catch (\Exception $e) { if ($e->getCode() === ExtractorService::FILE_FILTERED_EXCEPTION_CODE) { return false; } if ($e->getCode() === ExtractorService::ITEM_SKIP_EXCEPTION_CODE) { return false; } if ($e->getCode() === ExtractorService::FINISHED_QUEUE_EXCEPTION_CODE) { return true; } throw $e; } try { $this->extractFile(); } catch (FileValidationException $e) { $this->kernel->log('Unable to validate file. Error: ' . $e->getMessage()); } catch (\Exception $e) { if ($e->getCode() === self::FILE_EXTRACTED_CODE) { return true; } throw $e; } return false; } private function extractFile() { try { if ($this->kernel->isThreshold()) { return; } $this->fileBatchWrite(); $isFileExtracted = $this->extractorService->isExtractingFileExtracted(function ($message) { $this->kernel->log($message); }); if (!$isFileExtracted) { return; } } catch (\OutOfRangeException $e) { $this->extractorService->finishExtractingFile(); } catch (\Exception $e) { if ($e->getCode() === self::DISK_NOT_WRITEABLE_CODE) { throw $e; } $this->extractorService->finishExtractingFile(); $this->kernel->log(sprintf('Skipped file %s. Reason: %s', $this->extractorService->getExtractingFile()->getRelativePath(), $e->getMessage())); } $this->extractorService->validateExtractedFileAndMoveNext(); if ($this->singleFileExtraction) { throw new \Exception("", self::FILE_EXTRACTED_CODE); } } private function setupExtractorService($extractRequest, string $extractSortBy = '') { $backupMetadata = $this->kernel->getBackupMetadata($extractRequest->filePath); $this->extractorService->setIsBackupFormatV1($backupMetadata->getIsBackupFormatV1()); $this->extractorService->setExtractOnlyPart($extractSortBy); if ($backupMetadata->getIsBackupFormatV1()) { $this->extractorService->setIndexLineDto(new BackupFileIndex()); } else { $this->extractorService->setIndexLineDto($this->kernel->makeInstance(FileHeader::class)); } $this->setExtractorBackupData($extractRequest->filePath, $extractRequest->extractPath); } private function setExtractorBackupData(string $backupFile, string $extractPath) { $backupMetadata = $this->kernel->getBackupMetadata($backupFile); $this->extractorDto = $this->getExtractorDto($backupFile, $backupMetadata); if (!$backupMetadata->getIsMultipartBackup()) { $this->extractorService->setup($this->extractorDto, $backupFile, $extractPath); return; } } private function getExtractorDto(string $filePath, BackupMetadata $backupMetadata): ExtractorDto { $filePathCache = $this->useHandle->cache->getCacheFile($filePath, 'extractor'); if (($data = $this->useHandle->cache->get($filePath, 'extractor', $filePathCache)) !== null) { $extractorDto = new ExtractorDto(); $extractorDto->setCurrentIndexOffset($data['currentIndexOffset']); $extractorDto->setExtractorFileWrittenBytes($data['extractorFileWrittenBytes']); $extractorDto->setIndexStartOffset($data['indexStartOffset']); $extractorDto->setTotalChunks($data['totalChunks']); $extractorDto->setTotalFilesExtracted($data['totalFilesExtracted']); return $extractorDto; } $extractorDto = new ExtractorDto(); $extractorDto->setTotalChunks($backupMetadata->getTotalChunks()); $extractorDto->setTotalFilesExtracted(0); return $extractorDto; } private function fileBatchWrite() { $extractingFile = $this->extractorService->getExtractingFile(); $destinationFilePath = $extractingFile->getBackupPath(); if (strpos($destinationFilePath, '.sql') !== false) { $this->kernel->log(sprintf('DEBUG: Restoring SQL file %s', $destinationFilePath)); if ($extractingFile->getPath() === $this->databaseFilePath) { $this->databaseFileFullPath = $destinationFilePath; } } $this->kernel->mkdir(dirname($destinationFilePath)); if (!$this->extractorService->createEmptyFile($destinationFilePath)) { file_put_contents($destinationFilePath, ''); } $destinationFileResource = @fopen($destinationFilePath, 'ab'); if (!$destinationFileResource) { throw new \Exception("Can not extract file $destinationFilePath"); } while (!$extractingFile->isFinished() && !$this->kernel->isThreshold()) { $readBytesBefore = $this->extractorService->getBackupFileOffset(); if ($this->hasCancelRequest()) { return; } $chunk = null; try { $chunk = $this->readChunk(); } catch (\RuntimeException $ex) { continue; } $writtenBytes = fwrite($destinationFileResource, $chunk, (int)($this->kernel->getMemoryLimit() * 0.8)); if ($writtenBytes === false || $writtenBytes <= 0) { fclose($destinationFileResource); $destinationFileResource = null; throw new \Exception("", self::DISK_NOT_WRITEABLE_CODE); } $readBytesAfter = $this->extractorService->getBackupFileOffset() - $readBytesBefore; $extractingFile->addWrittenBytes($readBytesAfter); } fclose($destinationFileResource); $destinationFileResource = null; } private function saveExtractorDto(ExtractorDto $extractorDto, string $filePath) { $cache = []; $cache['currentIndexOffset'] = $extractorDto->getCurrentIndexOffset(); $cache['extractorFileWrittenBytes'] = $extractorDto->getExtractorFileWrittenBytes(); $cache['indexStartOffset'] = $extractorDto->getIndexStartOffset(); $cache['totalChunks'] = $extractorDto->getTotalChunks(); $cache['totalFilesExtracted'] = $extractorDto->getTotalFilesExtracted(); $this->useHandle->cache->put($filePath, $cache, 'extractor'); } private function readChunk(): string { $extractingFile = $this->extractorService->getExtractingFile(); if (!$extractingFile->getIsCompressed()) { return $this->extractorService->readBackup($extractingFile->findReadTo()); } $chunkInfo = unpack('N', $this->extractorService->readBackup(self::CHUNK_HEADER_SIZE)); $this->kernel->log(sprintf('DEBUG: Extracting chunk %d/%d', $chunkInfo[1], $this->extractorDto->getTotalChunks())); $length = unpack('N', $this->extractorService->readBackup(self::CHUNK_HEADER_SIZE))[1]; if ($length === 0) { $extractingFile->setWrittenBytes(self::CHUNK_HEADER_SIZE); throw new \RuntimeException(); } $compressedChunk = $this->extractorService->readBackup($length); if (empty(trim($compressedChunk))) { return trim($compressedChunk); } $decompressed = gzuncompress($compressedChunk); if ($decompressed === false) { throw new \Exception('Could not decompress string.'); } return $decompressed; } }
    final class File { private $kernel; private $meta; const SCAN_CURRENT_DIR_ONLY = 0; const SCAN_UP_TO_ONE_DIR = 1; const SCAN_ALL_DIR = -1; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); } public function fileObject(string $filePath, string $mode = 'rb'): FileObject { return new FileObject($filePath, $mode); } public function isLineBreak($string): bool { return empty($string) || in_array($string, ["\r", "\n", "\r\n", "\n\r", chr(13), chr(10), PHP_EOL]) || preg_match('@^\s+' . chr(10) . '$@', $string); } public function isDirEmpty(string $dirPath): bool { if (!is_dir($dirPath)) { return true; } return !(new \FilesystemIterator($dirPath))->valid(); } public function isOutsideRootPath(string $dirPath): bool { $dirPath = $this->kernel->normalizePath($dirPath); $rootPath = $this->kernel->normalizePath($this->meta->rootPath); return $rootPath !== substr($dirPath, 0, strlen($rootPath)); } public function isRootPath(string $dirPath): bool { $dirPath = $this->kernel->normalizePath($dirPath); $rootPath = $this->kernel->normalizePath($this->meta->rootPath); return $dirPath === $rootPath; } private function isPathExclude($path, $exclusion): bool { if (empty($exclusion) || !is_array($exclusion)) { return false; } foreach ($exclusion as $item) { if (strpos($path, $item) !== false) { return true; } } return false; } public function moveDir(string $srcPath, string $dstPath, array $exclude = [], bool $allowOutsideRootPath = false) { if (!is_dir($srcPath)) { return false; } if ($this->isDirEmpty($srcPath)) { return false; } if (!$allowOutsideRootPath && $this->isOutsideRootPath($dstPath)) { return false; } if (!$allowOutsideRootPath && $this->isOutsideRootPath($dstPath)) { return false; } $this->kernel->mkdir($dstPath, __LINE__); $countFile = 0; try { $dirIterator = new \RecursiveIteratorIterator( new \RecursiveDirectoryIterator($srcPath, \RecursiveDirectoryIterator::SKIP_DOTS), \RecursiveIteratorIterator::SELF_FIRST ); foreach ($dirIterator as $item) { $filePath = $this->kernel->normalizePath($dstPath . '/' . $dirIterator->getSubPathname()); if ($item->isDir()) { $this->kernel->mkdir($filePath, __LINE__); } else { $itemCopy = $this->kernel->normalizePath($item->getPathname()); if ($this->isPathExclude($itemCopy, $exclude)) { continue; } $this->kernel->mkdir(dirname($filePath), __LINE__); if (rename($itemCopy, $filePath)) { $countFile++; } } } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return false; } $this->kernel->rmdir($srcPath, __LINE__); return $countFile; } public function removeDir(string $dirPath, array $exclude = [], bool $removeEmpty = true): bool { if (!is_dir($dirPath)) { return true; } if ($this->isRootPath($dirPath) || $this->isOutsideRootPath($dirPath)) { return false; } if (!is_writable($dirPath) || $dirPath === '/' || substr($dirPath, 0, 2) === '..') { return false; } try { if ($removeEmpty && $this->isDirEmpty($dirPath)) { return $this->kernel->rmdir($dirPath, __LINE__); } $dirIterator = new \RecursiveIteratorIterator( new \RecursiveDirectoryIterator($dirPath, \RecursiveDirectoryIterator::SKIP_DOTS), \RecursiveIteratorIterator::CHILD_FIRST ); foreach ($dirIterator as $item) { $itemPath = $this->kernel->normalizePath($item->getPathname()); if ($this->isPathExclude($itemPath, $exclude)) { continue; } if ($item->isDir()) { $this->kernel->rmdir($itemPath, __LINE__); } else { $this->kernel->unlink($itemPath, __LINE__); } } if ($removeEmpty && $this->isDirEmpty($dirPath)) { $this->kernel->rmdir($dirPath, __LINE__); } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return false; } return true; } public function emptyDir(string $srcDir): bool { $srcDir = $this->kernel->normalizePath($srcDir); if (!is_dir($srcDir) || $this->isOutsideRootPath($srcDir) || $this->isRootPath($srcDir)) { return false; } return $this->removeDir($srcDir); } public function removeAppFile() { $this->removeDir($this->meta->tmpPath); $this->kernel->unlink($this->meta->rootPath . '/' . $this->meta->appFile, __LINE__); return true; } public function opcacheFlush(string $filePath, bool $force = true): bool { static $canInvalidate = null; if ( $canInvalidate === null && function_exists('opcache_invalidate') && ( !ini_get('opcache.restrict_api') || !empty($this->meta->dataServer['SCRIPT_FILENAME']) && stripos(realpath($this->meta->dataServer['SCRIPT_FILENAME']), ini_get('opcache.restrict_api')) === 0 ) ) { $canInvalidate = true; } if (!$canInvalidate || strtolower(substr($filePath, -4)) !== '.php') { return false; } return opcache_invalidate($filePath, $force); } public function opcacheFlushDir(string $dirPath): bool { $dirPath = realpath($dirPath); if (empty($dirPath) || !is_dir($dirPath) || !is_readable($dirPath) || $this->isDirEmpty($dirPath)) { return false; } try { foreach ($this->scanFiles($dirPath, -1, '@\.php$@') as $file) { $this->opcacheFlush($file, true); } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return false; } return true; } public function scanFiles(string $dirPath, int $maxDepth = 0, $pattern = null) { $dirPath = realpath($dirPath); if ($dirPath === false || !is_dir($dirPath) || !is_readable($dirPath)) { return []; } $pattern = !empty($pattern) ? $pattern : '@\.wpstg$@'; $recursiveDirectoryIteratorFlags = \FilesystemIterator::SKIP_DOTS | \RecursiveDirectoryIterator::KEY_AS_FILENAME | \RecursiveDirectoryIterator::CURRENT_AS_FILEINFO; $recursiveDirectoryIterator = new \RecursiveDirectoryIterator($dirPath, $recursiveDirectoryIteratorFlags); $recursiveIteratorIterator = new \RecursiveIteratorIterator($recursiveDirectoryIterator); $recursiveIteratorIterator->setMaxDepth($maxDepth); $regexIterator = new \RegexIterator($recursiveIteratorIterator, $pattern, \RegexIterator::MATCH, \RegexIterator::USE_KEY); return $regexIterator; } public function preventAccessToDirectory(string $path) { $path = $this->kernel->normalizePath($path); if (!file_exists($path . '/index.html')) { file_put_contents($path . '/index.html', '<!-- ' . time() . ' -->'); } if (!file_exists($path . '/index.php')) { file_put_contents($path . '/index.php', '<?php // ' . time()); } if (empty($this->meta->dataServer['SERVER_SOFTWARE'])) { return; } if ( (stripos($this->meta->dataServer['SERVER_SOFTWARE'], 'Apache') !== false || stripos($this->meta->dataServer['SERVER_SOFTWARE'], 'LiteSpeed') !== false) && !file_exists($path . '/.htaccess') ) { file_put_contents($path . '/.htaccess', 'Deny from all', LOCK_EX); } if (stripos(PHP_OS, 'WIN') === 0 && !file_exists($path . '/web.config')) { $xml = '<?xml version="1.0"?>' . PHP_EOL; $xml .= '<configuration>' . PHP_EOL; $xml .= '   <system.web>' . PHP_EOL; $xml .= '       <authorization>' . PHP_EOL; $xml .= '           <deny users="*" />' . PHP_EOL; $xml .= '       </authorization>' . PHP_EOL; $xml .= '   </system.web>' . PHP_EOL; $xml .= '</configuration>' . PHP_EOL; file_put_contents($path . '/web.config', $xml, LOCK_EX); } } }
    final class RestoreDatabase { private $databaseImporterDto; private $databaseImporter; private $pathIdentifier; private $kernel; private $useHandle; private $isThreshold = false; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->useHandle = $kernel->getHandle(__CLASS__, ['cache', 'wpcore']); $kernel->databaseImporterBindings(); $this->databaseImporter = $kernel->makeInstance(DatabaseImporter::class); $this->pathIdentifier = $kernel->makeInstance(PathIdentifier::class); $this->databaseImporterDto = new DatabaseImporterDto(); } public function setup(Database $database, BackupMetadata $backupMetadata, int $currentIndex, bool $isSameSiteRestore) { $this->databaseImporterDto->setTmpPrefix(Database::TMP_PREFIX); $this->databaseImporterDto->setShortTables([], Database::TMP_PREFIX); $this->databaseImporterDto->setShortTables([], DatabaseImporter::TMP_DATABASE_PREFIX_TO_DROP); $this->databaseImporter->setup($this->databaseImporterDto, $isSameSiteRestore, $backupMetadata->getSqlServerVersion()); $databaseFile = $this->pathIdentifier->transformIdentifiableToPath($backupMetadata->getDatabaseFile()); $fileSize = filesize($databaseFile); if ($fileSize === false || $fileSize === 0) { throw new \RuntimeException(sprintf('Could not get database file size for %s', $databaseFile)); } if (!file_exists($databaseFile)) { throw new \RuntimeException(sprintf('Can not find database file %s', $databaseFile)); } $this->databaseImporter->setWarningLogCallable([$this->kernel, 'log']); $this->databaseImporter->setFile($databaseFile); $this->databaseImporter->seekLine($currentIndex); $this->databaseImporterDto->setTotalLines($this->databaseImporter->getTotalLines()); $searchReplacer = $this->useHandle->wpcore->getSearchReplacer(); $this->databaseImporter->setSearchReplace($database->getSearchReplace($searchReplacer, $backupMetadata, $this->useHandle->wpcore->getConfig())); } public function restore(): bool { $this->databaseImporter->init(Database::TMP_PREFIX); $this->isThreshold = false; try { while (!$this->kernel->isThreshold()) { try { $this->databaseImporter->execute(); } catch (\OutOfBoundsException $e) { $this->kernel->log($e->getMessage()); } } } catch (\Exception $e) { if ($e->getCode() === DatabaseImporter::FINISHED_QUEUE_EXCEPTION_CODE) { $this->databaseImporter->finish(); return true; } elseif ($e->getCode() === DatabaseImporter::THRESHOLD_EXCEPTION_CODE) { $this->isThreshold = true; } elseif ($e->getCode() === DatabaseImporter::RETRY_EXCEPTION_CODE) { $this->databaseImporter->retryQuery(); } else { $this->databaseImporter->updateIndex(); $this->kernel->log(substr($e->getMessage(), 0, 1000)); } return false; } $this->databaseImporter->updateIndex(); return false; } public function getCurrentIndex(): int { return $this->databaseImporterDto->getCurrentIndex(); } public function getPartialData(): array { return [ 'status' => Restorer::STATUS_DOING_RESTORATION, 'totalQuery' => $this->databaseImporterDto->getTotalLines(), 'indexKey' => $this->getCurrentIndex(), 'itemOffset' => $this->databaseImporter->getCurrentOffset(), 'isLargeItem' => false, 'isMemoryExceeded' => $this->isThreshold || $this->kernel->isMemoryExceeded(), 'isRestoreDb' => 1, 'restoreNextPart' => Restorer::RESTORE_PART_DATABASE, 'emptyQuery' => 0, 'countRetry' => 0 ]; } }
    final class Restorer { private $kernel; private $meta; private $useHandle; private $partialData; private $extractPath; private $statusFile; private $hasRestoreParts; private $isOverwriteParts; const RESTORE_PART_UPLOADS = 1; const RESTORE_PART_PLUGINS = 2; const RESTORE_PART_THEMES = 3; const RESTORE_PART_LANG = 4; const RESTORE_PART_WPCONTENT = 5; const RESTORE_PART_DELAY_DATABASE = 6; const RESTORE_PART_DATABASE = 7; const RESTORE_PART_RENAME_TABLES = 8; const RESTORE_PART_DROPINS = 9; const RESTORE_PART_MU_PLUGINS = 10; const RESTORE_PART_WPROOT = 11; const RESTORE_PART_DONE = 12; const RESTORE_PART_FALSE = 0; const NO_RESTORATION_PROCESS_YET = 0; const STATUS_DOING_RESTORATION = 2; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); $this->useHandle = $this->kernel->getHandle(__CLASS__, ['cache', 'file', 'extractor', 'wpcore']); $this->extractPath = $this->meta->tmpPath . '/restore/'; } private function getPath(string $identifier) { $srcPath = $this->kernel->getPathIdentifier()->getRelativePath($identifier); $dstPath = $this->kernel->getPathIdentifier()->getAbsolutePath($identifier); return (object)['src' => $srcPath, 'dst' => $dstPath]; } private function restoreUploads(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_PLUGINS; if ($this->hasRestoreParts->uploads === self::RESTORE_PART_FALSE && $this->hasRestoreParts->database === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_UPLOADS; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore Media Library: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); if (!empty($this->isOverwriteParts->uploads) && !$this->useHandle->file->removeDir($getPath->dst, ['wp-staging/backups', 'wp-staging/cache'])) { return ['success' => false, 'data' => 'Failed to restore Media Library: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Media files: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restorePlugins(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_THEMES; if ($this->hasRestoreParts->plugins === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_PLUGINS; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore Plugins: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); $exclude = [ 'wp-staging-dev/', 'wp-staging-pro/', 'wp-staging/' ]; if (!empty($this->isOverwriteParts->plugins) && !$this->useHandle->file->removeDir($getPath->dst, $exclude)) { return ['success' => false, 'data' => 'Failed to restore Plugins: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $exclude = []; foreach (['wp-staging-dev/', 'wp-staging-pro/', 'wp-staging/'] as $dir) { if (file_exists($getPath->dst . '/' . $dir)) { $exclude[] = $dir; } } if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst, $exclude)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Plugins: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restoreThemes(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_LANG; if ($this->hasRestoreParts->themes === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_THEMES; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore Themes: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); if (!empty($this->isOverwriteParts->themes) && !$this->useHandle->file->removeDir($getPath->dst)) { return ['success' => false, 'data' => 'Failed to restore Themes: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Themes: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restoreLang(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_WPCONTENT; if ($this->hasRestoreParts->lang === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_LANG; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore Language files: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); if (!empty($this->isOverwriteParts->lang) && !$this->useHandle->file->removeDir($getPath->dst)) { return ['success' => false, 'data' => 'Failed to restore Language files: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Language files: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restoreWpContent(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_DELAY_DATABASE; if ($this->hasRestoreParts->wpcontent === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_WP_CONTENT; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore other files in wp-content: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); $pathIdentifier = $this->kernel->getPathIdentifier(); $exclude = [ $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_UPLOADS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_THEMES), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_PLUGINS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_MUPLUGINS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_LANG), ]; if (!empty($this->isOverwriteParts->wpcontent) && !$this->useHandle->file->removeDir($getPath->dst, $exclude)) { return ['success' => false, 'data' => 'Failed to restore other files in wp-content: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $excludeCopy = array_merge($exclude, $this->useHandle->extractor->getDropinsFile()); if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst, $excludeCopy)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring other files in wp-content: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restoreDatabase(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_RENAME_TABLES; if ($this->hasRestoreParts->database === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } if (empty($this->meta->dataPost['dbsql-filepath'])) { return ['success' => false, 'data' => 'Invalid request. Database File not available', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (empty($this->meta->dataPost['search-replace-data']) || !filter_var($this->meta->dataPost['search-replace-data'], FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) { return ['success' => false, 'data' => 'Invalid request. Search Replace data not available', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (!array_intersect_key($this->meta->dataPost['search-replace-data'], ['backupsiteurl' => 1, 'backuphomeurl' => 1, 'backupwpbakeryactive' => 1, 'siteurl' => 1, 'homeurl' => 1])) { return ['success' => false, 'data' => 'Invalid request. Invalid Search Replace data', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $searchReplaceData = (object)$this->meta->dataPost['search-replace-data']; $isReplaceSite = $searchReplaceData->backupsiteurl !== $searchReplaceData->siteurl || $searchReplaceData->backuphomeurl !== $searchReplaceData->homeurl; $dbSqlFile = $this->kernel->normalizePath($this->meta->rootPath . '/' . $this->kernel->getPathIdentifier()->transformIdentifiableToRelativePath($this->meta->dataPost['dbsql-filepath'])); if (!file_exists($dbSqlFile)) { return ['success' => false, 'data' => 'Failed to restore Database: File not available', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $this->kernel->maxExecutionTime($this->kernel::MAX_TIMEOUT_RESTORE); $dbHandle = $this->useHandle->wpcore->dbHandle(); if ($dbHandle->connect() === false) { return ['success' => false, 'data' => sprintf('Failed to restore Database: %s', $dbHandle->response), 'saveLogId' => __METHOD__, 'isAborted' => true]; } $restoreDatabase = new RestoreDatabase($this->kernel); $filePath = $this->meta->dataPost['backup-filepath']; $itemTimerStart = microtime(true); $isRestored = false; $indexKeyBefore = isset($this->partialData->indexKey) ? $this->partialData->indexKey : 0; try { $restoreDatabase->setup($dbHandle, $this->kernel->getBackupMetadata($filePath), $indexKeyBefore, !$isReplaceSite); $isRestored = $restoreDatabase->restore(); } catch (\Throwable $e) { if (strpos($e->getMessage(), 'Duplicate entry') !== false) { $this->kernel->log(sprintf('Warning: %s. DB File Line %d', $e->getMessage(), $restoreDatabase->getCurrentIndex()), __METHOD__); } else { return [ 'success' => false, 'data' => sprintf('Error: %s. Line %d', $e->getMessage(), $restoreDatabase->getCurrentIndex()), 'saveLogId' => __METHOD__, 'isAborted' => true ]; } } if ($isRestored) { $progressText = sprintf('Restoring Database was successful: Executed %d queries', $restoreDatabase->getCurrentIndex()); return [ 'success' => false, 'data' => '<!--{{saveResponseTag}}-->' . $progressText, 'saveLog' => $progressText, 'saveLogId' => __METHOD__, 'partialData' => $this->partialData ]; } $partialData = $restoreDatabase->getPartialData(); $indexKey = $partialData['indexKey']; $totalQuery = $partialData['totalQuery']; $queriesPerSecond = ($indexKey - $indexKeyBefore) / (microtime(true) - $itemTimerStart); $queriesPerSecond = abs($queriesPerSecond); $progressPercentage = null; $progressText = 'Restoring Database: Elapsed time: <span id="elapsedtime"><!--{{elapsedtime}}--></span>' . "\n"; if ($totalQuery > 0) { $executedText = sprintf( 'Restoring Database: Executed %s/%s queries (%s queries per second)', number_format($indexKey), number_format($totalQuery), number_format($queriesPerSecond) ); $progressPercentage = ceil(($indexKey / $totalQuery) * 100); if ($progressPercentage >= 99) { $progressPercentage = 100; } $progressText = sprintf('Restoring Database: Progress %d%% - Elapsed time: <span id="elapsedtime"><!--{{elapsedtime}}--></span>', $progressPercentage) . "\n"; } $partialDataText = $progressText . $executedText; return [ 'success' => false, 'data' => $partialDataText, 'partialData' => $partialData, 'isMemoryExceeded' => $partialData['isMemoryExceeded'], ]; } private function renameTables(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_DROPINS; if ($this->hasRestoreParts->database === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $this->kernel->maxExecutionTime($this->kernel::MAX_TIMEOUT_RESTORE); $dbHandle = $this->useHandle->wpcore->dbHandle(); if ($dbHandle->connect() === false) { return ['success' => false, 'data' => sprintf('Failed to rename Tables: %s', $dbHandle->response), 'saveLogId' => __METHOD__, 'isAborted' => true]; } $dbPrefix = isset($dbHandle->config->dbprefix) ? $dbHandle->config->dbprefix : 'wp_'; $dbTmpPrefix = $dbHandle::TMP_PREFIX; $result = $dbHandle->query('SHOW TABLES LIKE "' . $dbTmpPrefix . '%"'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return ['success' => false, 'data' => 'No tables found to rename', 'partialData' => $this->partialData]; } $countRenamed = 0; $tableCleanup = []; $itemTimerStart = microtime(true); $setPartialData = []; $totalRows = (int)$result->num_rows; try { $dbHandle->foreignKeyChecksOff(); $dbHandle->autocommit(false); $dbHandle->startTransaction(); while ($row = $result->fetch_row()) { if ($this->useHandle->extractor->hasCancelRequest()) { $this->useHandle->wpcore->enableMaintenance(false); $dbHandle->commit(); $dbHandle->autocommit(true); $dbHandle->close(); return ['success' => false, 'data' => 'The backup restoration was cancelled', 'saveLogId' => __METHOD__, 'isCancelled' => true]; } $isMemoryExceeded = $this->kernel->isMemoryExceeded(); $setPartialData = [ 'status' => self::STATUS_DOING_RESTORATION, 'isMemoryExceeded' => $isMemoryExceeded, 'isRestoreDb' => 1, 'restoreNextPart' => self::RESTORE_PART_RENAME_TABLES ]; if ($isMemoryExceeded || $this->kernel->isTimeExceed($this->meta->maxProcessingTime, $itemTimerStart)) { $dbHandle->commit(); return [ 'success' => false, 'data' => sprintf("Renaming Database tables: %d/%d", $countRenamed, $totalRows), 'saveLog' => true, 'saveLogId' => __METHOD__, 'partialData' => $setPartialData, 'isMemoryExceeded' => $isMemoryExceeded ]; } $tableTmp = $row[0]; $tableOld = str_replace($dbTmpPrefix, $dbPrefix, $dbHandle->getTableFromShortName($tableTmp)); $tableCleanup[$tableOld] = 1; if ($dbHandle->exec("DROP TABLE IF EXISTS `" . $tableOld . "`") && $dbHandle->exec("RENAME TABLE `" . $tableTmp . "` to `" . $tableOld . "`")) { $countRenamed++; } } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); $dbHandle->rollback(); $dbHandle->autocommit(true); $dbHandle->close(); return ['success' => false, 'data' => 'Renaming Database tables: failed to rename Database Tables', 'saveLogId' => __METHOD__, 'isAborted' => true]; } try { $totalOldTables = count($tableCleanup); $countRemoved = 0; if ($totalOldTables > 0) { $result = $dbHandle->query('SHOW TABLES LIKE "' . $dbPrefix . '%"'); if (($result instanceof \mysqli_result) && (int)$result->num_rows > 0) { while ($row = $result->fetch_row()) { $isMemoryExceeded = $this->kernel->isMemoryExceeded(); $setPartialData = [ 'status' => self::STATUS_DOING_RESTORATION, 'isMemoryExceeded' => $isMemoryExceeded, 'isRestoreDb' => 1, 'restoreNextPart' => self::RESTORE_PART_RENAME_TABLES ]; if ($isMemoryExceeded || $this->kernel->isTimeExceed($this->meta->maxProcessingTime, $itemTimerStart)) { $dbHandle->commit(); return [ 'success' => false, 'data' => sprintf("Removing Tables: %d/%d", $countRemoved, $totalOldTables), 'partialData' => $setPartialData, 'isMemoryExceeded' => $isMemoryExceeded ]; } if (!array_key_exists($row[0], $tableCleanup)) { if ($dbHandle->exec("DROP TABLE `" . $row[0] . "`")) { $countRemoved++; } } } } } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); $dbHandle->rollback(); $dbHandle->autocommit(true); $dbHandle->close(); return ['success' => false, 'data' => 'Renaming Database tables: failed to remove Database Tables', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $dbHandle->commit(); $dbHandle->autocommit(true); $dbHandle->close(); $this->useHandle->wpcore->maybeUpgradeDatabase(); $this->useHandle->wpcore->maybeRemoveStagingStatus(); return [ 'success' => false, 'data' => sprintf('Renaming Database tables was successful: Executed %d tables', $countRenamed), 'saveLog' => true, 'saveLogId' => __METHOD__, 'partialData' => $this->partialData, 'isAppendResponse' => true ]; } private function restoreDropins(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_MU_PLUGINS; if ($this->hasRestoreParts->dropins === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData, 'hasFile' => 0]; } $identifier = PathIdentifier::IDENTIFIER_WP_CONTENT; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { $this->kernel->log('Failed to restore Drop-in files: Could not get a valid path', __METHOD__); return ['success' => false, 'data' => '', 'partialData' => $this->partialData, 'hasFile' => 0, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); $this->kernel->mkdir($getPath->dst, __LINE__); $dropinsFile = $this->useHandle->extractor->getDropinsFile(); if (!empty($this->isOverwriteParts->dropins)) { foreach ($dropinsFile as $file) { $dstFile = $getPath->dst . '/' . $file; $this->kernel->unlink($dstFile, __LINE__); } } $countFile = 0; foreach ($dropinsFile as $file) { $srcFile = $getPath->src . '/' . $file; if (!file_exists($srcFile)) { continue; } $dstFile = $getPath->dst . '/' . $file; $this->kernel->unlink($dstFile, __LINE__); if (rename($srcFile, $dstFile)) { $countFile++; } } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Drop-ins: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData, 'hasFile' => $countFile]; } private function restoreMuPlugins(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_WPROOT; $identifier = PathIdentifier::IDENTIFIER_MUPLUGINS; $getPath = $this->getPath($identifier); $isRemoveOptimizer = false; if ($this->hasRestoreParts->muplugins === self::RESTORE_PART_FALSE) { if ($getPath->dst !== $identifier) { $this->kernel->mkdir($getPath->dst, __LINE__); $isRemoveOptimizer = $this->kernel->unlink($getPath->dst . '/wp-staging-optimizer.php', __LINE__); } return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore Mu-Plugins: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); if (!empty($this->isOverwriteParts->muplugins) && !$this->useHandle->file->removeDir($getPath->dst)) { return ['success' => false, 'data' => 'Failed to restore Mu-Plugins: Unable to overwrite directory', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst)) === false) { $countFile = 0; } if ($isRemoveOptimizer) { $this->kernel->log('Counting wp-staging-optimizer.php as a restored Drop-in file. The file will then be installed by the wp-staging plugin', __METHOD__); $countFile += 1; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring Mu-Plugins: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } private function restoreWpRoot(): array { $this->partialData->restoreNextPart = self::RESTORE_PART_DONE; if ($this->hasRestoreParts->wproot === self::RESTORE_PART_FALSE) { return ['success' => false, 'data' => '', 'partialData' => $this->partialData]; } $identifier = PathIdentifier::IDENTIFIER_ABSPATH; $getPath = $this->getPath($identifier); if ($getPath->src === $identifier || $getPath->dst === $identifier) { return ['success' => false, 'data' => 'Failed to restore other files in WP Root: Could not get a valid path', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $getPath->src = $this->kernel->normalizePath($this->extractPath . '/' . $getPath->src); $getPath->dst = $this->kernel->normalizePath($getPath->dst); $pathIdentifier = $this->kernel->getPathIdentifier(); $exclude = [ $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_UPLOADS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_THEMES), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_PLUGINS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_MUPLUGINS), $pathIdentifier->getRelativePath(PathIdentifier::IDENTIFIER_LANG), ]; $exclude = array_merge($exclude, $this->useHandle->wpcore->getWpCoreFiles()); if (($countFile = $this->useHandle->file->moveDir($getPath->src, $getPath->dst, $exclude)) === false) { $countFile = 0; } $text = ''; if ($countFile > 0) { $text = sprintf('Restoring other files in WP Root: %d files restored', $countFile); $this->kernel->log($text, __METHOD__); } return ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; } public function restoreBackup(): array { if (empty($this->meta->dataPost['total-files'])) { return ['success' => false, 'data' => 'Invalid request. Total files not available', 'saveLogId' => __METHOD__, 'isAborted' => true]; } if (empty($this->meta->dataPost['restore-parts']) || !filter_var($this->meta->dataPost['restore-parts'], FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) { return ['success' => false, 'data' => 'Invalid request. Restore parts not available', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $restorePartIntersectKey = [ PartIdentifier::PLUGIN_PART_IDENTIFIER => 'plugins', PartIdentifier::MU_PLUGIN_PART_IDENTIFIER => 'muplugins', PartIdentifier::THEME_PART_IDENTIFIER => 'themes', PartIdentifier::UPLOAD_PART_IDENTIFIER => 'uploads', PartIdentifier::WP_CONTENT_PART_IDENTIFIER => 'wpcontent', PartIdentifier::DATABASE_PART_IDENTIFIER => 'database', PartIdentifier::LANGUAGE_PART_IDENTIFIER => 'lang', PartIdentifier::DROPIN_PART_IDENTIFIER => 'dropins', PartIdentifier::WP_ROOT_PART_IDENTIFIER => 'wproot' ]; $restorePartData = $this->meta->dataPost['restore-parts']; if (!array_intersect_key($restorePartData, $restorePartIntersectKey)) { return ['success' => false, 'data' => 'Invalid request. Invalid Restore parts data', 'saveLogId' => __METHOD__, 'isAborted' => true]; } $overwritePartData = $this->meta->dataPost['overwrite-parts']; if (!array_intersect_key($overwritePartData, $restorePartIntersectKey)) { return ['success' => false, 'data' => 'Invalid request. Invalid Overwrite parts data', 'saveLogId' => __METHOD__, 'isAborted' => true]; } foreach ($restorePartIntersectKey as $key => $alias) { if ($key === $alias) { continue; } if (isset($restorePartData[$key])) { $restorePartData[$alias] = $restorePartData[$key]; unset($restorePartData[$key]); } if (isset($overwritePartData[$key])) { $overwritePartData[$alias] = $overwritePartData[$key]; unset($overwritePartData[$key]); } } $restorePartData = array_map(function ($data) { return (int)$data; }, $restorePartData); $this->hasRestoreParts = (object)$restorePartData; $overwritePartData = array_map(function ($data) { return (int)$data; }, $overwritePartData); $this->isOverwriteParts = (object)$overwritePartData; if ($this->useHandle->extractor->hasCancelRequest()) { $this->useHandle->wpcore->enableMaintenance(false); return ['success' => false, 'data' => 'The backup restoration was cancelled', 'saveLogId' => __METHOD__, 'isCancelled' => true]; } clearstatcache(); $this->partialData = $this->useHandle->extractor->getPartialDataFromAjaxRequest(); if (!isset($this->partialData->restoreNextPart)) { $this->partialData->restoreNextPart = self::NO_RESTORATION_PROCESS_YET; } if ($this->partialData->restoreNextPart === self::NO_RESTORATION_PROCESS_YET) { $extractRestorePartData = array_filter($restorePartData); if (!empty($this->meta->dataPost['restore-parts-listed']) && (int)$this->meta->dataPost['restore-parts-listed'] === count($extractRestorePartData)) { $extractRestorePartData = null; } $extract = $this->useHandle->extractor->extractBackup(true, $extractRestorePartData); if ($extract['success'] === false) { return $extract; } $this->partialData->status = self::STATUS_DOING_RESTORATION; $this->partialData->restoreNextPart = self::RESTORE_PART_UPLOADS; return ['success' => false, 'data' => $extract['data'], 'saveLog' => !empty($extract['saveLog']), 'saveLogId' => !empty($extract['saveLogId']) ? $extract['saveLogId'] : null, 'partialData' => $this->partialData]; } $this->kernel->maxExecutionTime($this->kernel::MAX_TIMEOUT_RESTORE); $this->useHandle->wpcore->enableMaintenance(true); $partResponse = []; switch ($this->partialData->restoreNextPart) { case self::RESTORE_PART_UPLOADS: $partResponse = $this->restoreUploads(); break; case self::RESTORE_PART_PLUGINS: $partResponse = $this->restorePlugins(); break; case self::RESTORE_PART_THEMES: $partResponse = $this->restoreThemes(); break; case self::RESTORE_PART_LANG: $partResponse = $this->restoreLang(); break; case self::RESTORE_PART_WPCONTENT: $partResponse = $this->restoreWpContent(); break; case self::RESTORE_PART_DELAY_DATABASE: $this->partialData->restoreNextPart = self::RESTORE_PART_DATABASE; $text = !empty($this->hasRestoreParts->database) ? 'Restoring Database in progress' : ''; $partResponse = ['success' => false, 'data' => $text, 'partialData' => $this->partialData]; break; case self::RESTORE_PART_DATABASE: $partResponse = $this->restoreDatabase(); break; case self::RESTORE_PART_RENAME_TABLES: $partResponse = $this->renameTables(); break; case self::RESTORE_PART_DROPINS: $partResponse = $this->restoreDropins(); if ($partResponse['hasFile']) { $this->useHandle->wpcore->flushObjectCache(); } break; case self::RESTORE_PART_MU_PLUGINS: $partResponse = $this->restoreMuPlugins(); break; case self::RESTORE_PART_WPROOT: $partResponse = $this->restoreWpRoot(); break; default: $partResponse = []; } if (!empty($partResponse)) { if (!empty($partResponse['isCancelled']) || !empty($partResponse['isAborted'])) { $this->useHandle->wpcore->enableMaintenance(false); if (!empty($partResponse['data'])) { $this->kernel->log($partResponse['data'], !empty($partResponse['saveLogId']) ? $partResponse['saveLogId'] : null); } } return $partResponse; } $this->useHandle->wpcore->enableMaintenance(false); $this->useHandle->file->removeDir($this->extractPath); $this->useHandle->wpcore->saveConfig(); return ['success' => true, 'data' => 'Restoring backup was successful', 'saveLog' => true, 'saveLogId' => __METHOD__, 'isCompleted' => true, 'isAppendResponse' => true]; } }
    final class SearchReplacer extends AbstractSearchReplacer { private $wpCore; private $kernel; public function __construct(\WPStagingRestorer $kernel, WpCore $wpCore, SubsitesSearchReplacer $subsitesSearchReplacer) { $this->kernel = $kernel; $this->wpCore = $wpCore; parent::__construct($subsitesSearchReplacer); } protected function normalizePath(string $path): string { return $this->kernel->normalizePath($path); } protected function getUploadUrl(): string { return $this->wpCore->getConfig()['uploadurl']; } }
    final class View
    {
        private $kernel;
        private $meta;
        private $useHandle;
        public function __construct(\WPStagingRestorer $kernel)
        {
            $this->kernel    = $kernel;
            $this->meta      = $this->kernel->getMeta();
            $this->useHandle = $this->kernel->getHandle(__CLASS__);
        }
        public function getWpVersion(): array
        {
            $wpver = [];
            $list  = $this->useHandle->backupListing->getBackupFiles();
            foreach ($list as $index => $data) {
                $wpver[$data['wpVersion']] = $data['wpVersion'];
            }
            return $wpver;
        }
        public function render(string $page): bool
        {
            if (is_object($this->useHandle) && !isset($this->useHandle->view)) {
                $useHandle         = (array)$this->useHandle;
                $useHandle['view'] = $this;
                $this->useHandle   = (object)$useHandle;
            }
            $methodName = lcfirst(str_replace(' ', '', ucwords(implode(' ', explode('-', $page)))));
            if (!method_exists($this, $methodName)) {
                printf('Item %s is not available', $this->kernel->escapeString($page));
                return false;
            }
            call_user_func([$this, $methodName]);
            return true;
        }
        private function LZWDecompress($binary): string
        {
            $dictionaryCount = 256;
            $bits            = 8;
            $codes           = [];
            $rest            = 0;
            $restLength      = 0;
            for ($i = 0; $i < strlen($binary); $i++) {
                $rest = ($rest << 8) + ord($binary[$i]);
                $restLength += 8;
                if ($restLength >= $bits) {
                    $restLength -= $bits;
                    $codes[] = $rest >> $restLength;
                    $rest &= (1 << $restLength) - 1;
                    $dictionaryCount++;
                    if ($dictionaryCount >> $bits) {
                        $bits++;
                    }
                }
            }
            $dictionary = range("\0", "\xFF");
            $output     = '';
            $word       = ' ';
            $element    = ' ';
            foreach ($codes as $i => $code) {
                $element = isset($dictionary[$code]) ? $dictionary[$code] : $word . $word[0];
                $output .= $element;
                if ($i) {
                    $dictionary[] = $word . $element[0];
                }
                $word = $element;
            }
            return $output;
        }
        private function escapeTooltip($text): string
        {
            return $this->kernel->escapeString($text, ['&#xa;']);
        }
        private function printAppFile()
        {
            echo $this->kernel->escapeString($this->meta->appFile);
        }
        private function printVersion()
        {
            echo $this->kernel->escapeString($this->meta->version);
        }
        private function printLicenseOwner()
        {
            $data = $this->useHandle->activate->getData();
            if (is_object($data) && !empty($data->name) && !empty($data->email)) {
                echo $this->kernel->escapeString($data->name . ' <' . $data->email . '>');
            }
        }
        private function printLicenseType()
        {
            $data = $this->useHandle->activate->getData();
            if (is_object($data) && !empty($data->type)) {
                echo '<a href="https://wp-staging.com" rel="noopener" target="new">' . $this->kernel->escapeString($data->type) . '</a>';
            }
        }
        private function printAssets($name, $isReturn = false)
        {
            $output = $this->meta->appFile . "?wpstg-restorer-file=print-" . $this->kernel->escapeString($name) . "&_=" . $this->kernel->escapeString($this->meta->buildId);
            if ($isReturn) {
                return $output;
            }
            echo $output;
        }
        private function printProcessLoader()
        {
            echo '<img id="wpstg-restorer-spinner" src="' . $this->printAssets('loader', true) . '">';
        }
        private function partSelection($metaData): array
        {
            $sortbyOption     = [];
            $sortbyOption[''] = 'All';
            $isNotHaveIndexPartSize = !isset($metaData->indexPartSize);
            if ($metaData->isExportingPlugins && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['pluginsSize']))) {
                $sortbyOption[PartIdentifier::PLUGIN_PART_IDENTIFIER] = 'Plugins';
            }
            if ($metaData->isExportingMuPlugins && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['mupluginsSize']))) {
                $sortbyOption[PartIdentifier::MU_PLUGIN_PART_IDENTIFIER] = 'Mu-Plugins';
            }
            if ($metaData->isExportingThemes && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['themesSize']))) {
                $sortbyOption[PartIdentifier::THEME_PART_IDENTIFIER] = 'Themes';
            }
            if ($metaData->isExportingUploads && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['uploadsSize']))) {
                $sortbyOption[PartIdentifier::UPLOAD_PART_IDENTIFIER] = 'Media Library';
            }
            if ($metaData->isExportingDatabase && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['sqlSize']))) {
                $sortbyOption[PartIdentifier::DATABASE_PART_IDENTIFIER] = 'Database';
            }
            if ($metaData->isExportingOtherWpContentFiles) {
                if (!$isNotHaveIndexPartSize) {
                    switch (true) {
                        case !empty($metaData->indexPartSize['langSize']):
                            $sortbyOption[PartIdentifier::LANGUAGE_PART_IDENTIFIER] = 'Languages';
                            break;
                        case !empty($metaData->indexPartSize['dropinsSize']):
                            $sortbyOption[PartIdentifier::DROPIN_PART_IDENTIFIER] = 'Drop-in File';
                            break;
                    }
                }
                if ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['wpcontentSize'])) {
                    $sortbyOption[PartIdentifier::WP_CONTENT_PART_IDENTIFIER] = 'Other Files in wp-content';
                }
            }
            if ($metaData->isExportingDatabase && ($isNotHaveIndexPartSize || !empty($metaData->indexPartSize['wpRootSize']))) {
                $sortbyOption[PartIdentifier::WP_ROOT_PART_IDENTIFIER] = 'Other Files In WP Root';
            }
            if (count($sortbyOption) - 1 < 2) {
                $sortbyOption = [];
            }
            return $sortbyOption;
        }
        private function partRestoreList($metaData, $wpcoreConfig): array
        {
            $hasIndexPartSize = !empty($metaData->indexPartSize);
            return [
                'Media Library'                 => [
                    'name'             => PartIdentifier::UPLOAD_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingUploads,
                    'path'             => $wpcoreConfig->uploads,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::UPLOAD_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Themes'                        => [
                    'name'             => PartIdentifier::THEME_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingThemes,
                    'path'             => $wpcoreConfig->themes,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::THEME_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Plugins'                       => [
                    'name'             => PartIdentifier::PLUGIN_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingPlugins,
                    'path'             => $wpcoreConfig->plugins,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::PLUGIN_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Mu-Plugins'                    => [
                    'name'             => PartIdentifier::MU_PLUGIN_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingMuPlugins,
                    'path'             => $wpcoreConfig->muplugins,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::MU_PLUGIN_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Languages'                     => [
                    'name'             => PartIdentifier::LANGUAGE_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingOtherWpContentFiles,
                    'path'             => $wpcoreConfig->lang,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::LANGUAGE_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Drop-in File'                  => [
                    'name'             => PartIdentifier::DROPIN_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingOtherWpContentFiles,
                    'path'             => $wpcoreConfig->wpcontent,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::DROPIN_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Other Files in wp-content'     => [
                    'name'             => PartIdentifier::WP_CONTENT_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingOtherWpContentFiles,
                    'path'             => $wpcoreConfig->wpcontent,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::WP_CONTENT_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 1,
                ],
                'Other Files in WP root folder' => [
                    'name'             => PartIdentifier::WP_ROOT_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingOtherWpContentFiles,
                    'path'             => $wpcoreConfig->wpcontent,
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::WP_ROOT_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 3, ],
                'Database File'                 => [
                    'name'             => PartIdentifier::DATABASE_PART_IDENTIFIER,
                    'status'           => (int)$metaData->isExportingDatabase,
                    'path'             => $metaData->isExportingDatabase && !empty($metaData->databaseFile) ? dirname($this->meta->rootPath . '/' . $this->kernel->getPathIdentifier()->transformIdentifiableToRelativePath($metaData->databaseFile)) : '',
                    'hasIndexPartSize' => $hasIndexPartSize && !empty($metaData->indexPartSize[PartIdentifier::DATABASE_PART_SIZE_IDENTIFIER]),
                    'restore'          => 1,
                    'overwrite'        => 2,
                ],
            ];
        }
        private function printBackupListingContains($metaData)
        {
            $isNotHaveIndexPartSize = !isset($metaData->indexPartSize);
            if ($metaData->isExportingDatabase) {
                $partSizeIdentifier = PartIdentifier::DATABASE_PART_SIZE_IDENTIFIER;
                $sqlSize            = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Database' . ($sqlSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($sqlSize) : '');
                if ($isNotHaveIndexPartSize || $sqlSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgDatabase(true) . '</div>';                }
            }
            if ($metaData->isExportingPlugins) {
                $partSizeIdentifier = PartIdentifier::PLUGIN_PART_SIZE_IDENTIFIER;
                $pluginsSize        = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Plugins' . ($pluginsSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($pluginsSize) : '');
                if ($isNotHaveIndexPartSize || $pluginsSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgPlugin(true) . '</div>';                }
            }
            if ($metaData->isExportingMuPlugins) {
                $partSizeIdentifier = PartIdentifier::MU_PLUGIN_PART_SIZE_IDENTIFIER;
                $muPluginsSize      = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Must-Use Plugins' . ($muPluginsSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($muPluginsSize) : '');
                if ($isNotHaveIndexPartSize || $muPluginsSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgMuplugin(true) . '</div>';                }
            }
            if ($metaData->isExportingThemes) {
                $partSizeIdentifier = PartIdentifier::THEME_PART_SIZE_IDENTIFIER;
                $themesSize         = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Themes' . ($themesSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($themesSize) : '');
                if ($isNotHaveIndexPartSize || $themesSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgTheme(true) . '</div>';                }
            }
            if ($metaData->isExportingUploads) {
                $partSizeIdentifier = PartIdentifier::UPLOAD_PART_SIZE_IDENTIFIER;
                $uploadsSize        = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Uploads' . ($uploadsSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($uploadsSize) : '');
                if ($isNotHaveIndexPartSize || $uploadsSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgUpload(true) . '</div>';                }
            }
            if ($metaData->isExportingOtherWpContentFiles) {
                $wpcontentPartSizeIdentifier = PartIdentifier::WP_CONTENT_PART_SIZE_IDENTIFIER;
                $wpcontentSize               = !empty($metaData->indexPartSize[$wpcontentPartSizeIdentifier]) ? $metaData->indexPartSize[$wpcontentPartSizeIdentifier] : 0;
                $langPartSizeIdentifier      = PartIdentifier::LANGUAGE_PART_SIZE_IDENTIFIER;
                $langSize                    = !empty($metaData->indexPartSize[$langPartSizeIdentifier]) ? $metaData->indexPartSize[$langPartSizeIdentifier] : 0;
                $wpcontentSize = $wpcontentSize + $langSize;
                $toolTip       = 'Other files in wp-content' . ($wpcontentSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($wpcontentSize) : '');
                if ($isNotHaveIndexPartSize || (int)$wpcontentSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgWpcontent(true) . '</div>';                }
            }
            if ($metaData->isExportingOtherWpRootFiles) {
                $partSizeIdentifier = PartIdentifier::WP_ROOT_PART_SIZE_IDENTIFIER;
                $wpRootSize         = !empty($metaData->indexPartSize[$partSizeIdentifier]) ? $metaData->indexPartSize[$partSizeIdentifier] : 0;
                $toolTip            = 'Other files in WP root folder' . ($wpRootSize ? '&#xa;Size: ' . $this->kernel->sizeFormat($wpRootSize) : '');
                if ($isNotHaveIndexPartSize || $wpRootSize > 0) {
                    echo '<div data-tooltip="' . $this->escapeTooltip($toolTip) . '">' . $this->printSvgWpRoot(true) . '</div>';                }
            }
        }
        public function backupPaging(string $backupFile, string $databaseFile, &$pagingData = '')
        {
            $filePathCache  = $this->useHandle->cache->getCacheFile($backupFile, 'backupmeta');
            $backupMetadata = new BackupMetadata();
            if (($data = $this->useHandle->cache->get($backupFile, 'backupmeta', $filePathCache)) !== null) {
                $backupMetadata = $backupMetadata->hydrate($data);
            } else {
                $backupMetadata = $backupMetadata->hydrateByFilePath($backupFile);
            }
            $indexLineDto = null;
            if ($backupMetadata->getIsBackupFormatV1()) {
                $indexLineDto = new BackupFileIndex();
            } else {
                $indexLineDto = $this->kernel->makeInstance(FileHeader::class);
            }
            $backupContent = new BackupContent();
            $backupContent->setPerPage(50);
            $backupContent->setBackup($backupFile, $indexLineDto, $backupMetadata);
            $backupContent->setPathIdentifier($this->kernel->getPathIdentifier());
            $backupContent->setDatabaseFiles([ $databaseFile ]);
            $pagingData = [
                'totalIndex'  => 0,
                'totalPage'   => 1,
                'indexPage'   => 1,
                'indexFilter' => '',
                'indexSortby' => ''
            ];
            if (!empty($this->meta->dataRequest['paging-data']) && filter_var($this->meta->dataRequest['paging-data'], FILTER_DEFAULT, FILTER_REQUIRE_ARRAY)) {
                $pagingData = array_merge($pagingData, $this->meta->dataRequest['paging-data']);
                foreach ($pagingData as $key => $value) {
                    if (in_array($key, ['indexFilter', 'indexSortby'])) {
                        $pagingData[$key] = (string)$value;
                        continue;
                    }
                    $pagingData[$key] = abs((int)$value);
                }
            }
            $pagingData = (object)$pagingData;
            $indexPage  = $pagingData->indexPage;
            $backupContent->setFilters([
                'filename' => $pagingData->indexFilter,
                'sortby'   => $pagingData->indexSortby
            ]);
            try {
                foreach ($backupContent->getFiles($indexPage) as $backupItem) {
                    if ($databaseFile === $backupItem->getIdentifiablePath()) {
                        $backupItem->setIsDatabase(true);
                    }
                    yield $backupItem->toArray();
                }
                $pagingData = (object)$backupContent->getPagingData();
            } catch (\Exception $ex) {
                $this->kernel->log($ex, __METHOD__);
            }
            return false;
        }
        private function printCss() {echo $this->LZWDecompress("#;gC8e!id0CLDg=M&spt2Nc 9Fr7MA+иj)ga:3٠4CJ;5`f1Zc7)-SJ3T4i;:Yd:*uZ=3SB/0l>\"-1\rܮ[/Fs;ڑpbÑ)ZHS)4c:\\MCym7ͦkh6n]nhSn-`: 3,CAF3A̰h0Hأ#*6@6+1!`0ØZ9jEcH2\rǿLٲ0%\0\\,I8X?,?̼ xޔH rc-\0H\\6͘j\nD?HSd9pzN:vM1↖:x\\\n\\\":6L9Mc86q\$Y2vI!:%ɂd\rAIDVtHuECc2r!piNM]A9I\$\06Loe\ndtscGt!JIB3]#@\$f*jbJ+2i=ħ5O2Lj8m6<}dC4(.2BJUu^U-{AS6-njc1coS\r-;C\r9Wee[6yp:A6:YlD_=p.\r.Ect7\rbjX)W83(@*!`7xX'ΓP9\$`?CD4ā\02,Mqn=B+|gj0N=0]}̵pZ4#գj8arVnR%9c@AU䚘Ff(j{4wj*`ݐg<i?Toܰ9UDF7L31 38\ns{M@hb|Ma%n j\$\rĕhC6Ea}OTaQ>H\"_D6`@r\rC(}@TChl@6,Q:)u(iգ\\JWj>\r52Y(RZ(:,L72C|A(C=H*F'5`b\$iݣ+ ]6>܊Hu܎\0L`l@Ig5eRaΆc)!\0>0v#w1]xA\0pbhS	\0xs\$0urpe!pl{Fjf=f; k;f>@rK\r\0&eI	!dj)9X]yT*|PZ&+/!3TȈ̹#0\\,pxR=^EuC+ElS]Hk!g&d.܃M9wNf	AI;v`*-KP#uv320d|y8xKYlxy6frЌ,;B\0s@W@C2\r)Po%*`Yɐ.G%7'ac#fEwj-̒{yӲbDu讂ץO_5dUdf1@`%8,VYcOM^M)&Ҏ;[c}Ð !@<Zvpp+e|/W@]ɔo.Vmw/1Ř&h7|vʖ>\$b~+ U\nd_\\3T*7\\ك-|F)UqUA`M,\$7x2.=2Xٟ<e,s(]j:L0yS-ITLԄS=F[4eVuZ]p5~ڣPW5nVC=hhy<S/asؘq籲XnN7<ˬ	oN:eIų6Dՙg#͠DĩM\0:AqkEescEZ:`nAJinT՗I@gEN-=n{\rr8CF~j/w9〃mˆLxd>h(0҃x^麟mWc>֘\\-\r=^YR\$P*Vg']\"tp[1.?Mپ~ʞ'ʬͣR⻃:ʹ]%{`2\\(%n^tc2ϖ&0`|RmzzØs;o!vCHAi^jele`p`prlCn\$f~h8jO ct(JV)Jd/N]R.S\rDdN q NjjeZIh&'kD\"N\$kBүhP0/w FOOQOPnXg j&|\rx\rU\rh*+v@t7J|GPvv`h1X(b0c(0:&wo)u§)Ak k֧R(lnmìn&noFo\0pGJgqqE'\"r`r.\$4\$:CBDtL\$TE2)@'j[tkx+H<=E=>g鍋\r̨)6+J5\nevYR%	\nh\rE\r A!X1%]!P@u	l/Enb\")%%eRTc҈9HpM\$H*/)U\nچ.4\",29B3DY*Vdf`m,*H-i+ܭ.\"D-(cD?/. q>2\$Ԋd?	U/l\01S#/:%B\rhD̉r	4b\$-,@fph32H4@p\0s	d	h#=pVRi%(sZ|^8(8Q.(4@?q51o[3	l`+J@J̪/2\0p\n˃\"1k+Ps]o>Фik5?	980#,ps\"3&%:0'ө@(KESLKCCӁ%%rEFb%NHtjt\"%4&Ɏ=V\0bɑ\r/H\rtCЊE4G	49rgEET-\"t[:c:fQ/J,K\$D!@ډ#k\\F b]((8@:+w;\rP(Q%ʿFIƐLSEsU2(Rub%ܽ^xoZVu ?OiW\r1P՛YSTUr[lt<BLqS;?XXT\r`D f+t׭M̵__UUm>-A_\"63KK6Y^unv䌶Lɶ 6Dw08\0PQKc\0BGkC:Dv,NDpCrEgbgv}X]f<pB^R9NP\r@ll!)Tj\$Bi]Qw/o}<&GștҵcRހ S̶Z(HtEq6qn`)N[o?r艷kт\"NѶM\"bb@l:B.sw()H+ނ\n\0jNB#d9O 1\0wvGloGdbd,WBT\$5RER0\"_(+l F%\\RÍ?W&\0uMwcnk[x60hKzt(#r<-vfZ򗭁GB8JW)PK4\\SSCAÂ@he\"[zʪ\\׸_&+/~h\\8b*l+huTXh\rxl `}KUmS=e:U/\r[+xp-eT]BS_W4C9Z^lkOmV+Bm8Xs,\\עJQbhʗf-ёZ&@́ɹVaGeW0wF:O<b;O9x4k` ڱn PY'Sya\\i\\yUt-JWPҷchbu(\rEB?dڛx96^\r9n=h/B@*f::Y\0ܠ@ٰ7])V\0AYXՓg5+r~f`9xF)QWmp>yzQw\r3SiAPDYH	\\\r:*~WwaZ|FZKnVWIhd\n@_zh-WNG}xxnmڅ\0Ũ/\n׌7Wv	Cj9x8YS(-z=8p9T6End)n5rJHCAuPwR\0}i}B岸Cߵ ]`T)kƻ{~WQo41{a۞\riWYcWړ\\B9n*YsⱢFĹِ'y'Ϲ:;׽/%yrySV`x7Zb̛C{ۡY\$ܼ'{]-zZgfEݚ˪?:{]HHS|#bܙ|ܣYOv<[TO{hۓ|}ܶbQԕlԃ9)]yN˗XÐ;eUR\";[&=δYi|\\KF{N6|4\\aH̛wXXюvX4:SlP.Nth0M|OY`}CI	Y4Ԕ<Ai9)_MyOtd鑼p=ELܔj3;\"]<n6=ޝJ77eϽ+][GbOSл!ci9V5>%Ž>՛A#i\"0\0c\"lI8F/ހU{gpxfVKǼ2bi^l,=}o\\e/Ҟa\$c֘1{'Sk-ֺ\nÃ0DL@^^ׯae9pϞŜQ,.yJOKu+D7?=_C{1_?2=LOixQeoo5+=|?v@Uq+瞋I;?0W/5r6u\\a}Eצ<_Y+jCx9ӯ1H_(?YI#IjR`9E\$+2N<!aF\n2\$`Mo{'ؾ寅0i_MN0#Hϛfm\nNBB3\0bՁ{b`m}k^Ǽ@kp\rr<r397:3XV4x9Aċ4;RHorxhTrH\$I\nT\0Z2{\0J`S6p4_\"\"|(\0@aCfI>\0A`a.R6&5)\rRwh[B`ИbD rR b,¢1:p`\nCņ<4mߢO\nRL2͕UC>3ЬvyIIJ%Ԛ2[)AH&suE_׊}S\n1K\\!nHr\n00\n\0dX`ÆpI2zELk*<=;eFLD`DH@w^hf!iĎ4}tMP@\0U;hbA	haEH<UɮU852j/,LR/8CN:[GFF(gnRHn(oR\r{E51:<#7x,cVXVׯ+8t\rp5pI1\n^xMq@P@L\$]	X?8&R*Т`n@A\neF`hi\\'16.XΣ]+prHIMXŊ&(f\\WcE\$w3E<㊴waܯXÒ\$lyL9'tSb%=F\nöVz sTJ2B.!шrI.\"̀,|bf1E%1yn#e G&*P˰HC2DK*\"UF'x(E064bKH~;0+)GpђJ#v!aiz\$9ER@ObFGPu\$I׍b\0005 f\r>@1pa؊V'Bl`L@\r`мH/G\0fHfx/Geu<|eC`:8\rpuهXz14	жGp%-Eil\0̠.+0cǎ!#)O>ڢ\"@l\"`sC7D(Fc8/	J%R\n)a=,itBYp̲@.<pI%wE-jNjHJIAEX\n'Rn	4LAȋARYE3SK\0005(l\0Y3|5EhP(Whɏ*AN)\0Lf1E\n!\rE*:11q4mߖx\r3Y-ǔ<T~#>-Y<Upbr֨X6@xT˦1h_||/STѬB}yѤZgS>aCf46ig!N\0͜o\$YώyXPsf֏b0̄.LNK%\\L 1Lg9\$NL>rc\n8@w2`̦}:D|g>Em+4g?T[\0	nⓌ~}");}
        private function printJs() {echo $this->LZWDecompress("\no7\nà\":̢ib#yeGCo3\r!e	E\"Id.2?e\n=\r3n:ΐ``)@hD*i3\n5V\r:FeNW3Dj(L#Ȁe8M8s ;M+FTjR;Ý#peGZ}Md2FS C#9jM0D>## 7G=' 9P\r)<,0\"㙲13~fca㬈Kдm+p0b@J=#hD#6!C5X9I;䟲Mpz=Hz7P2C8XGap0bx7=zL!`Qt0PT<(\n|o\"o4\nMcrn'IJ`\rʨӣt'rX2c8 nB>`:lL<TL	­,󻴑'a3Kr!`tDW42֕)R:FsA`)Dl7L;2{8CƋ	>|z PA\0-B:HH&78w!Jcs\"W\0Te32# ]̘ፃ%j'Pas.F48`Sce@XDIě'\rh9ѳ~7cL&&@;LA\\E2x*	`Hc8hu2/\$4]`pt+]KExw 31{\rv7#̘1Pΰ03wh	GO#l9jRR:&!yàZS`Z\0PM0ɍAj&.\$aaOe^|CS!8=/[sLK<ad27:#\nQvL]tOPA/nd\$ޞqj8CR\riɲ&xKPI*\0e0'rӄq!]DȬ9~CkJ),cVGC'_}LuCa&Lo	VDM;ԸnB]!tD;!Ɓɱu]Dc}GADd@SQFőY\"YcF Le3x&UPX*8q#,s\$삃h\nB\n)>2X%r;Ih&&,Ǚ1f4欹3d游0FVV9vaM1\rNp]r\\9/':/ȳ=QJtqCNGΐTN\$\rFp'S\0ȥf\\lO-唔=8=*܊-go\r0&LsgÝGFHS;+ERdgLWP!:'χ0xAsr3nBKn_C4ZwA_DI1&*Lmp&9da@VAqķα0~Y\\;pZ!T%6,RHGUPYeMJ&\r\090txiZc&o5PFzA@{(,޴S\0` \"s<&˪R\rjLs݁@/& Rc+_'a.%̺r^tlPI:+kmu=j(!-A::BTjuK]u	W'DXrE0TB\"+.'e]spu]Vi@3U2+Ș3:)\r,PX{PD\\<bŋ1H9n;r{ hn4-rUG\"l.ĵX}\rV,݌-:؜kwVN@`ʉ/b#fժ:zBmLZCIg- ]`wj;nOtd\"M\nv睸(VAalB&#]:k\n>CMXe3PDtmECڪj)Pqf\$DRZ)2P\rE:(#Tr۲~Kx,D*{l7elP\\w!@p֌oZ&TնTo`6.r+VnOAvۉ\\t=h'WnT*9X<x#L4\$;DsҵJz\"ԸuiSXBiک60	HW9qҴsbY+-)Tʵ?2cWޱv9fooXD0xӺAغ7Q#گ^BΓ(.J`CD%찫\n`vʶfj)p?Rp60:RVmzKӂJJ	0`@K\0@@D(L@/B+D>P[@3ɔ@L	pD||\"GԚLE(IX6ؤcpc;P\0dP\r̖bGfp\0D<`\0PtRM{uR@S&@Hm`D<fh2DPzRx(eBe`>uOpKXGPrZ,C\rgh+kQΆT	B\n\0g9\"b lѲe#&50:mD` `oZ \0IpZ:Xx\0~Qu{#D6>jLCM6m\\&\nf%[:bj(q\n@hC<eCacl@;@`v -<H!`\n\n}+ȧ/HsEjE\0}GL0S\0\rL}|jL`D6#h\$%3\$\"`bP-4SI*d.m`y 6 %`ZI\r\\ >Ȅ*Z¤\rA91C7%9cj!Dp Zj;8;#\"r!qxm`l W@DBf^1=D@T ~O@SA0-DNױLT?1;D@>1:TL Q+3@U?&A03Ӹ,=HE`KSEkEtCDtcFtjEHS?\nk`VMTtmdЄ(@Q@Ƅ\\L)MNQAT4h@U\nBOqAWB@wCp\rM}\nRNd5AN/HqVLFuOUMOtAp` \nucugQ4V=\n WX5QXRM{\n\n\nUSOOL\n`\n	T5`	 VeS5PE:V6@\"I\n*+\0`!ZI7\"PAYA4x!FbZ	Ds^šRu#btaMVC\nuYld.hm+eu\\7Q_UV71\0s_\"^aaT7Eq kb1@IA Ofom\$Ej+3bjeJbԎFY`m\0 vmAVӽ\"@d<Aqp&mh ^T{;<3<=3QsDE>3>)e/#1n:\0%L>t ZjfHp\0.`dc&&ywl,xy2_y| `z@rY{d`LZ\0jgF\nW\\@X	z	@Pif+d*3k6h&'+9fJb6`1fVPf.B^<&P\"`c<NkAVO\\fɄPJK=hÅXX(j72?Bri6l{X~+HbǘL>BA+#RozbxDL8 0q-Y@.z\rW\0rZ\$FnkP\$@& rN+~#PDZ2Zm'@cGQ0)@f\\t-zelK~_[` da\"l>jᭊ\\1<͕ߕc\0	1gظ*n޹xmDΌ@˔Ӕ\0d׹w>DI {.\$a~\\\0f׮^i`y-x՝Yj\0Р{FEbc `\$x!m\0¶!\rQ~z	Z!bNׁzPjhŌL)s\$Qfb`brcjQ(d\$ҏ37R>a&-E\0|99^ha`ް`R\rZ#`F@h>C\"L3*`Z3>Ծ\"S	4\r8\\~	r@k\0Ǟ<Cxv9X\"f\$K2z\nnef&b/Xoc*0f,c\n;Ǐ^HX.\$d\n`RK3) P>¶#ۗFDwłt<\npDخ`@ۀz\nc!B6M3xr7 c\0ݴ@xLq[bffj!g{)-\"r`mz~bq{<ow7yVg3ţČna=Ȉ\0'e2N\rLP<͘sm76?\r#|c#a<Qp|rK6ܶ͜' μȵ~& ,|͢ph(܇\n	o\0ޗĦoBB`D[Ĥ[w^^سlOQ։]lDmK6P^6#f6wG'Òκ1hu+oHteU.u\0Ge݂ߡ@XTB\0*}\074@pŲHZ>\r~\$`Y+cn\nP];63F\r\nÖ@്,cx\"	5Ӡ\r:m`1ZGf@<,d*\\+يݡ`ޛ/)|b3|B̚|KPicJr\0bh`	\nT0?,r\"DG1NL|->+e_}9'.a`u4յzGYDc[\"'\nwz>&%O}a_r.\n t;,\0QY_o\"'-*Qپ_6=Q}\\Ƥ?PmjjLh\"&~0dߐOM\r0fuQv]|}@i12K\\M\0@DGF	g>S@LzBnUD\\M.\0000.`d/T?@E2D4c<b6w3AZ㠈%O|l*Wu~PZ`'(\n&mvs@'i\0ZdU#֡h8\\#|Z:oy1p@v-@<{.@N`) l@zxU=͠'m\0N\00[pAGSxS \"G|bh`B=ظ]HC/paph*u0s|FCt6KzZ.q@D\rĳbM7д_ ?\rCBHTM]r<-5p0S#p\n&XCq}A\0S.r=6H\"@B&;oÉP0֬IMKb+v؂=dPlL`ZշYDB&FBGvIX6N:T?aDhWsvFQ2DoZR#/Q;aQHnq;+Kb@Zާ}CPQJ_ 1DFt*cƮ(1H/[gb><r#!{=MJyHvV؎\0`cclpyDKd#cr7(\r@Hiڜ!lۊ\\!i~ \"ӋEuc{J9\n\0쀨+\"JLY\$j+d:xCW}Ilh}tg?I\$AlL~@4_<c*&|fs^3\r'U!\0dZHO	\n.GktoahM)G{b\";B{qP=.w{!**\r\"4p͟,D9)Tdbjy	|IBw0|&29EY7\"ri|d-IO@&v<BOK=}-5LeéDbr K)i4WE^ԣ{/|_`\$JX)f+^ Qx/ 7C gp@A@1@OF\$ `i\"KhDa7	\r{v8dw/\"=/LO\nW/Lv۫\$]\">Y\"k`p#Sg5#{\\r9,>IR~`.`RLd'GxΗimAmnT@tQZŐZPB#F`: |%Fa^\"D*@aJ/et')081٠̾0*li`p4I|v8D@Ԑld07	0,Suxb4AAxUSݔ.\")m\",>N\rh5ч,a~ k8k9\0[\\,H\0WB`:ySe>/#ӕj2&s|Ti΄Gɝ\0:CxZ&d-yso'kΒ{eK<ғ^}}=bO`VWl-`[ZA*W[Khkѩhs8:ΐiDZG'LbR8'cMVCSк*2rPxG%hDI52x`u*o'*@Ɍ9ȹ%0\"{Et(S9.vdPrQRAlP1	5<U4Ӈ@DbVd_#>	cqTXհ1C[|ad@ٝ) d :pG]+EQ	+´nѢޖt-`F@?.`	bl=\0(\n*axcn学!ѫT6M0K|A/m;ajS&TQ9RoY\0 YMf&8N]dKyOZf.S-`ǩ=_娨rIݑlH04v@gIB>~~0v-`R6\0:M6'	Sm*`lӯ%TW{i*&;:`(g1'VL\r[E.A`i)\0E	⼇\\ч*P89AE\0[VozHw@\0(\"?(ZޢV]B8h5lò)l'&eY3Yi	d(2[t\nXՐk@(P-7X%ĭYlc[q\r~1`\0\"lEoEq m:kC^։A\"(	d'4+<m[տLkpU'l+de5C0da-gk>u\nr\0\0 ԃI\0^+[W	 Nc.7<E\n-4jdƵ=Yd?1H\n,,vY[-~kB1\"f.8H`\"HH;@5PTˉ(IsxI>YL4|%tNW`ﺌ!n<ϻU4\0=ۃ|[ܡ%>Q5hH{=\0_d(ABL} \n%I0\0P1=!:0Ѵ(\"A=Tj0\0[hcׇ#eZ0XY2j5mZ95\0jC:/iѼI5&(\$H?R~kcQڞB%N|g&.J^s*j(-4dLQW@n4o`A=wdaCi|%)C弧1dZRR@@+\0\0hntj]Yh9X0`kzyS,<UV!TG2H6Qiw<DK5LjЩ@&96#	 UErj.vf鄙DZ>x#3ǜB f-\n\0ج>FM5	hF8|&	41(lW@tr	WTl]6sL8ԗD3+N\$5Fzx@6mpw2046_Lwky1v瘽g@a))k£|0t\0z&*v۹6:7|\\ccmAk4l\nT]n\niI/X,\\4hn-0\0.!C\0AE:K>q5h0\$k{8JF\\\0tJ/@ܨaW	=gbr!ׂ\\*!avPȶ=jP3\\2H#J{<C9y xJfx8ۄg`jg\rYIk\"8M?{QaS¹vO|*elwH\n,UEJH@(1Ѓk*r\\\ne/Q	+\0004<M,cãYf1peMIbq-xrm;P!\0 k%M/mc!E[Ui/fCG}@gTTSaj0CSBpɲ4]?m-ֳ4훕Z\0,xqWT-\rݧ@Qn*!=Oj1\\ǭ٨pUz?yɬ`t?@+).nBm?\"&qL|lT>^n>El9W]\$8VOjJUOX-}nF+QZ􀦣k,> hzC~dpuڊdP\"`kM,&qzqp\0pΩ.URŒ[і/ZDwP^c:}1fWH8NcʳcyuH9U2li_Nl'a#䷨BC`Έ'Ee\063%i 3IztNi-K}\":	h\0p@yN6Xf|-}U95ֹl.ndX@X/bP+\\:g7aXŕ~Q!4n0PtD<tn\0^!	gcܨR;\"nZͷ]>u*ej1=H\\w\0ҥ\nYEa:։\r1Pb5`n_CcQZ@ !\0L.@طu9\0`p*Jj*slmhQ\" ,=8qfzɬ;.[h¼<.!{[p8gA\"ǈcR=C\$\0yԘĦT?	vF#U'*g˥\"	}վu\r^&4M\$\0&M5V*Ev`1%Skb:l[9̼Bj(؅mQs\"Sn|ծ3W\0ţSaӶ\$/L%0@\"b&Dmm4 ed7-j\08\rʚ/ajfX\$?MGn!aá#bWF^|k[eFog7iYNJӰsrcْx\$Nid`+K@Ø#/b[	(NZmC{/=z6Dɷs(EM!\0hSfYǀThSj2k#VËsG6ݸ%	Svߵ7+2 ?j1)KZ0Ef&hNFl %v^vz-CղLavXS0&V>ړ'qDjKIM~]S`X\r:ޘM`.*X~c6{\\4S\0w	H޷h\r9@Z,):\0`E'amXk\0Fa5`>Ia\$H]2Iz@jj`)o	K\"@\rH\0q?e}uop\" pfFCߙWwٍLex7I/R\rNI8,(tw1c8BÀRe0Kx(~Ȫ;ڱhB,AlykM&cE;@E\0=d(&8ͬ)''9#Dm#8P A^>1&U+X籀Ws7gBwRUxPeDJ_Ϙ*;exQqq\n_ėebi#va7mP8^Ifغ(,]\rxέ	a QsAyēs3S̕[\n煽dѰ[i]im/zӶbv4BY?E]\\!^&\$a\\lqz%]a:_\$1рj#~.B`QLj8B\$9KLS895Zl(gd0/t^{\r8Fz#)xYg`~hzk.<iAtkJ\"!lrznם!jQ`~P]3!S|4KkFq0v\$&\\4|lE7vgF#Z89g̢\$a[6= x@DJ!&#}1ʀ},nǬ~,0CG}7_8(/s&؀-T^\r\0ȡC\0\$B\"h<^DuG/@p >Y\n,*RIr.0&2P_kG;;zF-`Ω 7y9d˲i~O4дwf_Ѕ(WLZ,n\"C֠T}|f{HͿ5sc*x^BmFd6(.z^\rٵF>2fN\\iT^.7Xhe4=&l:v FIr~/FІ?LVr]eV.YuB.Vavd0#ḥׄw2p\";̐\\PF;I\$ݡio8߀w;w7`o5\n4m҆.Q\0p\npI\\(F_TBxp~}Kk_\\SօFƾHQ;s;YQt1zȰA6ANd5u.ZSQD생'Y'ϢTv	݂^xu%\nwL!fx`vhio۸[Bph69:\"Ɉ4CrңF~	TA8܁ϒgS_v=7OLo}6쓹_jThXL!#J6gPE\"ҹ\0,K8n6\$xM<@P~jU>̸sS\\WGr(P32,{\"*0A\0B? sM.4'ؘ`n3+\rJ!PAJOf,^㟽ڢ,*<bx4a;;?(֦2cX4<譯k`=SrFaꢃP,l\0\r+?-Fo-,O\$hw?N@(i3>/u;\".n9(6N񑢃:/>{{£ϭ?b*p}N\0tdH(/^f!_;0aoxPYVD(;h(h=2B3\\+.\0+]\0+\r/I=@ Epޘgk?q*t Po2/|*(gAΜ\rA[*jh`xZC(k4A,P.G\"0f#&ŦzHbI0<&\$?\n2=79bE-勿	|&qAHAJ1	+	<&@\"PR)%<*o26zPN\0-r!\"&P;]x<m~!\06zߩ;Kx+kj	:̳04=#όUhj%*	x楈`A2|pN\r@@zgpl4#غp6|ᱏj!pb.hG!t\\+A1E,pΒ1p>	Jn4*D@pj@{ݢ\nl0\nN+Q\ng\0]̎(;`҂墘UC&a*2jn}N\n`X@rT|&fSLI'0A\nĴ!	H2%+̏./\"hoPơ\"ht	}PC	4;)0|݈i\\Nb.8ڸ\rՃV33Xɦ\ri\"Q?r\nCTDIR\$<H\"L\$*tHl:CxH㱲<t*b\\I:xP <A+tHDF!DfKs1?sQHsoME*4bW\"Lb:7vwDT!\nMS\0Bl`2 Ӭ2|+/7Ӟl آ\$\0vwgSezKEm1,[h1qOEK\r+/U	6Dꨠ/}h	;aÎ9B *\$^pÖ_1Q \n\rzVDEdFF%u0\rj`2EaE	bчF 4cqEd^F#bD8h\n<l*=!4`B,{0>\rtjE\"\"m\0\"NCi\"6\0H\$,jH\\h*\0D?QD(2t|oe&)\nv(	|B,ZbQy\0Prr)Uyw0Z)qcfFx	,Y*0hQ[\$苯4rLⳝzuAAG*	91\$Zv)49\"=8惴?iޔwc\nC.07*\n`3\0[\0`kײi/#\0ϧ h:`2`*\ns*2?SiS 3OHahAY I1Rsqu\\hLXs!_3 GZ`赡|jGyH\06p!\0\$\n[HvNĩ\"\r>/,Z=8V	2b/i6H98 \rW4Q^ccV%\"`\rh6%Qr{#p/8H#u	#2(#䇒6#q/N\nTN؇\$!:I`/RD/jW Hs<>krrMA`pVOD1	T%Q7I:k\0u4-\$468p%HfҧPmwȅP;{H{,@ds@~y8'J^I|I5yfMq'|Y½*1QmJ!|ui>Q\r\0GSr+lWytzC1ʌ)\0a %ڔEGcQIDdBC/0/gDtWFql\0X,8<4GȪD3k=>H0&72jBDh`>6w9+@*t.ң~{|bQȿ4HAt\r\$ ).2 DeÈ\$eH1|!!r!ª8⭄-\0S;;P+` ƚ\r /\"4rB,9+\0'pɐA\0\$h*|.IbLlE3(X (	Ql怊yEph+/NށSyGK|\".<2%<kIe c?xr〮.s1loL6ߓHǔ/\"1+3Q0\$1n^z30(^u?!R\rLLɁ;BRJ;\naobK\$x+sLVWPUK/\$÷/TK􀫞!S/K2|p_s|*`AV:c[G(ub5X1x\0 )	2Kp\rоM&L^,\nHBXt.Y̋,p\"Ë,Xz'48`6Gx3q3)D<@i*HmF(0Ǜ+\0ߛo1Ahn\0+ROQZ&S3t)z@\n9Âm	V\n/XI+`)sHQO#;\rꍬ8N-6B&`AT (jͦ&zpL\r*X\r	@YVEߐ<x:PټE\0ӯʅk9CaƔ BCt,\$oSNHtd<M:͐\0Ѐ4i\"hB9,[;:=R^\"/F\0D&uP1,b?@P)d@]\")[m1t,`4a>\r\\;płya28\"qr!KS899GZ;dNdOː#H=\$!-b\"Q/.,O`\nB/z=-^rD\0Hdblυ<H7OO\0@ȸ\0=h\nx>~~ՊI%z/(A#u\n@tt\$@@0Nih 	'C2t~p,\"bIGtwqp>?0B=발BA7л;ot);:5mB!L/Mfu7B/>PCP)xPKFcM8 d2RL\r@bV᭚ NGB>*\0(t2R2 0WAtIjQv;\0*xbXT>,07L > 32?PTXfZL6>r\\~BHd&MBbD0&3,:ED3b'(ѝGt+at)	Oƅ\$	iPDDӘQMɽu~̈>TړH.\0]<9#!PbNt?;b9Pز+!َR!_A78jtMȨo)NL@lHC3^#vD+!QȰEeJPu&DHEܖ33郱.\r<oRQCcD:Ť_+4J(iJԈqxIIXp\0D\r'̛z0QF]fF;'dE,YRP`|ԌK)t-P% 25l3j!Fbz/D֕'sk4Ǡ,8ұLk@H+u7Զ[]+\"TS&JFIN\"3R'K*4Ҡס\n04=#/<K Jq=`u490*R؆c#F\n>\")<.-!xʶ8DJڏą\"34Q\$}4Rk&*Q.XB\0QDE\00Y\05HTY{F %[Izd%PXDD+ELB\n DIV\0H4l2Eafd`	OԤ%	\0%\$%;r9pXgEꂆɀvQ@)\nPUC/E	\n?\$Tb:\"ES@^UE0qcIZp;H\"	\"I;X\0U5@9ZpՇ\\E3C/MPT1%KS	d(0FC<i1VhXXF1QehȚAuE`]\$X-Ywl\0]|\0VlUW#ECS` \0{	a:Mbv7D;Ua\0VԹ'@2P@%nPFbŠb\0ƦpIUum'U\0!Z^<Q@>V.]Dpu\n&AJɼ-iq/\\+멻(fPl#&`X.W	\nJfjGX\0x1ū(,c^ˇVLVn_W(V%<ko5UiMFV+k5MTUzoubH1¶QVB/mTuWB*Hj.Hg2hښg횬L w8\\mp\$*7q*T:\"Y \\+Jo\nڊ2W\nF=tuעSÅ^EZ9[unU\0?\$|>Mo5\\~GD}#bW	bMIeNl\08жbrYe\$Gcm9#@VX19>g`@i`=@T%,?lN%kU3<LD C<pܡe\nH'ăPE\0\r@0Z8b7Dm\0:݅AW: #V8[pHtBXi ; bOv/;\$5xKҢԉhrE`ufYDȶ΄/Tji@\\ \$Ve\"Og16h5aͩ\rZȩd\0vO+XC B wt\\@d.L6H3e\0006ΞW38N8Ld2HPk!rp!Z\"V^[f!`iGBjblB2w8|^T;mu\0ʅŝcA\\hkg`!]Yt͟6tg?gvxh0%~ Yh]VC6'v!uV4b91a)7'΃I 7}JI^\"i\"\"<[8#\n@abͮ8X \"Z:uSm-_(449@6K\0r+TTPBkPJB]Fp\r{kKl[oCgl9-٨ l@6[\rghhTN<m3\0NN1΀ʅ\\Q?a\0FHq\0_iA7HO[[O܁\rg2Z[\r_R\\Kfk2~]DˋQ\"R\n?DL噂H#斸aG%cB.cbk7Pw&M2c'+AݡVB̐Z6Af9!=fpn!*'&Xo;.^A;3XjF@`1tk[OV,!.<%!s_3U*nR%aH;)z.qpPXCz]5Sn2lyLP4@dX-9o9@ֳKc=y|Z@ +貵}5Sb=L\"'LN65l \\ETN\"*Qնp}!2a`s=[lƂ#b14UQu(CQm\rFbLa8Yb;]@]IA.[<]XwL'S]0]o2ce8:X5O;a\$Hǰldq\$졐wivhy\$B3'uX \$lB\nY1]|O<,xd0`HJڴہZ\"r;s\n`ؿ4@IH`\0d.>B;=NkqTB8NpgBT]y4\")}q克w.^Sx⥚\\ca'\0h*eK䛜&yu\ngyWox8/Q2=8=W^=\"^%w&I\nnpDtӘvU<2])/FZ/+\nrӖ4mN7F4#\$\rB	<bKA\"*jp/#\0	A4v&whe\\Ų(P+Q9&qKW%J.7wCʃ[\"-):&5ggPҠt{\ns.=;֓A*k:Q>\0R)?.X0üIW|!yw	90]xwܬ#\nn'x\"b{\0`x\0\nZ#aW\n%N7t|WCQ]UDYnpN'\rnh\"j;\rޡ,񰈉ʳ⷗+>ǖ	&P,.(fW 7 oba\$R&\$)ΜI73\\23s6nK{&ATlx/}A:`QhHi#5w1qe+&h{`0oX9S`rU۠:CV|[E\\U.F{}a9JI*,ù\r\rg&'0\\_M!ąsoj\"2-w<}x`\r*rdm8` 6*\"ΕYdFPV4Y)?FUg=\\;Hkx+b-cX\0i_ݧH*{-];%؀FTTf8{X@x?S؍,	a\r++/	.lI*2uf(RژE4iĴ:L\n-].'L|͠bc@n8L/9`SMCX:ϩ}NRx3StPrf*9WHN-qcJڃ↏⫆}r+S\rwNЪ1:O+-s-b04Dt~ˢǪ*޷3r\nCɲ0tz뷴!43p!+wHjĤ*ԫ6Bΐ8\0{6{.870?-݂\"ކ]y*4P{XкԎq7_cxWu;b9m29jT*N8Dw+rZDL?zDF\$f\rTx66@BODi;v C*3^!I8\rl	v넧=hފ, AL1mL˂X8?a.\ns_6Gr+)k-oK1+'Te+7\$ˀr+W#sG`iTè36B40C\0㜬VʚuCaG20[YNc=y>NqFs\0oN8\rѣj@X:4g8r tQ¸؁Ck-	:;ei\rHƴRe9j[:e/y6eu];,Kt^FYzBqR%#VAt44Xs>@:Ŗ)2td/\08.!8ci\05rqM/d	Ch\rNf>!vd!Fx|#˒fe'^	er\"	\n\\iY\"c&fJ36h\"\0L`eHSk|ȹ&)70ز(r5IS^-Q<1͗\0ϕ\\9^3fHH)y1bo(<`-qg/49&A*	:CJ>	[n{`-ἏrMk-udr`d&C)/T>Ch@iףM-{{`WAp_.鋴g4yg\$b(4k㕞hCߞ<|\r}0DdKpNy`!Ά\r\$v>zƶ!y볒CǜC[\"Q LQygqx|Sc~u {Vy y;9{6h3p8wd;mD>\\Cg_vu{X9hvhyv'8\0kNhr0\rS@!{c*hH%fz;^ɢlj!5&whM<7跢*[׎hѡ&X%Fyz2hzpRga%1(Vf.	yc>؎c](8X\0٤f4X|_dC2<,sK(Z`/\\,h{`zAr9:fzh[)~ci\nƗAXP0b:ldIb:nj\n2Dbɰ`DmݧD0!\"DxW :~`k@!_^wSKvݷ rfM4aۨtFD\nX 7&\$vYUAJ,\rWmػ JZ#zM7jehp`8\"i\0sV\04ٞoc.~HB00B8h\r8}^(F\0hA\$A\n,/A:qy9ϗv#\06}ƠެWA'9bsZB֭\n֭tpzK﫠L/\nȔyY_lȤiXks[[ݘ\\墔:9y-ƤDk%ʄk[!A+Dn>Lٮs?yHg`IC90hoƷ2ηj~\"뇩4bk\$β\n~hkٮPZӮnn#/*fp_V~x)&JEA\\E|̅\0i&>f:,\$?mƵ׉^(9F `D^o؎}\"h==8|yYTJATs2Tx~gcy;Ge~ٴĵi\rkk\0bdQ![@}tM%kQ\rZُ%@{5&46N-!eNïK֯Qm(Zo5)d\rh@~={mX-Z6Z4d~,?:8]`@8d27%NNEz`Pj{;4yaT6\$Db\\ >DXIu\$Y @Qx}\0{VR@E&ѶiQ=.a\n	?	Gd+L݉MŅ3[\\C^K_P02jP/yvP\nAfn'+ BFuіj6AB{c؊m׀]߯R'C.s>Qvax=\\*#Z[=ۆ*Xk8-\0wC\0ID:\r̨)~Qql%|bX t@oKpfL\rm\"*P}BnǽA7,Ak%dbj t]:HV:\rj=n!\$q󔛏40;@ aOÅV/ N.BNxdEq1tSUr˅5o6iQķ-زBnuFKaTE!dM\\F+%M>B-C]!&ˍ!@bk3֥]xd\nɹ_woK̠MePVoCDVћAfx,VACؘ	x~f	,N|c<&`H(\\H*VWynJ\r1\n'P01.\$ˑ*8m׀mdN	*->q\nڎ&oGw!\0ݻBVC	4p\\67^d(4-prV͔l啷{Y~V;P!Yl}\">^s\0XwWram%<{oK0c<uj}vC|ƳSc(v!.y\$m.eu#epZV'd:'gAhT+/RKGYK@&ۛV5^GP!{-+ͥMtr&p\0+oÞ7WԈfxc|,7hIخJt26ep\0r=:_7]CQmm;b# NxAaP-o>&gM{;1\r\\Ɇ	{lLP-M?lAp4tiKOS\npZmM؆Y0A	ܳ;P|^)gHKH,l\nd`o{EHLM rKܳ/-|޴ފO.iĒ/M\\<l*'0(GT>\rHhK{m?!<('pʀ`6 a0&/rBXbnxHW5@0/s,\"Z̉+x<9\r8|k[7,OG G\0;CR񭰇=KԐ-0? 4qɝ#|`0x1IqͺE#vSd\nBVOk<?ܫ	\0l85JeUYա̬~򮬀Cpah\rvËϽ=*JlD6ᐫO؊+g<A\rOD)Iٞ}piKNDEܽPҘ7b<Ҥ\\8\ns%\"߉#|*I\"NŘ32C%0va/U8c9@clC*PslEW@ 9Dֵ<ѝJ0`#Xm۫Qϻ\nSp(?Cv\"vam\nuTkc	WT={ (ULU2\0~\r_/S@e&B\$6Y!-Uf5G+989m̙7΁\0o41Jcu:3\nRo_x]v	O<\0YHNlBZυ?\n|lg^'a\n~(\\G~rx&.So9@rݚwhcĄ8\0a`\r\0צpJih=S%ɓ%#p3@7vLGm\0000mvL@v?n2m]Oom\$3b8yW\0S =K\n	<3Yݙ΅0nrm1D5\ntVGlKbS،vcyu_n\0\0lv7`\0cݸe\$ ;S(sUHlIȮ	<V}sW\"y <\$*xN(?ܷ2}\0ҤwW]x1߷wtw(muL\\^|ǡ8T^]`	~\r\0b|cOw\\;߀f:T`ndWj8!w\\*a]ICm`!T>Upu>0eDLG@\"@#L\rdstMHcu]65[쥍WF	x^ld@3%}MֻUr5lmә&\$\$(1:/B=؊G	rk,NH#U[IX}x%ף{zṈDe^K0ow7xCW\nyXwO~In&0y\\	}:8lԥXADRJƶ:X	1Vc22[zr织_z~ v&A/ݯv\r?6wx\$t]\rހwW\"^=o#\0wu]c~_uwmP\";,:)+8_x\rHɂu:^'zUם`me+yS=@6s!w7蹞K	\nQ(B'E`W`=XxO%yc_^0Wf]}\r|phb~^\nKaZIuMڊ-7XIN#zխg;^r<\0zyMJ)]/Ul[\$KC1 b\\`r! 1w_2A\0pQ/'w*U#瘈<\0;'xh+(8Aɘ9^05ˀ(vȢ+;\n'l\r׺V.5-֗s\07w\nL4Il0d_Oi@pNWVh(XE(\"ˍQ*_0sT9\\׃9W^qo~|cq/?\n|F'v'2Gm1ľ|D?ġM4_\0E_鈌-\r*8Ǻ](nҶ'0&ج{ݞ^!zՑ\0ZpQHu^?f\0{j;%|-y-x>^9jsB:=	@E\0i1\0\$|]#{(p̛H`9aulofaB\$pjľkM=AEyփ2y+}do5[q/v}y\n@жA|Age=iBQ0,-[HL{iz\nG`	-\"{	]yB\n\0cbWQT'p0\r]*=.#}q.\0HEyu6m^M\$Qz%	\0ɦW˂2 h\rߖ>	x\0#Y( )AX{^e9xC}vVc~\"p%S@;OJ1?\\(6~~T(8]󦮞ic.\0\0(!\\*\rOh`	~*Ȉnw-֕ Ț(	pRKzx-&WwwOXͦ.#Rd\0\0q0klVvM]=98AR*\r_4_tMGpHQR|4c3AW(\\׹3c+1T:JtUfpxPs%l0+9vU y!#gg,SUB1cA Ixe!P`-\0_3^JLm_nvfY:[<FlY'ylrőw@ά\r*EzjQ3/Tȿ\0'RXh@pԫ\$FXBm\0\".%υ~⸀P\0%Xt&?o2BЗ+_;nB=F!f+W>@U8g@[jFA\"r<}; H0\"j5A#P8SOIkq`캜C8Rtdi	\\>:E+wEǁWT@'_@@}^B[Jb@MaC#@\r¹)d/.tdQ7j3pa4@.-+!VQwO>:>*`kaXXy6`	*RL)[7L ʻfHͲxBPE'<wdp2\neo`5gvP\"ł`M0%r<H84|זl^L>t	H\$an_]\r_̸8m\0_\$:A\rbO_)@FP'X&#I%aOo=c*\rP=c-*(`ҽJ	>Ȍ,LB֩lHڮ(	:iNTtܾH>\n4q7¶B@+eP<[<Pv[AxĠ0=/R*@㡘C10hናgTtbR\"8-Br fKZ8,Pl& (a\nNU/HZyjՀxu\0005^X~ i_+y6)[\0],çb@@A?!0ǣRe`3/䧙mw\$ɉ@sTB\0X+PpsA\0R%sa	`]91`\r\0T!y<RypRSs>^em2s%q AZ>5WA@ ~88IAe~=*dA=gH8\0\n\0-\ryb,r{i1΄!AH&ŏ˂|3\"`xGP6\nL'2GĜNBerڟRDQBu\nl3!>R\$3\\Pܟs\\M}[l:KSU{X9d*Q{!T1	: .]0ʂ7\0*xA,!a&E\0Y(WPlܟ2\n>ӯl@EA!\\3UKj\r4@jǂڧqyX.BmR^4Qp*kĩ*P9+p֛%S^c̙.l-F)Mxp &FTFf\$I]P{UyАZ0]\0F;BVo~YKN˾NJ@?4 y6x΋A;cTK`Aǵfy;rPF\rþa\"\r{g<}.	12t&?D3nT7T-;#@c.l9²_pB8q^n|Z\\0:sG++|FB&/wdCtuyg.xjAs	52x (ETzMEmaROLs育!+\$I|ʠR4 \n?#AXk^CxKB	-mAYCac\n>yBķA^2zŋkZy*0Q\0`҂eBc%Q\00039\$Oy2.6xQxuc,\"W:  Wd֞\rdV\"h?Ĭᘀ\r2JX{tW*:2'2 &<F0i\n!(7dYK\0js쎐aHl7dL!k4PhN*>q`nhK͊hj@݀+ /?4\n9W`>+rdD;Z<	\nY^F~z]13\nB8,T2ьq/\rL(drEdFBlCT*zW`/Y\0\\1d>&Mw@QC(֛̉D~Rۉ-5Ebw#\n24Jtw#)&h;E	[\n=wfa?*aehJtePa@ !15r@Ѽ!bV#\"L,dለTE'K4C0;AU@57bYER+uHJ\"u.\$<9RxtcXԤLllXRchG3WEzuSDA@3Ad&u+c\00θbIਲ਼/eB@\0r`qg*6\\g6)2h\"C}NCr}RLD,~0]D&27q81.f?B{ns=`v~+\0aE)z#0;\$g04n݇@\"0]шF'^,lgC41@a\n0\0@\"dXpgy˫(\\{79ƱN+,+mcd@ϝU~'LQUEq3Y`dw&dʁz,cq%W\n%S\\=iYd<,|}9;p PF1ckF0D` !r\"-J< Eg82	\0\n0lgH*c>j3(PAZ7r{\nNkc6`	Vj&%f0h35Esah}K|\0<R5C`\0<E/4\0Zq\r#D:T/8CeԳ|\"V6\n (E]\nn#HEF݊{EK3vix|J69R/,(uѨc<jbDfP42D<b٣``A_&\nf4\$h`rCREj܃ q~t3/\0\$D#RTqvc'x/:\"3\npuJt}JhE0iIB^\nAZs[OlJV:3z1ǴG2\0LOq6\"lĤl|nBPb:4w\r \$A\"|2b˗lYNmF;?(ghJ=jqqR<pB\$:ިn正\0j=Tb&@Eg:\0;tƜ:l2RI@Bl)N.`N攻GMe7'ٌwEzw)lT-x&P\\0,RRG\n\rFg䬦t̶x:W\"g>UV>\$ a꤮!cX x1c6\"V?qbTopu0EFGPSuBpArQBl/ǢTU#P\nv'j>ؑ\0*I mMTM5;3\$S*ObGzE0p!Y]N&#8ȀC,s9V6!sIG!4 ?~0!@H{!rB\$Ð\\Xba!@,p8.h`jr#/+P(:U3w0	bޕjCSlK`Fr5\"p>luȗB0Pr\\CG!\nb1PQ {Aȭ%8|B\$THCjqD.:li!L@ˀDWY1ŝ.\n|cAt\09LeBG@,2\0W}3#ZkQ_FDh2Zп(Qˀ9\nFH;k0<5BV\rL>ݫo0Z!%縬Oz\"\rl'\ncI^*EQ{ju(q]IIR)2BWzՙZ/(:d͇VǬoL`!dEXIAD5Gr_gj^gIAE	6*LV>?a<`ldo Rщ]D)(/`󠾓 %%)␗KAvLPr bjE|:L'&*7C塿6d*)W) ƏA1sC0z\r	:]<-\nJ%>Jsݝ`rE8O3o<`YY3#jŀ5Jms=;YőaD&PvN\0ܝ|kQ%	bJT	1A)'`)G\rjKPP]V?f`91Ae\\.HA(lLhS LW=\\\n63Ahڥr\$\$5]fx}#2C*YJt\\/דR|D+:	)hpKK2<JIb0_S̓ЕX0{Y!)v))ӃyBR\$)0!m`@\0b-Hf\0H[yM&rlGĝ\"aSx9Pe.fydI`׀k\$R(Trm(B1I	&4yf2iܻr1\"RVE?c*q85ܘNU,hrIR\0M@5Ri/mHw(w\08J/<=B\nОi043!{'|y!I-d=l2	mN^_/O?\rL7E)p'0J^`_<*Z2K\\8h`䆐L,*Ys5;dBI<^)(W`>-c]B:,\r_\0006@z>̽d%e?U88A^d5\0+cb4Bn&zE`7`An˓z`(\0KddspFP\n)PE<Zպ3}*!APUy@I(Z\$(H4I&&\\NŲJʔNZR ÐܝP@Yu`uS#D%/0)A񹎜Hj]u`Y.i*FYDz\"Ȧ<G~@vsrtԦ\nXN&\\O\0e/W-(L (\\p;R#\\@H|%9hsB]0Vܸ%}[Rg8JِB).NRP1.`aN5 %g*^t	dၵpJh\\\$\nQ.9U:z\n䩔N#.plP0@db]~G<KDu)(8<!mYvҒD\$X(jU\rJ[z\0\rn/.u%Tey@NR(y1>/&#y5_#E LZʅ\0,voDcrɐ	U<XZ)c<ʓ*\0c<bGcd'f4T퀇\"YUS_tFleڲ)1M*Dh3\n4\"\$\\\$AJnۘCԦbñ̄ à\n\n?68sd-\0VYDep'ܪvEIB,.B\0	`hЉpB,)[MLz\r\0 DF#nW3gah]f{\$3sFtV~v@1f0Y	,'AP~\$Uu^`ɞ45|fҿI68h	3VC˳I{A\0]< PY%zMMa,(25jbh\rA4|!`S*%3.AoEG/NRGpe5pek?% bQH8#B`f6Bě\\j*yYr3RkJ`)I02TN\"YlvO3SB!<G6žHP(\nPf1\0zc3eKaC 'h̕Vf\\Iiͯ3.#p`K˒Bm ɞf>既*=ř@gJ@ڐs_\0P.qɦCCb/PlϾ\0w\"dh-`9] K-o݂\0p}d˿rAzsX͸bDq3\0D^L4Q+aAg-S0a)[3'!+?*O԰譗G\0DM0&DE	KSdEI2#\n[H_I]@/Uqq\0!ݍLsFE\0lT-7ikX:q\0\0ZA)v`#J`HcI|4R[U\0.)z\0sua䉄mLμ:!Fh\neu%k@TL73zz%+zݧD^\nM@lB2y#:XN_NsHsYb#rKadl+L;yQGGYNՒ+ýBoDV\$hq nc\rjFNƢwj\r!b;<#1V镂75=f [?\$]%ӦO\n@\0jԦa.ΌאH- 3C턘-DcQ[BiІ:,n`/	\\r,s-\n7L*QB\0bo/:rM\"Rq2GДX5*?^b!,.-Ҟ10	2kzkbKG4G^\$n꿩+[ԡth,5V0Zb~Isf9vRf*@tAyVXANTTyHw.Wj	N	?!>IF%ϙ-ztpχ5X3ћtMSkv0.u+9ļaOGdh(\nQ\rgw\$\\s%SHS*ѵE\"3DG;9^@@M^ʐO.<dRb}~bQRsUD1zTY`5RSRn@fXTC<Re. eL^>)BP\r8;tAgB-:^\0H揔֜6A.DJqP.(Ry]FT,)&Pt*ޒW@7d5p ɽ\"CV\r@4\"Ib&gh<AՆ9HZjp[&n \"w!wh	4jBP,7b%x\\7&T:^H`KYkІB!(J:}kIyT#xM%j'8fX@މdh2H?魪=GOsR,\0Lg\r3h:@	!b\n.\\ӫM\"B3JKx @-PYI(57wЋxO}b'#kn([\nhp+6 \nOeBi05@Bߕ\0\00kB耀**^Sx6<t.\nET#N?\0xP\0Ir({JUa	AnpO%-VlNǄ\0z:b\"2)S>Aux2T8kP)CO:2rQ)IU093MjIEYRR*a\nUtE^l1\nNP&ZPԘgDdbŖ57ME=x JH+*c(Y6ދ.PtcxT+(+=>jkHm\nhĕ##\r׀G}ݸ7+]<OĀuuS9BY)B+(VpRhO\\<M26V@/r.eԌ@j=FJ80\n4x@ц,dȚ6TE*:\0p!(R@&!PipE3=TZp֑:Bi\rimfK;20iXӜ\"\0ρ?1F\0Zސ!ɯT`7%_7T\0\0'\0bD\0YU.t\r7bA'7t\0N\"\rPR7(R@tl	YiG1N\0\\zz=TӟI\$K0c` 4]ORnu;#1PFI'\"J\$ؔ<RJ Mne#AVRJJBSҊQKRGh\"w@Aj4QpSH<XP>v	T\0V.<IR	i\nV4h[p:G. \0(HL\"PR\08b0TӪV	QӖl]h&WۨC(H\$&KºH\\-ppFGtUy#2<*ybhD/>B̛GQgylM6`S*%au&'*Go2l0W[	>%`JlL2ǯ`,p~GMs=U\\`X\nʃA2\"e X41'c┪4xp\"\$pŀ:SyJ9d&d\"S< 3\"40m	#MAeMl*ᶥFEzU&xXQJ`DNPw3 tFq0`HLMfI&Ȳ3EiHi<?a,pR4PWJtކ0#)Y\r\nC|CV@C\0\$N*2nVʣf\\ځlH娢YT`ZP1ւ7n%JKc:!\"+oi8ƈ#|sؽQ)n\08@;N*;\n+2(P}=~@dM?F#Ҏ.uAU`>4P@+%;.AK!2M/\0Tv\$JT(ǣD Vg	jԕy\0Iu>]%7Oc:4EFCOZj\$HL\0A *\r(HB4wH`HYp\r?.r93\\,&DD*j.`4;\"FE6\$J!g/&vmv \n\rv|0EH\"T\0ER<~SzXl9N&QDt>15Jjz\0\$vi7p҈QYGD\rK֡tuj^\"cSZi~*b-X#:x\"Q7݀T_\r5\$Slg6gIteKju6iLKZzeO\0&7Ģ\n t\n\nT\$!}Q0\$;QThXTa#t@/H[\0m/p*8Jt8N\0)SڦPcS+/5¢&(dᇃ7D=T8Cw|CwX<:M'.@2#to@SvjkQқH=,F5\nIKTK'U(]8\n&Q|\0e);)(ItR900. M>S2*& /##aY	Tڕ.-¥m3h9 eNRĶ2{fsޠK,L4JAW\n~*oP\n [%a\rHJ9N\0`Z5tC&DϚH#4#O.Â`k8R&Gp_uܐ-1M)L]SU>~+	JP2OUB:6R/\reגAzQXs?Q.J\09Ā\0Q^RtM@d@8XɱQ\rٜB@SJn:ʄP=0Vz'M_KV6TntՄ]CeJr\"d̫Ϛ*C bՏñ5\0cP04	Κ>U+\"X+e<5ڗ3mI',߫7j=z*f^D\n@z*?Rzq*Mn~[ef>\n5!5GW30!\$(Ώ)|μe\r{9ZpP9-<GZ+E`,!X B\0gˎhk\"@'hQxQln%)F>pbY9Ql5V Qڠ߭2?`[\$2Ft\0ml	eZ%S|U-jgԷ\n&z:>\0\0Lj%F\$]W	\"^%U{7\\,#=MJ?D>ՒcDj:	{:q籖I\$r'T (]DN<,.4<d\0D=تNj-PwTNPE1kUҬ\$aE	F^صҫULW*T>[Z)el7fv1a1W`ؿ6a`3+\0xzDWLəT83xA{WPu5855)\r\"Jx8SqWCLL_\"dQ6cbL5](\0kH4p,	z'SuKFut\rͽ8Xo`S)-7@'M\"m.zt2W^YJ<tF+yTqA`i޷\r(!+\$5(nֺPʑe.&_Pz@Χv21AN%c+a:6E`YݔzHBsI\r\nBS`l=e\"ˣD%Xaۦ]0U[2XA<dhmC N]XM(\ra\rvc0օdys2	p!awA7Xm,8D/ܰX	PJjtAs~iqrcP^]`3\$ɺ!VpKɕ3ASJxv\$FSPHFו]&:p\0H.vp(.:\0pp~#,\$5\$_!|&\0wZ.J4Ԯ,YrD\nz\0h\0'T{\0\$^ lgr\rt`)e;q|0Drl\ncm@~4_胟kd:J(mv-)lCqjdB5d-e\rd!RodXq+Yuh#\\#\nF4nl)6%Y\\Ѡlls\raWiX'>\02e[+(,]\0}}dxYʚT*|Dn9g)2gTLet;p,C*!\"J\\z`HO\$Z\nqET4魶tq7*@H\n˰ũoJ륁V]!J1FHeEznVGm+\r1O	J\r~_u =9\rf5Cŝ٩Pif(Ų6pGٹHe800?@_I͕e\$`!Y)?e+F5Y*^Hʲ1kSUMUqM2P̙rj@g	Ct=*5Q6[v}J'GcF~\nK0,T;1cF( 3GfZ I\r)\"(Ѝ%[Bc@[CZ&T4,P\$Qb%jMvk.,Q	И?gLc5:r7B,YOr,4y[c\"r*<αi@J,)r6)a-N6Q\rB7HR#.ir༩ƼAY0,\\*_cl\$ɼVq,X_Uca#z,ǻ>8M`Y[R( w@-=\0P(`\\qB	z	7CWvai''{՚DފI@Sj)NDԫMvƃ{- \0xխ)P!ݨntUQ\0%QKQAL]\nkPT>\"UqSMFR#HZE!\n5)kqB\nDWQkh%cs͠CZڵzv`֮\0005%[a 'VȘA[%jO6ڴŭTwCTx]*\0ڠlxgMԕirrzI#M{%^=TV\0T0WrɌLjei`TD\"֣gx0î)R[NA|bhÈc\"\rF̐#TVP	3MXBkT\nTum:']j-Q1fF╹Mn8[~BU)LBʺϏ+b2*M\"&ۺ9aq)?Umz͸-[%1z\"N>e.nzkRT#L)Da@;.5ʉS9|!<P4CZ\nKPu%rVԦY/ӯw709Yba`lySƐNTB<	nJX\0P\0N(\"vѤJ65Vޞ}&Ѫʓ+s\08.\$(6m{7\rysw`^&Ovk̾VSZAeeJh_oU..:i6\$IH0F2{F^1i3Z\0fúkrOBvEu*ϲہוb	z8^\r%%:<	\n\nnY4V5!Ia[<\r4Wy/TxfBq1,`d\nB#\\rEMG]\\!x91[653<xvZF!b^yE`/p׺ªL0oVQ˛w0\"FzCb	>'P @cs	9SPY<)0cGB&4ϖ帒[Ƅ]\0s	ƆU#Yu\"e6jQ0Zp]0o9Kb@V2:e|BHe=s<(MA	bLFǕأ;~kVBZͪ*eP,)} q-a夂MB2@̲	HNX)r\$H37qbnwyaNɉo|2ݙƕ ]WF4#nR>X^aWk&7Ѻ\\86+ƙg \"0hJ:|+זd]\0cK@,ݖGi	z)pnأPq&?j`cct/J\nQ^q<5ޗ7GYV4+N\0Q#4Wt\0ȑ {XRI}	;ة2zfĝd-Gw`Z~(cdot\$Sظ@צȑib1ڍWk!\"(ݨ7 !eH;~\"\r.'¶׀PGuJk\r϶wL1!i U\$Ak%*Ivnׄ_L0Q[!tZX	㐆ld]t=d_`OփY{y;t/&-vm(d^`~VfNגv@xWB+*YF<J۫3a_a% 7v46U#!0`7J@@3'㆚zA;,%*IkT2vZ7˰p2¨m=ijb`\r5kB\r-zG@͇l.ؤ8'^\r&;QSB\"+po̓\0̉f{@8^O'{y٭޽H,:>EO\0@2Lw\r\n:~2wAiᣀA )#cw9\0Hp(J'*\$6\0վ-|:R\0x)dK\\cP;&28o`Ɇ(90dfmoSc}|5dI\0&-l!%LU|rd4ɇ4K	\0R4->0/BE)\$\\jh9ALD\0O%(\0 9(&@9ݰ7V0ЁHCD#|~Y7@- /N&,\"@g,)<BSlt ?`@([wZ|iWmGUyl!bQ%[-S	\"qe\$r]g7^~ShE8bm_}~|2ad]T;\\Rm1X!2k@t D9) :XAx=)qyhb@A:\r	ȸ'ƺ[H`*M27)i<\0-l*`iL`Bn0:\0gGI\rͱx\0,+<t\0SzC5/\n\0\n;Ƃ剿H0!@2\0e-2aSf@Q\n3\0i0Be 0\0N,2D\$\0'H92/s\"4&P.` JY/*t'K\"(06y\0cil\n.m&0\0VbTZB8s'E=Zi\rHr\n3S)fCh	\n0E=Y;|@KF?W\0sٸ(=^P>~`wɀ	x4\"7	F`i-!pi\0/\\>0)U6	t<d0X`}Xb@k-D=uybCuLN\n`M0źwS@UۇRX#j6A\09jITrD`H#|-X-`wX10dN&(ʝD/Sl\0`_[>z=e.\0SLCa>`X`SyKy`D%jf`	HC9Q-~@,E\0;nȞa\$&P4(Knʾ%N\nleY]<>\r=5p*0aZ! !X!`lq\0qX5/SDXGea*0\0s_m~ި. ,?\"ZLvC	ܧ|YXxT*>&(rKKQUs`+\08BFtqE`/h?*+y\0E|d vT\$;.06r<\0=è8CpQa#E\nT&C	&n\n]sH(.>XQ~q> L<@c\n0bF5W6\$a!4 bMڠRx'B3T\0^I{42A#LbѴHZٓ>aggܒnxV(y^!*L\\iʔ4U@n̅%ɉҸG\\QaL	+L@,f)Ga㈍&'KX_0ǉ@r`@3\";Ua},Nx\$bEXG0;![| h@F/q{0XE*\rdZFh@<Jʋ]}5FɱbᄳNP@.<.\0IP`\nd%%BD+1\0rC -͈Ov8JqW\0֏q\0ch%ex@bĒC+|,e/W(K|^r`I)2,\r@m#hU\0UJEsp6\$p0of݌xX1`ȸN;MN\":htJ+\nX6n\0~Z8́L%|hq;p\$[&7T&3p(kaq\0PRfs~c/\nnfDHȋ1ovaeDtV]M|QluI,!Ier=uG0A&bl\0 !D\0{eJ?rwX1œ֒F\nv/ɉG\n Y	=`*-ʀ6ҒwC`\0Ekn͎NJVX®'2	bΏq@ESDV#Ƙ\n)R<h Jm'y34qX1c˅F::ە\0000ǫq4ztF4А3G8jcM\0?e}VD8峢\">oX 	 uU2[\0­ؗ\n)e\nPXDd,\0@\\+4^`QPx&B=c^ ۨ.xҘD+م6\"r3hDnPp\n-@'pO?RǑtA^0TΞ,Х\"2k4GC(tM,7K[\03\0\n)\n^>94;2	h܍1`YR\\\0ݐ;hY ~r.gt(\rp\"ʹzVҫ]_ѵF|ZԞׅMQP!2ZbP^\0PN8_%:Lod+P4:qV몷B&?9xpyZ&lqu=Ւ<p\r\$K3#װ+Xfª{@\0-8Ni,o\n#I@Nƨ\0_C\\a⥋Q2m<'&v`=OXxh]p=[*fMk%?7qdض3v`ǘJ.\0@\0+*7FF1	(p\rH-|YeIB{>&<17a\0GiB\0v-@'kN8[i60)j\$.Y:܏!1V^:P镻X֐h*pk+Tli9Q{ZB,@\">_0zHFА!rp&\$JN*R+y<[Y0KTq:ʏ.&7[w	L4_4\r~/\0M;ECʥ(SitIz(pd\$9H2|;Abxrv%E׊\"\0=0:	\$y>rm.銐\\k% @^*3r3²@fM2qQՇ%va\"Td+\"tC^.ezPK/g#/ъ0s\0pEp,reutH ɉ\\\$3~Ӏ0 3	#̨EVDp8!cQx\\MB̃dENRSoB򭻗P%\rv0R\nNM-Y7Ҙ})>2E`<eTm@X0\$gë-pƠs9En\$#)rH):u'`\0YƝ+ɓfSwvb()f.qG\nFc0h-f&uL2fH]@ɡWbṂ\0bӦeZb9rfkff{_O@/@fmr35B:3z10\0ɀ1dk&hrn ҃Ӛ\$YF͆	*YEfu\n;/b	ařbp @Eq͆(!v+2P\0KssW0<Y)dg1X 6^!#@f..r[_X1fhkYRgRXKUt?\0R!eDyfP_;vo>2;v@\$hW7З9,3f}6Vgvܥ|y3g8r\n3FMd\rS5\n\\mr>S(kKk|ebƜ5ӵ\n;+2oJW(!+Lęu&t͓t/<:t2.ey΍6ty3_:`wXfڲ\0A|hD'϶Cw>bsd̏S2Vn,v̤/:z2YU279H^9@\$˥Lu|]BY>d.6l[٢-9ULr\0Ś*kbd&f!x\0002\0b3Ne*04\"͡'B@	5178rcgO74yz4̿16M\$9O\r͛6lYh5Њ\$	5	fDͷ6\$}͝-s\r0l\0Bnly3+b	],v-af;րٹtgݞ	\0Z gQhY\"/+y8	@X6d3-+=xA\0h6[Ic8N,Y22OG=J#3Gh/g=;CʹjAkƆy:vCv5\rĨIE	hGЕУz\r\nt+:0sgX]=h|̆2._4?D>e-\0\"fc\"TzVo2;B\$=~YFl~hNG72z*cлW?]CŞS>nHdg鞈F&z3fU'0+ފ}&Rf46dYSAv\0tmiGM4red{K1f\ry4sх9ƃXYjh2N=Z3iAFn#H\r%Dx*nxb-+oJ?=4ů[Jg's@hGCJ^zm)oEJI٘V0?\0_xm0*8li`\nsiҨb\04٬\\똌Z&ύsZKM!\$W@?JޕAZ\rTl̊F{\r:Hex:ztGۘOz<٪iͰFrs\0 K5}m,y+yǘ%20F6S1a4(b!PhP=% \$EAh#\"(60!\n)]q\0]_:&JB72l#)ZCKPaDш,ܩTtw5.c>Euʿ?+/Gԏ:VZ51W1<&jz+gLRږqceɧ?[:vsf	Ë`Ru`A`oޠo\0]1kFr	dlMsDn`9:˼⬉+/\\{%/@-\\v܌H[I\0(*\rW\n.\\^]Ez\"!+mSO˪5t̂00g1/ՏcVV-Y+2S	:_j@`uyQftT<R!!UqL@Ma <#vɹ#[Mf%dOicT`3ijmczk45PO\"BShнb6M+z1KbÚ5nN+zK2X.	(|ibc^ӫ(i!:4a(	T.\\ZKE}N9\0VR藅KkR0vMSӳ)]MTڽ-<-[fl<*%b]\0~dLh\0T! I(!(TGZ}_t\"lg]jAdH)!B.cZrzLLAUs&=fVkb-]l2UuY&H5[\0uj|ZQJFmsT_E`1-q?jp\nKH}TJ-rlVU#V^9>)sKD\rðe7YvXbYf5RPYX]ef['fUMfuk>hAKr:KPx=c\07\0T80X6>s+cƾ5ac{x	jfiθꮉaMQ&\rhG?\\[KЁ8Ҙ@ sȝU.p\$CʶD;s5Dɂf\r,frɨ`筍؇6H?S7y!lrU\$ȑy2\0?\$v9y\"5YdEP.ȍ@r6Ff=\\jnoONAeQpPp]UrG2K&x\"8j\r=q5k7˝Ge%{k۰CF4{l-Z:x6aa٤Ym[2l?`uҐ+0@k][O*of˭v&y٠M}\0hg>lwO}\n\0c٫;Wj/,,jb,~Dm	l!}{2ޭJA'\"	~7R<YajK\0QXgɱO!\"l.`pwS=~vk81ZUL3+[zvyw`\\k:a\\'WΘ=ʝ;Wh̵ya\01hlroԱ8V'Ii7:+Y̽g[5߭].lHآsyR~]@\"h?di#iفgR\\lԧg`<fX=	\$Ͱ9K 3ԇHR.grL0O1iDk	\$l4yd4`eʒ, !T6]ٝojf=T/_\rzd<9<iڽhF6K4ӂsf[[!B=ͮ\0	yRǷhnލ7:j:soaFW\rDm:@_T5t[֢M&WOX/斵4v8XJvtGEk٫6j{R\\4<<5,SGbnf׸u?ecruFӕeMr	kiz,N:ȧX-s-rhm.]=Oim÷*V\"|@YuD@,f-'&`ult X mF*¥&\ntC!y8nL;Ki7TѺ?tNL*gu^6ἒn.\0ut_7`%v,!RW?:=@*ua3s96C\rrot(}}}5h0;nNT76ۺ':5euH^4^	oyCTT\0zd<	DK-AʑYc7\$`\n[*Uk\rìcz):@\\Ø[XyRZk&#oV}u]Z*M369ΎRy5\nڍ[fUmmC^}d[ϴ4>QQ75;1cxƷVdk{(D׭M{7of֑_nF1S[Xq,ֶp]o0ԩ}ǹs'j 51HSzg\"IywwoZ+W.>~w,Ƃ a]\\zq! D@[(}u\0XnEl,74<9;]uI<Q@X{]{~a\0h{ט:㖽\0hsܻ+]MkZZ\0flZ{ƋŲWWnR)@9y}m9y 4z~Nݘw`(S7r3#y5DcoK-d\"{\0<-ݛwދ&0ognKQG`cy*w6D@ׂl6q#6ý\"1mPM#R2)h\rv'CۯNڨ] Mh \0.L3sb:j@ŮYJkv5j۲H ^Bv%m8\n6>md\nz}!LٶC!MoF\0CŶKF3LƂg8Hn\$-D`	=yWHVXgݼމg^Yq8C'p\\[_l[`lR8Hf;ٸ7ٱf5Yxޝ?zb<xCtquNy{ql/}a\\wp᣽gnm9sEG=Pj-·o\n,+[\rl3qЧvm gnM|6KbB6agV^|/8i-lgsHE2۱I5O\0{+\\RRa	\":8_|QvbۧcG.ϡb6s\rkT%Nk/vnHۆ5t'lH{^xpM8n;~,46۩_]NtO*qGlf2Y,xX\$\n/le!;zgX8|6CGetKmԩA'LNѨmL\\w-,Dwa1.QK)mԙCk\\Ho\0(_wk!yu>n=˗8@'GQOǀ)>A#yqeu~A9\nAPynݖ[u~.Cݱ6L\"\\7J;ӣOYS]9s|ܭwI]r\"8Uшe\nKyry}5u`54k2H[TK.>Ew'm\07I|][wUnַk#-ᵺf&@yrqeSܸA=fy-wCr.tl0;5=v(j``G>:=5*\\[co!>NaځBkx{	IYl/{^pSx(*~MMY7>W[Sᆵ!y`1pMO7`,pe%Q9\0/oI沜Tm豜RBrC|\r;,`\0>Vp\\BY\0dYcp.@@<1ϭ_x.'5p3זOPy=X+<`r93g,voo!w63 w&l\0u	w&-`2<8ƏȐ6@q)!,-3h)K9AYTأf9cwhh&Ikچ9f4Uw2A9<W,.d+̟`#.e@SJw5Ni9(Ao%Ѽ\0qv#z4?g9t=W3&VͭV\r8yԛ`]š7'eܣ|ȹа'?3)\\Su5^os`KCzAqQhsw.nEd6}8\nyne'\r<is1;g0ck^tgkFQktޮy&@ܛ/;	<aܵr&c|<<j8KpE\\(qsTvnb *oMS<vt[h6\"OuKKpf9MRnD\$ʧC~b/<9SSWB.6n ?k%!w\nǘn%\nnVsx|9ӽDan`#B~ܷ`M~=5葈ߢFމr襳/B7mq#sqgٳK'ڽHLu!\\al'&{mwvlmP{7̨zvۏkT6ܱ0ĩ/{?\$~9<>A;MY R<J`[IVo3,i؃8qѿn}[=Oop<ac0Fo^0\0mӇpxwtko2{ƼSkp=o׫<*māy!ց+m[tnӍ\$t/͛K?\\⳹Ak-[u#t КF,I̓*Xeb._[Ic?TMOaKhT8P.s	8Rˍ\rdxqf+m7:uen-8o5ޯ/xW<jJ1otq͏uRu Zk֫_4k`ϻG3ެ;+k;z=QⷴfZխ/޴\\ɸ#G{nmi@9Om^ Da-NCBg[>	+\"z?[&mޏDf@>kNs\"ֺmlEcly)ω\\d,ׅZBӌN\nlBߟ6qx2H7r%5?nSTTȶ샐1c\$݈	tU0:ozkYm~'많P]sAuG4N7b:b\\>n9LI<jiGFhi/`B`Qx_aGAn¥,'߲z+\"Oؐ \0;5N/&c}ş6{χw7ׂ7?.Шp{Ґ6pH|6Lû7Ԁ- G:v\\4\r]zAkibͰ \0emѶc,?9:s7×F.=zu'E]d{-ʻ\"}s0cۀvKc ·#43\n𹛃V(s2dƇ,1Ig1d8ݗꛑڵ\$\\vD4Yop:CtfC4fu]<,lCb@.\r85WgG[[Np/.7#F#b7fLX׶/Ӡ]wE\$(	a9l`㑮+\n%{ۀPfnqzvY~];p*\n(.WpY;QXm!z{ldGkQvKl?>Ġ\"(p\$,\rBh=\0\00,|'h @(v8>JY9'/w{R}@7w[{v:mA#4p)VQ0oFB	˼p-rP/3HEMDRGm9@rB\0u.xv|.S49\$F\\o(D+Ng6=t\npHwNo .{rׯpO=R JTR!Ƥ TA{E	<@~wpʆsɍKG-\rZtc/GbEP:G^pRʩ_ gkM si\$|-Q[9Is#dݴz1\0?Hq|j	eao n~>um^ư͑7b>;``{1tC\"=S燎\\f^HY\$5.j[5nG|Ro͠RB=rzSeN1~4>HIe:xҹ?pqt#_>cPHQ.!pS&:ۛ&=ڡL\0񭻲7D[<Zta/Wpeg=w@;\08\0h>;03N0rc|Z10-r=M}\r~ChY\n5J/{{k\rhm\0DIo5^B?URKy-^H`'§w,agWXn {,~P<yX姽O<`jx\0P?)d>'5fOEۢxxGG?NvzӃjϼ*GmV\0o0>0^\rڻĻhO\r{E<xm۴h\n&>a5}\0<Qp<FY)xqBM*{OW].Yh9_gL,>_xTڳM98	w9/Ǉ{[:yn3~l>0\rx%l7xl+H&\\vt}agk;[Lm&v?㎁yOCٻk:Jm,\\%NlAeԙ?2ۢcү.+9 33[Xi.>YOGN?\0X98Yߜ.?5{9>[l\\<j(@j\0|@di놪XjXd3U'`d \r<otЂiEgLDPMr=G[C\"e67AO5)(MvO>Jx^ΐ%. @=6=(\0");}
        private function printLogo() {echo $this->LZWDecompress("(Ph\0I\$!J\0dC\04<Oac,D\0?2NNbK؀΄ix00sBn\"IT<6P+Sctv%r\$PK894821\0.DLc@8Q\0	#bD\nH/d3/T{Uqj%Yjw@Q@(\\Tm#mJRJ(\n&hF@Oc\"4JwH\\X*5h\rYj0G)\rDf;Pv\nXWbQiĸh\0;gtZb<q]Hpq\$TǐnBHv\0c1[f&(%\"AZ_Q*#h zbq)\rЬi	d6\$٤\0\"hr4F'p^Ja2 8NJgpv;i@suai`:dr@)A&Y*\0ZE,rhpT\\UfyXdpnC8I`Aa\r4h8N8\\X~搌JA]	^\")\",Oɪ+\0\\y-aqa1c&\0ȰQx4c\"_:]@T!HnWa`gQpom\$i0x\nќ~`PP\n d5fq::|9n}.~8H\"QXF4\nwSd`r5	É08*FA[._\00023Lyp]&xhj\\g>!A:RFLdb@jq\nj\n#BIZz\0fIf&x`g#'Xl0bQh @t p@#lCU(p\0\\p@\0Ā\0B\0g@1@l\nCQ\0Z\0C\0he5,/0tD\r#{\0]\0(h@H9 <\0\0p\0~	QH0\0#*@Hb\0Xd\\@	D(f\0q\$\"_1 =\nÀnQz)Hncqbضe	P UB(	QTpbOGukz0=\0\0*\0\nt\n`4Axq#(o*\n\0*#XRa;\"QP'c\0qA9Pw\0y\n@{P`@/h4F`d%8t00\0XoBxx\rx!!_\0QRH#\0,@\0#8\02 \"\0@H2\0c9\n4X!`p\0\0\\<a!FXN!v\0kCǀ+aA8Z8Q~Cx\n\0g	1 +6B=a,\"D8`X1`i!:1#C|q0i`f?\08\"aǸ8\r`\nT\"4\n?Ћ\nЄ<\rb<T; \r\0/`@\\\03|\0K@R4	h\r182`t11Q	، \0#\\\0 ;CcP1sx.7rea>5X[!6\r*tz`,x=A\$`P7Ÿ`x\n'\$h\0A&\rW\0hiD@Dw\r:7\n '@`,I7	 X;!lO7E*\0` ^Q8@	`r>(TF \n(=* ,6(C`G	a*(E@0h )	@2=C0H\".X~\0@Bat=Cb_ 3\"\0#13hq\r :T\\6 \\P|4\0(3Q\\4x C`H=\r\0bv(eQm\0\0H\0'@1)cpox\r40f \0(0X,AA(aN\0n\0Dj7\0(<z0JXD`8\0`-En!D/qE`aD1l \$`HX\$@E`DcW\r!pCX`s\0\$\"@PB\"ǈY>	0q\0@qBnn\naf.Apo\0An  !Fzv<\0`aA!0>\rP D\0004\0x\n(\0z\0!pXA^`a j ,\0\0ա	(X\0ATlP\nA~Af\0 \0g|@@b\0\0~\0&!J !`X`!\"a	!@F@Z@H`(\0!\0nP@6\r6a  !.H\0	\0!haa.\"A` X} XFA`jM n`\0!\njB\0(4a\0`!!`D|\0>\"6~lela\0>XTA\nA\$z0``\r!`|\nx&^`:a4	N:@A ^\naR~A!d\0!\0Aa4`pA\r\r|\n\0\0@A@86`\0l:.aj\0F:>jA(e\$A aA`=@A|0\0\0	`\02\n`b@8@@J^Aaa@\r\0A	H\rA\n\0@\ra@n	\\p\n Vd	 8(\0r !d.\0\r DzX``\n\0ax,!\rA\ra\nnF!8A\n xa\\:UA\0`T\"af<F@\"@` Hz`H\nZ ^aD6BZ6aD8j!`,N` f`*	H<rbA@!@! a:\nU`xaz\rA!`8a \0@.A<\00A0!!^ҁa`\0H\0AApaah	b`:Ab3N@RqdV8!4\r\r\0 `aH!D<\0J!\r\0a&A Z\0!0\na8!\\ !ƶ!\$!A@a\0  @ (0\0`\$ 0\rBul`\0r`a\n\0ba\r@ &\0!4cf\0!A@A4@\0> 2b\0@d@`d\n@jx: t\0aj^*\r@!uH st J@A\0AN	A`aL:!6:@*`!*	@0^a @Jx~\rPA\n\0d\0\r\$`\0@a\0ht@D`h\nX4Aj	H\nAh\r \$!Z` \\!xzA\r!^\0\0``	RP!rav\0>@9\0A0\rlVhnaaZ\r^	!<`4G\0B@, 	`Vk\0 `\"xa \r@a&	F\r\"!\na\0~aL\0nCv`D8\r`AA\"\0B(A\nn\n@v\n! !BHax&\n\0B T!B\0\0L@^@\rat!`aV@@p`@à`|@8\nz!\n`:\0d&pp@D`N\r!\0,oN\0\0\0 0\0T!2\r>D`a!*v@\nZ!A@jj*`\r`\$ɡN!v[`\r ~d\08`Rrxj\nJ&\r \0n\0N!n\0\0@a|\\\rA^ \0ZAn` rApF\0	4!\0\0~@\r \ra\r@>~7<`a! x!\0@b`at-aZ\0v\nA2A0<a@j\0j@ zAa(!Z!\0~@6\"\0D `Jl! \r\0\0!rn\0aV\n t\n`^.!k/,\0\0An !c` 	a!l	<@0\$s:8  ,X4\$*p@>.`aB ~	\0\0\0!f4\0D|\0(A`r%`<\0nPS\018	L\r0\0\0\0  t\nf 0\0 Xx@py@z A@}@<(ArL4k*@b\0\0\0 .X:AD;\$@T7A\n\0X`#@\n4xX-AJL@P\n\0r\0 @\$< pi@{0I4\rA`@4!\n`H70{db(,@P`,=@`b@,h@l\0?@	,V\0p/w\n@0`c\0H\0 h6\0 @``:Qh cA*`3\0@v\0p\0\n1p @ox\0@ )\nn\r*h8 0pm	a	G\$\0`-~0@>(%`m\0,@<T\0\0OP3!R}@G0 P@fh/\n\n@L	M@i	\0pr\0\n%\0*@x8 o4:pjL`@nRPb^P*\0l\0&\0N\0=40\\ K;A0t>@\r4 \n	< @\$\0p\"@\07@TE\0y6@8@	\r2\r\n3\0-bs8  #\0>A\0Pd`x]\0\\\0`  H/\0G\$	P!aCd\r`P\0Xa b\0(@At\0DM\07PA0]@8@`!T\0Mh@TP>	@H%.9<Z\nA<@@*H\rC8N\0\$b\n)\0A8P\06t!@!V`H{l`AdKP@\0Mp5`\0x	,t	 	D0@5P`O+|\n}<\0h\0vЁ A:`('\0 ax:\0h\0)\0J !)P!\0v	PAXo@|5\0d\0)Z6X#q \04 Pu\$~< K28\r!@\0\$PV\n 	t /\0p+P ct\rҒXHzp*j`z0:Zh6;I\$\0&efh g\0pp@#A3D@X+h?x&.\0P,A)\0H7p*dh\0hT<\n\0@R1	E\$2R\0\0nX,\rрh9\0IT@:`x?TAJ 4\n`))@t&@&\r\\q8.^h]h-0r?@l8\0	OPb8@@d\0cA^P NWp<P&\0\0\0H`APG\0\0@9@");}
        private function printFaviconIco() {echo $this->LZWDecompress("\0\0\0@\0000\0a\0\0\n\0m\0\0)P7\0B(\0\00\0(A&!\rS8m7NgS}?PhT:%GRiTK}_3ۉn>ysOTQw(}T3wrײ).4#siv.(qwO/jeM=kgt;zD\rb=QQ-C]B|Ms	΁I6+X]⣣Pxx/\"RY^>Znw4WRa+XI6~~摞|%	0z 		8v(Ъtˤ.a읡w\\9hxcǐL@a!\nz@Ѹw7/2n\n +&TI/2pxBKr!  \"\"0;1KQTYFiQPAa1zdQQI~Iq)؞\rJo+}}a#gBxrB6MCiPh-`h;hZ6XXx'B-ǰ>H12|)vqL(fToc705b\"m\\WS\\*#ؖs3gqME	f{&ZZan{E))h?A8G1og>K4|sK[xStn	&FHTp	y#VӇ1NmGըw񎰐E}[BI.{\r_G^ZfPWl[&̈́!)G9@QGIK]I>\\G\rq\"|GdωGǃ#xuFw)f r;E@eV{:gP8B(2A*qiJ~L>\0#6`Y;`)Ez=[A,A@&ǉ0d?B qXN>*~?G( {qut'\"B ]E&r>(.*C[r59:ro#[y*b\$eǛ	u	XܣH\r|r&и{	\"P+}(=5\0\\<\"SNv.\re\\@#zZKinPIcG\r4W\n)@	`5\nX(-\0p5hp@!Px8|y7#\nE0\nL ,SC{B:b\\w+Mi#W	+D|xB<EXBR!T)T\n+U19ݽ'%FJ\$Ś]yUW_VX[\raEV\0'0 G#ŗDO<Cn^5xS\rA)ƘDp\n8EHBf1V2 CV+0s:\"raUEnb\0q\n\0D\0\$\0a6b \n1j\r\0bp\\2.I#E#D(	bd2x{D;1GX*^`=0 hC]comCVr/;xDBL_Q 0B8a\$DP!8Mc\$'C\nagL@.\n80\"`]1v0`0v	pH>8˰7l\\)G#d2vPYS+e2`Y3RY^;D`\rB0huc~,	7䐇2~QyW+圷ray3:F@=?GPIa36ܫj,\0	 nIM,RfAv@s	J=FരtlQj'PɁ\\yZSb<\0:\0Dq1'h=#89PwFIl=+ʠBx\0002;s |H1\$w\r.?Gczt4CθTX1PChE:h`TnP,6b0A25ao}xj^+ [֙'%W<{R=G܀}8{\\lp25ǯ@p;#t^_GCtl\rP.0eB{u,\$` 1giSw{<<H_P|\ra2Ɛ<N(A8lAN!`a!a\rd h@\0xl6`!A	\$ݮ~\"a 0NOV^ 8a6@>!\0DBA`JL!x XTh`\\ZZbAb0Ht0=\r\n@\r*aapn+A@,!,p	P	D!B`LAJ~TaQXbd`V@m\rp ||a	A|!sA!4\n/zn\0004A4pAQIQQY`emu|rovafcB}A:ﺯB!\"a^	a\0Pa<@DaO`SW\0ZXj0AR g\rX!z!BAA!al(a!z@Z`lXvpAdt\0\0lxc#AN)KN۪0oN-53U5d&]5a63e6si6m6q73u7sy7}783%\0\"b\0Z\"f#o5CxՂ*nna\\T}!RA(Kaa, !	2c6	@a!>]T^!'AA^f& 9 \0lD@hCPr\nl!v.!Xa	 @Bla \rz.DHYZ4fC&hBQ@n!z)TA	Ğ|AN@u\n@\0\rі!D!F[DrGQeEaH^`8j	`P`D	1J>&X\" E%.y*AO\"Ouv\nz	ƳXvABn Je\\:r8A\r'5OtU	h*!-*!H@PAbbobycX ^lv!4}za:ZR'mb3^w^Y\nw!a	b@0.@(!VA		@	@ck}JV!H!vZ֞	ban\r x !	\0\n\0\r/falhi>g't<!{vawa-Wf]Өp.4Upi9~~:fl,oja\"uaax*AE'N!* VADaA@~\nX`F\0!6\$@b\0!`k!!\n8\0t\0a|A ,0	ZA2(! 漸a\\a׆!!Z~H\n\0a\\a4(!Tl\r8\0`!-ߌaT\0œCyKR\n9WAO-\"3[t	9=EQYX('@\$(ْW'aA8ә9ٝٛR@!AlaBtۡ*! Z\0A	X	)&a!4_&O\\2Aban\n!᭬a ~!V~Aj<2!6\06@ݏ@(a@jN>paLl V!XX\0dfF̅!Zan:Ꮐ[ AH\$ F!Jx\0VAZFAN@hn\\!'r }(A\\tbv(+^)2AAsD5S:jw)3a3a88\"  \0\$d Saǂ^y>\0~\0ad\020\0.@\0a\0 \0	6\0b\0<:\0\0z\0D\0`\0< \0\0\0Ȁ|A\0\0>\0\0\0ڮ\0\0sN\0*\0@2\0\0\n\0\n,\0\0\06@\0\0 \0\0NP\$lC!\0&\0\0\0\0\0A\0\0\0P\0X\0\0:\0\0\0# 5ˊޡPa\0ȁf=h\0^܄E١ȁ 4\0}}\"af\0 \0W*\0=	\0\0p!\0 ˺*]\0\0꼦*1A!ܮ|Ba@\0\0? \0Ą\0}jaa0/\0m]~^\0\n`\0l\0	\0\0a`\0	Oh\0P\0!a ea!\02~\$\0\0<h\0)v*@\0x\0\0\n]ف5@\0`\0x\0\0F]\"ȍ\0Z 1Sa! <A\n\\!a\0\npL;\0[vȀ&H8Pd`\0@FPM\0,@Y!\0u4`\nx\0\008\r\0`@&T@X\$@)@R\0}0\0d\0H	p`\0D\0006	`R-T\r@n:\0X P=b`@(D	Ph`X1\0D 0@(`7`gt\0<А`A,`\0xA\"&\0@? \0p&XH@`\ri\0	\0P8@\rQ`@\0\n&");}
        private function printFaviconPng32() {echo $this->LZWDecompress("(Ph\0I\$!J\0C\04<z==!C9A,Q1\nDAM@!!z:! t	Dydr N(t<p\$NpXN\0I<t\$Hw(,(eZ*NHaK֨euWqL34%QbT1:\0bO\")\"Ԧn!%J%>ShtHlm(\"abIddpc2l1͌!!fY݋Vn}+(-eL?	H, t	hF`^xh:D0UgF	Jc)a@|c\0 z0mg)@#\"x+YX)#~Y\0Y%~)y&\"@XJňLb@\0q0g|g)|b)p71.d)bFA\nexX:aaxG[CyȾa̦y\0+B'\0	#\$	`(aFOMOᐬL&JK\"pa\r8@aŸVvD\$HJcЦ6&!\0raZ xCqfar!8QY<pFFl0GnAAm\06netlDu s@\n0~fP7@sDzC0=chV&@k p\nv#\0004XsicrJGe)\$0\0rLx<3C\nR\0)J8d@\ncɎYPɠ`0v|%p=DЬa\rFi@&PFqp_#YpF)F`'`2\$)|X/C>oX\")xPgFnldDg1tfK\r'[#x44GCDx/u\$9\03AH\r8|&-p \"\r)t;\r,>9\0a'>;F	7\r	4LX\0ah8HDF@`h0A@0p}';XpP'`j =\0h}*rD4!0*\r!ƘB(f8F	@3\0,7?*\0hE<(\\t	 .Űp66FôZ	\0nK\0DN0 ta\r bD|DHk\0>{\0 >A\rc	\n\0(8/C@		\n`\$q&Ĉ\ra\\=!E\0\0\0/\0xsA@\"Ɛ\rF@c]9EZ\0@(\0Q+`hp<H`RT)h^ 3>Aw`J#Ia\r\0(\0`jbT^EXA\01?F@\\p6@`F%d4!+  y1P)b4!n0jP@Ƙ<?(B|/Fp!pxS\0pKJ\nE p\0#'\0 m\n!\r#\n6:\0\"8bB>cH]q&>F0W#l!8!Dm}!:*@dD\n@	(\n~`L<\0AxA\0b7E<1rMTk<>XD :Q\"E};0 =.+-9\r0W	1-Ÿ\r1bGS\rL&2ȐC(ChCwkD@<6\0+CP\0j\0001(GExr`D aU\$@HjD08R臂PBt:PtÐe⁔\0 `-<NF5@`06C0y0[y?)|\0`;`d<+w9C`e<Ctd <	<`!XX	#\0000Fpc+	&\0@A;\ne1`\0\0J\0uy<5<\0 AA\0");}
        private function printLoader() {echo $this->LZWDecompress("G\${ dxl\$Hr^&r~(TT0[)%\niBPI lسhnڣT~gh22N`3K6i}11ƆKLj39ygB(I j-U+mn5iP\\@QpKy_9\\#2jSp}(9\\fS>NsU{,wJE( DtHΤ)ԝ%:/gcy=ηx';aج1q^wդj{|g}~Ќ\"-5\rÐ=Eđ,MLUől]Bbp*\nb(\\\0`\n\0'`\0\0'\0A\0 @8\$A\0T.BaF%AbQX0G`DdcAQ!.H E %b)D\$! %\0T+FQa\$.02eC9O`@(h&%ЌHGz\\0M0(\0nD)kfm	?\$XVa=	F<\0\$E(\0@a!<B@F\"	J0`h)	c\0cA|c`%QRg0X*p)\0)\0	D6bd{#^7\nIp\0\0 \na%FcY0c!\0\0q\0pZHEnbXip\",h`0 ,!\0A\0iÃb\\\0Z2 N@#\0Z\09D	\"aYp`&(,k &o\"\0\0Ab;`<0@\"-a<80a\0:Uh\0\0\0X` p<&ـ@&*\0\0a0\"<C`8A	 @\0	 Hl'\0z0\\0	0-8AJ\0P*+ȭ-`@B@3+c@oH'P\0,@:@s0TWb\nCk/Gc!\0R8\0&\$A:CJ+\$\0KP-D2K/dLP13,	L'3LMP/53l\rM77NP?93NG;\$OPO=D3OW?ePP_A	4,PgCLQPoE4lQwG!RPI)4!RЇK%1	#?	b0x!@Xp.R@)fh2\nDATm6hV+\r7XW[½n +\r7hUຽL32)\n8Àxf	@q8hNAJ8Kllr9I\0\$a\n84ڈ9pM4'aG0\nDq!lt> CE\r4:G@C+!m\$CQ!hG\$Ĉ\"dTD#0^!d1BA8[-X?\0n2:`Ql/	&Иd-6|M7@[t-a\0]\n/xJ'nF\0a11CPc2F@}C\$A\"FhC8d2\0BhV48fQ~2MC8c`/u|;F c3GQlTiQ5 #o\r8CpQ8G8cr\r9u;Xôr9xCx<czQ=jAh-m?w[[vnݻТR`%+RaLi3֛@+8.`!Iab0 A[%8l<!:GKAf&\0\0ap#q\0EBPg	r \0P\0ch rCP!`EXWÔkPC;!J.ØAaP9\" \0Qt#\01\r \" V=\n0\rD3`P@A*HPB 1*ȴ	!1\n :n16%`f@LR`\"UQX\\0@#h\$gx=`#R\01 lo?H\\z06xAF}HcѶ\r \0Q`|PZ\n4ba!F	 @\0 8`A0AH	\0@ @h\r&i:!\0P4\0TA\nH@AhA`^ \$ @d `@0AH@\n\0\0v\0(\0a\rP,vBta\n a@ D(!Adaff@!\0 \rHqP@FAj\n\0l\"@4@bfA@lr`\n \n\0p	Z\0`@N	Z@@*\r rX\0A<\$`n\r 'P@Z!\"`0!V N@\0ljax@. Z`A2AtAb\n LA L\0L`AH`n `>Xa@`	\n\0	`J8@K!D`P{-@jN \0p\0qn \0nT Z@ :I	F\0\"iZ\0I^\0ib\0f\0j\0n\0r	v)zI~iɎ	)Iiɮ	)Ii	)II\0JJ J(0J8@JHPJX` D D`Dh			\r\n <\0`\rA \r \r`\r`a\r`\rKt\07\0a8@ι@` ˀ|A	V	a@	\r\nbA\ntX@5\05\0x2p2Nh\n``j@x`\ra>@ \0!aT rA4h@f2Aj@b7[a=[aE[aP^&!j&!r&z&!(rhn@	|@!!a̐Ɂ\0~|!0AzP!tldVaz!aPt!LnN!l!V!pab!vaj~r!aaaA!!/a!!Aa!AaaT7TvAArrA!!a!MmW!dADA)}}WBKKLLMMa:`n 6GA*6``!F\0\0\rsavLT\n!<A\rT(`\0a. A`n@!a,:!zdLa a\r4\0002!1-A0Ѧyza\n`.`A@`\n!F\0r\0zR l\no\0Xb\0` l\n@V\r\0XAA\0006@&!bj(v\n\0!(@\" 	N r\0``& jAaJ`a0` T\0!\n^`a>p\0F\0\n`>!&=\\!@Pa6A\r@@TR ـ!\0\0F\0va@@K@<D| \0\nP\"@B<aA\n@2 @Al!\0N`bZ!P@f`<@\"0`.Fa\nA@\"`<` \0!fNaL@@`L! \n Aa!!hdA0tA&	\0D JX@a\r\\@a\0f^j`A la0\r@faAR!	 L@`%*`L\0R@@PdAdp8 P``e |A8l\0.\0 :!L\0! \n@@|Ap|v@`A\0|`\r@f HfI!67t)=7838939:3:;3;<3<=3=>3>?3?i	)Ij\n\n*Jj\"&*.2 t*J>jBFJNR:J^jbBFJN	>,	^0	~4	8	<	@	D\nH\n>L\n^P\n~T\nX\n\\\n`\nd\0\n`@\n\r\0\0\n!\\	`!1D \$@!\$\ra\0A!\r R/! `a\n@\nH4@4@|4@r1j\nVA4!?&\n0\0dAt!\0\rx\n\0a:\$!X0`tAN\0\0\nfnAr =\rǈ@tŁ!(!(!'p4`&!N<4.&!*'!,L? <'|P@A)\0S\0\0LY\0+ \\,0Zt\n>\$#`X	Ux JAvb0h0`~p0Pw80\r@aP1`mY1*vx\0004Ml\rCT\\9\rT@9`p]p;x\0P<y;\"Am x~`|{^ͼ q\"־	LCFMC|ߋ7\nc\0hL0+IA*0\0;A0!P%\\\n@`\0`j\0p	@T`@m`S\n@0f\0p&\0bf@ *\0000*P#l\\\08;A	1 % 1@.(@ X6\\\r`H.n\n&hP%4\0\0Ԏ3\0hI-\07	P\"q \0\r\0-\n`=@T\0t`7<Gp\0000P5p [+0v :@\$\r0J(@,\0ᬂX7\r {.THF`zꀚ.r\\`y=H@(@t`L)\0p7\0sh\r@	I8\0X2Tp|\04\0Pv-\05 A#,\r @nv`/;RP\0Kx5@	4[d@4F(&`EA@I,l@~ |\n\0;ApA(%Ai\"\0NM(0A	A  x\r % I\0 \$ w)T\0V\n0D5\0\$	 \nPQ@@0x#fPK\05l@(@\r o@@>PZ8@_9(  	\n8\$	 &H\rP W\02lO 7p\"sX	i\$8`^@(& w(H/\\@ah\n\0002o%XįLh@IK`,<	`-\0X\r`	Q`h\"@H	\$,0BL\07.\0@P\0.\ng@\nJ\"P\0\$@u@PJV%-pK^&!1Lf8&5Mnx'!9Nv?Py@PKAP&uߊx^\nPÔDE Ix41řyJw/ỳ8,DSX)hP\$O(`8f@- [h;U@\rPiVZ\r@-pZ>oh07_<1@.Jw` Pǲıhx`p\0003De@Y@A2 g0ԥ6p@@\\ ]E\0:HX\09[F*1R-\0 <)3J\0\r>L`'A@\\g )\rpW@@-0PZZV+6`]X>PA0a@&4`/z^0Aa\rXx2\0d\nAP4\0hg0\0` ABD#(	 kL^\nmh+\r[F~/P`R24`s\089Pf6)}Kj<@@9A@t@:v\0./pxR <\rB)t2h<ile@`	PK79a\\3|/k7\0000\0]PtJ\0`h`x	@\$E&`hp	J \0\$n0w	\n\0\n K\"7LG\0 \n@\r\0%`m\0	]t\nP\0\\p9\0Z\r\"W\0\0.\0 c\0#\0n`16\0<L`s\07@J\n0\"(\0b@<X	 ]\$u\r`\"\"\0;H9ð -\0P^0\rD&n\0-aA`fx	J1\0\0@c@P`6P>6\0 G\0j\0RO@;8AphH^\rJ\0``\ru-|H,`D\0@,03\0rP)rI,(\r`t`03\0-@_\0 hĲs\n@b d \0\0rH08-A-\08N\"( \0\0@g\$ 4\0vK@e\0{\" u \0cl1` OD!P2`)40\0d\0h1\r!\0#@%\r,.E(\0C*!~D(@9Pmd\08H:*\r\0@X0 h\0\0q5@	PYX@3@\0^-+B Y\0+\0\n\00+ &H\0p	(`+`-k\\sP2C&X:TeO\r4Qc 1A\n,R\0X/	 &T\$\03p@4A0#9aD`o8A; \r8\0h\ra8!9\0=@@(9\$-uT	Y3\$L86ND3L:>N4\$M<FOD4M1>NO5'h(ڊvgp(!܊\nwBؠx(Aފw&ҡg(aJx2&(n&7ٿpo sȀ@(<\n/(ʀ*<\n0̀8,ND3{ \\p`*t@O&TΔB0@|d\0pm\0\nϢ+s+^(7<\n,0egp4:\r*A\05\0@\r@CP \n``kY@*\\eq\0hh9\0r	ނ\n54tLulQA\nMb\0' P! )U0@-,@Y<h	\$	%lQ[\0V'\n& 	,2a`_AIAIقy=_`XT5̣x34 j)Pf4|ɣgRx#\nJx@(7\n\08\r(9ps,\r;ZT Pqiq0p'k\0x5kH`P7CN&(<MjlPv/H^=r,m`|/|A07>=y_o\0 -(`C@q\0\nAR\r d >i@DH	5 \0H,(\rTp		p9 HT\$`<PA\0  &\0~(1@\0`hAt0uH #D~\n	`)&#]p7\0\r\0qPO\0\0h\$	\$@7@dPJD	!2{,\0] *Dy<5Arh@%@\"\\ *0\0Cp(@\"!P8z\"\04,	!@a\n@\nP&@7p~p@wAjyh\npL\0000@)z0\0`b\0`-PP!x\08APZ\08w`:fR	%\0yA\n\0 t4p*@1Ƽ@F@3&\0qd@p@H 0\r F b\n\0 	\0` [;|#`np`3hE\0@D @@iq,A\n0?B\0A&pT\$p`k`	D`K0*r!\0h@(}9xYD02P	&7`dUATQHL\nY,\0,\n\nu@0v\n`TI\r\0@H	\0\"X@l\0	 h@d\nCh@!\0@4W`j8h(2P9\0\0I\0T	#`\0%-xX\nvQ\0h!Zh`^hPjH`/5vp`v\nlJ \0\$pv\03* jX	pT8D\$ۉ=i&ji*g)Ιtzijh)ޚxii)Z|ij)/'5kbZ/75͂b/G6k͢mNw^Wtݞ!7Mx^?8[s<8BrS\0{@_ 8`C\000\$x,a\0\njVS|1[8X:|z` R'L +@`\\2	H9@P?\0H0 @pA\\W@/3,s0\0aqpB<.\0`<*V0\0`9dp@p;z2@?\0p@ :AunLA\"sT`#A	GF0.u\n VT@iA29:%\0lPI* HȀJ(J(Al	o	n`'`pw7\n 4\r>\03F\n-` 0Fdt01<V x5i*\rm4- ^c8X@8ޓL58A\rtit<A\r\0yDxt6j2 A*E%OClp۫0o ~<-*\0Po\01\rX`Wppi`0.\0001d\0`)\$Lh/A``0y\08@<D@J*@Qhr'O\0-@\rZ)@\0\"\0.l\0\rAN\0w4DCfU&p\0+\0P6D@Vx8AzvH \0\0n`EP7@`4\0,T	H`\0jAW\r@\rM( &X\rpD\"X6rP,4\rhv~\0\0)\0%`\0&h\\2ʴ\0t*xp\0{\n\ru:\0 d4\0<8	\0h\r\0	0`1<ٜ\0)`\0=\nPL3pTDYx?@0Lh@]hp<Up<H qtŉ@0=P\0T`V)q4x\rA@,4\r\04>-i5Q*4``<0(4 n\0'O4\09R`\"\0&P4\r \n0\0000GHA0d\0` 5D`NRD	0,A\0p\rv4\0@m`P:@ u&Xېf>`@Th6;@=P\0\nx39rm \0f&6\00'Q`J\\\0	 TT\0	F\0Πh\r\0q	\r`\0ܓ,Aπ1@o3@^@<`\0@d ;0:h\0SIv0)d'\0s:K:iӎ2`3@uN陧tZ뛾:vnr[;#w˼s7j].vwܧswYݧwwާ{(鵯RjiZngxy'*Zoz/B/b7/\0.@P(`:3*\0`)sc\0_\0,\0\0+8 \n(|\0p\r@\0z	@\"'*}\$i\0)x`-A{'*T\n-D<T\n'9@>@s\0( .8(PRA:PA8*,!p\0EF	J	HAwbӁ ` &\n``0>\r\0CJ\rU\0:\$dP\0Z8\$	 &0@aPyN	b	rp'a8 eb\0fXhId\0.\"7P@<X\\CRj@eW@flstp\\Vp@V w0`bxǐ\0up\rR\0o1 u hw\r6 F썲:몪}*7Z*2jT0`s\\`#\0rA@mAB^b@KH@c\0J}p5@Cb\0`9 Pp%~](Gax\r`[@9\0\n>`T	`\\\0\\VV@j <B(`CH%p@&\n\0`\\\0 CP!xN 3``@Vh\0\0A\0\"`c\0pbb  5l ^\0\0tlhPvL\0002X\0`9\00 6Hs qfa\0\nlB6vX8	]Zg\0006(\08=j8]J [bX!`%86\0`EB7 f88	ft `7`pH\0Y>p\0{p\rr\0 \0@1`\0\\ˏ(B  c:m`pb1.\0R\0l\0?V8 ##Vp@\\`zj( J=fKf=`f\0BH \0#<\0*\"	\rI`I\0l؊7\0@@\0lׁ@%bw+\$H\0A0R\0T\0O	D\n\0F,\0`E^(2tP:N\0`f=,\0\0`4\0`<xy\0004Hop!a\rWY #B9V< \0\0p`s\$[ \r`R\0@0\0t@z\0P\0\rH\n j\0 \"\0`\0`8Ar(	\0\n*P\n0)`\0Hv\0\n@\0X2\0 	P#\0N(cT@@*b`u\n1h\0n@7\0` \n\0`6 b:vܩ5`l%l;scݦbM'Xuug[uv'^\0vvav3wdvcxggP\0\0\"\0R\0MhJ/rrp~p;~*\0\n@5\0p4\r\$<|FTD\0fx bX&a\"h\$nh	j\"B	@oRb0ew\0lYpl āp\\j	!pp\\RpQ\0 8`x U\n=P\0\0Mx-{\0H*t(CD8(?8:E+\"~e~p:\0	i}  <\0(\nN\0m'\\.`\0d\0(/\r:DK( KK3v^F U\0h`\\ ^(%X`o(o8ɠ5(HBx,EX[CJg[`\0tr`_dx2`F :Z8y@gz`o\0xڄ(v+x^,Ch̋\r{i^#LꢟHS @z*J2Rp`e@QV\0\0W:8 yJ\0f\0XMmnwgH]\0`\rn \rj \$\0006L\rl@@T\0R&fW\0b	@[\r`P`@W\0f`\0^\0ڠ@mv[영9@[\0\08K\0} X:2\0a2@A⋰`ez`\0\0h`\09L\0[@X@ !8\0p`BE\0\0h@\0 X\0}6`p)H(\0\08`o.x7\0 2\rHHH#~Jb r\0D)2\0	> `B\0f . X/7l\n)&\0Z`0Dxtp\0a4ܨ&\0\0h\r@p8H@\0p	@d\0C*X!]f*`bCEN@\n*\0\n >`I\0	 \0mG\00!`\0X\rq\0N(\0,\n4`@\0b`v0&#C\0`\0 CС@\0`Kx\0R&ځ`w\0Ը\0p\0I\0!H.:NP\0``=\0(\r\0!8MjE\0H+RH\0c@x0@4RX`s*\0UT\0^ )\0h\0Ř0` \0G(\\N\0`@bphOĦ󤭰\0p1`2 q@\0;\0b\0q.iA\0<Z9#.\0\0@\$jBrX x_ ?\rD\0dPŀA drpp`8@Y2hX\09`GZDڈw)=F\08p\0\r|m	<?u,Q&_R.m.R.rm.ݒ/ݲm/\n/m/HK?\0@\0@<	@ R7 |j}H@/\"/b/c\0@0p-3P=\0004PM5P]\0006Qm7Q\rE-`2\0X 56T\0 @)Fxd@j\0\"mtU@ɰ\0k\0Irf!ɁE`\0&\0ӟ\09	'\0E	-Q`r\r/T\nH0oF@)|9-7\"-EL&K86M;05X\nX@@E0sVemW\"[nj.oB&\0[f	\0[1#@0@(eR\0dh]1hD@ȷꏀCp j&Ljl|\0kjc\0f2qc@vĳf0fp\0fu\0k\0srQ́5@r8v(<Ș@\r`|4{lHBڅ,A,:*Prg>\0w\0F\0p,h`sKP\0zV\0,F\0LT\n~8ꌸ yP\0Hj\0@t\0(@Rh;6h@-\0\0 FfHL\0`jP4,hb\r\0J\0S\0<h\r jP 9\0@U`s\0` YN`F@:;(hd@[\"h >\$ i\0H`Bv_\0,R5\r <]'0hs\0G\0004 F0`p(\0V\0\"x\rv0`l6Qj@B\0x\0007>X\0}\0\"iN&\0K+Ϙ\0q[5`\0`bJ`F\0kh-\0[C`,Hp\0a0DO\0`x EJ!\0\0~UHm/\0@@\0 ~`)\0`2\0,N\0%\\U\0]	 '@N@s`` ZU(P2(+\0VF:@D\00 y\0 \0004H CG@.`<N\0jc\0Ji c(aKtU^`l0P G\0˔ 3B\0`@\"H0\0001	@\rr@wHX@Rl4<\0G܉`C#F3P\n`g\0`i\0004h @hQ * z`'\0\0@\0000\0`	' i(B\0V0\0R\0` @D\0F	r\0r83h@H\0Y<	ї\0DAJ`\0a @\0D0 N!V8@R\" }8H͋\0y8ihH\r`Oi56M\0-\$|Q@7/JMԝj\rםvڝ!؍ݝQMmzUЂޅmЊ޵ВC{7t0DiP,B/Ck.\r@y25\0003E4U\0005e6p\r.b60cv2c84`H,8P@\r\06XJ<\r m00\0MM\08\0@*: H6J)\$k\0U.`/@:`5Q%\0-\n4!'\0| *\nي0TP QftҀr\rh4WN|xǊ\0(6]@+`\r0\nJ\08D|hc9S][`K\$`O!\\C\\[d8^, bA^c@	_ fpb@\0hV`j[gi)R`ly.op fޤ8KhJC\0yp#^\rn5xuhc)jΡGL|yM#2B2A6@@.2#]\0 V`kf@ [Z\0H \r\\.\rml`l.\0d(@QX@<\0aVƀl0`dh\0!O(\r\0'\08 40`uh\0\0V \0.\0x`h\0XK\0\n\0@AXPt8`l 5 c\0=K`A\0Jp~,P\0)#0\r\0b@Y\0: \0v@\0H`\0\0\r`=\0 \0\\H	\0 gT0\0 0\0\0@\r(\0\n \0\0x\0&@\r'A[@6;[\0@{(`\n&Qb`X#>J\0	\0h`f`L\0i:J\r\0@Y@@\\﵀@B\0@d@\0\nLi`eX\0&\0 \$\0\0@\r`\0\n8\$^\0R\0`\03\$\r@AJ}2\0pI\0|5ϠJ\08  \0 \$HmB\$I`\0Rp`r `'B.\0/\0T\$MKJH\0\\\0pP!9p chPimJ9\rJ8@r\0v\n B r *-vVYmltY#@T>nix @\0HR\r\0PJw\0PM\0X	 X\0@H\n`R\r6\0JP\0\\o@\0ap\0L Z6VP`TDkL\0t	l9#g\0~]ITL6w!\0`@JPHN`J@ٰ\0H\0L`9_d@\$e`J8(\0*j\0007;X@\r@~A\$~ATAA)\0\$g}S{7ak|7a/v߅PPߵ/a؃t5qb56\$PC4=C4AD57ؾ 89 :Xx90\r:\$ 1A\r@Z;	#_m`h~[ Ny\"ٷfتȃ,lfTYf\"}6b| \0e;qh\nVZ\0T%\0001 \rPFR>\0?-E`\n#{2h\0I[2q6\00@/Z-{_hm2[+\\.w1\$9`Z(\\\" ^\0 a\"0 }*r\0gh\\@f56lBG\0l eѠhH`x( gjyR`g{`u#\nB+LEV2>_N#:_T\0-r(L8lpH\052`vdT\0\0h@YB@3:#T\0&\0s(|2@\\(\nQ(\r`S\0U\0YDJh0c .үk(`KȀJ\0\0`[\0\n@KXpH\$`W\0`@U	X\0\0tX \0=`9\0\0X@/`L@!h@d\0 3\0\0`4v@v*V 	rh \0\r\0O<0Wh +xx@`\0\0(`;\06`r\0U\0އx@e`a\"h 'jmpp \0 m(9P:E`qY@\0Tl\0\0D\0 g\00 h	@`&\0J\0p !W4\0`N5`#	@) @\0Z&\0{\$\0&E z\0ph\0	@-\"\0\$(@J>1\0 X&h`b\0@8h@MT\0`hhX\0H\0Z\$r=!<.*@@`3P8 :\0006/\0( 0 Cl#\0<\0{8\0TR\0\"\0U\0\$\0\0H8gy=v 0\0004y\$\nW@AY* 	v(\0U\0LTDP#)Izu8 U\0H@Fx{5 :H@\0^`1\0R\0\0\0R\0N\0w\0n`NNP@<\0`j(rP@T(dYI8J 8\04\0h\0n8\0@x`V\\G~j\"*GH\0007GYG-`d~!6\nGHAЅd#_ H+abg\0}V@;Bm!%u!UX}C6t4؉Cu9Xb]'أb7 7\n GX!@XSY\"W#14 YA֢\$jV%l!\$o\0g8@G\0lpV@&DPLph I`TH6!pTa8t[`'\\Ƌf,f̟@vbPK뇕ׁ\03.c\08Ts/	v8\n@rZ,\0r1̉=\r&\0 @8@p<%\0ec FM\0002zx8N`y\n1`:^j.CIXt	``\n`@+\0b\rLgE8{Pg@JY:,g&X`exeZh ii v\n֥<6!E\"n6z@쌡8Y{Z7\r7jO(\0h\0rH 0rH@ @ \0YL\"b	 ~PasS3- O04HP\0rX`8P`\0?G\0T9`\n&tl\0 4Rk`zZ2m#\0x\0\\p60\0~\n@NhP\r 6\0+i(\\`dLh\n`#\0@[\0D\0`U\0сB&`.\r`Wt ;ۥWUO\rL8	C(Q\0xk hPG⁀tP|\\\r@\0`=kռxL( \n#C8&H\0RF\0``e	\n0F\0lQP`\0@r\0 ș@\0:\rH`hp\0`	oÀ,@-\0IY\0\0p@mXؠe=Sl@8\0 d\0\$\n\0; 2\0bP{\0p( \"x(ш (\0pYJ@.DxU`@|`\0oY\0P%ـ3f\r k\0r`X; *_^`6H@(`N`jb\08(\n@\0JWlH}ZY\0aX e]\0Dp`^%j\\mN 1\0-\0` K\0li`nx\0:m;qњyV`\0xJ\0\0/X Vdp\0ԀV0` e\"-My(@v M9dB\0 'Ҷp\nـdn8	\n\0Tv\rt	B\0~etX@XA-tXA]X#AtX+Ag,DtMޤ t0_\03B*gWauPߥP]/k@>T KP`V؜\r\0005bv*D\0@`\r@oX\04\0p@*KR	- !&ɞ3`+ W.Ҁz\r(/\nҀ\rx0@'	nf\$e~H@5TJDX`ZsV`[9 [(\n.[xPd PWab\0Z`]`^ŀbY ~\$n'oX\0i^ih@hZ^[ %|h0d`hBjZH\0kZVki: iEbR bthk BW\rj@fK\\050yF uV%ЁP]9tB5<bBx h z\r6phI!5Xb3խ)7SLP `\0f2F0 j(\0)kx@غc\0w\0V`\065' >\02>R;+\0¸FLP\0\nW H\0\0H^,xJ\0\$\0 *p`7c6 2BjP+\0\$  G]P`kZNSrPo\0(j`c\0M;\0\0X\nT>\0Oo\0KH `dZx\0x	%I\0\"\0Q\0\0007\0@\$B\0},X WP`? [\0JC``V\0c\r 8\0W`1nM@rn*\0b<^D`ћNF\0)\0`e#vd=?%PXp\0Hrb@\0\nK\0//`\n`	\0o@FrhtH\0i +1*yh8xt92 @!Hd@	 2aq9jh\06\0hn\0@@4\0006E \0\0  T@e\0X\0^u&/XP=,2d\0PQSc!Q\0@fL F^qfr8@]H`\$\0B`Q|`\0<`w|	@d\0Y~9\0<[@S 4VM@)2&vC\0@Q	`Fj`\0f\0 m&oL\0F\0006h\r\0\"~݊(\0006hF`&Q@p;Gue9==PFEPReP^OPj7 &7Kyh`P5lzH\0;\0Dd\n\$	 gPh	 o\0P%@=8@Aps QmP	t# '&\0D> `?P6Qr/a &Ɍpf-2hPT\n°%E\nZP|X&r\nfZM\0`8\03`=\0x<,\0@N>RH\0~\$ `(Bh=`E`m<`O`q\0G`QYaH`32Hvz\0?H'ewrw;>U	[⹑P&'n\0K;`M OzQ\0LpTRU,Y_`V\$@Xn!YVƀ\\\0]@`zWz9~(ƀi X`i` j\0b0j8IKHi.āJOOX\\`kn`i2\\;}`@h l]`p¸ej v@`tT]vܧv |chBΧziܯD.)c\$ҺMr\078\0\0\\ \0004\00060lfHݒ\0r 0z]\0-\" @{\0X@y:.p`\0\0\n`2l3\\vKK`@2zz jf\0`r\nF:xI\0\0`ex8@P\0y#q;' \0k\")\0BclkA\0`˕\08X	Ih\08 *H\0`-ԇ@q8 &0	`Q#\n\0dq3\0	tX\0000NQ\0\0`h\0]X\0`M\06i\0pHǮ@f\08%\0q\0	|O MM\0fh>ex\rAiMP `F0؀x0mf۴xp\0J*\n/\n\0#W/u1ŀ 290\0(B@o\0KÕ@\0L\")L`dY\r BCEAJ\0 @` 20R\0`bMW\0+X{w@ t2C\$X5\0x@\n`!\0NJX\0\0|\0@	`<\0BPF( +\0(\0007\0Zh W\0\\x\n@Ol>\rJ\0i\08	@,B@8r`B\0C-È	\0(\0\n 	5\0x r06\0FP\0o`\nj #\0@&(2xl6+x\0  az#eF@b\0\0 h́\n`\0ӓhZ\0phv>\0z\0d\0p@x\" *# :\$ J\$S	@T1\0%Q[r(SH& n@`v3dE|	'ࠧp\n(\$\n8) ()*``*P\n+`@,`,<@@?p.\0\0f.HN `7\0V\0000@p` \n81 ŃJy\0p1N&2J3'tЃF\r(P\rP, Y\r	 qF( 	@p@7n\r69\0z7@܀8\r\n`-,d9 僚x: #=0z;a;@Ȉ;FdeS8 ^vÁz=?Ã^H=p>\0aj`}6T@g@r?@i@!n zs |\$@^6m3Cn\rr^\"QG,ecD#y\0k.!j\0'Y8O~5*]p !\0P\"\0\0005;'\0006@|\0x\0Pp(\0`%P\0;p:&*p&\0000H\0 \"<\0\0@\0\0hE\0\0\0<|@ (@\n\0\0d	a`@15\0\0 \0\0pX	\02\0\0F P`\0B\0\0 \r@@T\0@\0\0  1)9@Z\0-0\0	` @k\0R;O\0\0D\0%`\0000\0+\0}\"5\0@ ?\n\0\0(\0\0F\0,\0\0@R+\0 @`\0|\0L`\r7,`7D5 4\0\0\n\0`\0\0\n\0\0`@:\0(\0D(\rPi)~8\0A P\r\0Rf1m\0\0<\0@\0@;B\0@I	@	\0#\0s\0rGa@+\0\0\09!\0\0\0@ `-\0@.\0\0 /@<\0(\0\0@ 8d@\0Q\0 q`@V1\0\0`\0A| KcP 4@\0dp @*b\0F\0\0\\G`\0(\0\0h\0Z \0r\0Ri8\nl\0:/N\r \0002\0`d	\0@\0\0`*\0t\0y\0\0@6x\0\$P\0V@\0PX\0%\\\0P \0%8D (*n\0`!>T8\0`d\0<f\0 -@v\0Bv\r\0 h\0  \0ۀ,\0001D`\rY\0\0006\0_P`[,\0L\$r4 \0,B\0(<@ 1p\0F_&8%J(?%JFqməƺgqrrnYʛ_o%;sK7<g<oa\0mЙѠnEa:\"`B\0X`\$\"oX̀\01\0elv.\"Z\0;0\nN\0+SA ,\09'L\08\$\0P\nB \0̂LcCg ;u8\"Ѐep	 oZ %5UdX	3\$(S8<x\05FT<|\r(K|l'@*\0Ģ0@Z\0wp\$fƎj>h 0DP6t0\n@[\nl	ÛH2\$[ja: ;M;rp\0\$|X3.\0.8C\$p@H 1\08p1`\$e!f-P\$l4\nҀ*J\0An%:m-`7IL5Jk`<\0c<9P;ߏ(\r9\0v!YN+p\0\"H)M\0I_ֵp!LB\n׎VDeyRGF\0	`5ʅH\0	@8tsƀg!(̉@j\nt		\0\$@.@k;Xh\0 @Cy\0 \r+\0<18рŀ\0\\@\0@ a\0\rO6#\0f, .@=.D\0X@\0,Fou8\0<9P0oC@j\08@`L'\0h6\0\0SP\0\n\08\07<8(@8Dr\0HPPM\0\0Hh	@f\0\0x	0\0awQFU\"@\0Ku,t||!\n>@A:BP&:\0\0\0\0x	\0T!\0ާm\$,\0hC\0+\0@\0IV!h4.\0\"d\0ppJ+\0C(	\00T\0ɐ@P@G;s@15\0002X\0VSU(@8\0;\0\08	\0&\0\0\0\0x[Ā\0c,X\0#k0\0|\0x\$6hE\0&x\n\0000\0p\0H[dSo\0\0\0ZN'\0\0/P%w\0\0R&h8̀\0s\0\0\0 t*F\00\0fVX0\0\nP\0\0(n<\0P '\0!L\0\0\0v\0\\\0\0)\0>@ 'O6\00000@X\0%d>Cc 	&hτ\0\0 2\0*\0~8&,`\0\$\0p\0\0\$\n0e}Qm\0?d\0\0X\0A\0A\0#`\0\r]\0)4``\0\$\0\0H	\0Yk\0sth0@C\0004%hPi\n\0\n (Cr	y\0BS:7Iќ2q\rș:gasrrY/g(39u[3uua#9XWX#:dLH>εBt\0K[0PƀaxEJ63^,V`4i2,fXбXfx\n	  @No\0y( _b\0( \0003\0\0EZ\0000\0\0x7\0lO`;iLb\n><r3\00D`Èk\0002 \0X	0\n\0*8CS٠9x 8q%PȖM\"l\$/(lh	Q%/\n,xP`4\0@z) \"A+`h6^a\0.o\$\n8w 1Z@ ,X017yh.\0#Թ|4\n @6@p`\r,CP\rB5\06Ÿ`[@!@t\00@1\0a\0Q2xp\\p\0`;CN\0\rL\\2b@tjN2.\\ D'<o|ı0с6<\0@u\0004\0J\n`/UZ=p  #	`\0	TU(#L@0+\0^|	\0\"#{\$\00\n@.6'VD\0Y@ ᣀj\np)A\0jp@\r%\0)\0@K\0L\0V,@\n\r\0-	\$@	\0#\0Hd@jM\$H!X`\"(\0^rL\0	(ʆ\0\$Xp\0BiNB\0(W*_<\08\0)@\$\0\0@\0cU ;\0 :[瀐>D  .3\0,	 QZ[ PbE@L\\\0ƓP`u\0L(\0lXuW\0>J\0b\0<p\0\r@(x\0CA/i64H@\"\0tXa4\0F?1@@\0F\0\nN(\np\0\rE\0:\r:\0r\0D\0W!U\0!8\0E!5H@fHl``b-:@\0\0Rx\0 @i\0Z@0n1\0001*\0\0\0&\0G\0\0\0R^\n\r\0vͼ\0\0\0	 @3@!\0@H\0\0\rn\0\0A` &\0i\0l\00\rc@~KrQ]!X@&X\0#W\0X` 	`+}l`\0 \n`%\0F \0H\0\0btw\0P\0a\00\0\0_P8M\\\0@̀H\0y\r\0\0l`\0 O?\0H\0(@\0L\0\\h\0000\"*'\0\0\r\"e\\\0#\0>\0r\0Ŋ(/\05F\0L\0M \0+R`v>7+~A, Bq` q7;XF:&2YCm\"Ф#nBp[ũgr6-kwЌYųXUbŕlX!\0Za\00\$z?d\r@ݪ\0\0xUzM\ri7\0oQ`\\Q@gQn}	m8>`d\0d8И\0ELo8Ш!ĠEK>8\0\n\n5\0H`k*ʥ\0qģx\rPf\0@@'=\0D?+PNh@-t;/\0o\0\n #1AB`-Y9c-H	\nQ7>9xT@#o\\ .^\0\0-gja\0nҐah @]T\\0߀]\0\r\r/\0 42N@vYRص)K✄@ny\"dpנ<@rpB(ODaNS9Cy\0SH\0PL	\0N~\0\0lPCR\0@\0y\0hP@}\0\0@?B> H\\ <M2\0\0@.\0I'K&|4P`:\0N)@\r;\0*T\\@@\0U\0h07@f)\"8(0J\0t@\r @t\0\0hP3BNp(`\0\0P\0q @\03P(gP`0@D{\08\0P`3\"xs` 	Clp@7\0b\0004\09K\0<\0 @JPk0\r#;B\08\r9\0 \00J@.u\0jn @\rG,H0	CӉHDlhp\0\0\0Q :\$\0  q-89 \0vtN C̉64\0^`RD'U\0Px\nn@U&@ 2+\0a*&\0D\0{HY?	;\0h( &x,pH!0Ff^\\p\0ـv\04\0M\0\0qp@e4jD5\0\n\0\0fLKL9\0	G`u\0\0p`[spkӝ\0.v`@<\0t@)_\r@%\0O\0\0\0xq.	`'y?\\.j'qZ@\0\0(\0P\0&JNGN\0\\tl\0Q	0n\0R\$hrD@Q\0\0 0`߼t`	 \0@v\0\0(@\0`\0\0_`i\r\0Q\0(`\0j1a\0@\08\0UpAPȰpGD\rp.X0h ;	f8\raHGy:@`\$E`X)K@\0>\0>|@i;\0`\0\0^W\0\0̎X`_)WYnVuֳr.njus#@\0006\0hx@7\\\08W@ '*Dr0P	\0001@(\0K(h\rP)@QQPHb봱UrSG\0h`\$f`g@>Za@\nu\0\0M rX48PTf>!@Es\0t\0zh8@!k.xi 9&x  !F\08h 1@F`X	\0&2\0H\"R8LP\0RxD	B@%\0h@ \0.IFN9?H@\0Nn	<7>\nu\"Юo>D#8`\0\0PP8&@\0H:Erru>(P &%|9@b#Tt0\0f\0*OeA	`.JR@i>\r0@g\0\0P9@9Ay(Y@Z6Yx\0 .dQ\0aH<~\0Di7o5T~B\r)X8X1mعsV\nk 9C`:mlD`<@qd(hb@z8\\HlaI/`JWB\rJ(}nyD,Gb>2ѿel{B\0\r@SF 6\0\0@\0\0 @Ws\0BL@1z\0(\0԰2\0\$%`.@0(tT0\r	'\0\0XX\0@B\0&\0[y\0@0@\0JJ\0\0  !\0Ji&a\0l34,`@H\0\0lq@.@/\0`3\0@31\0Z/@U\0H\0p\0(H\0'\$\0004\0\0h\n@:@=\0\0\0H@c\0003tq	@\0lޗ\0\0p%@\0v@8	`@)ap\0\0\0vp`	\0\0\\*	P%\0AQ\0\0Hp1;\09@\0\0\0D `d\0\0p\0001`\0 \n\0K\0<\0I`6h`\0	\0\nlXSʀ\0&\0\0@# <\0pg@\0R#;\0\r3|NQ \0/\0\0h\0Hx\0!FUB\0XpT\0&ڃDPҀB\0YP\0>\r\0=@,NPep@\0\0Z\0TB[0\00019\0\0`P\0p_W\0)%\0a\0JnB@\0 Hr\0871ȣ&@\$Gp\n\0]\0pKڀ @:\0K6\08S}`\0rF\0`@Z7\0\\\0c`\"jI\0RRd@\0\0001\0\0Rk1\0P	P	\n;\0d \n@@0 :I*iǕr\0K\0V eL@	+\0S((C4(d@uk\0*,RK#\n\0n5p,\0v&!0`\00i\0`p	G>	\0,\$nSdP@i\0\0648@\0HF@\08m@1Bf\0\0Y5\0\n4\0 ͯ\0\0D8@\n)i1eymWnBMcrUuܵ~+ĺ7\0H \n,\0jh \00\n/3\0l\rb|@*/xA\0'ABNgH\0#\$\0yS27\08,\0 ~*\0OU	/6\0h@h)%ദ;(\0a	 -&a%An)@#(]h-Agc\$BH &@.6=l '6\"@P\0zxP \0qr\0 g\0\0@\$x\0`uL\";h\0~@\n!@ hIJ\"@!h\0-;88#@\"hX.\0\$@#h\0L>@	\n%@\$h\0\\N	J&@%h\0l^	 &F@ \n@)@UcT`P	,@\\\0Gf#`k=nDXa 09D?	L@RFCD}Hc0oBA,,' &\$Γ\0,:\nd\0(2@\\|C}zpMÅwQh\r\03h09`Z̮'hX\r`,os)@/\0£TP@7@h\0:dR\r`/K1\r8d5@x?-	8\0wn;e\0FDCbd)B]3DZ['\r7`9ҧ}MK/(\0J!ưyH@u\0\0@!\0\rYd|*\0f*%hOV\0\\\0\$\0d \0g\0p1\0H#\0\0\0:\00@(P0`\0pj0\0`E|@0\0T@@<!?\0	rCL]\0Gp^`8s\0\0H\0	`.nb  +M(Z\0L3\0@\$D iv{Ln \0000b)4 \0p1+!Z\"\nV8\0`\0p\0A0@8\06ǀ\0>\0P% 5`]\0\0p\n``\0A\0(\0\0p\0\0:x@\0-ә\0uI98\0c@\0\0004\0@ HtR\\\08\0`S@vX\0(ː	`@jb:x \n\0O{hU\0\r@\0(@X\0>\$BX]#ˀ\"@0\0K(\0ч <\0F\0@0\rIP2\0E^pPk\0K  \r7\00a#+i=g\r	\0\0h?0\0R\0h4k`&S'\0 (  -\0\0\0L``\r\0q\0lq\n ?@v \0zaD\0hp ]+\0`x`/ʚW!24Ed`3\0Kj\0F\0\nPD\0\0H4 \rX\"\0\0PH9@g]4>Pk`\0\n	M9\0V%[^I!@L\0Pl@+@\0\0\0Dq\r\0C\n`@\$H\n\0\0#\r\0P;d;X#F3N\0#t!i`0@^\0l\$\r\0\0ffGx@(G\0ibNQX\0{,O\\\0\0\r(b\rd\r@\0003@h\0\0W&1]h!EwuA`2?Xz\$\$?'AAy\0Мy\0`\$A\0XnD8/p	G@&	U.`@`'@s@@;\0Vd`*MR\\P\np`:S\0:j  '\0?<='`4HP\0C,	s%\04M٬gcĠHPXP@#IA\0\0[k{\0~-Z-8@6NSٴ+0o%T @*p{dC\$\0Hu3I k8h`,I={\0B\0P \0,'|l\0\0/<\n\0+ P	 _Lj<P0\n\0n<(%P\0(*\"KgQDp@Ŋ\$\0\"ȢKDM%K3kDމ	A|L,0l	ʣ@'j\0<<	@n\0S\0\00*\0004eGxB2-F\0cpbᅀK60V>4*#9y8y\0r	\n0( )9M@\0/GWppƀ1}Ҍi\01`x\rP4m\0pp 6@n!\07pqF3a\0)Z董աt#\r@Op@<adS`=H:1|(pgRֲ%y\rS^ma|\nfiGr5GQ}ZqdS\n5\0<4@\0!\0kP@@c\0nPI\0c\00`8\0)\0ۊ@2'\0r\0 P@1\0MCa)Wg\0/0\n\0M\0\0 2P\r1H.BH3EhKP -\0[p}X{`Kp5o\0@M\0&\$h0`v\0\00drJ,\r1:]\0p-`3ȀTzJ\n<\0j0\rh8>3E#3~\r@mO(`2&\0o`<M\0\0ds@-[Lշ=\0P@\$Z,\0t \0s\0.`/) b\0mV`\rע\0\0 C)\0|Cqv@b\0\r\\3`\0%1#Pn8\0\0B^`dE0p\0H0 \0003\"`@9@\0	K@	%\\:7h	ph\0G\0\0 P@6X[\01HP`;D\0004\0A\0\$\0X	\0\0\0_8 :\0:\0t\0`\"\"D(P\r\0&\0\0-K@1M\0002Jظ0\0%'ZzPwp\"Ѐ7\0\0x\n`3\0W\0lXGD\$\0|\$\0cd\0V\"6H\n\n@rLE\0 LQtP>(N\0H8s]\0y\0/iP&@.} _ǀ^\0\0,\0`\n8\0xh8\rD\0TL(\0P0`\0]Pm0@\nB-b,\"a.KL`-\0E:ch:XG/h8P: )\0P\0F c\n\0\0\0002Zn\$\0&\08?'GSqss	CPBYuT.nQP֝C%\rT6uPB@u\0x;0\0\0\0j\0 `@\$@Un\0L\0p\r0\0l\08\0n2\n 7\0`Ev-H0\">OOt|XBu\0X@W+	A[l#E UaYG>iр36IL8E@,[\0F(\n	&B\0c^(P\r`4n\0F;1py\0@,BQ\0DB@QD:\"tEh7Dv\$@&\0HL*Hp	@K>d(\n n&R\r-Q\0Sx\n0@,[=:*u\0N|5o 'v\08	p`'\0JQ&A:I{I\n\0e0#BqLs<{\0 H\rF\0'\08,`Pp\0@W\0\0|<dL=\0gϚ+ -Rɾ|\n	jxm\0a@<)@P1DD\rb6fr&X	@'_jPg,@ott|)`A\0VP\\`k <@qU1.bu8m7f*۴؆z~QP@JgVasvux,qf0rx\06eQ(\0E\r,p\r3aBF3 @9\0\0HPd>@)T4@>\0jXp\n`!@4\0dHE\0:9H6\0b\\\n@1iQ\0;p@+@pxh\$<\0V`xPXiJ\0(	@/S\0>\0 {\0\n7(@@/\0)Ne@c\r 5xP)\0z\0x&gU\0\0+\0\\\07x2WX\034\r	@)\0DD\0b` @,\0VS@R\0@`@ZUl@\n *X3^\0J0 8E\0{}ODxđ`Lm /Ϛ\0\r̐0P\0\0HzqO P\"f<b)P\0`4I\0\028@8\0005KPpP	\$3EH7\rV#1VqGʛ1S\$cu\0d(Wexm3E\0\0.Gզ<T	\0\r@]WI |; eSr\0\0*{G`*\$\0\08v/\0d\0\0C\0icR\0<-5 /\0v\05n@+\0H\0lXL\0X\r\0<~ƀ\0)>T\0	\rO\0<8\0\0Ġ\0>kg7\0.\"\rd=x \rV	l\0`K\0000``?\0F[\$%lp	ňL\0\0\0e(\rP\n\0(5\0cNaO\0`\0\r@B\0\0p\\9=@jR@Ge	RJ[rJڨbܲz_m\0V\0`5[\0Zkp=Kf\0W\n\0001QL\n5\0V*+Vu@oz6msq=d\0E'\0Ѽ|l\0rHRh[\0~/;\$6 \0/\0o+x#0^ow1n[N@ 3#	\0+@	@W\0S\0@@5fx\r@=\0p\0a.ـ>\0k(	@N\0\0`Fz\0T\0 \0 Y\0\0t#`\n2QNj\n*ҩ\n&' RX8 OUAZDxF@.\0~?2X`(FC67x ^FTɷҋAt@4gD\r'3?E5.mȀ  \0+T<Z\\ @n(,bbT80AQZ\0\08 \"0L\0Բ`˸	p:\0ZjD 9\0J.\0o2V%%9\0miF3j\0Tƨ\rg 6Cp}Pkx\0t\0\rv.laCdbB4hD,\\<!0Bh	؛y\n@eռx,k@V\0\0v\0e\\\0e`\0p\0\0BQ8KWXx	;0`w1v	T\0\08\0z&\0c@\0N:XP@@>8\\fUD-ce\n@ #\000\0xh	@\0m\0B(!\0Wz J\0=\0W5@\0\0D\0Tp\0k؄5\"Uhrh 71	\0V\\p\r\0C\$\0004p\nR\0\0.\0` \0?\0003Tp`h v \0\0@?@\"l3Vvh\0@\r)*\0p4\0	\0\0r\0D,P7\0\0g\\\0NC@|\0007\0\${ 6`;@T#c\0\0@@\$|vPAF8x\0DqQe#!e_i\\E<\n\08!{NJA`5z`\nlX0j/?@@\0Br \rV \0P%`xP\\^\$ix\n>9@  JZ@L\0w\npVF\0'Hh0 )\0d\0NBIEK-da\0+\0>	T.h\ni:@@UJCR @\0Tt0m*S\0>` `	(f(h(@ώ2\0rR4\0\0 \0@{vL\0`Ij-\0L]`+΀x\nɁ\0L8  -,ˀ3BP;e\r+\0RI\0\0)R\0l}\0}\"cցc6&`7bW+UjP@'\0'>\0+`)\0Ig\$Kr[\0hcu#GMlMW%ŶLeA>Lƨ\$[nm`\r\rUKH_MaRdP\0@#nHI\$5)a\0(`	\0006EH4Rh1@sGd@Hq5J \"jQQ T` 9*U,jC``Bπ^4\\,	\$Y`1%~|q{D4\n~h`dB_\\V9\0i:m& ?\0a( y %@D\0nx\n3C~#9+d		\nE@[Il	бfu\0<+0zpx2=\0\0=b\0Qia\0`\0e>Π:m|0 2b%׫͙n(Ȁ9XS@N\0\rU_ʼ\0fAL7@akY\r1d@p\0z`ik ,\0R9Iqp\0XFh8\r4_`6s0/Ty\"cTQBf+XgMu86Wڅ=޼moV7bD`Xmqt=\0P;\0tP,\n`.\0X1\00\n@@<	hʊ@2R(|I(\0h&So\0z\0Ɗ0	P`\0005%ˮlX@ @\0o\n`\0O\0e\0)I\0f1 \0@I\0:qM\0AW+@D\0p\0886\r \0,@85Y@\r@@P@=b\0>#`!L\0rpBP#Sـ\r\0S\0\0Kk1?\0\0W,6\\p4\0dO/qp\0\0.\0l3B\0\0+@k%7<%Դ7\0h1=+	\$G5\0K&ؠ\0 yL\0D+@\0Nm\0c\0\0a\"P\r5`\$E\"\0z\0Us	 	6R\0LX\0JF(̨\0\"{@>.\09\0j\0*vH\0@s\0\$*aT`+\09\0\\sh'\0^\0 (\0Jqt\0+7P\n a\0	\0\\\n]⦎@\0|\0\0:aD8\0B	\0\0\"d-XS@%\0000D7X\nq^s,\0`8Vq(/r\0`j\0/ 4H 	\0-B,?i`(@\0m( \np@5Et\n@@Hڞz9\"P\0m\0ad#4F\0%5RXf\0	L\0^ 	 \r,NO-̴fP @c\$`)S3@[OEdk۲N\0t\09 \0\0&\n\0_|\0 >'bx\rB)\nFKDk	XQiB85UY`QB\0\0d\r&D[\04\0 ]*`\$ʀ\0\0m~u6+ۂnj6+ۊn2\0007XntsЄE\nN\$tF\0\0HPX-t\0\0n\rP\n\"@)\n *4¬\nl\"b7|`dlXXPa҅~qfiL\ra0F(T\01(\0^S	0i0 ByAV.0piz#X9Ac\$%0iX	 &.6T)3\0+nP %\0-\00rbX\0\0P@'G28\nPm\09nL^ƚ`!.e0QI1\0P@cTr	pI[x 94i*-@H%H=TcI@9s0	.㘡\0K@\n/\0Tg~t(c\0Z@ 9@_pXҒll`h8b\0b\0Dy 3@v\09@p\rRuKd7\\-<7+p@oH6Ð`9\0蛔dY~d%\0\r652\0~S.mpn6#@y\0\0pg\0v#f:`v\\^\0wH\0@*X7UH]@!g\0\0\0p@4\0ZP@1I`\0\0\0\0i\0\00 *\0	\0\0# c\0N<\r@#|\0g\0:dn\0\rYP]5\0000lD@/Tp I[\0I\0\0h@Fl\0p\0<N\"h4OFXw\0\0)@?\0;Ｔ_\0W0\n@L4\0\0@\r	 0|x\n =ͻ6#\0[8@S\0m\rX\0F\0	f\0w\0/40\0a 1\0S]3\0\r@\0k\0\0.`\0H1\0ִh@3@I\0\nU`&'\0pI4\0 5 \0[J(	\0\0e-VԠ,8\00K۪\0&_X	CmpM\0T\0\0\0`\0>hW/@4+Vxe	\0y< C`+X\0NZHF\0D\0)*\0\0#`h\0ϾRP PVRF.,/@T5\0B\0\nP)\0+\"*kR\0\0yd1N\0I s\$8Pfx\0P/z\0,BmXf(\nxӪ@q\0G\0\0y\0<\0\"ww\0PlkP@@\0\0ϐ0%@A7\0#\0\0喀4@ 0Wa[\0\04<\0[΀	\0h=?cG2%	850[P+}@``0郀N`bBP\0,R\npTـ&5\0m\0?n\r_\0(>8KH1p\"R1,T+z-/gNM \0\0(\0N\\<Qc\0*X-amuf	_NV,@\n\0005OlaN\0h\n\0007P\0{[l2^,Ff{,E`XǓkoTI>	C\0(~	q{rʌ3\0҂<\\`\r\08I\0SDø@r-SN;F	 F@<*` @&\0CQcLu@;\0O|a\\	*@Of>P\n\0*Pd\n0\"KJjlD1`<	8Iwhyo\0rTh~\0f\0.(@c\0\0lk \n\n0\0T5'P1`@Ph>%\"\$sO#m\n5@LSe0l	\0'0g\0 H2ǢYEp\r\$#i+.H	U (.\0\nă1\0r\\άq20§\n/<hp<z\0x\0\ra	PdҼN]V	I_&-hK7Po l\0L8\02\0FA\0\n7L^\\[\0H@4[wf(a(3(\0\0h\03/f\0If|0 !\0001*QpL\0f7\0\nB\0h\0 \\\0\0-A^;u%\0㮾\nq\0Qej@\0@\0T\0L5<\rG+0T;\0@	\0q70\0T\0 /\082\0Dd`\r @Y\0M\n`x\0x\0004\0U(	\n@+\0/Q\0000\0dFlґr @9F\0l5@o\0j \0\0=l\09Fʸ	\0ڠ@\0x	\r\0\0&uB\08\0h`\r@\06\0%};@\06\0p\05[H7@R*DN4&Ũ\0\r\0k8p	\0R\0]Vľ\0X@\rFCg\0H U*\09p:M]\08уE\0h<\0	`'퀵t	\r\0@Ƨ0\rQ`{6P!\0e2\0Ilh\nS0M\088@@@)\0|d\0H\rm&n/(5O1\0q\0@m\0BZ7(\0{^\$c\r \r@m,0m1\$Ӱ\0\0` F4\r\0\0Li0\$˲@4\0[.p276P;\0jL	0\$zg\0l\\ (\0`Δ\0000v\0E~p`(0/#IB.ud8\r\0e|pPx<Q ذ`ǥ\0F\n@6,Z;@: }UzY^h#W]Y`(W+97\$!y!p\$ŘP!:QI\0n\0,	\0&\06af@R\\^Ȁb	54\0CTi\rSj@o`e\0`f\0!\0A&n\0f\0\0vc3rS\n'Т@@qJàL@`ENf(*Ġi\0U	e(;o`07s\0{3.\".\0MR9\030-M\0]\0X`*߀W)\0j7&ܕ) '&@\0UH\n7踸?\nc\"1\0y(i@\0/ЉRhtBIIQ\r!ز\r:	80Ѯ.mPiZv\\\rP0J\0607\0_Ȣzc /yJT.`0VNC `4@y\0:j|<\08n8UǺt:ƭbJu)#r)]Ch?7\",&r5&1%\0]\0W`Vg)tP`;uxd` @QDװ\0`u\0zȗ!I\0\0d\0s\0	i0\0џJH\n@B6\0004\0\0i@\n\0\0lXWk2Zu\0-@\ny*8`6Z[\0t\0(@	ۉ6\0`ޠ[\0E\0 \0\0Xp\0(\r\0t	`Hk  \r\09*s\0 f\0\0Տ0;\0R\0006@\0@\0007U?-\0|\$?\0\$\0Q2P7mu4T\0P\nw	@VG\0t`\r ʀ?\0@\0u\r'\0\0006@S\0\00068pyDպ.\0M`Q3\0|\0'9oYc&\0=C̀eo@ZhcؘHg\0LΐFe;,s(@3\0:m8\0i\06B0 @A\0d\003\0\0pBn >\0+O3e\0007'p\0@aXp	ujdPQ \0L\0\r\0	+\0\0\\@xEp\0h{Q@ԣD=P0\0\0e\0\0\$\0q&,x	@:@l\0rJ\"<i@ \0000Hf8U\0 @I\0Xt@!g\0002JRt )N\0\0:\$2(\0.ʗYt\\}9M\n\0Ye[rE\\`l\0DHõ\0@\0p0\0'\0E4\$P6\$jX\08JG@{Z\0O;\0000jzj	\0mY`7Z(p,v\0d\ry_p\r\0\0m\$:/nc\$X	4n6cs x9ŐBTYVj\r\0*\0ͱ_#@\n \rA\0:HEV\0kGP\0DQ8@A0`\0!\0(:.AX)C&g1 I\n~9K@\0s\0j\0F\09[(\$ݶs20	-Rr_,eqv\$P0\0007@YPN/UN  ,@,\0i\"@ @&;\0Jd\nWQxGϪ07>f>+]+SL1V|aÀ-t1b8Ā<CF%wpበ9_\08(H3>k(:'\0@_@2\0DV^xp!\0OL\$ Ϡ01-xx:.<&C	6x,wi`Q~\05\rP:\0f:ppY{z\0y\0ʍހ<ͼ=qƠH]t.`H\r+Ϡ٧Sҽg:nVw	NQ6\0\r\0	V\nu5C\0;@QHHK0H(`@qH(\n)\0.yhj[ S\0lHd	\0P	URl\0W\$\0\08X \"q\0v\0\0d͠)\0ZaXǮ\0`e',-5\00\0\0]\0@`;\0sdh\0RF\0 ANi\0;\0	L-fA\0x @\0E\0KtL=M{@x\0K\0p\0-4Cp;fr!q\0\0X\0#G@\0004Bh\0n\01\r/d\0p@r+\"`D`.HVh\0006+?5\0;\0\0OA\0ibpw}ZhxU06Kr\0\0 H!bE(\0c\0\0P@0FG6E]rh@72\0& 	-J\0Bm} 18@#zB8`L2\0{\0 `\rD`Y\0\00003AK*kXpE\0\"z{=r\0s@@U\0Bit\0+\0C28\0`.\0005R\0\0V\0<X\0d9D\07=t\068\0XPWɃ29\0}PNo@)@xw	%8+ *`C\0n`s'QOAW>Z&@:\0d  @32Bnqy1=\\G p%0p/\0\0`(\04!zhP68&C\0ld`\r851Ttds	۪,0lT71Q*|E71V2|A/:nz!eۢ7<%P@9D\0	6Op	&lA_\00*\0QcAUvן'	\r:m%D\0|\"˨J\0&B\\\00\nc\0*x/y8KjZ_j@\r5*޳!@<~0!\$oHc\$(\\\"\0l\0\0`\n\0S\0y\0\nю04]\0|ϼErQ:dUkXPD\n+#@|\nC-7q-Ua\0es\r!\0i\rt6\0j@xzds&`|;\0X 3w\02,\n\0{.?(hb\0/\$ڞ^Ju\n(6@_\0VRx .@vw&Te9l kb5j`\nZ҅a	A.t꩜sU\0D x)ԕ34;fidYLl~\0=ʀ)L31Y-ijVE<uZt8\0\0%\0T@T\0000\0Z\0NY0M\0\rwB)QP:\0,hx@#H+\\46^XZXH \0bZ\0#;` \r\0\0c0t?Z|[\0ER0;ھiL2\$\0ۉqg`-*\rX8\n\0]P&\0X\0`\n@a\0\0@r4f`6\0aotp`e\0004VK\0\"J\0\0d:@!@k1\0\02D >#T!\0,\0\0p\0H\n`%@D\000@̡4I \0t]\0\r,\0MyW2\0\0[1)\0\0&2p<vPxFQX\0001oB(p@0g\0xH8\0SɁ*@\"	\0f\0L`#@6D;@Bu0+ZC\0v  \0\0\0-\0\0C),8jW\0-Ν\0@p\06\r	i\0^\0E\0(p@4\0:ϐ@H_6\08og,\0h	:\0Hvn@\n0@,@a}(@u\0l \0zq\0\0D8 \n\$+*NqDSH9*F\0H(P \0Y\0vkj4饀GHHl\n@+@g\0X`\08T !\0o~5`^XH \0	<PbE\0##Fэ\0007\0\$h\nВwQ\0-.W\0	[T\0=>W݈\r	YjC\ncഖaEtXJ`0yt\0)\0\$L\0~\0(8p;<l``s\rG8q\\s?9r\\s-_9s\\s=:t\\sMΟG:u\\s]ο;v\\smߝ;w\\s}<x\\s\0\0");}
        private function printSvgDatabase($isReturn = false) {$svg = '<svg id="printSvgDatabase" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M10 6c3.9 0 7-.9 7-2s-3.1-2-7-2-7 .9-7 2 3.1 2 7 2zm0 9c-3.9 0-7-.9-7-2v3c0 1.1 3.1 2 7 2s7-.9 7-2v-3c0 1.1-3.1 2-7 2zm0-4c-3.9 0-7-.9-7-2v3c0 1.1 3.1 2 7 2s7-.9 7-2V9c0 1.1-3.1 2-7 2zm0-4c-3.9 0-7-.9-7-2v3c0 1.1 3.1 2 7 2s7-.9 7-2V5c0 1.1-3.1 2-7 2z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgMuplugin($isReturn = false) {$svg = '<svg id="printSvgMuplugin" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M13.6 5.1l-3.1 3.1 1.8 1.8 3.1-3.1c.3-.3.2-1-.3-1.5s-1.1-.6-1.5-.3zm.3-4.8c-.7-.4-9.8 7.3-9.8 7.3S.6 5.5.1 5.9c-.5.4 4 5 4 5S14.6.6 13.9.3zm5.5 9.3c-.5-.5-1.2-.6-1.5-.3l-3.1 3.1 1.8 1.8 3.1-3.2c.3-.2.2-.9-.3-1.4zm-11.7-1c-.7.7-1.1 2.7-1.1 3.8v3.8l-1.2 1.2c-.6.6-.6 1.5 0 2.1s1.5.6 2.1 0l1.2-1.2h3.8c1.2 0 3-.4 3.7-1.1l1.2-.8-8.9-8.9-.8 1.1z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgPlugin($isReturn = false) {$svg = '<svg id="printSvgPlugin" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M13.11 4.36L9.87 7.6 8 5.73l3.24-3.24c.35-.34 1.05-.2 1.56.32.52.51.66 1.21.31 1.55zm-8 1.77l.91-1.12 9.01 9.01-1.19.84c-.71.71-2.63 1.16-3.82 1.16H6.14L4.9 17.26c-.59.59-1.54.59-2.12 0-.59-.58-.59-1.53 0-2.12l1.24-1.24v-3.88c0-1.13.4-3.19 1.09-3.89zm7.26 3.97l3.24-3.24c.34-.35 1.04-.21 1.55.31.52.51.66 1.21.31 1.55l-3.24 3.25z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgTheme($isReturn = false) {$svg = '<svg id="printSvgTheme" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M2 2h5v11H2V2zm6 0h5v5H8V2zm6 0h4v16h-4V2zM8 8h5v5H8V8zm-6 6h11v4H2v-4z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgUpload($isReturn = false) {$svg = '<svg id="printSvgUpload" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M4 15v-3H2V2h12v3h2v3h2v10H6v-3H4zm7-12c-1.1 0-2 .9-2 2h4c0-1.1-.89-2-2-2zm-7 8V6H3v5h1zm7-3h4c0-1.1-.89-2-2-2-1.1 0-2 .9-2 2zm-5 6V9H5v5h1zm9-1c1.1 0 2-.89 2-2 0-1.1-.9-2-2-2s-2 .9-2 2c0 1.11.9 2 2 2zm2 4v-2c-5 0-5-3-10-3v5h10z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgWpcontent($isReturn = false) {$svg = '<svg id="printSvgWpcontent" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M18 12h-2.18c-.17.7-.44 1.35-.81 1.93l1.54 1.54-2.1 2.1-1.54-1.54c-.58.36-1.23.63-1.91.79V19H8v-2.18c-.68-.16-1.33-.43-1.91-.79l-1.54 1.54-2.12-2.12 1.54-1.54c-.36-.58-.63-1.23-.79-1.91H1V9.03h2.17c.16-.7.44-1.35.8-1.94L2.43 5.55l2.1-2.1 1.54 1.54c.58-.37 1.24-.64 1.93-.81V2h3v2.18c.68.16 1.33.43 1.91.79l1.54-1.54 2.12 2.12-1.54 1.54c.36.59.64 1.24.8 1.94H18V12zm-8.5 1.5c1.66 0 3-1.34 3-3s-1.34-3-3-3-3 1.34-3 3 1.34 3 3 3z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgInfoOutline($isReturn = false) {$svg = '<svg id="printSvgInfoOutline" class="svg-icon" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 20 20"><rect x="0" fill="none" width="20" height="20"/><g><path d="M9 15h2V9H9v6zm1-10c-.5 0-1 .5-1 1s.5 1 1 1 1-.5 1-1-.5-1-1-1zm0-4c-5 0-9 4-9 9s4 9 9 9 9-4 9-9-4-9-9-9zm0 16c-3.9 0-7-3.1-7-7s3.1-7 7-7 7 3.1 7 7-3.1 7-7 7z"/></g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgWpRoot($isReturn = false) {$svg = '<svg width="20px" height="20px" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg" stroke="#000000"><g id="SVGRepo_bgCarrier" stroke-width="0"></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round" stroke="#CCCCCC" stroke-width="0.096"></g><g id="SVGRepo_iconCarrier"> <path d="M13.2686 14.2686L15 16M12.0627 6.06274L11.9373 5.93726C11.5914 5.59135 11.4184 5.4184 11.2166 5.29472C11.0376 5.18506 10.8425 5.10425 10.6385 5.05526C10.4083 5 10.1637 5 9.67452 5H6.2C5.0799 5 4.51984 5 4.09202 5.21799C3.71569 5.40973 3.40973 5.71569 3.21799 6.09202C3 6.51984 3 7.07989 3 8.2V15.8C3 16.9201 3 17.4802 3.21799 17.908C3.40973 18.2843 3.71569 18.5903 4.09202 18.782C4.51984 19 5.07989 19 6.2 19H17.8C18.9201 19 19.4802 19 19.908 18.782C20.2843 18.5903 20.5903 18.2843 20.782 17.908C21 17.4802 21 16.9201 21 15.8V10.2C21 9.0799 21 8.51984 20.782 8.09202C20.5903 7.71569 20.2843 7.40973 19.908 7.21799C19.4802 7 18.9201 7 17.8 7H14.3255C13.8363 7 13.5917 7 13.3615 6.94474C13.1575 6.89575 12.9624 6.81494 12.7834 6.70528C12.5816 6.5816 12.4086 6.40865 12.0627 6.06274ZM14 12.5C14 13.8807 12.8807 15 11.5 15C10.1193 15 9 13.8807 9 12.5C9 11.1193 10.1193 10 11.5 10C12.8807 10 14 11.1193 14 12.5Z" stroke="#000000" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function printSvgUpdateAlt($isReturn = false) {$svg = '<svg id="printSvgUpdateAlt" class="svg-icon" xmlns="http://www.w3.org/2000/svg" width="1em" height="1em" viewBox="0 0 20 20"><path fill="currentColor" d="M5.7 9c.4-2 2.2-3.5 4.3-3.5c1.5 0 2.7.7 3.5 1.8l1.7-2C14 3.9 12.1 3 10 3C6.5 3 3.6 5.6 3.1 9H1l3.5 4L8 9zm9.8-2L12 11h2.3c-.5 2-2.2 3.5-4.3 3.5c-1.5 0-2.7-.7-3.5-1.8l-1.7 1.9C6 16.1 7.9 17 10 17c3.5 0 6.4-2.6 6.9-6H19z"/></svg>'; if ($isReturn) {return $svg;} echo $svg; }
        private function pageActivate() {
?>
<?php
$data = $this->useHandle->activate->getData(); ?>
<h2>Restorer Security</h2>
<p>
    Request activation for this site using the license key to use the WP Staging Restore
</p>
<button class="action" data-action="activate-license">Activate License</button>
<?php $this->useHandle->view->printProcessLoader();?>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageBackupContent() {
?>
<?php
$backupIndex = $this->meta->dataPost['backupIndex']; $data = $this->useHandle->backupListing->getBackupFiles($backupIndex); $metaData = (object)$this->useHandle->backupListing->readBackupMetaDataFile($data['metaFile']); $extractPath = $this->useHandle->extractor->getDefaultExtractPath(); $totalFiles = !empty($metaData->totalFiles) ? (int)$metaData->totalFiles : 0; $sortbyOption = $this->useHandle->view->partSelection($metaData); if (empty($metaData->databaseFile)) { $metaData->databaseFile = ''; } ?>
<div id="backup-extract">
    <ul class="breadcrumb">
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-action="page-main">Home</a></li>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="extract" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">Extract Backup</a></li>
        <li>View Backup</li>
        <?php if (!$data['isMultisite']) : ?>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="restore" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">Restore Backup</a></li>
        <?php endif;?>
    </ul>
    <h3>View Backup</h3>
    <div id="extract-info" class="info-block">
        <div>
            <label>Backup Name</label>
            <span><?php echo $this->kernel->escapeString(basename($metaData->name));?></span>
        </div>
        <div>
            <label>Backup File</label>
            <span><?php echo $this->kernel->escapeString(basename($data['path']));?></span>
        </div>
        <div>
            <label>Backup Size</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->sizeFormat($metaData->backupSize));?></span>
            <span> ( <?php echo $this->kernel->escapeString($totalFiles) . " " . ( $totalFiles > 1 ? "Files" : "File");?> )</span>
        </div>
        <div id="root-path">
            <label>Root Path</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->normalizePath($this->meta->rootPath));?></span>
        </div>
    </div>
    <div id="extract-block" class="action-block hide">
        <h3 id="extract-to-path">Extract to Directory Path</h3>
        <input type="text" name="extract-path" id="extract-path" value="<?php echo $this->kernel->escapeString($extractPath);?>" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
        <label for="extract-path-overwrite" class="checkbox">
            <input type="checkbox" id="extract-path-overwrite" name="extract-path-overwrite" value="1">
            <span>Overwrite directory
                <span data-tooltip="Check this option to completely remove the extract directory before the extraction process"><?php $this->useHandle->view->printSvgInfoOutline();?></span>
            </span>
        </label>
        <?php if ($metaData->isExportingDatabase) :?>
        <label id="normalize-db-file-block" for="normalize-db-file" class="checkbox">
            <input type="checkbox" id="normalize-db-file" name="normalize-db-file" value="1" checked>
            <span>
                Normalize database file
                <span data-tooltip="Check this option to normalize the Database file by replacing the WPSTG tag with actual data">
                    <?php $this->useHandle->view->printSvgInfoOutline();?>
                </span>
            </span>
        </label>
        <?php endif;?>
        <input type="hidden" name="backupfile-path" value="<?php echo $this->kernel->escapeString($data['path']);?>">
        <input type="hidden" name="total-files" value="<?php echo (int)$totalFiles;?>">
        <button class="action" data-action="extract">Extract</button>
        <button class="action-close" data-action="extract-block-close">Close</button>
        <button class="action-cancel hide" data-action="extract-cancel">Cancel</button>
        <button class="action-green hide" data-action="extract-retry">Retry</button>
        <?php $this->useHandle->view->printProcessLoader();?>
    </div>
    <div id="wpstg-restorer-console"></div>
    <div id="extract-list" class="action-block">
        <?php if ($totalFiles > 1) :?>
        <div id="paging">
            <div>
                <input type="text" id="index-filter" name="index-filter" value="" placeholder="filename">
                <button class="action" data-action="filter">Search</button>
                <button class="action-cancel hide" data-action="filter-reset">Reset</button>
            </div>
            <div>
                <?php if (!empty($sortbyOption)) :?>
                <select id="index-sortby" name="index-sortby" data-action="sortby">
                    <?php foreach ($sortbyOption as $sortbyId => $sortbyName) :?>
                    <option value="<?php echo $this->kernel->escapeString($sortbyId);?>"><?php echo $this->kernel->escapeString($sortbyName);?></option>
                    <?php endforeach;?>
                </select>
                <?php endif;?>
                <button class="action" data-action="paging-prev" data-value="1" disabled>Prev</button>
                <button class="action" data-action="paging-next" data-value="1">Next</button>
                <input type="hidden" id="index-total" name="index-total" value="<?php echo (int)$totalFiles;?>">
                <input type="hidden" id="index-page-total" name="index-page-total" value="0">
            </div>
        </div>
        <div id="paging-bottom">
            <div class="left"></div>
            <div class="right"></div>
        </div>
        <?php endif;?>
        <div id="paging-table">
            <table>
                <thead>
                    <tr>
                        <th><input type="checkbox" value=""></th>
                        <th>File</th>
                        <th>Size</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
$pagingData = ''; foreach ($this->useHandle->view->backupPaging($data['path'], $metaData->databaseFile, $pagingData) as $data) : $hasSqlFile = !empty($data[4]) ? " data-is-sqlfile=1" : ""; ?>
                    <tr>
                        <td>
                            <input type="checkbox" name="item[]" value="<?php echo (int)$data[2];?>" <?php echo $this->kernel->escapeString($hasSqlFile);?>>
                        </td>
                        <td>
                            <p title="<?php echo $this->kernel->escapeString($data[1]);?>"><?php echo $this->kernel->escapeString($data[1]);?></p>
                        </td>
                        <td>
                            <p title="<?php echo $this->kernel->sizeFormat($data[3]);?>"><?php echo $this->kernel->sizeFormat($data[3]);?></p>
                        </td>
                    </tr>
                    <?php endforeach;?>
                </tbody>
            </table>
            <?php
if (is_object($pagingData)) { $code = '<script id="paging-data" type="application/json">'; $code .= json_encode($pagingData); $code .= '</script>'; echo $code; } ?>
        </div>
    </div>
</div>
<?php }
        private function pageBackupExtract() {
?>
<?php
$backupIndex = $this->meta->dataPost['backupIndex']; $data = $this->useHandle->backupListing->getBackupFiles($backupIndex); $metaData = (object)$this->useHandle->backupListing->readBackupMetaDataFile($data['metaFile']); $extractPath = $this->useHandle->extractor->getDefaultExtractPath(); $totalFiles = !empty($metaData->totalFiles) ? $metaData->totalFiles : 0; $sortbyOption = $this->useHandle->view->partSelection($metaData); if (empty($metaData->databaseFile)) { $metaData->databaseFile = ''; } $extractData = [ 'total-files' => $totalFiles, 'backupfile-path' => $data['path'], 'dbfile-path' => $metaData->databaseFile ]; ?>
<div id="backup-extract">
    <ul class="breadcrumb">
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-action="page-main">Home</a></li>
        <li>Extract Backup</li>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="content" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">View Backup</a></li>
        <?php if (!$data['isMultisite']) : ?>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="restore" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">Restore Backup</a></li>
        <?php endif;?>
    </ul>
    <h3>Extract Backup</h3>
    <div class="info-block">
        <div>
            <label>Backup Name</label>
            <span><?php echo $this->kernel->escapeString(basename($metaData->name));?></span>
        </div>
        <div>
            <label>Backup File</label>
            <span><?php echo $this->kernel->escapeString(basename($data['path']));?></span>
            <?php foreach ($extractData as $key => $value) :?>
            <input type="hidden" name="<?php echo $this->kernel->escapeString($key);?>" id="<?php echo $this->kernel->escapeString($key);?>" value="<?php echo $this->kernel->escapeString($value);?>">
            <?php endforeach;?>
        </div>
        <div>
            <label>Backup Size</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->sizeFormat($metaData->backupSize));?></span>
            <span> ( <?php echo $this->kernel->escapeString($totalFiles) . " " . ( $totalFiles > 1 ? "Files" : "File");?> )</span>
        </div>
        <div>
            <label>Root Path</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->normalizePath($this->meta->rootPath));?></span>
        </div>
    </div>
    <div class="action-block">
        <h3>Extract to Directory Path</h3>
        <div id="action-option">
            <?php if (!empty($sortbyOption)) :?>
            <select id="index-sortby" name="index-sortby">
                <?php foreach ($sortbyOption as $sortbyId => $sortbyName) :?>
                <option value="<?php echo $this->kernel->escapeString($sortbyId);?>"><?php echo $this->kernel->escapeString($sortbyName);?></option>
                <?php endforeach;?>
            </select>
            <?php endif;?>
            <input type="text" name="extract-path" id="extract-path" value="<?php echo $this->kernel->escapeString($extractPath);?>" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
        </div>
        <label for="extract-path-overwrite" class="checkbox">
            <input type="checkbox" id="extract-path-overwrite" name="extract-path-overwrite" value="1">
            <span>
                Overwrite directory
                <span data-tooltip="Check this option to completely remove the extract directory before the extraction process">
                    <?php $this->useHandle->view->printSvgInfoOutline();?>
                </span>
            </span>
        </label>
        <?php if ($metaData->isExportingDatabase) :?>
        <label id="normalize-db-file-block" for="normalize-db-file" class="checkbox">
            <input type="checkbox" id="normalize-db-file" name="normalize-db-file" value="1" checked>
            <span>
                Normalize database file
                <span data-tooltip="Check this option to normalize the Database file by replacing the WPSTG tag with actual data">
                    <?php $this->useHandle->view->printSvgInfoOutline();?>
                </span>
            </span>
        </label>
        <?php endif;?>
        <button class="action" data-action="extract">Extract</button>
        <button class="action-close" data-action="page-main">Close</button>
        <button class="action-cancel hide" data-action="extract-cancel">Cancel</button>
        <button class="action-green hide" data-action="extract-retry">Retry</button>
        <?php $this->useHandle->view->printProcessLoader();?>
    </div>
</div>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageBackupList() {
?>
<h2 class="backup-list-header">
    Available Backups <span data-tooltip="Rescan available backups" data-action="reload-backup-list"><?php $this->useHandle->view->printSvgUpdateAlt();?></span>
</h2>
<?php
$listBackup = $this->useHandle->backupListing->getBackupFiles(); if (empty($listBackup)) : ?>
<p>No backup available</p>
    <?php
endif; foreach ($listBackup as $fileIndex => $arrData) : if (!$arrData['isValid']) { continue; } $metaData = (object)$this->useHandle->backupListing->readBackupMetaDataFile($arrData['metaFile']); if (!isset($metaData->id)) { continue; } $backupTypeTitle = !empty($arrData['isMultisite']) ? 'Multi Site' : 'Single Site'; if (!empty($arrData['backupType'])) { switch ($arrData['backupType']) { case 'multi': $backupTypeTitle = 'Entire Network'; break; case 'main-network-site': $backupTypeTitle = 'Main Network Site'; break; case 'network-subsite': $backupTypeTitle = 'Network Subsite'; break; case 'single': $backupTypeTitle = 'Single Site'; break; default: $backupTypeTitle = 'Unknown Backup Type'; } } ?>
<div class="backuplist" data-backup-id="<?php echo $this->kernel->escapeString($metaData->id);?>">
    <main>
        <div>
            <label>Name</label>
            <span class="name" title="<?php echo $this->kernel->escapeString(basename($arrData['path']));?>">
                <?php echo $this->kernel->escapeString($metaData->name);?>
            </span>
        </div>
        <div>
            <label>Type</label>
            <span>
                <?php echo $this->kernel->escapeString($backupTypeTitle);?>
            </span>
        </div>
        <div>
            <label>Created On</label>
            <span>
                <?php
$dateCreated = (new \DateTime())->setTimestamp($metaData->dateCreated); echo $this->kernel->escapeString($this->kernel->setDateTime($dateCreated)); ?>
            </span>
        </div>
        <div>
            <label>Backup Version</label>
            <span>
                <?php
echo $this->kernel->escapeString($metaData->backupVersion); ?>
            </span>
        </div>
        <div>
            <label>Size</label>
            <span>
                <?php echo $this->kernel->escapeString($this->kernel->sizeFormat($metaData->backupSize));?>
            </span>
        </div>
        <div>
            <label>Contains</label>
            <span class="backup-list-tooltip">
                <?php $this->useHandle->view->printBackupListingContains($metaData); ?>
            </span>
        </div>
    </main>
    <aside>
        <div>
            <button class="action" data-page="extract" data-index="<?php echo $this->kernel->escapeString($fileIndex);?>">Extract Backup</button>
            <?php if ($arrData['isMultisite']) : ?>
            <button class="action-disabled" data-tooltip="The restorer does not support Restore for Multisite backups">Restore Backup</button>
            <?php else : ?>
            <button class="action" data-page="restore" data-index="<?php echo $this->kernel->escapeString($fileIndex);?>">Restore Backup</button>
            <?php endif; ?>
        </div>
    </aside>
</div>
<?php endforeach;?>
<?php }
        private function pageBackupRestore() {
?>
<?php
$backupIndex = $this->meta->dataPost['backupIndex']; $data = $this->useHandle->backupListing->getBackupFiles($backupIndex); $metaData = (object)$this->useHandle->backupListing->readBackupMetaDataFile($data['metaFile']); if ($this->useHandle->wpcore->isWpMultisite() || $data['isMultisite']) { $this->kernel->addBootupError('wpmultiste', 'The restorer does not yet support restoring backups for WordPress Multisites.'); $this->useHandle->view->render('page-bootup-error'); return; } if (empty($metaData->databaseFile)) { $metaData->databaseFile = ''; } $extractPath = $this->useHandle->extractor->getDefaultExtractPath(); $totalFiles = !empty($metaData->totalFiles) ? (int)$metaData->totalFiles : 0; $wpcoreConfig = (object)$this->useHandle->wpcore->getConfig(); $wpBakeryActive = !empty($metaData->wpBakeryActive) ? 1 : 0; $hasExportParts = count(array_filter([ $metaData->isExportingPlugins, $metaData->isExportingMuPlugins, $metaData->isExportingThemes, $metaData->isExportingUploads, $metaData->isExportingOtherWpContentFiles, $metaData->isExportingDatabase, ])); $restoreData = [ 'total-files' => $totalFiles, 'wp-version' => $metaData->wpVersion, 'backupfile-path' => $data['path'], 'sqlfile-path' => $metaData->databaseFile, 'searchreplace-backupsiteurl' => $metaData->siteUrl, 'searchreplace-backuphomeurl' => $metaData->homeUrl, 'searchreplace-backupwpbakeryactive' => (int)$wpBakeryActive, 'searchreplace-siteurl' => $wpcoreConfig->siteurl, 'searchreplace-homeurl' => $wpcoreConfig->homeurl, ]; $restoreList = $this->useHandle->view->partRestoreList($metaData, $wpcoreConfig); ?>
<div id="backup-extract">
    <ul class="breadcrumb">
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-action="page-main">Home</a></li>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="extract" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">Extract Backup</a></li>
        <li><a href="<?php $this->useHandle->view->printAppFile();?>" data-page="content" data-index="<?php echo $this->kernel->escapeString($backupIndex);?>">View Backup</a></li>
        <li>Restore Backup</li>
    </ul>
    <h3>Restore Backup</h3>
    <div class="info-block">
        <div>
            <label>Backup Name</label>
            <span><?php echo $this->kernel->escapeString(basename($metaData->name));?></span>
        </div>
        <div>
            <label>Backup File</label>
            <span><?php echo $this->kernel->escapeString(basename($data['path']));?></span>
            <?php foreach ($restoreData as $key => $value) :?>
            <input type="hidden" name="<?php echo $this->kernel->escapeString($key);?>" id="<?php echo $this->kernel->escapeString($key);?>" value="<?php echo $this->kernel->escapeString($value);?>">
            <?php endforeach;?>
        </div>
        <div>
            <label>Backup Size</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->sizeFormat($metaData->backupSize));?></span>
            <span> ( <?php echo $this->kernel->escapeString($totalFiles) . " " . ( $totalFiles > 1 ? "Files" : "File");?> )</span>
        </div>
        <div>
            <label>Root Path</label>
            <span><?php echo $this->kernel->escapeString($this->kernel->normalizePath($this->meta->rootPath));?></span>
        </div>
    </div>
    <div class="action-block">
        <?php if ($hasExportParts) : ?>
        <h3>Available Contents</h3>
        <div id="restore-table">
            <table>
                <thead>
                    <tr>
                        <th>Parts</th>
                        <th>Path</th>
                        <th>Restore</th>
                        <th>Overwrite</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($restoreList as $type => $data) : if (!$data['status']) : continue; endif; if (!empty($metaData->indexPartSize) && !$data['hasIndexPartSize']) : continue; endif; if (in_array($data['name'], ['lang', 'dropins']) && !$data['hasIndexPartSize']) : ?>
                    <tr class="hide">
                        <?php else : ?>
                    <tr>
                        <?php endif; ?>
                        <td>
                            <p title="<?php echo $this->kernel->escapeString($type);?>"><?php echo $this->kernel->escapeString($type);?></p>
                        </td>
                        <td>
                            <p title="<?php echo $this->kernel->escapeString($data['path']);?>"><?php echo $this->kernel->escapeString($this->kernel->normalizePath($data['path']));?></p>
                        </td>
                        <td>
                            <?php if ($data['restore'] === 1) : ?>
                            <input type="checkbox" name="restore-<?php echo $this->kernel->escapeString($data['name']);?>" value="1" checked>
                            <?php elseif ($data['overwrite'] === 2) : ?>
                            <input type="checkbox" name="restore-bydefault-<?php echo $this->kernel->escapeString($data['name']);?>" value="1" checked disabled>
                            <?php elseif ($data['overwrite'] === 3) : ?>
                            <input type="checkbox" name="restore-bydefault-<?php echo $this->kernel->escapeString($data['name']);?>" value="0" disabled>
                            <?php else : ?>
                            <input type="checkbox" name="restore-<?php echo $this->kernel->escapeString($data['name']);?>" value="1">
                            <?php endif;?>
                        </td>
                        <td>
                            <?php if ($data['overwrite'] === 1) : ?>
                            <input type="checkbox" name="overwrite-<?php echo $this->kernel->escapeString($data['name']);?>" value="1" checked>
                            <?php elseif ($data['overwrite'] === 2) : ?>
                            <input type="checkbox" name="overwrite-bydefault-<?php echo $this->kernel->escapeString($data['name']);?>"" value=" 1" checked disabled>
                            <?php elseif ($data['overwrite'] === 3) : ?>
                            <input type="checkbox" name="overwrite-bydefault-<?php echo $this->kernel->escapeString($data['name']);?>" value="0" disabled>
                            <?php else : ?>
                            <input type="checkbox" name="overwrite-<?php echo $this->kernel->escapeString($data['name']);?>" value="1">
                            <?php endif;?>
                        </td>
                    </tr>
                    <?php endforeach;?>
                </tbody>
            </table>
        </div>
        <button class="action" data-action="restore">Restore</button>
        <button class="action-close" data-action="page-main">Close</button>
        <button class="action-cancel hide" data-action="restore-cancel">Cancel</button>
        <button class="action-green hide" data-action="restore-retry">Retry</button>
            <?php $this->useHandle->view->printProcessLoader();?>
        <?php else : ?>
        <p>No contents available to restore</p>
        <div class="action-block">
            <button class="action-close" data-action="page-main">Close</button>
        </div>
        <?php endif; ?>
    </div>
</div>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageBootupError() {
?>
<h2>Restorer Error</h2>
<p>
    WP Staging Restore could not continue for a reason:
</p>
<ul>
    <?php foreach ($this->kernel->getBootupError() as $id => $text) :?>
    <li><?php echo $this->kernel->escapeString($text); ?></li>
    <?php endforeach;?>
</ul>
<button class="action" data-action="page-main">Reload Page</button>
<?php }
        private function pageHash() {
?>
<script id="wpstg-restorer-page"></script>
<?php }
        private function pageLogin() {
?>
<h2>Restorer Security</h2>
<p>
    Please enter the backup file name or a valid license key.
</p>
<input class="action" type="text" name="backupfile" id="backupfile" value="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false" autofocus>
<button class="action" data-action="verify-backup-filename">Verify</button>
<?php $this->useHandle->view->printProcessLoader();?>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageLogout() {
?>
<h2>Restorer Security</h2>
<p>
    WP Staging Restore session will terminate
</p>
<div id="logout" class="action-block">
    <label class="checkbox">
        <input type="checkbox" name="remove-app-file" id="remove-app-file" value="1">
        <span>
            Remove wpstg-restore.php
            <span data-tooltip="Check this option to remove the wpstg-restore.php file">
                <?php $this->useHandle->view->printSvgInfoOutline();?>
            </span>
        </span>
    </label>
</div>
<button class="action" data-action="access-terminate">Logout</button>
<button class="action-close" data-action="page-main">Cancel</button>
<?php }
        private function pageMain() {
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="robots" content="noindex, nofollow">
    <meta name="access-token" content="<?php echo $this->useHandle->access->getInitialToken();?>">
    <meta name="app-file" content="<?php $this->useHandle->view->printAppFile();?>">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php $this->useHandle->view->printAssets('favicon-png32');?>">
    <link rel="shortcut icon" type="image/png" sizes="32x32" href="<?php $this->useHandle->view->printAssets('favicon-ico');?>">
    <title>WP Staging | Restore v<?php $this->useHandle->view->printVersion();?></title>
    <link rel="stylesheet" type="text/css" media="all" href="<?php $this->useHandle->view->printAssets('css');?>">
    <script type="text/javascript" src="<?php $this->useHandle->view->printAssets('js');?>"></script>
</head>
<body>
    <div id="wpstg-restorer">
        <?php
$activateIsActive = $this->useHandle->activate->isActive(); $accesshasSession = $this->useHandle->access->hasSession(); ?>
        <header>
            <div class="header-left">
                <img src="<?php $this->useHandle->view->printAssets('logo');?>">
            </div>
            <div class="header-right">
                <table>
                    <tr>
                        <td>
                            <span class="app-name">Restore</span>
                            <span class="app-version">v<?php $this->useHandle->view->printVersion();?></span>
                            <?php if ($activateIsActive && $accesshasSession) :?>
                            <span class="app-license-type"><?php $this->useHandle->view->printLicenseType();?></span>
                            <?php endif;?>
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <?php if ($activateIsActive && $accesshasSession) :?>
                            <span class="app-license-owner">
                                Licensed to: <?php $this->useHandle->view->printLicenseOwner();?>
                            </span>
                            <?php endif;?>
                        </td>
                    </tr>
                </table>
                <?php if ($accesshasSession) :?>
                <span class="app-logout">
                    <a href="<?php $this->useHandle->view->printAppFile();?>" data-action="page-logout">Logout</a>
                </span>
                <?php endif;?>
            </div>
        </header>
        <div class="content">
            <?php
if (!empty($this->kernel->getBootupError())) { $this->useHandle->view->render('page-bootup-error'); } elseif (!$accesshasSession) { $this->useHandle->view->render('page-login'); } elseif (!$activateIsActive) { $this->useHandle->view->render('page-activate'); } elseif (!$this->useHandle->wpcore->isAvailable()) { $this->useHandle->view->render('page-wpcore-install'); } elseif (!$this->useHandle->wpcore->isReady()) { if (!$this->useHandle->wpcore->isDbConnect()['success']) { $this->useHandle->wpcore->resetDbConfig(); $this->useHandle->view->render('page-wpcore-setup-db'); } elseif (!$this->useHandle->wpcore->isDbInstalled()) { $this->useHandle->view->render('page-wpcore-setup-site'); } else { $this->useHandle->view->render('page-wpcore-setup-complete'); } } else { $this->useHandle->view->render('page-hash'); }?>
        </div>
    </div>
</body>
</html>
<?php }
        private function pageWpcoreInstall() {
?>
<h2>Install WordPress</h2>
<p>
    The WordPress Core is not installed.
</p>
<div id="wpcore" class="form-block">
    <div>
        <label>WordPress Version</label>
        <select id="wpversion" name="wpversion">
            <option value="latest">Latest</option>
            <?php foreach ($this->getWpVersion() as $id => $wpVersion) : ?>
            <option value="<?php echo $this->kernel->escapeString($wpVersion);?>"><?php echo $this->kernel->escapeString($wpVersion);?></option>
            <?php endforeach; ?>
        </select>
    </div>
</div>
<button class="action" data-action="wpcore-install">Install WordPress Core</button>
<?php $this->useHandle->view->printProcessLoader();?>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageWpcoreSetupComplete() {
?>
<h2>Install WordPress</h2>
<p>
    WP Staging Restore detects your site has a Database installed. No further action is required.
</p>
<p>
    Click the Finish button to complete the WordPress installation.
</p>
<button class="action" data-action="wpcore-setup-complete">Finish</button>
<?php $this->useHandle->view->printProcessLoader();?>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageWpcoreSetupDb() {
?>
<?php
$wpPrefix = $this->useHandle->cache->get('wpprefix', 'setup'); $wpPrefix = !empty($wpPrefix) ? $wpPrefix : ''; ?>
<h2>Database Settings</h2>
<div id="dbconfig" class="form-block">
    <div>
        <label>Database Server</label>
        <input type="text" name="dbhost" id="dbhost" value="localhost" placeholder="localhost" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false" autofocus>
    </div>
    <div>
        <label>Database Name</label>
        <input type="text" name="dbname" id="dbname" value="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Database User</label>
        <input type="text" name="dbuser" id="dbuser" value="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Database Password</label>
        <input type="password" name="dbpass" id="dbpass" value="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Table Prefix</label>
        <input type="text" name="dbprefix" id="dbprefix" value="<?php echo $this->kernel->escapeString($wpPrefix);?>" placeholder="wp_" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Custom Port</label>
        <input type="text" name="dbport" id="dbport" value="" placeholder="" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Enable SSL</label>
        <input type="checkbox" name="dbssl" id="dbssl" value="1"> <span>Disable this option if not supported by the database</span>
    </div>
</div>
<button class="action" data-action="wpcore-setup-db">Submit</button>
<?php $this->useHandle->view->printProcessLoader();?>
<div id="wpstg-restorer-console"></div>
<?php }
        private function pageWpcoreSetupSite() {
?>
<h2>Install WordPress</h2>
<p>
    Click submit to complete the WordPress installation.
</p>
<div id="siteconfig" class="form-block">
    <ul>
        <li>If you restore a backup file in the next step, the login credentials you enter here will be overwritten by those from the backup.</li>
        <li>If you don't restore a backup, you can log in to WordPress using the credentials provided below.</li>
    </ul>
    <div>
        <label>Site Title</label>
        <input type="text" name="sitetitle" id="sitetitle" value="WP Staging | Restore" placeholder="Site Title" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false" autofocus>
    </div>
    <div>
        <label>Admin Username</label>
        <input type="text" name="siteuser" id="siteuser" value="wpstg-restore" placeholder="Enter Admin User" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Admin Email</label>
        <input type="email" name="siteemail" id="siteemail" value="" placeholder="Enter Admin Email Address" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
    <div>
        <label>Admin Password</label>
        <input type="password" name="sitepass" id="sitepass" value="" placeholder="Enter Admin Password" autocomplete="off" autocorrect="off" autocapitalize="off" spellcheck="false">
    </div>
</div>
<button class="action" data-action="wpcore-setup-site">Submit</button>
<?php $this->useHandle->view->printProcessLoader();?>
<button class="action-green hide" data-action="page-main">Continue</button>
<div id="wpstg-restorer-console"></div>
<?php }
    }
    final class WpCore { private $kernel; private $meta; private $useHandle; private $taskFile; private $dbConfigFile; private $wpConfigFile; private $downloadUrl; private $maintenanceFile; const WPCORE_INSTALL_FAILURE = 0; const WPCORE_INSTALL_SUCCESS = 1; const WPCORE_INSTALL_DONE = 2; const IS_STAGING_KEY = 'wpstg_is_staging_site'; const STAGING_FILE = '.wp-staging'; public function __construct(\WPStagingRestorer $kernel) { $this->kernel = $kernel; $this->meta = $this->kernel->getMeta(); $this->useHandle = $this->kernel->getHandle(__CLASS__, ['file', 'cache']); $this->taskFile = $this->meta->tmpPath . '/wpstg-task-wpcore.php'; $this->dbConfigFile = $this->meta->tmpPath . '/wpstg-dbconfig.php'; $this->wpConfigFile = $this->locateWpConfigFile(); $this->downloadUrl = 'https://wordpress.org'; $this->maintenanceFile = $this->meta->rootPath . '/.maintenance'; } private function loadLibrary(): bool { static $isLoaded = false; if ($isLoaded) { return true; } if (!$this->isAvailable()) { return false; } if (!$this->isReady()) { return false; } $isMaintenance = $this->isMaintenance(); if ($isMaintenance) { $this->enableMaintenance(false); } try { define('SHORTINIT', true); require_once __DIR__ . '/wp-load.php'; wp_plugin_directory_constants(); require_once ABSPATH . WPINC . '/class-wp-textdomain-registry.php'; if (!isset($GLOBALS['wp_textdomain_registry']) || !($GLOBALS['wp_textdomain_registry'] instanceof \WP_Textdomain_Registry)) { $GLOBALS['wp_textdomain_registry'] = new \WP_Textdomain_Registry(); } foreach ( [ 'l10n.php', 'class-wp-user.php', 'class-wp-roles.php', 'class-wp-role.php', 'class-wp-session-tokens.php', 'class-wp-user-meta-session-tokens.php', 'http.php', 'formatting.php', 'capabilities.php', 'user.php', 'link-template.php' ] as $file ) { require_once ABSPATH . WPINC . '/' . $file; } wp_cookie_constants(); foreach ( [ 'vars.php', 'kses.php', 'cron.php', 'rest-api.php', 'pluggable.php', 'theme.php' ] as $file ) { require_once ABSPATH . WPINC . '/' . $file; } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return false; } if ($isMaintenance) { $this->enableMaintenance(true); } $isLoaded = true; return true; } public function maybeUpgradeDatabase(): bool { if (!$this->loadLibrary()) { return false; } try { if (file_exists(trailingslashit(ABSPATH) . 'wp-admin/includes/upgrade.php')) { global $wpdb, $wp_db_version, $wp_current_db_version; wp_templating_constants(); require_once ABSPATH . WPINC . '/class-wp-theme.php'; require_once ABSPATH . WPINC . '/class-wp-walker.php'; require_once ABSPATH . 'wp-admin/includes/upgrade.php'; $wp_current_db_version = (int)__get_option('db_version'); if (!empty($wp_current_db_version) && !empty($wp_db_version) && $wp_db_version !== $wp_current_db_version) { $wpdb->suppress_errors(); wp_upgrade(); $this->kernel->log(sprintf('WordPress database upgraded successfully. Old version: %s, New version: %s', $wp_current_db_version, $wp_db_version), __METHOD__); return true; } } else { $this->kernel->log('Could not upgrade WordPress database version as the wp-admin/includes/upgrade.php file does not exist', __METHOD__); } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); } return false; } public function getDirectoryAdapter(): Directory { $directory = new Directory($this); return $directory; } public function getDatabaseAdapter(): DatabaseAdapter { $database = new DatabaseAdapter($this); return $database; } public function getSearchReplacer(): SearchReplacer { $searchReplacer = new SearchReplacer($this->kernel, $this, $this->kernel->makeInstance(SubsitesSearchReplacer::class)); return $searchReplacer; } public function maybeRemoveStagingStatus(): bool { if (!$this->loadLibrary()) { return false; } if (defined('WPSTAGING_DEV_SITE') && (bool)constant('WPSTAGING_DEV_SITE') === true) { return false; } if (file_exists(ABSPATH . self::STAGING_FILE)) { return false; } if (get_option(self::IS_STAGING_KEY) === "true") { return delete_option(self::IS_STAGING_KEY); } return false; } public function flushObjectCache(): bool { if (!$this->loadLibrary()) { return false; } $dropInFile = wp_normalize_path(WP_CONTENT_DIR) . '/object-cache.php'; clearstatcache(true, $dropInFile); if (!file_exists($dropInFile) || !function_exists('wp_cache_flush')) { return true; } try { wp_cache_flush(); } catch (\Throwable $e) { $this->kernel->log('Failed to flush object cache', __METHOD__); $this->kernel->log($e, __METHOD__); return false; } return true; } public function getConfig(bool $force = false) { $data = $this->useHandle->cache->get('wpcoreconfig', 'config'); if (!$force && $data !== null) { return $data; } return $this->saveConfig(); } public function getBackupPath(): string { $backupPath = $this->meta->backupPath; $config = $this->getConfig(false); if (empty($config) || empty($config['uploads'])) { return $backupPath; } $uploadPath = $config['uploads']; if ($uploadPath !== $this->meta->uploadPath) { $backupPath = $uploadPath . '/' . $this->meta->backupDir; $this->kernel->log($backupPath); } return $backupPath; } public function saveConfig() { if (!$this->loadLibrary()) { return false; } list( $host, $port, $socket, $isIPv6 ) = $this->parseDbHost(DB_HOST); $siteUrl = get_option('siteurl'); $homeUrl = get_option('home'); $guessUrl = wp_guess_url(); if ($guessUrl !== $siteUrl) { $siteUrl = $guessUrl; $homeUrl = $guessUrl; } $uploads = wp_upload_dir(null, false, false); $keys = [ 'abspath' => ABSPATH, 'uploads' => wp_normalize_path($uploads['basedir']), 'plugins' => wp_normalize_path(WP_PLUGIN_DIR), 'muplugins' => wp_normalize_path(WPMU_PLUGIN_DIR), 'themes' => wp_normalize_path(get_theme_root(get_template())), 'wpcontent' => wp_normalize_path(WP_CONTENT_DIR), 'lang' => wp_normalize_path(WP_LANG_DIR), 'dbname' => DB_NAME, 'dbuser' => DB_USER, 'dbpass' => DB_PASSWORD, 'dbhost' => $host, 'dbport' => $port, 'dbssl' => defined('MYSQL_CLIENT_FLAGS') ? 1 : 0, 'dbprefix' => isset($GLOBALS['table_prefix']) ? $GLOBALS['table_prefix'] : 'wp_', 'dbcharset' => DB_CHARSET, 'dbcollate' => DB_COLLATE, 'siteurl' => $siteUrl, 'homeurl' => $homeUrl, 'uploadurl' => $uploads['baseurl'], 'multisite' => defined('WP_ALLOW_MULTISITE') && constant('WP_ALLOW_MULTISITE') && defined('MULTISITE') && constant('MULTISITE') ? 1 : 0 ]; if ($this->useHandle->cache->put('wpcoreconfig', $keys, 'config')) { return $keys; } return false; } public function isMaintenance(): bool { clearstatcache(); return file_exists($this->maintenanceFile); } public function enableMaintenance(bool $isMaintenance): bool { if ($isMaintenance && !$this->isMaintenance()) { file_put_contents($this->maintenanceFile, '<?php $upgrading = time() ?>', LOCK_EX); $this->kernel->chmod($this->maintenanceFile, false, __LINE__); return true; } if (!$isMaintenance && $this->isMaintenance()) { $this->kernel->unlink($this->maintenanceFile, __LINE__); return true; } return false; } public function isAvailable(): bool { clearstatcache(); return file_exists($this->meta->rootPath . '/wp-load.php') && file_exists($this->meta->rootPath . '/wp-blog-header.php') && file_exists($this->meta->rootPath . '/wp-settings.php') && file_exists($this->meta->rootPath . '/wp-includes/load.php') && file_exists($this->meta->rootPath . '/wp-admin/admin.php') && is_dir($this->meta->rootPath . '/wp-content'); } public function isReady(): bool { if (!file_exists($this->wpConfigFile)) { return false; } if (!$this->isWpIndex()) { return false; } return true; } public function isWpIndex(): bool { $wpIndex = $this->meta->rootPath . '/index.php'; if (!file_exists($wpIndex)) { return false; } $content = file_get_contents($wpIndex, false, null, 0, 8 * 1024); if (empty($content) || strpos($content, '/wp-blog-header.php') === false) { return false; } $wpIndexSetup = $this->meta->rootPath . '/index-wp.php'; if (file_exists($wpIndexSetup)) { $this->kernel->unlink($wpIndexSetup, __LINE__); } return true; } public function isWpMultisite(): bool { if (!file_exists($this->wpConfigFile)) { return false; } $content = file_get_contents($this->wpConfigFile, false, null, 0, 8 * 1024); if (empty($content)) { return false; } if (!preg_match('@define\(\s+(\'|")WP_ALLOW_MULTISITE(\'|"),\s+(true|1)\s+\)\;@', $content) && !preg_match('@define\(\s+(\'|")MULTISITE(\'|"),\s+(true|1)\s+\)\;@', $content)) { return false; } return true; } private function setTaskStatus($status, $text, $callback = false): bool { $data = $this->getTaskStatus(); if (empty($data) || !is_array($data)) { $data[0] = [ 'status' => $status, 'text' => $text, 'callback' => $callback, ]; } else { $lastData = !empty($data[0]) && count($data) > 0 ? $data[count($data) - 1] : $data; if ($lastData['status'] !== self::WPCORE_INSTALL_DONE) { $data[] = [ 'status' => $status, 'text' => $text, 'callback' => $callback, ]; } } $this->kernel->log($text, __METHOD__); return $this->useHandle->cache->put('wpcoretask', $data); } public function getTaskStatus(): array { $data = $this->useHandle->cache->get('wpcoretask'); return is_array($data) ? $data : []; } public function resetTaskStatus(): bool { return $this->useHandle->cache->remove('wpcoretask'); } private function tempName(string $input): string { return substr(md5($input), 0, 12); } public function downloadStatus(string $savePath): int { $fileName = $this->tempName(basename($savePath)) . '.txt'; $filePath = $this->meta->tmpPath . '/download-status-' . $fileName; if (!file_exists($filePath)) { return 0; } $data = file_get_contents($filePath); if (empty($data)) { return 0; } $data = strtok($data, '|'); return (int)$data; } private function downloadFile(string $fileUrl, string $savePath, bool $refresh = false): bool { if ($refresh && file_exists($savePath)) { unlink($savePath); } $saveName = basename($savePath); $this->setTaskStatus(self::WPCORE_INSTALL_SUCCESS, sprintf('Downloading %s as %s', $fileUrl, $saveName), ['downloadStatus', $savePath]); if (!($fileHandle = fopen($savePath, 'wb'))) { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to create %s', $saveName)); return false; } $curlHandle = curl_init($fileUrl); $fileName = $this->tempName($saveName) . '.txt'; curl_setopt_array($curlHandle, [ CURLOPT_USERAGENT => $this->kernel->userAgent(), CURLOPT_SSL_VERIFYHOST => 0, CURLOPT_SSL_VERIFYPEER => 0, CURLOPT_HEADER => false, CURLOPT_FOLLOWLOCATION => true, CURLOPT_BINARYTRANSFER => true, CURLOPT_NOPROGRESS => false, CURLOPT_FORBID_REUSE => true, CURLOPT_FRESH_CONNECT => true, CURLOPT_TIMEOUT => 180, CURLOPT_FILE => $fileHandle, CURLOPT_PROGRESSFUNCTION => function ($resource, $downloadSize, $downloaded, $uploadSize, $uploaded) use ($fileName, $fileUrl) { if (!empty($downloadSize)) { $percentage = ($downloaded / $downloadSize) * 100; file_put_contents($this->meta->tmpPath . '/download-status-' . $fileName, $percentage . '|' . $fileUrl, LOCK_EX); } }, ]); if (!($status = curl_exec($curlHandle))) { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to download %s: %s', $fileUrl, curl_error($curlHandle))); } curl_close($curlHandle); fclose($fileHandle); return $status ? true : false; } private function checksum(string $zipFile, string $md5File): bool { return trim(file_get_contents($md5File)) === md5_file($zipFile); } private function extractFile(string $zipFile): bool { $zipFileName = basename($zipFile); $this->setTaskStatus(self::WPCORE_INSTALL_SUCCESS, sprintf('Extracting %s', $zipFileName), ['wpcorestatusextract']); try { $zip = new \ZipArchive(); if ($zip->open($zipFile) && $zip->extractTo($this->meta->tmpPath)) { $this->useHandle->cache->put('wpcorestatusextract', '<!--{{taskCallbackDone}}-->'); } $zip->close(); } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to extract %s: %s', $zipFileName, $e->getMessage())); return false; } return true; } private function copyToRootPath(): bool { $this->setTaskStatus(self::WPCORE_INSTALL_SUCCESS, 'Copying WordPress files to the root path', ['wpcorestatuscopy']); $dstPath = $this->meta->rootPath; $srcPath = $this->meta->tmpPath . '/wordpress'; if (!is_dir($dstPath) || $dstPath === '/' || !is_dir($srcPath) || $srcPath === '/') { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, 'Failed to copy WordPress files to the root path'); return false; } try { $this->useHandle->cache->remove('wpcorestatuscopy'); $dirIterator = new \RecursiveIteratorIterator( new \RecursiveDirectoryIterator($srcPath, \RecursiveDirectoryIterator::SKIP_DOTS), \RecursiveIteratorIterator::SELF_FIRST ); foreach ($dirIterator as $item) { $filePath = $this->kernel->normalizePath($dstPath . '/' . $dirIterator->getSubPathname()); if ($item->isDir()) { $this->kernel->mkdir($filePath, __LINE__); } else { if ($filePath === $this->meta->rootPath . '/index.php') { $filePath = $dstPath . '/index-wp.php'; } $itemCopy = $this->kernel->normalizePath($item->getPathname()); $this->kernel->mkdir(dirname($filePath), __LINE__); if (!rename($itemCopy, $filePath)) { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to copy WordPress file: %s', $this->kernel->stripRootPath($filePath))); return false; } $this->useHandle->cache->put('wpcorestatuscopy', $this->kernel->stripRootPath($filePath)); } } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to copy WordPress files to the root path: %s', $e->getMessage())); return false; } $this->useHandle->cache->put('wpcorestatuscopy', '<!--{{taskCallbackDone}}-->'); $this->useHandle->file->removeDir($srcPath); return true; } public function getTaskResponse(): array { $data = $this->getTaskStatus(); if (empty($data) || !is_array($data)) { return [ 'success' => true, 'data' => [ 'status' => self::WPCORE_INSTALL_SUCCESS, 'content' => 'Checking.. please wait.', ] ]; } $lastData = !empty($data[0]) && count($data) > 0 ? $data[count($data) - 1] : $data; $content = ''; foreach ($data as $k => $arr) { $text = $arr['text']; if (!empty($arr['callback']) && is_array($arr['callback'])) { if ($arr['callback'][0] === 'downloadStatus') { $percent = $this->downloadStatus($arr['callback'][1]); if ($percent > 0 && $percent < 100) { $text .= '.. ' . $percent . "%\n"; } } elseif (substr($arr['callback'][0], 0, 12) === 'wpcorestatus') { $status = $this->useHandle->cache->get($arr['callback'][0]); if (!empty($status)) { $text .= $status === '<!--{{taskCallbackDone}}-->' ? ' was successful' : ': ' . $status; } } } if (!empty($text)) { $content .= $text . "\n"; } } return [ 'success' => true, 'data' => [ 'status' => $lastData['status'], 'content' => $content ] ]; } public function runTask(): bool { $this->kernel->maxExecutionTime(240); $version = !empty($this->meta->dataPost['wpcore-version']) ? $this->meta->dataPost['wpcore-version'] : 'latest'; $zipFileName = 'wordpress-' . $version . '.zip'; $zipUrl = $this->downloadUrl . '/' . $zipFileName; $md5Url = $zipUrl . '.md5'; $zipFile = $this->meta->tmpPath . '/' . $zipFileName; $md5File = $this->meta->tmpPath . '/' . $zipFileName . '.md5'; clearstatcache(); if (!file_exists($zipFile) && !$this->downloadFile($zipUrl, $zipFile)) { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to download %s', $zipUrl)); unlink($zipFile); return false; } if (!file_exists($md5File) && !$this->downloadFile($md5Url, $md5File)) { $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Failed to download %s', $md5Url)); unlink($md5File); return false; } $this->setTaskStatus(self::WPCORE_INSTALL_SUCCESS, sprintf('Validating checksum %s', $zipFileName), ['wpcorestatuschecksum']); if (!$this->checksum($zipFile, $md5File)) { unlink($zipFile); unlink($md5File); $this->setTaskStatus(self::WPCORE_INSTALL_FAILURE, sprintf('Invalid checksum for %s', $zipFileName)); return false; } $this->useHandle->cache->put('wpcorestatuschecksum', '<!--{{taskCallbackDone}}-->'); if (!$this->extractFile($zipFile)) { return false; } if (!$this->copyToRootPath()) { return false; } $this->setTaskStatus(self::WPCORE_INSTALL_DONE, 'Installing WordPress was successful'); return true; } private function randomNumber($min = null, $max = null): int { static $rndValue; $maxRandomNumber = 3000000000 === 2147483647 ? (float) '4294967295' : 4294967295; if ($min === null) { $min = 0; } if ($max === null) { $max = $maxRandomNumber; } $min = (int) $min; $max = (int) $max; static $useRandomIntFunctionality = true; if ($useRandomIntFunctionality) { try { $smax = max($min, $max); $smin = min($min, $max); $val = random_int($smin, $smax); if ($val !== false) { return abs((int) $val); } else { $useRandomIntFunctionality = false; } } catch (\Throwable $e) { $useRandomIntFunctionality = false; } } if ($rndValue === null || strlen($rndValue) < 8) { static $seed = ''; $rndValue = md5(uniqid(microtime() . mt_rand(), true) . $seed); $rndValue .= sha1($rndValue); $rndValue .= sha1($rndValue . $seed); $seed = md5($seed . $rndValue); } $value = substr($rndValue, 0, 8); $rndValue = substr($rndValue, 8); $value = abs(hexdec($value)); $value = $min + ( $max - $min + 1 ) * $value / ( $maxRandomNumber + 1 ); return abs((int) $value); } private function generateSaltKey(int $length = 12, bool $specialChars = true, bool $extraSpecialChars = false): string { $chars = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'; if ($specialChars) { $chars .= '!@#$%^&*()'; } if ($extraSpecialChars) { $chars .= '-_ []{}<>~`+=,.;:/?|'; } $saltkey = ''; for ($i = 0; $i < $length; $i++) { $saltkey .= substr($chars, $this->randomNumber(0, strlen($chars) - 1), 1); } return $saltkey; } private function parseDbHost(string $host) { $socket = null; $isIPv6 = false; $socketPos = strpos($host, ':/'); if ($socketPos !== false) { $socket = substr($host, $socketPos + 1); $host = substr($host, 0, $socketPos); } if (substr_count($host, ':') > 1) { $pattern = '#^(?:\[)?(?P<host>[0-9a-fA-F:]+)(?:\]:(?P<port>[\d]+))?#'; $isIPv6 = true; } else { $pattern = '#^(?P<host>[^:/]*)(?::(?P<port>[\d]+))?#'; } $matches = []; $result = preg_match($pattern, $host, $matches); if ($result !== 1) { return false; } $host = !empty($matches['host']) ? $matches['host'] : ''; $port = !empty($matches['port']) ? abs((int) $matches['port']) : null; return [$host, $port, $socket, $isIPv6]; } public function dbHandle(): Database { $dbData = $this->getDbConfig(); if (empty($dbData)) { throw new \BadMethodCallException('Failed to read database config'); } return new Database($this->kernel, $dbData); } public function isDbConnect(): array { clearstatcache(); if (!file_exists($this->dbConfigFile)) { $dbData = $this->parseWpConfigForDb(); $isSaveDbConfig = false; if (!empty($dbData) && is_array($dbData)) { $this->meta->dataPost['db-data'] = $dbData; $isSaveDbConfig = $this->saveDbConfig()['success'] === true; unset($this->meta->dataPost['db-data']); } if (!$isSaveDbConfig) { return ['success' => false, 'data' => 'Configuration not found']; } } try { $dbHandle = $this->dbHandle(); if ($dbHandle->connect() === false) { return ['success' => false, 'data' => $dbHandle->response]; } } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return ['success' => false, 'data' => sprintf('Error: %s', $e->getMessage())]; } $text = sprintf("Connection Success: %s\nServer Info: %s\n", $dbHandle->clientInfo(), $dbHandle->serverInfo()); $dbHandle->close(); return ['success' => true, 'data' => $text]; } public function isDbInstalled(): bool { $dbHandle = $this->dbHandle(); if ($dbHandle->connect() === false) { return false; } $dbPrefix = $dbHandle->dbPrefix; $result = $dbHandle->query('SHOW TABLES LIKE "' . $dbPrefix . '%"'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return false; } $wpTables = [ $dbPrefix . 'commentmeta' => 1, $dbPrefix . 'comments' => 1, $dbPrefix . 'links' => 1, $dbPrefix . 'options' => 1, $dbPrefix . 'postmeta' => 1, $dbPrefix . 'posts' => 1, $dbPrefix . 'term_relationships' => 1, $dbPrefix . 'term_taxonomy' => 1, $dbPrefix . 'termmeta' => 1, $dbPrefix . 'terms' => 1, $dbPrefix . 'usermeta' => 1, $dbPrefix . 'users' => 1, ]; $tableTotal = (int)$result->num_rows; $tableFound = 0; while ($row = $result->fetch_row()) { if (isset($wpTables[$row[0]])) { $tableFound++; } } if ($tableFound !== count($wpTables)) { return false; } $result = $dbHandle->query('SELECT ID from `' . $dbPrefix . 'users` LIMIT 1'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return false; } $result = $dbHandle->query('SELECT option_id from `' . $dbPrefix . 'options` LIMIT 1'); if (! ($result instanceof \mysqli_result) || (int)$result->num_rows === 0) { return false; } return true; } public function getDbConfig() { $this->maybeCreateDbConfig(); try { $dbData = include $this->dbConfigFile; } catch (\Throwable $e) { $this->kernel->log($e, __METHOD__); return false; } return $dbData; } private function maybeCreateDbConfig(): bool { clearstatcache(); if (!file_exists($this->wpConfigFile) || (file_exists($this->dbConfigFile) && filemtime($this->dbConfigFile) > filemtime($this->wpConfigFile))) { return false; } $config = $this->getConfig(true); if (empty($config) || !is_array($config)) { return false; } $config = (object)$config; $this->meta->dataPost['db-data'] = [ 'dbname' => $config->dbname, 'dbuser' => $config->dbuser, 'dbpass' => $config->dbpass, 'dbhost' => $config->dbhost, 'dbport' => $config->dbport, 'dbssl' => $config->dbssl, 'dbprefix' => $config->dbprefix, 'dbcharset' => $config->dbcharset, 'dbcollate' => $config->dbcollate, ]; if ($this->saveDbConfig()['success'] === false) { return false; } return true; } public function saveDbConfig(): array { if (empty($this->meta->dataPost['db-data'])) { return ['success' => false, 'data' => 'Please enter database setting!']; } $dbData = []; foreach ($this->meta->dataPost['db-data'] as $key => $value) { if ($key === 'dbpass') { $value = htmlspecialchars_decode($value); } $dbData[$key] = $value; } $errorData = []; foreach (['dbhost','dbname', 'dbuser', 'dbpass', 'dbprefix', 'dbport', 'dbssl', 'dbipv6', 'dbcharset', 'dbcollate'] as $key) { if (empty($dbData[$key])) { switch ($key) { case 'dbhost': $dbData[$key] = 'localhost'; break; case 'dbname': $errorData[$key] = 'Please enter Database Name!'; break; case 'dbuser': $errorData[$key] = 'Please enter Database User!'; break; case 'dbpass': $errorData[$key] = 'Please enter Database Password!'; break; case 'dbprefix': $dbData[$key] = 'wp_'; break; case 'dbssl': $dbData[$key] = 0; break; case 'dbipv6': $dbData[$key] = 0; break; case 'dbport': $dbData[$key] = null; break; case 'dbcharset': $dbData[$key] = 'utf8'; break; case 'dbcollate': $dbData[$key] = ''; break; } } } if (!empty($errorData)) { return ['success' => false, 'data' => implode("\n", $errorData)]; } $this->useHandle->file->opcacheFlush($this->dbConfigFile); $hostData = $this->parseDbHost($dbData['dbhost']); if ($hostData) { list( $host, $port, $socket, $isIPv6 ) = $hostData; $dbData['dbipv6'] = $isIPv6 ? 1 : 0; } $code = '<?php return ' . var_export($dbData, true) . ';'; if (!file_put_contents($this->dbConfigFile, $code, LOCK_EX)) { return ['success' => false, 'data' => 'Failed to save database setting']; } return $this->isDbConnect(); } public function resetDbConfig(): bool { if ($this->kernel->unlink($this->dbConfigFile)) { if ($this->isWpIndex()) { rename($this->meta->rootPath . '/index.php', $this->meta->rootPath . '/index-wp.php'); } return true; } return false; } private function writeWpConfig(): array { if (($dbData = $this->getDbConfig()) === false) { return ['success' => false, 'data' => 'Failed to get Database configuration']; } $dbData = (object)$dbData; $dbHost = $dbData->dbhost . ( !empty($dbData->dbport) ? ':' . $dbData->dbport : ''); $dbPass = addslashes($dbData->dbpass); $code = '<?php ' . PHP_EOL; $code .= '// Generated by WP Staging Restore: ' . date('M j, Y H:i:s') . ' UTC' . PHP_EOL; $code .= "define('WP_CACHE', false);" . PHP_EOL; $code .= "define('WP_REDIS_DISABLED', true);" . PHP_EOL; foreach ( [ 'DB_NAME' => $dbData->dbname, 'DB_USER' => $dbData->dbuser, 'DB_PASSWORD' => $dbPass , 'DB_HOST' => $dbHost, 'DB_CHARSET' => 'utf8', 'DB_COLLATE' => '', 'AUTH_KEY' => $this->generateSaltKey(64, true, true), 'SECURE_AUTH_KEY' => $this->generateSaltKey(64, true, true), 'LOGGED_IN_KEY' => $this->generateSaltKey(64, true, true), 'NONCE_KEY' => $this->generateSaltKey(64, true, true), 'AUTH_SALT' => $this->generateSaltKey(64, true, true), 'SECURE_AUTH_SALT' => $this->generateSaltKey(64, true, true), 'LOGGED_IN_SALT' => $this->generateSaltKey(64, true, true), 'NONCE_SALT' => $this->generateSaltKey(64, true, true) ] as $name => $value ) { $code .= "define('" . $name . "', '" . $value . "');" . PHP_EOL; } if ($dbData->dbssl) { $code .= "define('MYSQL_CLIENT_FLAGS', MYSQLI_CLIENT_SSL | MYSQLI_CLIENT_SSL_DONT_VERIFY_SERVER_CERT);" . PHP_EOL; } $code .= "\$table_prefix = '" . $dbData->dbprefix . "';" . PHP_EOL; $code .= "define('WP_DEBUG', false);" . PHP_EOL; $code .= "if (!defined('WP_DISABLE_FATAL_ERROR_HANDLER')) { define( 'WP_DISABLE_FATAL_ERROR_HANDLER', true ); }" . PHP_EOL; $code .= "if (!defined('WP_HTTP_BLOCK_EXTERNAL')) { define( 'WP_HTTP_BLOCK_EXTERNAL', false ); }" . PHP_EOL; $code .= "if (!defined('WP_ACCESSIBLE_HOSTS')) { define( 'WP_ACCESSIBLE_HOSTS', 'analytics.local, analytics.wp-staging.com' ); }" . PHP_EOL; $code .= "if (!defined('ABSPATH')) { define( 'ABSPATH', __DIR__ . '/' ); }" . PHP_EOL; $code .= "require_once ABSPATH . 'wp-settings.php';" . PHP_EOL; if (!file_put_contents($this->wpConfigFile, $code, LOCK_EX)) { return ['success' => false, 'data' => 'Failed to create wp-config.php']; } $this->kernel->chmod($this->wpConfigFile, false, __LINE__); return ['success' => true, 'data' => 'Creating wp-config.php succesful']; } public function installSite(): array { if (empty($this->meta->dataPost['site-data'])) { return ['success' => false, 'data' => 'Please enter Site setting!']; } $siteData = []; foreach ($this->meta->dataPost['site-data'] as $key => $value) { if ($key === 'sitepass') { $value = htmlspecialchars_decode($value); } $siteData[$key] = $value; } $errorData = []; foreach (['sitetitle','siteuser', 'siteemail', 'sitepass'] as $key) { if (empty($siteData[$key])) { switch ($key) { case 'sitetitle': $errorData[$key] = 'Please enter Site Title!'; break; case 'siteuser': $errorData[$key] = 'Please enter Admin User!'; break; case 'siteemail': $errorData[$key] = 'Please enter Admin Email!'; break; case 'sitepass': $errorData[$key] = 'Please enter Admin Password!'; break; } } else { switch ($key) { case 'siteemail': if (!filter_var($siteData[$key], FILTER_VALIDATE_EMAIL)) { $errorData[$key] = sprintf('Invalid email address %s!', $siteData[$key]); } break; } } } if (!empty($errorData)) { return ['success' => false, 'data' => implode("\n", $errorData)]; } $isWriteWpconfig = $this->writeWpConfig(); if ($isWriteWpconfig['success'] === false) { return $isWriteWpconfig; } $isUserExists = false; try { global $wpdb; define('WP_INSTALLING', true); require_once __DIR__ . '/wp-load.php'; require_once ABSPATH . 'wp-admin/includes/upgrade.php'; require_once ABSPATH . WPINC . '/class-wpdb.php'; $appFile = $this->meta->appFile; $siteUrl = str_replace('/' . $appFile, '/', wp_guess_url()); define('WP_SITEURL', $siteUrl); $wpdb->suppress_errors(true); $isUserExists = username_exists($siteData['siteuser']); $wpdb->suppress_errors(false); ignore_user_abort(true); wp_install($siteData['sitetitle'], $siteData['siteuser'], $siteData['siteemail'], false, null, $siteData['sitepass']); $isInstallComplete = $this->installComplete(); if ($isInstallComplete['success'] === false) { return $isInstallComplete; } } catch (\Throwable $e) { return ['success' => false, 'data' => $e->getMessage(), 'saveLog' => $e, 'saveLogId' => __METHOD__]; } $text = 'WordPress installation was successful'; if ($isUserExists !== false) { $text .= "\nUser already exists. Password inherited."; return ['success' => true, 'data' => $text, 'isprompt' => 1, 'saveLog' => str_replace("\n", ". ", $text)]; } return ['success' => true, 'data' => $text, 'saveLog' => true, 'saveLogId' => __METHOD__]; } public function installComplete(): array { $isWriteWpconfig = $this->writeWpConfig(); if ($isWriteWpconfig['success'] === false) { return $isWriteWpconfig; } $rootPath = $this->meta->rootPath; $this->useHandle->file->opcacheFlush($rootPath . '/index.php'); if (file_exists($rootPath . '/index-wp.php') && !rename($rootPath . '/index-wp.php', $rootPath . '/index.php')) { return ['success' => false, 'data' => 'Failed to complete WordPress installation', 'saveLog' => true, 'saveLogId' => __METHOD__]; } if (!$this->isWpIndex()) { return ['success' => false, 'data' => 'Something went wrong, missing index.php']; } return ['success' => true, 'data' => 'WordPress installation was successful', 'saveLog' => true, 'saveLogId' => __METHOD__]; } private function locateWpConfigFile() { $upperPath = dirname($this->meta->rootPath); if (file_exists($upperPath . '/wp-config.php') && !file_exists($upperPath . '/wp-settings.php')) { return $upperPath . '/wp-config.php'; } return $this->meta->rootPath . '/wp-config.php'; } private function parseWpConfigForDb() { if (!file_exists($this->wpConfigFile)) { return false; } $content = file_get_contents($this->wpConfigFile, false, null, 0, 8 * 1024); if (empty($content) || strpos($content, 'DB_') === false) { return false; } $pattern = 'define\(\s?(\'|")(DB_(HOST|NAME|USER|PASSWORD))(\'|")\s?,\s?(\'|")(.*?)(\'|")\s?\)\;'; $pattern .= '|define\(\s?(\'|")(MYSQL_CLIENT_FLAGS)(\'|")\s?,\s?(.*?)\s?\)\;'; $pattern .= '|\$(table_prefix)\s?=\s?(\'|")(.*?)(\'|")\;'; if (!preg_match_all('@' . $pattern . '@m', $content, $matches, PREG_SET_ORDER)) { return false; } $dbData = [ 'dbhost' => '', 'dbname' => '', 'dbuser' => '', 'dbpass' => '', 'dbprefix' => 'wp_', 'dbssl' => 0, ]; foreach ($matches as $match) { switch ($match[2]) { case 'DB_HOST': list( $host, $port, $socket, $isIPv6 ) = $this->parseDbHost($match[6]); $dbData['dbhost'] = $host; $dbData['dbport'] = $port; break; case 'DB_NAME': $dbData['dbname'] = $match[6]; break; case 'DB_USER': $dbData['dbuser'] = $match[6]; break; case 'DB_PASSWORD': $dbData['dbpass'] = $match[6]; break; } if (isset($match[9]) && isset($match[11]) && $match[9] === 'MYSQL_CLIENT_FLAGS' && strpos($match[11], 'MYSQLI_CLIENT_SSL') !== false) { $dbData['dbssl'] = 1; } if (isset($match[12]) && !empty($match[14]) && $match[12] === 'table_prefix') { $dbData['dbprefix'] = $match[14]; } } return $dbData; } public function getWpCoreFiles(): array { return [ "index.php", "license.txt", "readme.html", "wp-activate.php", "wp-admin", "wp-blog-header.php", "wp-comments-post.php", "wp-config.php", "wp-config-sample.php", "wp-content", "wp-cron.php", "wp-includes", "wp-links-opml.php", "wp-load.php", "wp-login.php", "wp-mail.php", "wp-settings.php", "wp-signup.php", "wp-trackback.php", "xmlrpc.php", ]; } }
}
namespace {
    if (!getenv('wpstg-restorer-as-library')) {
        (new \WPStagingRestorer())->run();
    }
}
